@@ -18,8 +18,10 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
+#include <stdio.h>
 
 #include <iostream>
+#include <list>
 #include <string>
 
 #include "command.h"
@@ -28,8 +30,10 @@ Boston, MA 02111-1307, USA.  */
 
 #include "../src/breakpoints.h"
 #include "../src/expr.h"
+#include "../src/operator.h"
 #include "../src/gpsim_object.h"
 #include "../src/ui.h"
+#include "../src/value.h"
 
 cmd_break c_break;
 
@@ -41,6 +45,7 @@ cmd_break c_break;
 #define STK_OVERFLOW  7
 #define STK_UNDERFLOW 8
 #define WDT           9
+#define EASRT         10
 
 static cmd_options cmd_break_options[] = {
   {"c",   CYCLE,        OPT_TT_BITFLAG},
@@ -51,7 +56,8 @@ static cmd_options cmd_break_options[] = {
   {"so",  STK_OVERFLOW, OPT_TT_BITFLAG},
   {"su",  STK_UNDERFLOW, OPT_TT_BITFLAG},
   {"wdt", WDT,          OPT_TT_BITFLAG},
-  {0, 0, 0}
+  {"asrt",EASRT,        OPT_TT_BITFLAG},
+  {nullptr, 0, 0}
 };
 
 
@@ -161,6 +167,8 @@ unsigned int cmd_break::set_break(cmd_options *co, ExprList_t *pEL, bool bLog)
   Expression *pSecond  = (ei != pEL->end()) ? *ei++ : nullptr;
   Expression *pThird = (ei != pEL->end()) ? *ei : nullptr;
 
+  int cmdopt = co->value;
+
   if (verbose) {
     std::cout << "setting breakpoint:\n";
 
@@ -206,17 +214,26 @@ unsigned int cmd_break::set_break(cmd_options *co, ExprList_t *pEL, bool bLog)
     }
   }
 
+  if (cmdopt == EASRT) {
+      if (pSecond) {
+          // Assert uses inverse logic; the action must run when the condition
+          // is false. To achieve that, the condition must be negated
+          pSecond = new OpLogicalNot(pSecond);
+      }
+      cmdopt = EXECUTION;
+  }
+
   if (!pFirst) {
-    return set_break(co->value, bLog);
+    return set_break(cmdopt, bLog);
   }
 
   // See if the expression supports break points. If it does, the break points
   // will get set and the expressions deleted.
-  int bpn = pFirst ? pFirst->set_break(MapBreakActions(co->value),
+  int bpn = pFirst ? pFirst->set_break(MapBreakActions(cmdopt),
                                        (bLog ? gpsimObject::eActionLog : gpsimObject::eActionHalt),
                                        pSecond) : -1;
 
-  if (bpn == -1 && co->value != CYCLE)
+  if (bpn == -1 && cmdopt != CYCLE)
     GetUserInterface().DisplayMessage("break cannot be set on '%s'\n",
                                       pFirst->toString().c_str());
 
@@ -224,7 +241,7 @@ unsigned int cmd_break::set_break(cmd_options *co, ExprList_t *pEL, bool bLog)
     // We failed to set a break point from the first expression.
     // It may be that we have a type of break point that is not supported
     // by the expression code.
-    if (co->value == CYCLE) {
+    if (cmdopt == CYCLE) {
       LiteralInteger *pLitInt = dynamic_cast<LiteralInteger*>(pFirst);
       Integer *pInt = pLitInt ? dynamic_cast<Integer*>(pLitInt->evaluate()) : nullptr;
       guint64 ui64Val = pInt ? (guint64)pInt->getVal() : 0;
