@@ -24,9 +24,8 @@ Boston, MA 02111-1307, USA.  */
 #include <glib.h>
 #include "command.h"
 
-#include "../src/value.h"
+#include "../src/expr.h"
 
-class Expression;
 class gpsimObject;
 struct cmd_options;
 
