@@ -18,18 +18,22 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_CLEAR_H__
-#define __CMD_CLEAR_H__
+#ifndef CLI_CMD_CLEAR_H_
+#define CLI_CMD_CLEAR_H_
+
+#include "command.h"
 
 class Expression;
 
 class cmd_clear : public command
 {
 public:
-  cmd_clear(void);
+  cmd_clear();
+
   void clear(Expression *);
 };
 
 extern cmd_clear clear;
+
 #endif
 
