@@ -18,34 +18,34 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_DUMP_H__
-#define __CMD_DUMP_H__
+#ifndef CLI_CMD_DUMP_H_
+#define CLI_CMD_DUMP_H_
 
+#include "command.h"
 #include "../src/hexutils.h"
+class gpsimObject;
+class Register;
 
-class cmd_dump : public command, IntelHexProgramFileType
-{
+class cmd_dump : public command, IntelHexProgramFileType {
 public:
-
   enum {
     DUMP_EEPROM = 1,
     DUMP_RAM,
     DUMP_SFRS
   };
 
-
-  cmd_dump(void);
+  cmd_dump();
   //  void dump(void);
 
   void dump(int bit_flag);
   int dump(int bit_flag, gpsimObject* module, const char * filename);
 
 private:
-  void dump_sfrs(void);
+  void dump_sfrs();
   void dump_regs(Register **fr, unsigned int mem_size, int reg_size, int mem_type);
-
 };
 
 extern cmd_dump dump;
+
 #endif
 
