@@ -19,12 +19,11 @@ the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
 
-#include <iostream>
-#include <iomanip>
 #include <string>
 
 #include "command.h"
 #include "cmd_echo.h"
+#include "misc.h"
 
 // See cmd_echo.h for why this file is basically a skeleton
 
@@ -32,16 +31,16 @@ cmd_echo echo;
 
 static cmd_options cmd_echo_options[] =
 {
-  {0,0,0}
+  {nullptr, 0, 0}
 };
 
 
 cmd_echo::cmd_echo()
-  : command("echo",0)
+  : command("echo", nullptr)
 { 
-  brief_doc = string("echo \"text\"");
+  brief_doc = "echo \"text\"";
 
-  long_doc = string ("echo \"text\" - useful for command files\n");
+  long_doc = "echo \"text\" - useful for command files\n";
 
   token_value = 0;
   op = cmd_echo_options; 
