@@ -18,24 +18,28 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_ECHO_H__
-#define __CMD_ECHO_H__
+#ifndef CLI_CMD_ECHO_H_
+#define CLI_CMD_ECHO_H_
+
+#include "command.h"
+
+#include <iostream>
 
 class cmd_echo : public command
 {
 public:
-
-  cmd_echo(void);
+  cmd_echo();
 
   // The echo command is handled by the lexical analyzer (scan.l)
   // and not by this class. Note that this is different than the
   // other commands. The only reason the 'echo' class exists is to
   // provide a consistant way for displaying help text.
 
-  void echo(void) { cout << "BUG: echo command does not execute!\n";};
+  void echo() { std::cout << "BUG: echo command does not execute!\n"; }
 
 };
 
 extern cmd_echo echo;
+
 #endif
 
