@@ -20,33 +20,31 @@ Boston, MA 02111-1307, USA.  */
 
 
 #include <iostream>
-#include <iomanip>
 #include <string>
-#include <vector>
 
 #include "command.h"
 #include "cmd_frequency.h"
+#include "misc.h"
 
-#include "../src/pic-processor.h"
+#include "../src/processor.h"
 
 static cmd_options cmd_frequency_options[] =
 {
-  {0,0,0}
+  {nullptr, 0, 0}
 };
 
-cmd_frequency::cmd_frequency(void)
+cmd_frequency::cmd_frequency()
   : command("frequency", "freq")
-{ 
+{
+  brief_doc = "Set the clock frequency";
 
-  brief_doc = string("Set the clock frequency");
-
-  long_doc = string ("\nfrequency [value]\n"
+  long_doc = "\nfrequency [value]\n"
     "\tThis command sets the clock frequency. By default gpsim uses 4 MHz\n"
     "\tas clock. The clock frequency is used to compute time in seconds.\n"
     "\tUse this command to adjust this value.\n"
     "\tIf no value is provided this command prints the current clock.\n"
     "\tNote that PICs have an instruction clock that's a forth of the\n"
-    "\texternal clock. This value is the external clock.\n");
+    "\texternal clock. This value is the external clock.\n";
 
   op = cmd_frequency_options;
 }
@@ -54,25 +52,23 @@ cmd_frequency::cmd_frequency(void)
 
 void cmd_frequency::set(Expression *expr)
 {
-
   Processor *pCpu = GetActiveCPU(true);
-  if(!pCpu)
+  if (!pCpu)
     return;
 
-  double frequency = evaluate(expr);
+  double freq = evaluate(expr);
 
-  if(frequency <= 0.0) 
-    cout << "Error: the clock must be a positive value.\n";
+  if (freq <= 0.0)
+    std::cout << "Error: the clock must be a positive value.\n";
   else
-    pCpu->set_frequency(frequency);
-
+    pCpu->set_frequency(freq);
 }
 
 void cmd_frequency::print()
 {
   Processor *pCpu = GetActiveCPU(true);
-  if(pCpu)
-    cout << "Clock frequency: " << pCpu->get_frequency()/1e6 << " MHz.\n";
+  if (pCpu)
+    std::cout << "Clock frequency: " << pCpu->get_frequency() / 1e6 << " MHz.\n";
 }
 
 cmd_frequency frequency;
