@@ -18,20 +18,23 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_FREQUENCY_H__
-#define __CMD_FREQUENCY_H__
+#ifndef CLI_CMD_FREQUENCY_H_
+#define CLI_CMD_FREQUENCY_H_
+
+#include "command.h"
 
 class Expression;
 
 class cmd_frequency : public command
 {
 public:
+  cmd_frequency();
 
-  cmd_frequency(void);
   void set(Expression *);
   void print();
 };
 
 extern cmd_frequency frequency;
+
 #endif
 
