@@ -18,23 +18,23 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_HELP_H__
-#define __CMD_HELP_H__
+#ifndef CLI_CMD_HELP_H_
+#define CLI_CMD_HELP_H_
+
+#include "command.h"
 
 class gpsimObject;
 
 class cmd_help : public command
 {
 public:
-
   cmd_help();
 
   void help();
   void help(const char *cmd);
   void help(gpsimObject *);
 
-  virtual int is_repeatable() { return 1; };
-
+  int is_repeatable() override { return 1; }
 };
 
 extern cmd_help help;
