@@ -18,13 +18,14 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
+#include <stdio.h>
 
 #include <iostream>
-#include <iomanip>
 #include <string>
 
 #include "command.h"
 #include "cmd_icd.h"
+#include "misc.h"
 #include "../src/icd.h"
 
 cmd_icd c_icd;
@@ -34,54 +35,50 @@ cmd_icd c_icd;
 static cmd_options cmd_icd_options[] =
 {
   {"open",	ICD_OPEN_CMD,	OPT_TT_STRING},
-  {0,0,0}
+  {nullptr, 0, 0}
 };
 
 cmd_icd::cmd_icd()
-  : command("icd",0)
+  : command("icd", nullptr)
 { 
-  brief_doc = string("ICD command.");
+  brief_doc = "ICD command.";
 
-  long_doc = string ("\nicd [open <port>]\n\
+  long_doc = "\nicd [open <port>]\n\
 \tThe open command is used to enable ICD mode and specify the serial\n\
 \tport where the ICD is. (e.g. \"icd open /dev/ttyS0\").\n\
 \tWithout options (and after the icd is enabled), it will print some\n\
-\tinformation about the ICD.\n\
-");
+\tinformation about the ICD.\n";
 
   op = cmd_icd_options; 
 }
 
-#include <stdio.h>
-
 void cmd_icd::icd()
 {
-    if(icd_detected())
-    {
-        printf("ICD version \"%s\" was found.\n",icd_version());
-        printf("Target controller is %s.\n", icd_target());
-        printf("Vdd: %.1f\t",icd_vdd());
-        printf("Vpp: %.1f\n",icd_vpp());
-	if(icd_has_debug_module())
-		puts("Debug module is present");
-	else
-		puts("Debug moudle is NOT present.");
-    }
+  if (icd_detected()) {
+    printf("ICD version \"%s\" was found.\n", icd_version());
+    printf("Target controller is %s.\n", icd_target());
+    printf("Vdd: %.1f\t", icd_vdd());
+    printf("Vpp: %.1f\n", icd_vpp());
+
+    if (icd_has_debug_module())
+      puts("Debug module is present");
     else
-    {
-        printf("ICD has not been opened (use the \"icd open\" command)\n");
-    }
+      puts("Debug moudle is NOT present.");
+
+  } else {
+    printf("ICD has not been opened (use the \"icd open\" command)\n");
+  }
 }
 
 void cmd_icd::icd(cmd_options_str *cos)
 {
-  switch(cos->co->value) {
+  switch (cos->co->value) {
   case ICD_OPEN_CMD:
-	cout << "ICD open " << cos->str << endl;
-	icd_connect(cos->str);
-	break;
-  default:
-    cout << " Invalid set option\n";
-  }
+    std::cout << "ICD open " << cos->str << '\n';
+    icd_connect(cos->str.c_str());
+    break;
 
+  default:
+    std::cout << " Invalid set option\n";
+  }
 }
