@@ -18,19 +18,24 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_ICD_H__
-#define __CMD_ICD_H__
+#ifndef CLI_CMD_ICD_H_
+#define CLI_CMD_ICD_H_
+
+#include "command.h"
+
+class cmd_options_str;
 
 class cmd_icd : public command
 {
 public:
+  cmd_icd();
 
-  cmd_icd(void);
-  void icd(void);
+  void icd();
   void icd(cmd_options_str *cos);
-  virtual int is_repeatable(void) { return 0; };
+  int is_repeatable() override { return 0; }
 };
 
 extern cmd_icd c_icd;
+
 #endif
 
