@@ -18,22 +18,26 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_LIST_H__
-#define __CMD_LIST_H__
+#ifndef CLI_CMD_LIST_H_
+#define CLI_CMD_LIST_H_
+
+#include "command.h"
+
+struct cmd_options;
 
 class cmd_list : public command
 {
 public:
   int file_id,  starting_line,  ending_line;
 
-  cmd_list(void);
-  void list(void);
+  cmd_list();
 
+  void list();
   void list(cmd_options *opt);
-  virtual int is_repeatable(void) { return 1; };
-
+  int is_repeatable() override { return 1; }
 };
 
 extern cmd_list c_list;
+
 #endif
 
