@@ -18,22 +18,26 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_LOAD_H__
-#define __CMD_LOAD_H__
+#ifndef CLI_CMD_LOAD_H_
+#define CLI_CMD_LOAD_H_
 
 #include "../src/hexutils.h"
+#include "command.h"
+
+class gpsimObject;
 
 class cmd_load : public command, IntelHexProgramFileType
 {
 public:
-
   cmd_load();
-  int load(int bit_flag,const char *filename);
+
+  int load(int bit_flag, const char *filename);
   int load(int bit_flag, gpsimObject* module, const char *filename);
-  int load(gpsimObject *file, gpsimObject * pProcessorType = NULL);
+  int load(gpsimObject *file, gpsimObject * pProcessorType = nullptr);
   int load(const char *file, const char *pProcessorType);
 };
 
 extern cmd_load c_load;
+
 #endif
 
