@@ -18,22 +18,25 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_LOG_H__
-#define __CMD_LOG_H__
+#ifndef CLI_CMD_LOG_H_
+#define CLI_CMD_LOG_H_
 
-#include <glib.h>
+#include "../src/expr.h"
 #include "command.h"
 
+struct cmd_options;
+
 class cmd_log : public command
 {
 public:
-
   cmd_log();
+
   void log();
   void log(cmd_options *opt);
   void log(cmd_options *opt, ExprList_t *el);
 };
 
 extern cmd_log c_log;
+
 #endif
 
