@@ -57,10 +57,7 @@ public:
   void add_body(const char *line);
   void end_define(const char *opt_name = nullptr);
 
-  virtual int is_repeatable()
-  {
-    return 1;
-  }
+  int is_repeatable() override { return 1; }
 };
 
 extern cmd_macro c_macro;
