@@ -18,23 +18,23 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_NODE_H__
-#define __CMD_NODE_H__
-#include "misc.h"
+#ifndef CLI_CMD_NODE_H_
+#define CLI_CMD_NODE_H_
+
+#include "command.h"
 
 #include <list>
-using namespace std;
+#include <string>
 
 class cmd_node : public command
 {
 public:
+  cmd_node();
 
-  cmd_node(void);
-  void list_nodes(void);
-  void add_nodes(list <string> *);
-
-
+  void list_nodes();
+  void add_nodes(std::list<std::string> *);
 };
 
 extern cmd_node c_node;
+
 #endif
