@@ -18,24 +18,22 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_PROCESSOR_H__
-#define __CMD_PROCESSOR_H__
+#ifndef CLI_CMD_PROCESSOR_H_
+#define CLI_CMD_PROCESSOR_H_
+
+#include "command.h"
 
 class cmd_processor : public command
 {
 public:
+  cmd_processor();
 
-  cmd_processor(void);
-
-  void processor(void);
-
+  void processor();
   void processor(int bit_flag);
-
   void processor(const char *proc, const char *name);
-
-
 };
 
 extern cmd_processor c_processor;
+
 #endif
 
