@@ -19,36 +19,34 @@ the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
 
-#include <iostream>
-#include <iomanip>
 #include <string>
 
 #include "command.h"
 #include "cmd_reset.h"
-
-#include "../src/pic-processor.h"
+#include "misc.h"
+#include "../src/gpsim_classes.h"
+#include "../src/processor.h"
 
 cmd_reset reset;
 
 static cmd_options cmd_reset_options[] =
 {
-  {0,0,0}
+  {nullptr, 0, 0}
 };
 
 
 cmd_reset::cmd_reset()
-  : command("reset",0)
+  : command("reset", nullptr)
 { 
-  brief_doc = string("Reset all or parts of the simulation");
+  brief_doc = "Reset all or parts of the simulation";
 
-  long_doc = string ("Reset all or parts of the simulation\n");
+  long_doc = "Reset all or parts of the simulation\n";
 
   op = cmd_reset_options; 
 }
 
-void cmd_reset::reset(void)
+void cmd_reset::reset()
 {
-  if(GetActiveCPU())
+  if (GetActiveCPU())
     GetActiveCPU()->reset(POR_RESET);
-
 }
