@@ -18,47 +18,44 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-
-#include <iostream>
-#include <iomanip>
 #include <string>
 
 #include "command.h"
 #include "cmd_run.h"
+#include "misc.h"
 
-#include "../src/pic-processor.h"
+#include "../src/gpsim_interface.h"
+#include "../src/symbol.h"
+#include "../src/value.h"
 
-extern void redisplay_prompt(void);  // in input.cc
+extern void redisplay_prompt();  // in input.cc
 
 cmd_run c_run;
 
 static cmd_options cmd_run_options[] =
 {
-  {0,0,0}
+  {nullptr, 0, 0}
 };
 
 
 cmd_run::cmd_run()
-  : command("run",0)
+  : command("run", nullptr)
 { 
-  brief_doc = string("Initiate the simulation");
+  brief_doc = "Initiate the simulation";
 
-  long_doc = string ("run\n\
+  long_doc = "run\n\
 \tStart simulating and don't stop until a break is encountered.\n\
-\tUse CTRL->C to halt the simulation execution.\n\
-\n");
+\tUse CTRL->C to halt the simulation execution.\n\n";
 
   op = cmd_run_options; 
 }
 
 void cmd_run::run()
 {
-
   Integer &verbosity = *globalSymbolTable().findInteger("sim.verbosity");
 
   get_interface().start_simulation();
 
-  if((int)verbosity)
+  if ((int)verbosity)
     redisplay_prompt();
-
 }
