@@ -18,20 +18,22 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_RUN_H__
-#define __CMD_RUN_H__
+#ifndef CLI_CMD_RUN_H_
+#define CLI_CMD_RUN_H_
+
+#include "command.h"
 
 class cmd_run : public command
 {
 public:
-
   cmd_run();
-  void run();
-  virtual int is_repeatable() { return 1; };
 
+  void run();
+  int is_repeatable() override { return 1; }
 };
 
 extern cmd_run c_run;
 extern bool GbDoRun;
+
 #endif
 
