@@ -18,17 +18,19 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
+#include <glib.h>
 
 #include <iostream>
-#include <iomanip>
 #include <string>
-#include <stdio.h>
 
 #include "command.h"
 #include "cmd_set.h"
-#include "input.h"
+#include "misc.h"
 
-#include "../src/pic-processor.h"
+#include "../src/errors.h"
+#include "../src/expr.h"
+#include "../src/ui.h"
+#include "../src/value.h"
 
 static int radix = 0;   // FIXME
 
@@ -45,54 +47,52 @@ static cmd_options cmd_set_options[] =
   {"radix",      SET_RADIX,      OPT_TT_NUMERIC},
   {"v",          SET_VERBOSE,    OPT_TT_BITFLAG},
   {"verbose",    SET_VERBOSE,    OPT_TT_BITFLAG},
-  {0,0,0}
+  {nullptr, 0, 0}
 };
 
 
 cmd_set::cmd_set()
-  : command("set",0)
+  : command("set", nullptr)
 {
-  brief_doc = string("display and control gpsim behavior flags");
+  brief_doc = "display and control gpsim behavior flags";
 
-  long_doc = string ("set\n"
+  long_doc = "set\n"
     "\twith no options, set will display the state of all of gpsim's\n"
     "\tbehavior flags. Use this to determine the flags that may be\n"
     "\tmodified.\n"
-    "\n");
+    "\n";
 
   op = cmd_set_options;
 }
 
 
-
-void cmd_set::set(void)
+void cmd_set::set()
 {
-
-  cout << "r | radix = " << radix << " (not fully functional)\n";
-  cout << "v | verbose =  " << (unsigned int)verbose << '\n';
+  std::cout << "r | radix = " << radix << " (not fully functional)\n";
+  std::cout << "v | verbose =  " << (unsigned int)verbose << '\n';
   //  cout << "gui_update = " << gi.update_rate << '\n';
 }
 
 void cmd_set::set(int bit_flag, Expression *expr)
 {
-  int number=1;
+  int number = 1;
 
-  if(expr) {
+  if (expr) {
     try
       {
-	Value *v = expr->evaluate();
-	if(v) {
-	  gint64 i;
-	  v->get(i);
-	  number = (int)i;
-	  delete v;
-	}
-	delete expr;
+        Value *v = expr->evaluate();
+        if (v) {
+          gint64 i;
+          v->get(i);
+          number = (int)i;
+          delete v;
+        }
+        delete expr;
       }
-    catch (Error &err)
+    catch (const Error &err)
       {
-	  std::cout << "ERROR:" << err.what() << '\n';
-	return;
+        std::cout << "ERROR:" << err.what() << '\n';
+        return;
       }
   }
 
@@ -100,8 +100,9 @@ void cmd_set::set(int bit_flag, Expression *expr)
   case SET_VERBOSE:
     GetUserInterface().SetVerbosity(number);
     break;
+
   default:
-    cout << " Invalid set option\n";
+    std::cout << " Invalid set option\n";
   }
 }
 
