@@ -18,20 +18,23 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_SET_H__
-#define __CMD_SET_H__
+#ifndef CLI_CMD_SET_H_
+#define CLI_CMD_SET_H_
+
+#include "command.h"
 
 class Expression;
 
 class cmd_set : public command
 {
 public:
-  cmd_set(void);
-  void set(void);
+  cmd_set();
 
-  void set(int bit_flag,Expression *);
+  void set();
+  void set(int bit_flag, Expression *);
 };
 
 extern cmd_set c_set;
+
 #endif
 
