@@ -18,24 +18,26 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_STEP_H__
-#define __CMD_STEP_H__
+#ifndef CLI_CMD_STEP_H_
+#define CLI_CMD_STEP_H_
+
+#include "command.h"
 
 class Expression;
 
 class cmd_step : public command
 {
 public:
-
-  cmd_step(void);
+  cmd_step();
 
   void step(int);
   void step(Expression *);
-  void over(void);
+  void over();
 
-  virtual int is_repeatable(void) { return 1; };
+  int is_repeatable() override { return 1; }
 };
 
 extern cmd_step step;
+
 #endif
 
