@@ -18,29 +18,34 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_STIMULUS_H__
-#define __CMD_STIMULUS_H__
+#ifndef CLI_CMD_STIMULUS_H_
+#define CLI_CMD_STIMULUS_H_
 
+#include "../src/expr.h"
 #include "command.h"
 
+class cmd_options_str;
+
 class cmd_stimulus : public command
 {
 public:
-  int valid_options,options_entered;
-  int have_data;
+    int valid_options;
+    int options_entered;
+    int have_data;
 
-  cmd_stimulus(void);
-  void stimulus(void);
+    cmd_stimulus();
+    void stimulus();
 
-  void stimulus(int bit_flag);
-  void stimulus(cmd_options_expr *coe);
-  void stimulus(cmd_options_str *cos);
-  void stimulus(ExprList_t *);
-  void end(void);
+    void stimulus(int bit_flag);
+    void stimulus(cmd_options_expr *coe);
+    void stimulus(cmd_options_str *cos);
+    void stimulus(ExprList_t *);
+    void end();
 
-  bool can_span_lines(void) {return 1;};
+    bool can_span_lines() override { return 1; }
 };
 
 extern cmd_stimulus c_stimulus;
+
 #endif
 
