@@ -18,35 +18,39 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
+#include <stdio.h>
 
 #include <iostream>
-#include <iomanip>
 #include <string>
 #include <typeinfo>
 
 #include "command.h"
 #include "cmd_symbol.h"
-#include "../src/cmd_gpsim.h"
-#include "../src/modules.h"
-#include "../src/symbol.h"
+#include "misc.h"
 #include "../src/ValueCollections.h"
+#include "../src/errors.h"
+#include "../src/gpsim_object.h"
+#include "../src/modules.h"
 #include "../src/pic-instructions.h"
+#include "../src/symbol.h"
+#include "../src/ui.h"
+#include "../src/value.h"
+
 
 cmd_symbol c_symbol;
 
 static cmd_options cmd_symbol_options[] =
 {
-  {0,0,0}
+  {nullptr, 0, 0}
 };
 
 
 cmd_symbol::cmd_symbol()
-  : command("symbol",0)
+  : command("symbol", nullptr)
 {
+  brief_doc = "Add or display symbols";
 
-  brief_doc = string("Add or display symbols");
-
-  long_doc = string ("symbol [<symbol_name>]\n"
+  long_doc = "symbol [<symbol_name>]\n"
     "symbol <symbol_name>=<value>\n"
     "\n"
     "\tIf no options are supplied, the entire symbol table will be\n"
@@ -63,20 +67,19 @@ cmd_symbol::cmd_symbol()
     "Examples:\n"
     "\tsymbol                     // display the symbol table\n"
     "\tsymbol GpsimIsGreat=true   // create a new constant symbol\n"
-    "\n");
+    "\n";
 
   op = cmd_symbol_options;
 }
 
-static string table;
+static std::string table;
 
 void dumpOneSymbol(const SymbolEntry_t &sym)
 {
-
-  string out;
+  std::string out;
 
   Value *pVal = dynamic_cast<Value *>(sym.second);
-  if (pVal != NULL && typeid(*pVal) == typeid(LineNumberSymbol))
+  if (pVal != nullptr && typeid(*pVal) == typeid(LineNumberSymbol))
      return;
 
   if (table != "__global__")
@@ -95,13 +98,13 @@ void dumpSymbolTables(const SymbolTableEntry_t &st)
 
 void cmd_symbol::dump_all()
 {
-  cout << "\nSymbol table\n";
+  std::cout << "\nSymbol table\n";
   globalSymbolTable().ForEachModule(dumpSymbolTables);
 }
 
 void cmd_symbol::dump_one(const char *sym_name)
 {
-  string sName(sym_name);
+  std::string sName(sym_name);
   Module *pM = globalSymbolTable().findModule(sName);
 
   if (pM)
@@ -117,7 +120,7 @@ void cmd_symbol::dump_one(gpsimObject *s)
     if (pM)
       pM->getSymbolTable().ForEachSymbolTable(dumpOneSymbol);
     else
-      cout << s->toString() << endl;
+      std::cout << s->toString() << '\n';
   }
 }
 
@@ -138,7 +141,7 @@ void cmd_symbol::EvaluateAndDisplay(Expression *pExpr) {
     Value * pValue = pExpr->evaluate();
     GetUserInterface().DisplayMessage("%s\n", pValue->toString().c_str());
   }
-  catch(Error &pMessage)  {
+  catch (const Error &pMessage)  {
     GetUserInterface().DisplayMessage("%s\n", pMessage.what());
   }
 }
@@ -148,7 +151,7 @@ void cmd_symbol::dump(gpsimObject *s, ExprList_t*e)
   Value *pValue = dynamic_cast<Value *>(s);
   if (pValue) {
     IndexedSymbol sym(pValue, e);
-    cout << sym.toString() << endl;
+    std::cout << sym.toString() << '\n';
   }
 }
 
@@ -158,7 +161,7 @@ void cmd_symbol::Set(gpsimObject *s, ExprList_t*e, Expression *pExpr)
   if (pValue) {
     try {
       IIndexedCollection *pCollection = dynamic_cast<IIndexedCollection*>(s);
-      if(pCollection == NULL) {
+      if (pCollection == nullptr) {
         GetUserInterface().DisplayMessage("%s is not an indexed symbol\n",
                                           s->name().c_str());
       }
@@ -166,7 +169,7 @@ void cmd_symbol::Set(gpsimObject *s, ExprList_t*e, Expression *pExpr)
         pCollection->SetAt(e, pExpr);
       }
     }
-    catch (Error &Message)  {
+    catch (const Error &Message)  {
       GetUserInterface().DisplayMessage("%s\n", Message.what());
     }
   }
