@@ -18,16 +18,17 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_SYMBOL_H__
-#define __CMD_SYMBOL_H__
+#ifndef CLI_CMD_SYMBOL_H_
+#define CLI_CMD_SYMBOL_H_
+
+#include "command.h"
+#include "../src/expr.h"
 
-class Expression;
 class gpsimObject;
 
 class cmd_symbol : public command
 {
 public:
-
   cmd_symbol();
 
   void dump_all();
@@ -36,11 +37,12 @@ public:
   void dump(gpsimObject *, ExprList_t*);
   void EvaluateAndDisplay(Expression *pExpr);
 
-  void Set(gpsimObject *s, ExprList_t*e, Expression *pExpr);
+  void Set(gpsimObject *s, ExprList_t *e, Expression *pExpr);
 
   void add_one(const char *sym_name, Expression *);
 };
 
 extern cmd_symbol c_symbol;
+
 #endif
 
