@@ -18,17 +18,22 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_TRACE_H__
-#define __CMD_TRACE_H__
+#ifndef CLI_CMD_TRACE_H_
+#define CLI_CMD_TRACE_H_
 
 #include "command.h"
 
+class Expression;
+class cmd_options_str;
+struct cmd_options;
+struct cmd_options_num;
+
 class cmd_trace : public command
 {
 public:
+  cmd_trace();
 
-  cmd_trace(void);
-  void trace(void);
+  void trace();
 
   void trace(cmd_options *co);
   void trace(cmd_options_expr *coe);
@@ -37,9 +42,10 @@ public:
   void trace(cmd_options_num *con);
   void trace(cmd_options_str *cos);
   void trace(int bit_flag, int force_bit_test);
-  virtual int is_repeatable(void) { return 1; };
+  int is_repeatable() override { return 1; }
 };
 
 extern cmd_trace c_trace;
+
 #endif
 
