@@ -19,30 +19,28 @@ the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
 
-#include <iostream>
-#include <iomanip>
 #include <string>
 
 #include "command.h"
 #include "cmd_version.h"
+#include "misc.h"
 
 cmd_version version;
 
-extern void gpsim_version(void);
+extern void gpsim_version();
 
 static cmd_options cmd_version_options[] =
 {
-  {0,0,0}
+  {nullptr, 0, 0}
 };
 
 
 cmd_version::cmd_version()
   : command("version", "ver")
-{ 
+{
+  brief_doc = "Display the gpsim's version";
 
-  brief_doc = string("Display the gpsim's version");
-
-  long_doc = string("Display the gpsim's version");
+  long_doc = "Display the gpsim's version";
 
   op = cmd_version_options; 
 }
