@@ -18,18 +18,21 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __CMD_VERSION_H__
-#define __CMD_VERSION_H__
+#ifndef CLI_CMD_VERSION_H_
+#define CLI_CMD_VERSION_H_
+
+#include "command.h"
 
 class cmd_version : public command
 {
 public:
+  cmd_version();
 
-  cmd_version(void);
-  void version(void);
-  virtual int is_repeatable(void) { return 1; };
+  void version();
+  int is_repeatable() override { return 1; }
 };
 
 extern cmd_version version;
+
 #endif
 
