@@ -30,17 +30,23 @@ public:
 
   void x();
   void x(int reg, Expression *pExpr = nullptr);
+  
   void x(char *reg_name, int val);
   void x(char *reg_name);
-  void x(Expression *);
+  void x(Expression * , Expression *pExpr = nullptr);
 
-  virtual int is_repeatable()
-  {
-    return 1;
-  }
+  int is_repeatable() override { return 1; }
+  bool int_from_expression(Expression *, unsigned int &val);
 };
 
 extern cmd_x c_x;
 
+class cmd_reg : public command 
+{
+public:
+    cmd_reg();
+};
+
+extern cmd_reg c_reg;
 #endif
 
