@@ -18,18 +18,14 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-
 #include <iostream>
-#include <iomanip>
 #include <string>
-#include <vector>
-
-#include "../config.h"
 
+#include "../src/errors.h"
 #include "../src/expr.h"
-#include "../src/pic-processor.h"
 #include "../src/sim_context.h"
-#include "../src/trace.h"
+#include "../src/ui.h"
+#include "../src/value.h"
 
 #include "command.h"
 
@@ -61,6 +57,7 @@ Boston, MA 02111-1307, USA.  */
 #include "cmd_version.h"
 #include "cmd_x.h"
 #include "cmd_icd.h"
+#include "misc.h"
 
 int quit_gpsim = 0;
 
@@ -85,6 +82,7 @@ command *command_list[] =
   &c_node,
   &c_processor,
   &quit,
+  &c_reg,
   &reset,
   &c_run,
   &c_set,
@@ -98,11 +96,10 @@ command *command_list[] =
 
 
 command::command(const char *_name, const char *_abbr)
-  : m_pName(_name), m_pAbbreviation(_abbr)
+  : op(nullptr), token_value(0), m_pName(_name), m_pAbbreviation(_abbr)
 {
-  op = 0;
-  token_value = 0;
 }
+
 /*
 command::command(struct cmd_options *options,int tv)
 {
@@ -115,151 +112,145 @@ command::command(struct cmd_options *options,int tv)
 int number_of_commands = sizeof(command_list) / sizeof(command  *);
 
 
-command *search_commands(const string &s)
+command *search_commands(const std::string &s)
 {
+    int i = 0;
 
-  int i=0;
+    while (i < number_of_commands) {
+        command * cmd = command_list[i];
 
-  while(i<number_of_commands) {
-    command * cmd = command_list[i];
-    if(strcmp(cmd->name(), s.c_str()) == 0 ||
-       (cmd->abbreviation() != 0 && strcmp(cmd->abbreviation(), s.c_str()) == 0 )) {
-      return cmd;
+        if (s == cmd->name() || (cmd->abbreviation() && s == cmd->abbreviation() )) {
+            return cmd;
+        }
+
+        i++;
     }
 
-    i++;
-
-  }
-
-  return 0;
+    return nullptr;
 }
 
 void execute_line(char *cmd)
 {
-  if(verbose)
-    cout << "Executing a line:\n  " << cmd;
+    if (verbose)
+        std::cout << "Executing a line:\n  " << cmd;
 }
 
 Processor *command::GetActiveCPU(bool bDisplayWarnings)
 {
-  Processor *pCpu = CSimulationContext::GetContext()->GetActiveCPU();
-  if (bDisplayWarnings && !pCpu)
-    cout << "No cpu has been selected\n";
-  return pCpu;
+    Processor *pCpu = CSimulationContext::GetContext()->GetActiveCPU();
+    if (bDisplayWarnings && !pCpu)
+        std::cout << "No cpu has been selected\n";
+    return pCpu;
 }
 
 Value *command::toValue(Expression *expr)
 {
-  if(expr)
-    return expr->evaluate();
+    if (expr)
+        return expr->evaluate();
 
-  return new Integer(0);
+    return new Integer(0);
 }
+
 double command::evaluate(Expression *expr)
 {
-  double value = 0.0;
+    double value = 0.0;
 
-  try {
-    if(expr) {
+    try {
+        if (expr) {
 
-      Value *v = toValue(expr);
+            Value *v = toValue(expr);
 
-      v->get(value);
+            v->get(value);
+
+            delete v;
+            delete expr;
+        }
 
-      delete v;
-      delete expr;
     }
 
-  }
+    catch (const Error &err) {
+        std::cout << "ERROR:" << err.what() << '\n';
+    }
 
-  catch (Error &err) {
-    std::cout << "ERROR:" << err.what() << '\n';
-  }
-
-  return value;
+    return value;
 }
 
 
 static gint64 evaluateToInt(Expression *expr)
 {
-  gint64 value = 0;
+    gint64 value = 0;
 
-  try {
-    if(expr) {
+    try {
+        if (expr) {
 
-      Value *v = expr->evaluate();
+            Value *v = expr->evaluate();
 
-      v->get(value);
+            v->get(value);
+
+            delete v;
+            delete expr;
+        }
 
-      delete v;
-      delete expr;
     }
 
-  }
+    catch (const Error &err) {
+        std::cout << "ERROR:" << err.what() << '\n';
+    }
 
-  catch (Error &err) {
-    std::cout << "ERROR:" << err.what() << '\n';
-  }
-
-  return value;
+    return value;
 }
+
 void command::evaluate(ExprList_t *eList,
                        guint64 *parameters,
                        int *nParameters)
 {
-  ExprList_itor ei;
-
-  if (!eList) {
-    if(nParameters)
-      *nParameters = 0;
-    return;
-  }
-
-  if ( !parameters || !nParameters || !*nParameters)
-    return;
-
-  int n = 0;
-  for(ei = eList->begin();
-      (ei != eList->end()) && (n < *nParameters);
-      ++ei, n++)
-    {
-      parameters[n] = evaluateToInt(*ei);
-      cout << "p" << n << " = " << parameters[n] << endl;
+    ExprList_itor ei;
 
+    if (!eList) {
+        if (nParameters)
+            *nParameters = 0;
+        return;
     }
 
-  *nParameters = n;
+    if ( !parameters || !nParameters || !*nParameters)
+        return;
+
+    int n = 0;
+    for (ei = eList->begin();
+        (ei != eList->end()) && (n < *nParameters);
+        ++ei, n++)
+    {
+        parameters[n] = evaluateToInt(*ei);
+        std::cout << 'p' << n << " = " << parameters[n] << '\n';
+    }
+
+    *nParameters = n;
 }
 
 //========================================================================
 // Command options
 
 cmd_options_str::cmd_options_str(const char *new_val)
+    : co(nullptr)
 {
-  if(new_val)
-    str = strdup(new_val);
-  else
-    str = 0;
+  if (new_val)
+    str = new_val;
 }
 
 cmd_options_str::~cmd_options_str()
 {
-
-  if(str)
-    free (str);
-
-
 }
 
 
 cmd_options_expr::cmd_options_expr(cmd_options *_co, Expression *_expr)
 {
-  co = _co;
-  expr = _expr;
+    co = _co;
+    expr = _expr;
 }
 
 cmd_options_expr::~cmd_options_expr()
 {
-  delete co;
-  delete expr;
+    delete co;
+    delete expr;
 }
+
