@@ -33,6 +33,7 @@ Boston, MA 02111-1307, USA.  */
 #ifdef _WIN32
 #include <direct.h>
 #include "fd2raw.h"
+#include "../src/processor.h"
 #define GETCWD _getcwd
 
 #else
@@ -139,9 +140,9 @@ void EnableSTCEcho(bool bEnable)
 
 class CCliCommandHandler : public ICommandHandler {
 public:
-  virtual const char *GetName();
-  virtual int Execute(const char * commandline, ISimConsole *out);
-  virtual int ExecuteScript(std::list<std::string *> &script, ISimConsole *out);
+  const char *GetName() override;
+  int Execute(const char * commandline, ISimConsole *out) override;
+  int ExecuteScript(const std::list<std::string> &script, ISimConsole *out) override;
 };
 
 
@@ -223,7 +224,6 @@ LLInput::~LLInput()
 
 LLStack::LLStack()
   : LLdata(nullptr), next_stack(nullptr)
-
 {
   msi_StackDepth++;
   //  cout << "Stack depth: " << level() << endl;
@@ -993,7 +993,7 @@ int CCliCommandHandler::Execute(const char *commandline, ISimConsole * /* out */
 }
 
 
-int CCliCommandHandler::ExecuteScript(list<string *> &script, ISimConsole * /* out */ )
+int CCliCommandHandler::ExecuteScript(const std::list<std::string> &script, ISimConsole * /* out */ )
 {
   if (verbose & 4) {
     std::cout << "GCLICommandHandler::Execute Script:\n";
@@ -1012,13 +1012,9 @@ int CCliCommandHandler::ExecuteScript(list<string *> &script, ISimConsole * /* o
   Stack = nullptr;
   start_new_input_stream();
   add_string_to_input_buffer("\n");
-  std::list <std::string *> :: iterator command_iterator;
 
-  for (command_iterator = script.begin();
-       command_iterator != script.end();
-       ++command_iterator) {
-    std::string *cmd = *command_iterator;
-    add_string_to_input_buffer(cmd->c_str());
+  for (const auto &cmd : script) {
+    add_string_to_input_buffer(cmd.c_str());
   }
 
   // Start parsing the script that we just placed into the command stream
