@@ -8,10 +8,10 @@
 /*****
 * eXdbm.c : eXdbm main source file
 *
-* This file Version     $Revision: 2216 $
+* This file Version     $Revision: 2356 $
 *
-* Last modification:    $Date: 2013-06-30 10:56:58 +1000 (Sun, 30 Jun 2013) $
-* By:                                   $Author: roy_r_rankin $
+* Last modification:    $Date: 2015-10-29 17:47:26 +1100 (Thu, 29 Oct 2015) $
+* By:                                   $Author: errolv $
 * Current State:                $State$
 *
 * Copyright (C) 1997 Fred Pesch
@@ -35,7 +35,7 @@
 *
 *****/
 
-/*      $Id: eXdbm.c 2216 2013-06-30 00:56:58Z roy_r_rankin $         */
+/*      $Id: eXdbm.c 2356 2015-10-29 06:47:26Z errolv $         */
 
 /* includes */
 
@@ -226,6 +226,7 @@ int eXdbmOpenDatabase(char *filename,  DB_ID *dbid)
  DbmDbList->dblist[temp_id].filename = (char *) malloc(sizeof(char)* (strlen(filename)+1));
   if(DbmDbList->dblist[temp_id].filename == NULL) {
     RaiseError(DBM_ALLOC);
+    fclose(f);
     return(-1);
   }
 
@@ -562,7 +563,10 @@ int eXdbmReloadDatabase(DB_ID *dbid, int update)
 
   ret = eXdbmCloseDatabase(*dbid, update);
 
-  if(ret == -1) return(-1);
+  if(ret == -1) {
+    free(filename);
+    return(-1);
+  }
 
   /* then, reopen it */
 
