@@ -21,7 +21,7 @@ Boston, MA 02111-1307, USA.  */
 /*
   Scripting
 
-  client2.cc - a program to demonstrate gpsim scripting.
+  client3.cc - a program to demonstrate gpsim scripting.
 
 */
 
@@ -221,15 +221,24 @@ void *thread3(void *ignored)
   while (i++<4)
     sleep(1);
 
+  sock->SendCmd("load s gensquares.cod\n");
   if (sock->CreateCallbackLink(0x1000)) {
     printf("created callback link\n");
   }
+  sock->SendCmd("break c 0x5000\n");
+  sock->SendCmd("run\n");
 
-  while (1) {
-    printf("thread 3 received%s\n", sock->Receive());
+
+
+  for(int i = 0; i<4; i++)
+  {
+      printf("thread 3 recieved %s\n", sock->Receive());
   }
 
+  sock->SendCmd("quit\n");
+  delete sock;
   printf("thread 3 is complete\n");
+  return 0;
 }
 
 void start_threads(void)
@@ -263,11 +272,10 @@ int main(int argc, char **argv)
   sock3 = new ClientSocketInterface(argc>2 ? argv[2] : 0, PORT);
 
   start_threads();
+  void * status;
 
-  while(1) {
-    printf("main\n");
-    sleep(1);
-  }
+  pthread_join(thThread3, &status);
+  printf("thread 3 exit %d\n", status);
   return 0;
 }
 
