@@ -83,7 +83,8 @@ enum {
 class dht11Module::Pin : public IO_open_collector
 {
   public:
-    Pin(dht11Module* new_parent) : IO_open_collector("data")
+    explicit Pin(dht11Module* new_parent)
+        : IO_open_collector("data")
     {
       parent = new_parent;
       parent->addSymbol(this);
@@ -101,7 +102,7 @@ class dht11Module::Pin : public IO_open_collector
                     false); // Don't update the node. (none is attached).
     }
 
-    ~Pin() {};
+    ~Pin() {}
 
     /* This gets called whenever the pin voltage changes */
     virtual void set_nodeVoltage(double newvolts)
@@ -151,7 +152,7 @@ class dht11Module::IntegerAttribute : public Integer
 {
 public:
   IntegerAttribute(const char *_name,  gint64 newValue = 0,
-                   const char *desc=0)
+                   const char *desc = nullptr)
     : Integer(_name, newValue, desc)
   {
   }
@@ -162,7 +163,7 @@ public:
 // Initially (0) we're just after the start signal and we're high
 //                 so then we pull low for 80us
 //            1  we've been low, now pull high
-void dht11Module::callback_intro(void)
+void dht11Module::callback_intro()
 {
   switch (state & 0xf) {
     case 0:
@@ -170,7 +171,7 @@ void dht11Module::callback_intro(void)
       break;
 
     case 1:
-      set_state_callback(STATE_HUMIDITY_INT | STATE_TEMP_DATA_LOW, 80.0,1);
+      set_state_callback(STATE_HUMIDITY_INT | STATE_TEMP_DATA_LOW, 80.0, 1);
       
     default:
       Dprintf(("Bad state\n"));
@@ -182,7 +183,7 @@ void dht11Module::callback_intro(void)
 // Handler for the end states - 50us low pulse at the end
 //   0 - Where we pull it low
 //   1 - We're done, release and no more callbacks
-void dht11Module::callback_end(void)
+void dht11Module::callback_end()
 {
   switch (state & 0xf) {
     case 0:
@@ -203,7 +204,7 @@ void dht11Module::callback_end(void)
 
 //--------------------------------------------------------------
 // Gets called on 'set_break' timeouts
-void dht11Module::callback(void)
+void dht11Module::callback()
 {
   Dprintf(("at %" PRINTF_GINT64_MODIFIER "d in 0x%x\n", get_cycles().get(), state));
 
@@ -283,7 +284,7 @@ void dht11Module::set_state_callback(guint8 new_state, double delay_us, bool lev
 {
   guint64 now = get_cycles().get();
   guint64 future_time;
-  future_time = now+1+((delay_us/1000000.0)*get_cycles().instruction_cps());
+  future_time = now + 1 + ((delay_us / 1000000.0) * get_cycles().instruction_cps());
   Dprintf(("State: %d->%d wait %lf s pin->%d now=%" PRINTF_GINT64_MODIFIER "d future=%" PRINTF_GINT64_MODIFIER "d\n", state, new_state, delay_us, level, now, future_time));
 
   state = new_state;
@@ -294,7 +295,7 @@ void dht11Module::set_state_callback(guint8 new_state, double delay_us, bool lev
 
 //--------------------------------------------------------------
 // Called by the pin to indicate reception of start signal
-void dht11Module::start(void)
+void dht11Module::start()
 {
   if (state != STATE_IDLE) {
     /* I don't see anything to indicate what should happen here */
@@ -322,7 +323,9 @@ Module * dht11Module::construct(const char *_new_name)
 
 }
 
-dht11Module::dht11Module(const char *_name) : TriggerObject(), Module(_name, "dht11")
+dht11Module::dht11Module(const char *_name)
+    : TriggerObject(), Module(_name, "dht11"),
+      m_pin(nullptr)
 {
 
   /* DHT11's actually never do the decimal part of either the humidity or temperature, even
@@ -355,4 +358,3 @@ void dht11Module::create_iopin_map()
 
 }
 
-
