@@ -36,6 +36,7 @@ SED1520::SED1520()
   randomizeRAM();
 }
 
+
 //------------------------------------------------------------------------
 void SED1520::setA0(bool newA0)
 {
@@ -43,29 +44,32 @@ void SED1520::setA0(bool newA0)
   m_controlState |= (newA0 ? eA0 : 0);
 }
 
+
 void SED1520::setRW(bool newRW)
 {
   m_controlState &= ~eRW;
   m_controlState |= (newRW ? eRW : 0);
 }
 
+
 void SED1520::setE(bool newE)
 {
-
   if (m_bE != newE && newE) {
-
     switch (m_controlState) {
     case eDataRead:
       driveDataBus(getData());
       advanceColumnAddress();
       break;
+
     case eDataWrite:
       storeData();
       advanceColumnAddress();
       break;
+
     case eStatusRead:
       driveDataBus(getStatus());
       break;
+
     case eCommandWrite:
       executeCommand();
       break;
@@ -73,86 +77,95 @@ void SED1520::setE(bool newE)
   }
 
   m_bE = newE;
-
 }
 
 
-
 void SED1520::setData(unsigned int d)
 {
   m_dataBus = d;
 }
 
+
 void SED1520::driveDataBus(unsigned int d)
 {
   m_dataBus = d;
 }
 
+
 void SED1520::advanceColumnAddress()
 {
   m_columnAddress += (m_columnAddress < eNCOLUMNS_PER_PAGE) ? 1 : 0;
 }
 
+
 void SED1520::storeData()
 {
-  m_ram[eNCOLUMNS_PER_PAGE*m_page + m_columnAddress] = m_dataBus;
+  m_ram[eNCOLUMNS_PER_PAGE * m_page + m_columnAddress] = m_dataBus;
 }
 
+
 unsigned int SED1520::getData()
 {
-  m_dataBus = m_ram[eNCOLUMNS_PER_PAGE*m_page + m_columnAddress];
+  m_dataBus = m_ram[eNCOLUMNS_PER_PAGE * m_page + m_columnAddress];
   return m_dataBus;
 }
 
+
 unsigned int SED1520::getStatus()
 {
   return 0;
 }
 
+
 void SED1520::executeCommand()
 {
-
-  // decode the command 
-
-  if ( (m_dataBus & 0x80) == 0) {
+  // decode the command
+  if ((m_dataBus & 0x80) == 0) {
     // Set column address
-
     m_columnAddress = (m_dataBus & 0x7f) % eNCOLUMNS_PER_PAGE;
 
   } else {
-
     if ((m_dataBus & 0x7C) == 0x38)
       // set Page Address
+    {
       m_page = m_dataBus & 3;
-
+    }
   }
 }
 
+
 //------------------------------------------------------------------------
 bool SED1520::dataBusDirection()
 {
   return (m_controlState & (eE | eRW)) == (eE | eRW);
 }
+
+
 //------------------------------------------------------------------------
 unsigned int SED1520::getDataBus()
 {
   return m_dataBus;
 }
+
+
 //------------------------------------------------------------------------
 
 void SED1520::randomizeRAM()
 {
-  for (unsigned int i=0; i < eNCOLUMNS_PER_PAGE * eNPAGES; i++)
-    m_ram[i] =  (rand()>>8) & 0xff;
-
+  for (unsigned int i = 0; i < eNCOLUMNS_PER_PAGE * eNPAGES; i++) {
+    m_ram[i] = (rand() >> 8) & 0xff;
+  }
 }
+
+
 //------------------------------------------------------------------------
 // prBadRam - private function called when ever an illegal access is made
 // to the RAM
 unsigned int &SED1520::prBadRam(unsigned int index)
 {
   static unsigned int si;
-  printf("WARNING SED1520 - illegal RAM access index=%u\n",index);
+  printf("WARNING SED1520 - illegal RAM access index=%u\n", index);
   return si;
 }
+
 #endif // HAVE_GUI
