@@ -19,8 +19,8 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __GUI_H__
-#define __GUI_H__
+#ifndef GUI_GUI_H_
+#define GUI_GUI_H_
 
 #include "../config.h"
 
@@ -30,6 +30,7 @@ Boston, MA 02111-1307, USA.  */
 #include <glib.h>
 #include <gtk/gtk.h>
 #include "../src/processor.h"
+#include "../src/xref.h"
 #include "settings.h"
 
 //#define DEBUG
@@ -76,7 +77,7 @@ public:
   EntryWidget();
   virtual ~EntryWidget();
 
-  virtual void Update()=0;
+  virtual void Update() = 0;
   virtual void set_editable(bool Editable = true);
   void SetEntryWidth(int string_width);
 
@@ -97,7 +98,7 @@ public:
   {
   }
 
-  virtual void Update();
+  void Update() override;
   virtual void put_value(unsigned int);
 
 private:
@@ -109,8 +110,8 @@ public:
   RegisterLabeledEntry(GtkWidget *, Register *, bool);
   virtual ~RegisterLabeledEntry();
 
-  virtual void put_value(unsigned int);
-  virtual void Update();
+  void put_value(unsigned int) override;
+  void Update() override;
 private:
   Register *reg;
   char pCellFormat[10];
@@ -136,6 +137,6 @@ int config_remove(const char *module, const char *entry);
 
 int gui_get_value(const char *prompt);
 
-#endif // __GUI_H__
-
 #endif // HAVE_GUI
+
+#endif // GUI_GUI_H_
