@@ -22,33 +22,38 @@ Boston, MA 02111-1307, USA.  */
 #include "../config.h"
 #ifdef HAVE_GUI
 
+#include <cairo.h>
+#include <gdk/gdk.h>
+#include <gtk/gtk.h>
+#include <glib.h>
+#include <glib-object.h>
 
+#include <cassert>
+#include <cmath>
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
-#include <gtk/gtk.h>
-#include <glib.h>
-#include <glib/gprintf.h>
-#include <cmath>
-#include <cassert>
 
 #include <algorithm>
 #include <iostream>
+#include <list>
+#include <map>
+#include <memory>
 #include <string>
 #include <typeinfo>
-
-#include "../src/modules.h"
-#include "../src/symbol.h"
-#include "../src/stimuli.h"
-#include "../src/value.h"
-#include "../src/errors.h"
-#include "../src/packages.h"
-#include "../src/ui.h"
-#include "../src/xref.h"
-
-#include <map>
 #include <utility>
 
+#include "../src/errors.h"
+#include "../src/gpsim_object.h"
+#include "../src/modules.h"
+#include "../src/packages.h"
+#include "../src/processor.h"
+#include "../src/stimuli.h"
+#include "../src/symbol.h"
+#include "../src/ui.h"
+#include "../src/value.h"
+#include "../src/xref.h"
+
 #include "gui.h"
 #include "gui_breadboard.h"
 #include "gui_processor.h"
@@ -101,12 +106,12 @@ static unsigned int ysize;
 
 class BreadBoardXREF : public CrossReferenceToGUI {
 public:
-  void Update(int /* new_value */)
+  void Update(int /* new_value */) override
   {
-    Breadboard_Window *bbw  = static_cast<Breadboard_Window *>(parent_window);
+    auto bbw  = static_cast<Breadboard_Window *>(parent_window);
     bbw->Update();
   }
-  void Remove() {}
+  void Remove() override {}
 };
 
 
@@ -131,10 +136,8 @@ static inline unsigned char *board_matrix_pt(unsigned int x, unsigned int y)
 {
   if (x < xsize && y < ysize) {
     return board_matrix + y * xsize + x;
-
-  } else {
-    return nullptr;
   }
+  return nullptr;
 }
 
 
@@ -142,10 +145,8 @@ static inline unsigned short *mask_matrix_pt(unsigned int x, unsigned int y)
 {
   if (x < xsize && y < ysize) {
     return mask_matrix + (y * xsize + x);
-
-  } else {
-    return nullptr;
   }
+  return nullptr;
 }
 
 
@@ -216,49 +217,6 @@ static void prepend_point_to_path(std::list<path> &pat, point p)
   pat.push_front(new_point);
 }
 
-
-#if 0
-/* failed attempt to remove unnessessary points in paths. FIXME bug*/
-// Compress sequences with same x or y to one sequence
-static void compress_path(path **pat)
-{
-  int x, y;
-  path *current_path;
-  current_path = *pat;
-  x = current_path->p.x;
-  y = current_path->p.y;
-
-  while (current_path != 0) {
-    path *next_path = current_path->next;
-    path *next2_path = next_path->next;
-
-    if (next_path == 0 || next2_path == 0) {
-      break;
-    }
-
-    if (current_path->p.x == next_path->p.x &&
-        current_path->p.x == next2_path->p.x &&
-        current_path->dir == next_path->dir &&
-        current_path->dir == next2_path->dir) {
-      current_path->next = next2_path;
-      free(next_path);
-      continue;
-    }
-
-    if (current_path->p.y == next_path->p.y &&
-        current_path->p.y == next2_path->p.y &&
-        current_path->dir == next_path->dir &&
-        current_path->dir == next2_path->dir) {
-      current_path->next = next2_path;
-      free(next_path);
-      continue;
-    }
-
-    current_path = current_path->next;
-  }
-}
-#endif
-
 // maxdepth is shortest path from start to end
 static unsigned short maxdepth;
 
@@ -476,7 +434,7 @@ static bool trace_two_points(std::list<path> &pat,   // Pointer to resulting pat
   }
 
   // Check if some of the recursive traces went well.
-  if (retval == true) {
+  if (retval) {
     // We found a path to end. Add point p to path.
     // This is first or second point.
     prepend_point_to_path(pat, p);
@@ -511,7 +469,7 @@ gboolean Breadboard_Window::layout_expose(GtkWidget *,
   cairo_set_source_rgba(cr, 0.0, 0.0, 0.0, 1.0);
   cairo_set_line_join(cr, CAIRO_LINE_JOIN_ROUND);
   cairo_set_line_cap(cr, CAIRO_LINE_CAP_ROUND);
-  std::vector<std::list<path>>::iterator iter = nodepath_list.begin();
+  auto iter = nodepath_list.begin();
 
   for (; iter != nodepath_list.end(); ++iter) {
     std::list<path>::const_iterator current_path = (*iter).begin();
@@ -544,8 +502,8 @@ void Breadboard_Window::update_board_matrix()
     xsize = width / ROUTE_RES;
     ysize = height / ROUTE_RES;
     delete [] board_matrix;
-    board_matrix = new unsigned char[xsize * ysize];
     delete [] mask_matrix;
+    board_matrix = new unsigned char[xsize * ysize];
     mask_matrix = new unsigned short[xsize * ysize];
   }
 
@@ -564,14 +522,12 @@ void Breadboard_Window::update_board_matrix()
   }
 
   // Loop all modules, and put its package and pins to board_matrix
-  std::vector<GuiModule *>::iterator mi = modules.begin();
+  auto mi = modules.begin();
 
   for (; mi != modules.end(); ++mi) {
     GuiModule *p = *mi;
 
     if (p && p->IsBuilt()) {
-      x = p->x();
-      y = p->y();
       width = p->width();
       height = p->height();
 
@@ -668,7 +624,7 @@ static void add_path_to_matrix(const std::list<path> &pat)
 {
   int x = -1;
   int y = -1;
-  std::list<path>::const_iterator iter = pat.begin();
+  auto iter = pat.begin();
 
   if (iter != pat.end()) {
     x = iter->p.x;
@@ -849,7 +805,7 @@ static bool trace_node(gui_node *gn)
     const std::pair<int, int> coord = std::make_pair(
                                         shortest_permutation[i],
                                         shortest_permutation[i + 1]);
-    std::map<std::pair<int, int>, std::list<path>>::iterator iter = shortest_path.find(coord);
+    auto iter = shortest_path.find(coord);
 
     if (iter != shortest_path.end()) {
       path_copy_and_cat(nodepath, iter->second);
@@ -860,7 +816,6 @@ static bool trace_node(gui_node *gn)
   delete[] shortest_permutation;
 
   if (!nodepath.empty()) {
-    //          compress_path(&nodepath);
     add_path_to_matrix(nodepath);
     nodepath_list.push_back(nodepath);
   }
@@ -871,11 +826,7 @@ static bool trace_node(gui_node *gn)
 
 GuiPin *find_gui_pin(Breadboard_Window *bbw, stimulus *pin)
 {
-  std::vector<GuiModule *>::iterator iter = bbw->modules.begin();
-
-  for (; iter != bbw->modules.end(); ++iter) {
-    GuiModule *m = *iter;
-
+  for (auto &m : bbw->modules) {
     for (int i = 1; i <= m->module()->get_pin_count(); ++i) {
       stimulus *p = m->module()->get_pin(i);
 
@@ -908,7 +859,7 @@ static void treeselect_stimulus(GuiPin *pin)
     g_snprintf(string, sizeof(string), "Stimulus %s", pin->getIOpin()->name().c_str());
     pString = string;
 
-    if (pin->getSnode() != 0) {
+    if (pin->getSnode() != nullptr) {
       g_snprintf(text, sizeof(text), "Connected to node %s", pin->getSnode()->name().c_str());
 
     } else {
@@ -931,7 +882,7 @@ static std::string full_name;
 
 static void dumpStimulus(const SymbolEntry_t &sym)
 {
-  stimulus *ps = dynamic_cast<stimulus *>(sym.second);
+  auto ps = dynamic_cast<stimulus *>(sym.second);
 
   if (ps == stim) {
     full_name = module_name + std::string(".") + ps->name();
@@ -961,7 +912,7 @@ static void treeselect_node(gui_node *gui_node)
 
   //    printf("treeselect_node %p\n",gui_node);
 
-  if (gui_node->node != 0) {
+  if (gui_node->node != nullptr) {
     char str[STRING_SIZE];
     g_snprintf(str, sizeof(str), "Node %s", gui_node->node->name().c_str());
     gtk_frame_set_label(GTK_FRAME(gui_node->bbw->node_frame), str);
@@ -977,7 +928,7 @@ static void treeselect_node(gui_node *gui_node)
   g_object_get(gui_node->bbw->node_clist, "model", &list_store, nullptr);
   gtk_list_store_clear(list_store);
 
-  if (gui_node->node != 0) {
+  if (gui_node->node != nullptr) {
     // Add to node_clist
     stimulus = gui_node->node->stimuli;
 
@@ -1018,12 +969,14 @@ static void treeselect_cb(GtkTreeSelection *selection, gpointer)
     }
 
   } else {
-    if (strlen(spath) > 1) {
-      GuiPin *gp;
+    // For a module spath is just a number
+    // For pin spath is module:pin
+    if (strpbrk(spath, ":")) { //Pin
+      GuiPin *gp = NULL;
       gtk_tree_model_get(model, &iter, 1, &gp, -1);
       treeselect_stimulus(gp);
 
-    } else {
+    } else {			//Module
       GuiModule *module;
       gtk_tree_model_get(model, &iter, 1, &module, -1);
       treeselect_module(module);
@@ -1086,8 +1039,8 @@ static void settings_set_cb(GtkWidget *, Breadboard_Window *bbw)
       // Update clist
       treeselect_module(bbw->selected_module);
 
-    } catch (Error &err) {
-      std::cout << __FUNCTION__ << ": " << err.what() << '\n';
+    } catch (const Error &err) {
+      std::cout << __func__ << ": " << err.what() << '\n';
     }
 
   } else {
@@ -1101,7 +1054,7 @@ static GtkWidget *attribute_clist;
 
 static void clistOneAttribute(const SymbolEntry_t &sym)
 {
-  Value *pVal = dynamic_cast<Value *>(sym.second);
+  auto pVal = dynamic_cast<Value *>(sym.second);
 
   if (attribute_clist && pVal) {
     // read attributes and add to clist
@@ -1192,24 +1145,23 @@ void GuiModule::SetPosition(int nx, int ny)
     }
 
     // Position module_widget
-    if (m_pinLabel_widget)
+    if (m_pinLabel_widget) {
       gtk_layout_move(GTK_LAYOUT(m_bbw->layout), m_pinLabel_widget,
                       m_x,
                       m_y);
+    }
 
-    if (m_module_widget)
+    if (m_module_widget) {
       gtk_layout_move(GTK_LAYOUT(m_bbw->layout), m_module_widget,
                       m_x + m_module_x,
                       m_y + m_module_y);
+    }
 
     // Position module_name
     gtk_layout_move(GTK_LAYOUT(m_bbw->layout), m_name_widget->gobj(), m_x, m_y - 20);
     // Position pins
-    std::vector<GuiPin *>::iterator piniter = m_pins.begin();
-
-    for (; piniter != m_pins.end(); ++piniter) {
-      GuiPin *pin = *piniter;
 
+    for (auto &pin : m_pins) {
       if (pin->orientation == RIGHT) {
         pin->SetPosition(m_x + pin->module_x() + PINLENGTH, m_y + pin->module_y() + pin->height() / 2);
 
@@ -1278,10 +1230,8 @@ static GuiModule *find_closest_module(Breadboard_Window *bbw, int x, int y)
 {
   GuiModule *closest = nullptr;
   double min_distance = 1000000.0;
-  std::vector<GuiModule *>::iterator mi = bbw->modules.begin();
 
-  for (; mi != bbw->modules.end(); ++mi) {
-    GuiModule *p = *mi;
+  for (auto &p : bbw->modules) {
     double distance = p->Distance(x, y);
 
     if (distance < min_distance) {
@@ -1308,7 +1258,7 @@ void grab_module(GuiModule *p)
                    TRUE,
                    (GdkEventMask)(GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK),
                    gtk_widget_get_window(p->bbw()->layout),
-                   0,
+                   nullptr,
                    GDK_CURRENT_TIME);
   treeselect_module(dragged_module);
   dragging = 1;
@@ -1325,13 +1275,12 @@ void Breadboard_Window::pointer_cb(GtkWidget *w,
                                    GdkEventButton *event,
                                    Breadboard_Window *bbw)
 {
-  int x, y;
-  x = (int)(event->x);
-  y = (int)(event->y);
+  int x = (int)(event->x);
+  int y = (int)(event->y);
 
   switch (event->type) {
   case GDK_MOTION_NOTIFY:
-    if (dragging && 0 != dragged_module) {
+    if (dragging && dragged_module) {
       dragged_module->SetPosition(x + pinspacing, y + pinspacing);
     }
 
@@ -1350,12 +1299,12 @@ void Breadboard_Window::pointer_cb(GtkWidget *w,
     } else {
       dragged_module = find_closest_module(bbw, x, y);
 
-      if (0 != dragged_module) {
+      if (dragged_module) {
         gdk_pointer_grab(gtk_widget_get_window(w),
                          TRUE,
                          (GdkEventMask)(GDK_POINTER_MOTION_MASK | GDK_BUTTON_PRESS_MASK),
                          gtk_widget_get_window(w),
-                         0,
+                         nullptr,
                          GDK_CURRENT_TIME);
         treeselect_module(dragged_module);
         dragging = 1;
@@ -1400,7 +1349,7 @@ static gboolean button(GtkWidget *,
 {
   if (event->type == GDK_BUTTON_PRESS && event->button == 1) {
     if (p->getSnode()) {
-      gui_node *gn = static_cast<gui_node *>(
+      auto gn = static_cast<gui_node *>(
                        g_object_get_data((GObject*)p->bbw()->tree, p->getSnode()->name().c_str()));
 
       if (gn) {
@@ -1421,7 +1370,7 @@ static gboolean button(GtkWidget *,
 
   if (event->type == GDK_BUTTON_PRESS && event->button == 2) {
     if (p->getSnode()) {
-      gui_node *gn = static_cast<gui_node *>(
+      auto gn = static_cast<gui_node *>(
                        g_object_get_data((GObject*)p->bbw()->tree,
                                          p->getSnode()->name().c_str()));
 
@@ -1547,7 +1496,7 @@ static Stimulus_Node *select_node_dialog(Breadboard_Window *bbw)
                       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                       nullptr);
   GtkWidget *vbox = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
-  GtkWidget *scrolledwindow = gtk_scrolled_window_new(0, 0);
+  GtkWidget *scrolledwindow = gtk_scrolled_window_new(nullptr, nullptr);
   gtk_box_pack_start(GTK_BOX(vbox), scrolledwindow, TRUE, TRUE, 0);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow),
                                  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -1567,7 +1516,7 @@ static Stimulus_Node *select_node_dialog(Breadboard_Window *bbw)
                    G_CALLBACK(select_node_ok_cb), dialog);
   gtk_widget_show_all(dialog);
   int resp = gtk_dialog_run((GtkDialog*)dialog);
-  Stimulus_Node *snode = static_cast<Stimulus_Node*>(g_object_get_data((GObject*) dialog, "snode"));
+  auto snode = static_cast<Stimulus_Node*>(g_object_get_data((GObject*) dialog, "snode"));
   gtk_widget_destroy(dialog);
 
   if (resp == GTK_RESPONSE_ACCEPT) {
@@ -1585,7 +1534,7 @@ static std::string select_module_dialog(Breadboard_Window *bbw)
                       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                       nullptr);
   GtkWidget *vbox = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
-  GtkWidget *scrolledwindow = gtk_scrolled_window_new(0, 0);
+  GtkWidget *scrolledwindow = gtk_scrolled_window_new(nullptr, nullptr);
   gtk_box_pack_start(GTK_BOX(vbox), scrolledwindow, TRUE, TRUE, 0);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow),
                                  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -1658,28 +1607,23 @@ static std::string select_module_dialog(Breadboard_Window *bbw)
 #else //OLD_MODULE_LIBRARY
   extern ModuleLibraries_t ModuleLibraries;
 
-  for (
-    ModuleLibraries_t::iterator mti = ModuleLibraries.begin();
-    mti != ModuleLibraries.end();
-    ++mti) {
-    const char *text[3];
-    Module_Types * (*get_mod_list)(void) = mti->second->mod_list();
+  for (const auto &mti : ModuleLibraries) {
+    Module_Types * (*get_mod_list)() = mti.second->mod_list();
     Module_Types *pLibModList = get_mod_list();
-    text[2] = mti->second->user_name().c_str();
+    std::string text_2 = mti.second->user_name();
 
-    if (pLibModList)
+    if (pLibModList) {
       for (Module_Types *pModTypes = pLibModList;  pModTypes->names[0]; pModTypes++) {
         GtkTreeIter iter;
-        text[0] = pModTypes->names[0];
-        text[1] = pModTypes->names[1];
         gtk_list_store_append(list_store, &iter);
         gtk_list_store_set(list_store, &iter,
-                           0, text[0],
-                           1, text[1],
-                           2, text[2],
-                           3, text[0],
+                           0, pModTypes->names[0],
+                           1, pModTypes->names[1],
+                           2, text_2.c_str(),
+                           3, pModTypes->names[0],
                            -1);
       }
+    }
   }
 
 #endif
@@ -1708,66 +1652,11 @@ static std::string select_module_dialog(Breadboard_Window *bbw)
 }
 
 
-#if 0
-// Display a file in a text widget.
-static void text_dialog(const char *filename)
-{
-  static GtkWidget *dialog;
-  GtkWidget *cancelbutton;
-  GtkWidget *vbox;
-  GtkWidget *scrolledwindow;
-  GtkWidget *text;
-  char string[STRING_SIZE];
-  FILE *fi = fopen(filename, "r");
-
-  if (fi == 0) {
-    return;
-  }
-
-  if (dialog != 0) {
-    gtk_widget_destroy(dialog);
-  }
-
-  // Build window
-  dialog = gtk_dialog_new();
-  gtk_window_set_title(GTK_WINDOW(dialog), filename);
-  vbox = GTK_DIALOG(dialog)->vbox;
-  scrolledwindow = gtk_scrolled_window_new(0, 0);
-  gtk_widget_show(scrolledwindow);
-  gtk_box_pack_start(GTK_BOX(vbox), scrolledwindow, TRUE, TRUE, 0);
-  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-  text = gtk_text_new(0, 0);
-  gtk_container_add(GTK_CONTAINER(scrolledwindow), text);
-  gtk_widget_show(text);
-  cancelbutton = gtk_button_new_with_label("Ok");
-  gtk_widget_show(cancelbutton);
-  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->action_area), cancelbutton, FALSE, FALSE, 0);
-  gtk_signal_connect_object(GTK_OBJECT(cancelbutton), "clicked",
-                            GTK_SIGNAL_FUNC(gtk_widget_hide), GTK_OBJECT(dialog));
-  gtk_window_set_default_size(GTK_WINDOW(dialog), 400, 400);
-
-  while (fgets(string, sizeof(string), fi) != 0) {
-    gtk_text_insert(GTK_TEXT(text),
-                    0,
-                    0,
-                    0,
-                    string,
-                    strlen(string));
-  }
-
-  fclose(fi);
-  gtk_widget_show(dialog);
-  return;
-}
-#endif
-
-
 static void stimulus_add_node(GtkWidget *, Breadboard_Window *bbw)
 {
-  Stimulus_Node *node;
-  node = select_node_dialog(bbw);
+  Stimulus_Node *node = select_node_dialog(bbw);
 
-  if (node != 0 && bbw->selected_pin != 0) {
+  if (node && bbw->selected_pin) {
     node->attach_stimulus(bbw->selected_pin->getIOpin());
     // Update stimulus frame
     treeselect_stimulus(bbw->selected_pin);
@@ -1800,18 +1689,18 @@ static void add_module(GtkWidget *, Breadboard_Window *bbw)
   std::string module_type = select_module_dialog(bbw);
 
   if (!module_type.empty()) {
-    std::string module_name = gui_get_string("Module name", module_type.c_str());
+    std::string name = gui_get_string("Module name", module_type.c_str());
     grab_next_module = 1;
 
-    if (!module_name.empty())
+    if (!name.empty())
 #ifdef OLD_MODULE_LIBRARY
-      ModuleLibrary::NewObject(module_type.c_str(), module_name.c_str());
+      ModuleLibrary::NewObject(module_type.c_str(), name.c_str());
 
 #else
     {
-      if (!ModuleLibrary::InstantiateObject(module_type, module_name))
+      if (!ModuleLibrary::InstantiateObject(module_type, name))
         fprintf(stderr, "Module load of %s %s failed\n",
-                module_type.c_str(), module_name.c_str());
+                module_type.c_str(), name.c_str());
     }
 #endif
   }
@@ -1820,11 +1709,11 @@ static void add_module(GtkWidget *, Breadboard_Window *bbw)
 
 void Breadboard_Window::remove_module(GtkWidget *, Breadboard_Window *bbw)
 {
-  delete (bbw->selected_module->module());
+  delete bbw->selected_module->module();
   // FIXME the rest should be as callback from src
   // Remove pins
   std::vector<GuiPin *> *e = bbw->selected_module->pins();
-  std::vector<GuiPin *>::iterator pin_iter = e->begin();
+  auto pin_iter = e->begin();
 
   for (; pin_iter != e->end(); ++pin_iter) {
     GuiPin *pin = *pin_iter;
@@ -1851,8 +1740,7 @@ void Breadboard_Window::remove_module(GtkWidget *, Breadboard_Window *bbw)
   gtk_tree_store_set((GtkTreeStore*) model, &iter, 1, nullptr, -1);
   gtk_tree_store_remove((GtkTreeStore*) model, &iter);
   // Remove from local list of modules
-  std::vector<GuiModule *>::iterator mi =
-    std::find(bbw->modules.begin(), bbw->modules.end(), bbw->selected_module);
+  auto mi = std::find(bbw->modules.begin(), bbw->modules.end(), bbw->selected_module);
 
   if (mi != bbw->modules.end()) {
     bbw->modules.erase(mi);
@@ -1934,7 +1822,7 @@ static FILE *fo;
 
 static void OneAttribute(const SymbolEntry_t &sym)
 {
-  Value *pVal = dynamic_cast<Value *>(sym.second);
+  auto pVal = dynamic_cast<Value *>(sym.second);
 
   if (pVal && fo) {
     // read attributes and add to clist
@@ -2002,24 +1890,18 @@ static void save_stc(GtkWidget *, Breadboard_Window *bbw)
 #else
   extern ModuleLibraries_t ModuleLibraries;
 
-  for (
-    ModuleLibraries_t::iterator mti = ModuleLibraries.begin();
-    mti != ModuleLibraries.end();
-    ++mti) {
-    fprintf(fo, "module library %s\n", mti->second->user_name().c_str());
+  for (const auto &mti : ModuleLibraries) {
+    fprintf(fo, "module library %s\n", mti.second->user_name().c_str());
   }
 
 #endif
   // Save modules
   fprintf(fo, "\n\n# Modules:\n");
-  std::vector<GuiModule *>::iterator module_iterator = bbw->modules.begin();
 
-  for (; module_iterator != bbw->modules.end(); ++module_iterator) {
-    GuiModule *p = *module_iterator;
+  for (const auto &p : bbw->modules) {
     m = p->module();
     SymbolTable_t *st = &m->getSymbolTable();
-    Processor *cpu;
-    cpu = dynamic_cast<Processor*>(m);
+    auto cpu = dynamic_cast<Processor*>(m);
 
     if (cpu == nullptr) {
       // Module, not a processor, so add the load command
@@ -2035,17 +1917,14 @@ static void save_stc(GtkWidget *, Breadboard_Window *bbw)
 
   // Save nodes and connections
   fprintf(fo, "\n\n# Connections:\n");
-  std::vector<Stimulus_Node *>::iterator list = bbw->nodes.begin();
 
-  for (; list != bbw->nodes.end(); ++list) {
-    Stimulus_Node *node = *list;
-    stimulus *stimulus;
+  for (const auto &node : bbw->nodes) {
     fprintf(fo, "node %s\n", node->name().c_str());
 
-    if (node->stimuli != 0) {
+    if (node->stimuli) {
       fprintf(fo, "attach %s", node->name().c_str());
 
-      for (stimulus = node->stimuli; stimulus; stimulus = stimulus->next) {
+      for (stimulus *stimulus = node->stimuli; stimulus; stimulus = stimulus->next) {
         fprintf(fo, " %s", stim_full_name(stimulus));
       }
     }
@@ -2056,7 +1935,6 @@ static void save_stc(GtkWidget *, Breadboard_Window *bbw)
   fprintf(fo, "\n\n# End.\n");
   fclose(fo);
   fo = nullptr;
-  //text_dialog(filename);
 }
 
 
@@ -2097,12 +1975,7 @@ static void trace_all(GtkWidget *, Breadboard_Window *bbw)
 
   bbw->draw_nodes();
 
-  if (!did_work) {
-    gtk_label_set_text(GTK_LABEL(bbw->status_line), "Cannot trace all nodes");
-
-  } else {
-    gtk_label_set_text(GTK_LABEL(bbw->status_line), "");
-  }
+  gtk_label_set_text(GTK_LABEL(bbw->status_line), did_work ? "" : "Cannot trace all nodes");
 
   all_trace = 1;
 
@@ -2119,11 +1992,6 @@ GuiBreadBoardObject::GuiBreadBoardObject(Breadboard_Window *bbw, int x, int y)
 }
 
 
-GuiBreadBoardObject::~GuiBreadBoardObject()
-{
-}
-
-
 void GuiBreadBoardObject::SetPosition(int x, int y)
 {
   m_x = x;
@@ -2351,13 +2219,13 @@ void GuiPin::DrawLabel(cairo_t *cr)
     return;
   }
 
-  const char *name = iopin->GUIname().empty()
-                     ? iopin->name().c_str() : iopin->GUIname().c_str();
+  const std::string &name = iopin->GUIname().empty()
+                     ? iopin->name() : iopin->GUIname();
 
-  if (*name) {
+  if (!name.empty()) {
     PangoLayout *layout = pango_cairo_create_layout(cr);
     pango_layout_set_font_description(layout, m_bbw->pinnamefont);
-    pango_layout_set_text(layout, name, -1);
+    pango_layout_set_text(layout, name.c_str(), -1);
     pango_cairo_update_layout(cr, layout);
     cairo_move_to(cr, m_label_x,
                   m_label_y - pango_layout_get_baseline(layout) / PANGO_SCALE);
@@ -2409,10 +2277,8 @@ gboolean GuiModule::module_expose(GtkWidget *widget,
 {
   cairo_t *cr = gdk_cairo_create(gtk_widget_get_window(widget));
   p->DrawCaseOutline(cr);
-  std::vector<GuiPin *>::iterator pin_iter = p->m_pins.begin();
 
-  for (; pin_iter != p->m_pins.end(); ++pin_iter) {
-    GuiPin *pin = *pin_iter;
+  for (const auto &pin : p->m_pins) {
     pin->DrawLabel(cr);
   }
 
@@ -2440,23 +2306,19 @@ void GuiModule::Update()
 
   // Delete the static module pixmap if there is no widget
   // in the module.
-  if (m_module->get_widget() == 0) {
+  if (m_module->get_widget() == nullptr) {
     gtk_widget_destroy(m_pinLabel_widget);
   }
 
   // Delete the pins
-  std::vector<GuiPin *>::iterator pin_iter = m_pins.begin();
-
-  for (; pin_iter != m_pins.end(); ++pin_iter) {
-    GuiPin *pin = *pin_iter;
+  for (const auto &pin : m_pins) {
     pin->Destroy();
   }
 
   // Destroy name widget
   delete m_name_widget;
   // Remove module from list
-  std::vector<GuiModule *>::iterator iter =
-    std::find(m_bbw->modules.begin(), m_bbw->modules.end(), this);
+  auto iter = std::find(m_bbw->modules.begin(), m_bbw->modules.end(), this);
 
   if (iter != m_bbw->modules.end()) {
     m_bbw->modules.erase(iter);
@@ -2471,10 +2333,8 @@ void GuiModule::Update()
 void GuiModule::UpdatePins()
 {
   bool change = false;
-  std::vector<GuiPin *>::iterator pin_iter = m_pins.begin();
 
-  for (; pin_iter != m_pins.end(); ++pin_iter) {
-    GuiPin *pin = *pin_iter;
+  for (const auto &pin : m_pins) {
     change |= pin->DrawGUIlabel();
     pin->Update();
   }
@@ -2492,7 +2352,7 @@ protected:
   Breadboard_Window *bbw;
 public:
   PositionAttribute(Breadboard_Window *_bbw, const char *n, double v);
-  void set(Value *v);
+  void set(Value *v) override;
 };
 
 
@@ -2532,7 +2392,7 @@ static float hackPackageHeight = 0.0;
 void GuiModule::AddPin(unsigned int pin_number)
 {
   IOPIN *iopin = m_module->get_pin(pin_number);
-  BreadBoardXREF *cross_reference = 0;
+  BreadBoardXREF *cross_reference = nullptr;
 
   if (iopin) {
     // Create xref
@@ -2542,7 +2402,7 @@ void GuiModule::AddPin(unsigned int pin_number)
     iopin->add_xref(cross_reference);
   }
 
-  GuiPin *pin = new GuiPin(m_bbw, this, m_module->package, pin_number);
+  auto pin = new GuiPin(m_bbw, this, m_module->package, pin_number);
   pin->addXref(cross_reference);
   m_pins.push_back(pin);
 }
@@ -2593,8 +2453,7 @@ void GuiModule::AddPinGeometry(GuiPin *pin)
       break;
 
     default:
-      printf("################### Error:\n");
-      printf("Undefined orientation.\n");
+      printf("################### Error:\nUndefined orientation.\n");
       assert(0);
     }
 
@@ -2642,11 +2501,7 @@ void GuiModule::AddPinGeometry(GuiPin *pin)
 //------------------------------------------------------------------------
 void GuiModule::Build()
 {
-  if (m_bIsBuilt || !m_bbw) {
-    return;
-  }
-
-  if (!m_bbw->enabled) {
+  if (m_bIsBuilt || !m_bbw || !m_bbw->enabled) {
     return;
   }
 
@@ -2736,14 +2591,12 @@ void GuiModule::Build()
   // Create xref
   cross_reference = new BreadBoardXREF();
   cross_reference->parent_window = (gpointer) m_bbw;
-  cross_reference->data =  0;
+  cross_reference->data = nullptr;
   m_module->xref->_add(cross_reference);
   // Create name_widget
   m_name_widget = new BB_ModuleLabel(m_module->name(), m_bbw->pinnamefont);
-  std::vector<GuiPin *>::iterator pin_iter = m_pins.begin();
 
-  for (; pin_iter != m_pins.end(); ++pin_iter) {
-    GuiPin *pin = *pin_iter;
+  for (auto &pin : m_pins) {
     AddPinGeometry(pin);
     gtk_layout_put(GTK_LAYOUT(m_bbw->layout), pin->m_pinDrawingArea, 0, 0);
     // Add pin to tree
@@ -2777,8 +2630,8 @@ void GuiModule::Build()
 //========================================================================
 
 GuiModule::GuiModule(Module *_module, Breadboard_Window *_bbw)
-  : GuiBreadBoardObject(_bbw, 0, 0), m_module(_module), m_module_widget(0),
-    m_pinLabel_widget(0), m_module_x(0), m_module_y(0), m_name_widget(0),
+  : GuiBreadBoardObject(_bbw, 0, 0), m_module(_module), m_module_widget(nullptr),
+    m_pinLabel_widget(nullptr), m_module_x(0), m_module_y(0), m_name_widget(nullptr),
     m_pin_count(0)
 {
   m_width = 0;
@@ -2842,11 +2695,7 @@ void Breadboard_Window::Update()
     return;
   }
 
-  std::vector<GuiModule *>::iterator iter = modules.begin();
-
-  for (; iter != modules.end(); ++iter) {
-    GuiModule *p = *iter;
-
+  for (const auto &p: modules) {
     if (p->IsBuilt()) {
       // Check if module has changed number of pins
       if (p->pin_count() != p->module()->get_pin_count())
@@ -2897,7 +2746,7 @@ void Breadboard_Window::NewProcessor(GUI_Processor *)
 /* When a module is created */
 void Breadboard_Window::NewModule(Module *module)
 {
-  GuiModule *p = new GuiModule(module, this);
+  auto p = new GuiModule(module, this);
 
   if (!enabled) {
     return;
@@ -2924,7 +2773,7 @@ void Breadboard_Window::NodeConfigurationChanged(Stimulus_Node *node)
     return;
   }
 
-  gui_node *gn = static_cast<gui_node*>(g_object_get_data(G_OBJECT(tree), node->name().c_str()));
+  auto gn = static_cast<gui_node*>(g_object_get_data(G_OBJECT(tree), node->name().c_str()));
   GtkTreeStore *tree_store;
   g_object_get(tree, "model", &tree_store, nullptr);
 
@@ -2963,21 +2812,17 @@ GtkWidget *Breadboard_Window::bb_hbox()
 GtkWidget* Breadboard_Window::add_button(const char *label, GCallback f,
     GtkWidget *box)
 {
-  GtkWidget *button = gtk_button_new_with_label(label);
-  gtk_widget_show(button);
-  gtk_box_pack_start(GTK_BOX(box), button, FALSE, FALSE, 0);
-  g_signal_connect(button, "clicked", G_CALLBACK(f), this);
-  return button;
+  GtkWidget *btn = gtk_button_new_with_label(label);
+  gtk_widget_show(btn);
+  gtk_box_pack_start(GTK_BOX(box), btn, FALSE, FALSE, 0);
+  g_signal_connect(btn, "clicked", G_CALLBACK(f), this);
+  return btn;
 }
 
 
 void Breadboard_Window::Build()
 {
-  if (bIsBuilt) {
-    return;
-  }
-
-  if (!enabled) {
+  if (bIsBuilt || !enabled) {
     return;
   }
 
@@ -3032,7 +2877,7 @@ void Breadboard_Window::Build()
   gtk_paned_pack1(GTK_PANED(hpaned1), vbox9, FALSE, TRUE);
   vbox13 = bb_vbox();
   gtk_box_pack_start(GTK_BOX(vbox9), vbox13, TRUE, TRUE, 2);
-  scrolledwindow4 = gtk_scrolled_window_new(0, 0);
+  scrolledwindow4 = gtk_scrolled_window_new(nullptr, nullptr);
   gtk_widget_show(scrolledwindow4);
   gtk_box_pack_start(GTK_BOX(vbox13), scrolledwindow4, TRUE, TRUE, 0);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow4),
@@ -3068,11 +2913,11 @@ void Breadboard_Window::Build()
   vbox11 = gtk_vbox_new(FALSE, 0);
   gtk_widget_show(vbox11);
   gtk_container_add(GTK_CONTAINER(node_frame), vbox11);
-  scrolledwindow2 = gtk_scrolled_window_new(0, 0);
+  scrolledwindow2 = gtk_scrolled_window_new(nullptr, nullptr);
   gtk_widget_show(scrolledwindow2);
   gtk_box_pack_start(GTK_BOX(vbox11), scrolledwindow2, TRUE, TRUE, 0);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow2), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-  viewport7 = gtk_viewport_new(0, 0);
+  viewport7 = gtk_viewport_new(nullptr, nullptr);
   gtk_widget_show(viewport7);
   gtk_container_add(GTK_CONTAINER(scrolledwindow2), viewport7);
   renderer = gtk_cell_renderer_text_new();
@@ -3107,11 +2952,11 @@ void Breadboard_Window::Build()
   vbox10 = gtk_vbox_new(FALSE, 0);
   gtk_widget_show(vbox10);
   gtk_container_add(GTK_CONTAINER(module_frame), vbox10);
-  scrolledwindow1 = gtk_scrolled_window_new(0, 0);
+  scrolledwindow1 = gtk_scrolled_window_new(nullptr, nullptr);
   gtk_widget_show(scrolledwindow1);
   gtk_box_pack_start(GTK_BOX(vbox10), scrolledwindow1, TRUE, TRUE, 0);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow1), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-  viewport6 = gtk_viewport_new(0, 0);
+  viewport6 = gtk_viewport_new(nullptr, nullptr);
   gtk_widget_show(viewport6);
   gtk_container_add(GTK_CONTAINER(scrolledwindow1), viewport6);
   renderer = gtk_cell_renderer_text_new();
@@ -3141,7 +2986,7 @@ void Breadboard_Window::Build()
   gtk_box_pack_start(GTK_BOX(vbox10), hbox14, FALSE, FALSE, 0);
   add_button("Remove module", G_CALLBACK(remove_module), hbox14);
   add_button("Save Configuration ...", G_CALLBACK(save_stc), vbox9);
-  scrolledwindow5 = gtk_scrolled_window_new(0, 0);
+  scrolledwindow5 = gtk_scrolled_window_new(nullptr, nullptr);
   gtk_widget_show(scrolledwindow5);
   gtk_paned_pack2(GTK_PANED(hpaned1), scrolledwindow5, TRUE, TRUE);
   vadj = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(scrolledwindow5));
@@ -3192,9 +3037,9 @@ void Breadboard_Window::Build()
     pinspacing += ROUTE_RES;
   }
 
-  gui_node *gn = new gui_node;
+  auto gn = new gui_node;
   gn->bbw = this;
-  gn->node = 0; // indicates that this is the root node.
+  gn->node = nullptr; // indicates that this is the root node.
   GtkTreeIter iter;
   gtk_tree_store_append(tree_store, &iter, nullptr);
   gtk_tree_store_set(tree_store, &iter,
@@ -3203,42 +3048,17 @@ void Breadboard_Window::Build()
                      -1);
   node_iter = &iter;
   // Handle nodes added before breadboard GUI enabled
-  std::vector<Stimulus_Node *>::iterator list = nodes.begin();
 
-  for (; list != nodes.end(); ++list) {
-    NodeConfigurationChanged(*list);
+  for (auto &list : nodes) {
+    Breadboard_Window::NodeConfigurationChanged(list);
   }
 
   bIsBuilt = true;
   UpdateMenuItem();
   draw_nodes();
-  // cout << "FIXME gui_breadboard.cc " << __FUNCTION__ << endl;
-  /*
-  // Loop module list
-  Symbol_Table::module_symbol_iterator mi = get_symbol_table().beginModuleSymbol();
-  Symbol_Table::module_symbol_iterator itModEnd = get_symbol_table().endModuleSymbol();
-  for(mi = get_symbol_table().beginModuleSymbol();
-      mi!=itModEnd;
-      mi++)
-  {
-        NewModule((*mi)->get_module());
-  }
 
-  // Loop node list
-  Symbol_Table &ST = get_symbol_table();
-  Symbol_Table::node_symbol_iterator it;
-  Symbol_Table::node_symbol_iterator itEnd = ST.endNodeSymbol();
-  for(it = ST.beginNodeSymbol(); it != itEnd; it++) {
-    Stimulus_Node *node = (*it)->getNode();
-    assert(node != NULL);
-    if(node != NULL) {
-        NodeConfigurationChanged(node);
-    }
-  }
-  */
-  //gtk_widget_show_all(window);
   gtk_widget_show(window);
-  Update();
+  Breadboard_Window::Update();
 }
 
 
@@ -3253,10 +3073,10 @@ Breadboard_Window::~Breadboard_Window()
 
 Breadboard_Window::Breadboard_Window(GUI_Processor *_gp)
   : GUI_Object("pinout"),
-    pinstatefont(0), pinnamefont(0), node_clist(0),
-    stimulus_settings_label(0), stimulus_add_node_button(0),
-    hadj(0), vadj(0), node_iter(0),
-    selected_pin(0), selected_node(0), selected_module(0)
+    pinstatefont(nullptr), pinnamefont(nullptr), node_clist(nullptr),
+    stimulus_settings_label(nullptr), stimulus_add_node_button(nullptr),
+    hadj(nullptr), vadj(nullptr), node_iter(nullptr),
+    selected_pin(nullptr), selected_node(nullptr), selected_module(nullptr)
 {
   menu = "/menu/Windows/Breadboard";
   mask_matrix = nullptr;
@@ -3264,7 +3084,7 @@ Breadboard_Window::Breadboard_Window(GUI_Processor *_gp)
   gp = _gp;
 
   if (enabled) {
-    Build();
+    Breadboard_Window::Build();
   }
 }
 
