@@ -22,6 +22,11 @@ Boston, MA 02111-1307, USA.  */
 #ifndef GUI_GUI_BREADBOARD_H_
 #define GUI_GUI_BREADBOARD_H_
 
+#include <cairo.h>
+#include <gdk/gdk.h>
+#include <glib.h>
+#include <gtk/gtk.h>
+
 #include "../src/packages.h"
 #include "../src/stimuli.h"
 #include "gui_object.h"
@@ -72,7 +77,7 @@ class GuiModule;
 class GuiBreadBoardObject {
 public:
   GuiBreadBoardObject(Breadboard_Window *, int x, int y);
-  virtual ~GuiBreadBoardObject();
+  virtual ~GuiBreadBoardObject() = default;
 
   virtual void Draw() = 0;
   virtual void Update() = 0;
@@ -132,9 +137,9 @@ public:
   void toggleDirection();
 
   void addXref(CrossReferenceToGUI *);
-  virtual void Draw();
-  virtual void Update();
-  virtual void Destroy();
+  void Draw() override;
+  void Update() override;
+  void Destroy() override;
 
   void SetModulePosition(int x, int y);
   int module_x()
@@ -240,11 +245,11 @@ public:
   void GetPosition(int &x, int &y);
   double Distance(int x, int y);
 
-  virtual void Update();
+  void Update() override;
   virtual void UpdatePins();
   virtual void Build();
-  virtual void Draw();
-  virtual void Destroy();
+  void Draw() override;
+  void Destroy() override;
   virtual void DrawCaseOutline(cairo_t *);
 
   virtual void AddPin(unsigned int);
@@ -298,7 +303,7 @@ private:
 class GuiDipModule : public GuiModule {
 public:
   GuiDipModule(Module *, Breadboard_Window *);
-  virtual void DrawCaseOutline(cairo_t *);
+  void DrawCaseOutline(cairo_t *) override;
 };
 
 
@@ -350,9 +355,9 @@ public:
   explicit Breadboard_Window(GUI_Processor *gp);
   virtual ~Breadboard_Window();
 
-  virtual void Build();
-  virtual void NewProcessor(GUI_Processor *gp);
-  virtual void Update();
+  void Build() override;
+  void NewProcessor(GUI_Processor *gp) override;
+  void Update() override;
   virtual void NewModule(Module *module);
   virtual void NodeConfigurationChanged(Stimulus_Node *node);
 
