@@ -1,5 +1,5 @@
-#ifndef __GUI_INTERFACE_H__
-#define __GUI_INTERFACE_H__
+#ifndef GUI_GUI_INTERFACE_H_
+#define GUI_GUI_INTERFACE_H_
 
 class GUI_Processor;
 
@@ -9,4 +9,4 @@ void gui_new_source(unsigned int pic_id);
 void update_register(unsigned int reg_number);
 void update_program_memory(GUI_Processor *gp, unsigned int reg_number);
 
-#endif /* __GUI_INTERFACE_H__ */
+#endif // GUI_GUI_INTERFACE_H_
