@@ -25,8 +25,10 @@ Boston, MA 02111-1307, USA.  */
 #ifdef HAVE_GUI
 
 #include <gtk/gtk.h>
+#include <glib.h>
 
 #include "../src/gpsim_interface.h"
+#include "../src/xref.h"
 
 #include "gui.h"
 #include "gui_breadboard.h"
@@ -49,6 +51,11 @@ Boston, MA 02111-1307, USA.  */
 #include "settings_reg.h"
 #endif
 
+class Module;
+class Processor;
+class Settings;
+class Stimulus_Node;
+
 extern int gui_animate_delay; // in milliseconds
 
 /*
@@ -92,26 +99,23 @@ private:
   GUI_Processor *gp;
 
 public:
-
-  virtual void UpdateObject (gpointer xref, int new_value);
-  virtual void RemoveObject (gpointer xref);
-  virtual void SimulationHasStopped (gpointer object);
-  virtual void NewProcessor (Processor *);
-  virtual void NewModule (Module *module);
-  virtual void NodeConfigurationChanged (Stimulus_Node *node);
-  virtual void NewProgram  (Processor *);
-  virtual void Update  (gpointer object);
-
+  explicit GUI_Interface(GUI_Processor *_gp);
   virtual ~GUI_Interface();
 
-  explicit GUI_Interface(GUI_Processor *_gp);
+  void UpdateObject(gpointer xref, int new_value) override;
+  void RemoveObject(gpointer xref) override;
+  void SimulationHasStopped(gpointer object) override;
+  void NewProcessor(Processor *) override;
+  void NewModule(Module *module) override;
+  void NodeConfigurationChanged(Stimulus_Node *node) override;
+  void NewProgram(Processor *) override;
+  void Update(gpointer object) override;
 };
 
 
 GUI_Interface::GUI_Interface(GUI_Processor *_gp)
-  : Interface ( (gpointer *) _gp)
+  : Interface ( (gpointer *) _gp), gp(_gp)
 {
-  gp = _gp;
 }
 
 GUI_Interface::~GUI_Interface()
@@ -146,7 +150,7 @@ GUI_Interface::~GUI_Interface()
 
 void GUI_Interface::UpdateObject(gpointer gui_xref, int new_value)
 {
-  CrossReferenceToGUI  *xref = static_cast<CrossReferenceToGUI *>(gui_xref);
+  CrossReferenceToGUI *xref = static_cast<CrossReferenceToGUI *>(gui_xref);
   xref->Update(new_value);
 }
 
@@ -157,7 +161,7 @@ void GUI_Interface::UpdateObject(gpointer gui_xref, int new_value)
 
 void GUI_Interface::RemoveObject(gpointer gui_xref)
 {
-  CrossReferenceToGUI  *xref = static_cast<CrossReferenceToGUI *>(gui_xref);
+  CrossReferenceToGUI *xref = static_cast<CrossReferenceToGUI *>(gui_xref);
   xref->Remove();
 }
 
@@ -211,7 +215,7 @@ void GUI_Interface::NewProcessor(Processor *new_cpu)
 {
   // Create a gui representation of the new processor
 
-  if(gp) {
+  if (gp) {
     gp->SetCPU(new_cpu);
 
     gp->regwin_ram->NewProcessor(gp);
@@ -237,7 +241,7 @@ void GUI_Interface::NewProcessor(Processor *new_cpu)
 void GUI_Interface::NewModule(Module *module)
 {
   // FIX ME - need to search for *p in the gp list...
-  if(gp)
+  if (gp)
     gp->breadboard_window->NewModule(module);
 }
 
@@ -247,7 +251,7 @@ void GUI_Interface::NewModule(Module *module)
 void GUI_Interface::NodeConfigurationChanged(Stimulus_Node *node)
 {
   // FIX ME - need to search for *p in the gp list...
-  if(gp)
+  if (gp)
     gp->breadboard_window->NodeConfigurationChanged(node);
 }
 
