@@ -23,6 +23,7 @@ Boston, MA 02111-1307, USA.  */
 #ifdef HAVE_GUI
 
 #include <gtk/gtk.h>
+#include <glib-object.h>
 #include <glib.h>
 
 #include "gui.h"
@@ -59,7 +60,7 @@ int config_remove(const char *module, const char *entry)
 }
 
 GUI_Object::GUI_Object(const std::string &p_name)
-  : gp(0), menu(0), x(0), y(0), width(100), height(100),
+  : gp(nullptr), menu(nullptr), x(0), y(0), width(100), height(100),
     enabled(FALSE), bIsBuilt(false), m_name(p_name)
 {
   window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
