@@ -19,8 +19,8 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __GUI_OBJECT_H__
-#define __GUI_OBJECT_H__
+#ifndef GUI_GUI_OBJECT_H_
+#define GUI_GUI_OBJECT_H_
 
 #include <gdk/gdk.h>
 #include <glib.h>
@@ -87,6 +87,4 @@ private:
   std::string m_name;
 };
 
-
-
-#endif  // __GUI_OBJECT_H__
+#endif  // GUI_GUI_OBJECT_H_
