@@ -22,9 +22,7 @@ Boston, MA 02111-1307, USA.  */
 #include "../config.h"
 #ifdef HAVE_GUI
 
-#include <gtk/gtk.h>
-
-#include "gui.h"
+#include "../src/processor.h"
 #include "gui_breadboard.h"
 #include "gui_profile.h"
 #include "gui_register.h"
@@ -42,22 +40,23 @@ Boston, MA 02111-1307, USA.  */
 void create_dispatcher ();
 
 GUI_Processor::GUI_Processor()
-  : source_window(0), cpu(0), m_pGUIRamRegisters(0), m_pGUIEEPromRegisters(0)
+  : source_window(nullptr), cpu(nullptr),
+    m_pGUIRamRegisters(nullptr), m_pGUIEEPromRegisters(nullptr)
 {
   create_dispatcher();
 
-  regwin_ram =  new  RAM_RegisterWindow(this);
-  regwin_eeprom = new  EEPROM_RegisterWindow(this);
-  program_memory = new  SourceBrowserOpcode_Window(this);
-  source_browser = new  SourceBrowserParent_Window(this);
-  symbol_window = new  Symbol_Window(this);
-  watch_window = new  Watch_Window(this);
-  stack_window = new  Stack_Window(this);
-  breadboard_window = new  Breadboard_Window(this);
-  trace_window = new  Trace_Window(this);
-  profile_window = new  Profile_Window(this);
-  stopwatch_window = new  StopWatch_Window(this);
-  scope_window = new  Scope_Window(this);
+  regwin_ram =  new RAM_RegisterWindow(this);
+  regwin_eeprom = new EEPROM_RegisterWindow(this);
+  program_memory = new SourceBrowserOpcode_Window(this);
+  source_browser = new SourceBrowserParent_Window(this);
+  symbol_window = new Symbol_Window(this);
+  watch_window = new Watch_Window(this);
+  stack_window = new Stack_Window(this);
+  breadboard_window = new Breadboard_Window(this);
+  trace_window = new Trace_Window(this);
+  profile_window = new Profile_Window(this);
+  stopwatch_window = new StopWatch_Window(this);
+  scope_window = new Scope_Window(this);
 }
 
 void GUI_Processor::SetCPU(Processor *new_cpu)
