@@ -19,8 +19,8 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __GUI_PROCESSOR_H__
-#define __GUI_PROCESSOR_H__
+#ifndef GUI_GUI_PROCESSOR_H_
+#define GUI_GUI_PROCESSOR_H_
 
 #define NEW_SOURCE_BROWSER
 
@@ -48,9 +48,9 @@ class GUIRegisterList;
 
 class GUI_Processor {
  public:
-
   GUI_Processor();
-
+  GUI_Processor(const GUI_Processor &) = delete;  // Mark non-copiable
+  GUI_Processor& operator =(const GUI_Processor &) = delete;
   void SetCPU(Processor *new_cpu);
 
   RAM_RegisterWindow *regwin_ram;
@@ -72,10 +72,8 @@ class GUI_Processor {
 
   GUIRegisterList * m_pGUIRamRegisters;
   GUIRegisterList * m_pGUIEEPromRegisters;
-private:
-  GUI_Processor(const GUI_Processor&);  // Mark non-copiable
 };
 
 
-#endif //__GUI_PROCESSOR_H__
+#endif // GUI_GUI_PROCESSOR_H_
 
