@@ -28,16 +28,23 @@ Boston, MA 02111-1307, USA.  */
 #ifdef HAVE_GUI
 
 #include <gtk/gtk.h>
-#include <gdk/gdk.h>
-#include <gdk/gdkkeysyms.h>
 #include <glib.h>
+#include <glib-object.h>
+
 #include <math.h>
 
 #include <cassert>
-#include <cstdio>
 #include <cstdlib>
+#include <string>
 
+#include "../src/gpsim_time.h"
+#include "../src/pic-instructions.h"
+#include "../src/processor.h"
+#include "../src/registers.h"
+#include "../src/trace.h"
+#include "../src/trigger.h"
 #include "gui.h"
+#include "gui_processor.h"
 #include "gui_profile.h"
 
 enum {
@@ -70,32 +77,32 @@ enum {
 
 gint histogram_list_compare_func_cycles(gconstpointer a, gconstpointer b)
 {
-    const struct cycle_histogram_counter *h1=(struct cycle_histogram_counter*)a;
-    const struct cycle_histogram_counter *h2=(struct cycle_histogram_counter*)b;
+    const struct cycle_histogram_counter *h1 = (struct cycle_histogram_counter*)a;
+    const struct cycle_histogram_counter *h2 = (struct cycle_histogram_counter*)b;
 
-    if(h1->histo_cycles > h2->histo_cycles)
+    if (h1->histo_cycles > h2->histo_cycles)
         return 1;
-    if(h1->histo_cycles == h2->histo_cycles)
+    if (h1->histo_cycles == h2->histo_cycles)
         return 0;
     return -1;
 }
 
 gint histogram_list_compare_func(gconstpointer a, gconstpointer b)
 {
-    const struct cycle_histogram_counter *h1=(struct cycle_histogram_counter*)a;
-    const struct cycle_histogram_counter *h2=(struct cycle_histogram_counter*)b;
+    const struct cycle_histogram_counter *h1 = (struct cycle_histogram_counter*)a;
+    const struct cycle_histogram_counter *h2 = (struct cycle_histogram_counter*)b;
 
-    if(h1->start_address > h2->start_address)
+    if (h1->start_address > h2->start_address)
         return 1;
-    if(h1->start_address == h2->start_address)
+    if (h1->start_address == h2->start_address)
     {
-        if(h1->stop_address > h2->stop_address)
+        if (h1->stop_address > h2->stop_address)
             return 1;
-        if(h1->stop_address == h2->stop_address)
+        if (h1->stop_address == h2->stop_address)
         {
-            if(h1->histo_cycles*h1->count > h2->histo_cycles*h2->count)
+            if (h1->histo_cycles * h1->count > h2->histo_cycles * h2->count)
                 return 1;
-            if(h1->histo_cycles*h1->count == h2->histo_cycles*h2->count)
+            if (h1->histo_cycles * h1->count == h2->histo_cycles * h2->count)
                 return 0;
         }
     }
@@ -104,90 +111,89 @@ gint histogram_list_compare_func(gconstpointer a, gconstpointer b)
 
 double calculate_median(GList *start, GList *stop)
 {
-    GList *sorted_list=0;
+    GList *sorted_list = nullptr;
 
     struct cycle_histogram_counter *chc_start, *chc_stop;//, *chc_result;
 //    GList *result;
-    int count_sum=0;
+    int count_sum = 0;
 
-    if(start==0)
+    if (!start)
         return -4.2;
 
-    if(stop==0)
+    if (!stop)
     {
-        stop=start;
-        while(stop->next!=0)
-            stop=stop->next;
+        stop = start;
+        while (stop->next)
+            stop = stop->next;
     }
 
     // Copy list and sort it on cycles
-    while(start!=stop)
+    while (start != stop)
     {
-        sorted_list=g_list_append(sorted_list,start->data);
-        start=start->next;
+        sorted_list = g_list_append(sorted_list, start->data);
+        start = start->next;
     }
-    sorted_list=g_list_append(sorted_list,start->data);
+    sorted_list = g_list_append(sorted_list, start->data);
 
-    sorted_list=g_list_sort(sorted_list,histogram_list_compare_func_cycles);
+    sorted_list = g_list_sort(sorted_list, histogram_list_compare_func_cycles);
 
-    start=sorted_list;
-    stop=start;
-    while(stop->next!=0)
-        stop=stop->next;
+    start = sorted_list;
+    stop = start;
+    while (stop->next)
+        stop = stop->next;
 
+    chc_start = (struct cycle_histogram_counter*)start->data;
+    chc_stop = (struct cycle_histogram_counter*)stop->data;
 
-    chc_start=(struct cycle_histogram_counter*)start->data;
-    chc_stop=(struct cycle_histogram_counter*)stop->data;
-
-    while(start!=stop)
+    while (start != stop)
     {
-        if(count_sum>=0)
+        if (count_sum >= 0)
         {
             // Move start to right
             start = start->next;
-            count_sum-=chc_start->count;
-            chc_start=(struct cycle_histogram_counter*)start->data;
+            count_sum -= chc_start->count;
+            chc_start = (struct cycle_histogram_counter*)start->data;
             continue;
         }
         else
         {
             // Move stop to left
-            stop=stop->prev;
-            count_sum+=chc_stop->count;
-            chc_stop=(struct cycle_histogram_counter*)stop->data;
+            stop = stop->prev;
+            count_sum += chc_stop->count;
+            chc_stop = (struct cycle_histogram_counter*)stop->data;
             continue;
         }
     }
 
-    if(count_sum>(int)chc_start->count)
+    if (count_sum>(int)chc_start->count)
     {
-        start=start->next;
-        chc_start=(struct cycle_histogram_counter*)start->data;
+        start = start->next;
+        chc_start = (struct cycle_histogram_counter*)start->data;
         g_list_free(sorted_list);
         return (double)chc_start->histo_cycles;
     }
-    if(-count_sum>(int)chc_start->count)
+    if (-count_sum>(int)chc_start->count)
     {
-        start=start->prev;
-        chc_start=(struct cycle_histogram_counter*)start->data;
+        start = start->prev;
+        chc_start = (struct cycle_histogram_counter*)start->data;
         g_list_free(sorted_list);
         return (double)chc_start->histo_cycles;
     }
-    if(-count_sum==(int)chc_start->count)
+    if (-count_sum == (int)chc_start->count)
     {
-        stop=stop->prev;
-        chc_stop=(struct cycle_histogram_counter*)stop->data;
+        stop = stop->prev;
+        chc_stop = (struct cycle_histogram_counter*)stop->data;
         g_list_free(sorted_list);
-        return (chc_start->histo_cycles+chc_stop->histo_cycles)/2.0;
+        return (chc_start->histo_cycles + chc_stop->histo_cycles) / 2.0;
     }
-    if(count_sum==(int)chc_start->count)
+    if (count_sum == (int)chc_start->count)
     {
-        stop=stop->next;
-        chc_stop=(struct cycle_histogram_counter*)stop->data;
+        stop = stop->next;
+        chc_stop = (struct cycle_histogram_counter*)stop->data;
         g_list_free(sorted_list);
-        return (chc_start->histo_cycles+chc_stop->histo_cycles)/2.0;
+        return (chc_start->histo_cycles + chc_stop->histo_cycles) / 2.0;
     }
-    if((unsigned int)abs(count_sum)<chc_start->count)
+    if ((unsigned int)abs(count_sum) < chc_start->count)
     {
         g_list_free(sorted_list);
         return (double)chc_start->histo_cycles;
@@ -199,29 +205,27 @@ double calculate_median(GList *start, GList *stop)
 
 double calculate_stddev(GList *start, GList *stop, double average)
 {
-    int count=0;
+    int count = 0;
     double sum = 0.0;
     struct cycle_histogram_counter *chc_start;
 
     if (start == stop)
         return 0.0;
 
-    if (stop == 0)
+    if (!stop)
     {
         stop = start;
-        while (stop->next != 0)
+        while (stop->next)
             stop = stop->next;
     }
 
     while (start != stop)
     {
-        double diff, diff2;
-
         chc_start = (struct cycle_histogram_counter*)start->data;
 
-        diff = chc_start->histo_cycles-average;
+        double diff = chc_start->histo_cycles - average;
 
-        diff2 = diff * diff;
+        double diff2 = diff * diff;
 
         sum += diff2 * chc_start->count;
 
@@ -237,10 +241,10 @@ double calculate_stddev(GList *start, GList *stop, double average)
 
 void Profile_Window::Update()
 {
-  if(!enabled)
+  if (!enabled)
     return;
 
-  if(!gp || !gp->cpu)
+  if (!gp || !gp->cpu)
   {
     return;
   }
@@ -295,37 +299,37 @@ void Profile_Window::Update()
                                            histogram_list_compare_func);
   // Remove all of list (for now)
   gtk_list_store_clear(profile_exestats_list);
-  if(histogram_profile_list!=0)
+  if (histogram_profile_list != 0)
   {
       struct cycle_histogram_counter *chc;
       int count_sum = 0;
       unsigned int start = 0xffffffff, stop = 0xffffffff;
       guint64 min = 0xffffffffffffffffULL, max = 0;
       guint64 cycles_sum = 0;
-      GList *list_start = 0, *list_end = 0;
+      GList *list_start = nullptr, *list_end = nullptr;
 
       GList *iter = histogram_profile_list;
       list_start = iter;
-      while(iter!=0)
+      while (iter)
       {
-          chc=(struct cycle_histogram_counter*)iter->data;
+          chc = (struct cycle_histogram_counter*)iter->data;
 
 
-          if(start==chc->start_address &&
-             stop==chc->stop_address)
+          if (start == chc->start_address &&
+             stop == chc->stop_address)
           {
               // Add data to statistics
 
-              count_sum+=chc->count;
-              if(chc->histo_cycles<min)
-                  min=chc->histo_cycles;
-              if(chc->histo_cycles>max)
-                  max=chc->histo_cycles;
-              cycles_sum+=chc->histo_cycles*chc->count;
+              count_sum += chc->count;
+              if (chc->histo_cycles < min)
+                  min = chc->histo_cycles;
+              if (chc->histo_cycles > max)
+                  max = chc->histo_cycles;
+              cycles_sum += chc->histo_cycles * chc->count;
           }
           else
           {
-              if(count_sum!=0)
+              if (count_sum != 0)
               {
                   // We have data, display it.
                   GtkTreeIter titer;
@@ -347,17 +351,17 @@ void Profile_Window::Update()
               }
 
               // Start new calculation
-              count_sum=chc->count;
+              count_sum = chc->count;
               start = chc->start_address;
               stop = chc->stop_address;
-              min=chc->histo_cycles;
-              max=chc->histo_cycles;
-              cycles_sum=chc->histo_cycles*chc->count;
+              min = chc->histo_cycles;
+              max = chc->histo_cycles;
+              cycles_sum = chc->histo_cycles * chc->count;
               list_start = iter;
 
           }
-          list_end=iter;
-          iter=iter->next;
+          list_end = iter;
+          iter = iter->next;
       }
       // add current to list
 
@@ -372,16 +376,16 @@ void Profile_Window::Update()
         PROFILE_EXESTATS_MEDIAN, calculate_median(list_start , list_end),
         PROFILE_EXESTATS_AVERAGE, cycles_sum / (double)count_sum,
         PROFILE_EXESTATS_STDDEV,
-          calculate_stddev(list_start , list_end ,cycles_sum / (double)count_sum),
+          calculate_stddev(list_start, list_end, cycles_sum / (double)count_sum),
         PROFILE_EXESTATS_TOTAL, cycles_sum,
         -1);
   }
 }
 
 #define END_OF_TIME 0xFFFFFFFFFFFFFFFFULL
-static guint64 startcycle=END_OF_TIME;
+static guint64 startcycle = END_OF_TIME;
 static unsigned int startaddress;
-static guint64 stopcycle=END_OF_TIME;
+static guint64 stopcycle = END_OF_TIME;
 static unsigned int stopaddress;
 
 //------------------------------------------------------------------------
@@ -398,12 +402,12 @@ public:
     address = _address;
   }
 
-  void callback(void)
+  void callback() override
   {
-    if(!gpGuiProcessor || !gpGuiProcessor->cpu || !pw->gp->cpu)
+    if (!gpGuiProcessor || !gpGuiProcessor->cpu || !pw->gp->cpu)
       return;
 
-    if(startcycle==END_OF_TIME) {
+    if (startcycle == END_OF_TIME) {
       startcycle   = get_cycles().get();
       startaddress = pw->gp->cpu->pma->get_PC();
     }
@@ -420,7 +424,6 @@ private:
 //
 class ProfileStop : public TriggerObject
 {
-
 public:
   ProfileStop(Profile_Window *_pw, int _address)
   {
@@ -428,59 +431,56 @@ public:
     address = _address;
   }
 
-  void callback(void)
+  void callback() override
   {
-    if(!gpGuiProcessor || !gpGuiProcessor->cpu || !pw->gp->cpu)
+    if (!gpGuiProcessor || !gpGuiProcessor->cpu || !pw->gp->cpu)
       return;
 
-    if(stopcycle==END_OF_TIME && startcycle!=END_OF_TIME) {
+    if (stopcycle == END_OF_TIME && startcycle != END_OF_TIME) {
 
       stopcycle = get_cycles().get();
-      if(startcycle==stopcycle)
+      if (startcycle == stopcycle) {
         // This was probably an attempt to measure the whole loop.
         // Set stopcycle to unset, and wait for the next one
-        stopcycle=END_OF_TIME;
+        stopcycle = END_OF_TIME;
 
-      else {
-
-        guint64 cycles;
-        GList *iter;
-  stopaddress=pw->gp->cpu->pma->get_PC();
+      } else {
+        stopaddress = pw->gp->cpu->pma->get_PC();
 
         // We have a new measurement
-        cycles=(int)stopcycle-(int)startcycle;
+        guint64 cycles_count = (int)stopcycle - (int)startcycle;
 
         // Search to see if there are an entry with this startaddress,
         // stopaddress and cycle count.
-        iter=pw->histogram_profile_list;
-        while(iter!=0) {
+        GList *iter = pw->histogram_profile_list;
+        while (iter != 0) {
 
           struct cycle_histogram_counter *chc;
-          chc=(struct cycle_histogram_counter*)iter->data;
-          if(chc->start_address == startaddress &&
+          chc = (struct cycle_histogram_counter*)iter->data;
+          if (chc->start_address == startaddress &&
              chc->stop_address == stopaddress &&
-             chc->histo_cycles == cycles)
+             chc->histo_cycles == cycles_count)
             {
               // If so then add 1 to the counter
               chc->count++;
               break;
             }
-          iter=iter->next;
+          iter = iter->next;
         }
 
-        if(iter==0) {
+        if (iter == 0) {
 
           // Else create a new struct, fill with values and add (sorted) to list
           struct cycle_histogram_counter *chc = new cycle_histogram_counter;
-          chc->start_address=startaddress;
-          chc->stop_address=stopaddress;
-          chc->histo_cycles=cycles;
-          chc->count=1;
+          chc->start_address = startaddress;
+          chc->stop_address = stopaddress;
+          chc->histo_cycles = cycles_count;
+          chc->count = 1;
 
-          pw->histogram_profile_list=g_list_append(pw->histogram_profile_list,chc);
+          pw->histogram_profile_list = g_list_append(pw->histogram_profile_list, chc);
         }
 
-        startcycle=stopcycle=END_OF_TIME;
+        startcycle=stopcycle = END_OF_TIME;
       }
     }
   }
@@ -499,25 +499,22 @@ private:
  */
 void Profile_Window::StartExe(int address)
 {
-
-  if(!enabled)
+  if (!enabled)
     ChangeView(VIEW_SHOW);
 
-  if(gp->cpu->pma->address_has_profile_start(address))
+  if (gp->cpu->pma->address_has_profile_start(address))
     gp->cpu->pma->clear_profile_start_at_address(address);
   else {
 
-    if(gp->cpu->pma->address_has_profile_stop(address))
+    if (gp->cpu->pma->address_has_profile_stop(address))
       // Can't have both start and stop at the same address
       // ..it becomes difficult to calculate the cycles
       gp->cpu->pma->clear_profile_stop_at_address(address);
 
     // FIXME -- memory leak...
     gp->cpu->pma->set_profile_start_at_address(address,
-                                              new ProfileStart(this,address));
-
+                                              new ProfileStart(this, address));
   }
-
 }
 
 /*****************************************************************
@@ -528,21 +525,21 @@ void Profile_Window::StartExe(int address)
  */
 void Profile_Window::StopExe(int address)
 {
-  if(enabled)
+  if (enabled)
     ChangeView(VIEW_SHOW);
 
-  if(gp->cpu->pma->address_has_profile_stop(address))
+  if (gp->cpu->pma->address_has_profile_stop(address))
     gp->cpu->pma->clear_profile_stop_at_address(address);
   else {
 
-    if(gp->cpu->pma->address_has_profile_start(address))
+    if (gp->cpu->pma->address_has_profile_start(address))
       // Can't have both start and stop at the same address
       // ..it becomes difficult to calculate the cycles
       gp->cpu->pma->clear_profile_start_at_address(address);
 
     // FIXME -- memory leak...
     gp->cpu->pma->set_profile_stop_at_address(address,
-                                              new ProfileStop(this,address));
+                                              new ProfileStop(this, address));
   }
 }
 
@@ -556,17 +553,17 @@ void Profile_Window::NewProgram(GUI_Processor *_gp)
 {
   unsigned int uPMIndex;
 
-  if(!_gp)
+  if (!_gp)
     return;
 
   gp = _gp;
 
-  if(!gp->cpu)
+  if (!gp->cpu)
     return;
 
-  program=1;
+  program = 1;
 
-  if(!enabled)
+  if (!enabled)
     return;
 
   profile_keeper.enable_profiling();
@@ -576,24 +573,23 @@ void Profile_Window::NewProgram(GUI_Processor *_gp)
   ProgramMemoryAccess *pPMA = pProcessor->pma;
   for (uPMIndex = 0; uPMIndex < pProcessor->program_memory_size(); uPMIndex++) {
 
-    guint64 cycles;
     instruction * pInstruction = pProcessor->pma->getFromIndex(uPMIndex);
     guint uAddress = pProcessor->map_pm_index2address(uPMIndex);
-    if(pPMA->hasValid_opcode_at_index(uPMIndex)) {
-      cycles = pProcessor->cycles_used(uPMIndex);
+    if (pPMA->hasValid_opcode_at_index(uPMIndex)) {
+      guint64 cycles_used = pProcessor->cycles_used(uPMIndex);
       GtkTreeIter iter;
       gtk_list_store_append(profile_list, &iter);
 
       gtk_list_store_set(profile_list, &iter,
         PROFILE_ADDRESS, uAddress,
-        PROFILE_CYCLES, cycles,
+        PROFILE_CYCLES, cycles_used,
         PROFILE_INSTRUCTION, pInstruction->name().c_str(),
         -1);
     }
   }
 
   // Register list
-  for(unsigned int i = 0; i < pProcessor->rma.get_size(); i++) {
+  for (unsigned int i = 0; i < pProcessor->rma.get_size(); i++) {
     Register *reg = pProcessor->rma.get_register(i);
 
     //
@@ -601,7 +597,7 @@ void Profile_Window::NewProgram(GUI_Processor *_gp)
     // register, then we can profile it.
     //
 
-    if(reg && reg->isa() != Register::INVALID_REGISTER    // i.e. the register is valid
+    if (reg && reg->isa() != Register::INVALID_REGISTER    // i.e. the register is valid
           &&
        !((reg->isa() == Register::SFR_REGISTER) || (i != reg->address)) ) {
 
@@ -651,7 +647,7 @@ static void address_data_func(GtkTreeViewColumn *,
 
   g_snprintf(buf, sizeof(buf), "0x%04x", addr);
 
-  g_object_set(renderer, "text", buf, NULL);
+  g_object_set(renderer, "text", buf, nullptr);
 }
 
 // Call-back to format the count for the cell renderer
@@ -669,7 +665,7 @@ static void cycles_data_func(GtkTreeViewColumn *,
 
   g_snprintf(buf, sizeof(buf), "0x%" PRINTF_GINT64_MODIFIER "x", addr);
 
-  g_object_set(renderer, "text", buf, NULL);
+  g_object_set(renderer, "text", buf, nullptr);
 }
 
 // Call-back to formation floating point information
@@ -687,7 +683,7 @@ static void float_data_func(GtkTreeViewColumn *,
 
   g_snprintf(buf, sizeof(buf), "%.1f", floating_data);
 
-  g_object_set(renderer, "text", buf, NULL);
+  g_object_set(renderer, "text", buf, nullptr);
 }
 
 void Profile_Window::Build()
@@ -709,7 +705,7 @@ void Profile_Window::Build()
   notebook = gtk_notebook_new();
   gtk_widget_show(notebook);
 
-  gtk_box_pack_start (GTK_BOX (main_vbox), notebook, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(main_vbox), notebook, TRUE, TRUE, 0);
 
 
   GtkCellRenderer *renderer;
@@ -723,28 +719,28 @@ void Profile_Window::Build()
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("Address",
-    renderer, "text", PROFILE_ADDRESS, NULL);
+    renderer, "text", PROFILE_ADDRESS, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(profile_tree), column);
   gtk_tree_view_column_set_cell_data_func(
     column, renderer,
     address_data_func,
-    GINT_TO_POINTER(PROFILE_ADDRESS), NULL);
+    GINT_TO_POINTER(PROFILE_ADDRESS), nullptr);
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("Cycles",
-    renderer, "text", PROFILE_CYCLES, NULL);
+    renderer, "text", PROFILE_CYCLES, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(profile_tree), column);
   gtk_tree_view_column_set_cell_data_func(
     column, renderer,
     cycles_data_func,
-    GINT_TO_POINTER(PROFILE_CYCLES), NULL);
+    GINT_TO_POINTER(PROFILE_CYCLES), nullptr);
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("Instruction",
-    renderer, "text", PROFILE_INSTRUCTION, NULL);
+    renderer, "text", PROFILE_INSTRUCTION, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(profile_tree), column);
 
-  scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+  scrolled_window = gtk_scrolled_window_new(nullptr, nullptr);
 
   gtk_container_add(GTK_CONTAINER(scrolled_window), profile_tree);
 
@@ -753,7 +749,7 @@ void Profile_Window::Build()
   gtk_widget_show(scrolled_window);
 
 //  gtk_box_pack_start(GTK_BOX(main_vbox), scrolled_window, TRUE, TRUE, 0);
-  label=gtk_label_new("Instruction profile");
+  label = gtk_label_new("Instruction profile");
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook),scrolled_window,label);
   ///////////////////////////////////////////////////
 
@@ -766,37 +762,37 @@ void Profile_Window::Build()
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("Address",
-    renderer, "text", PROFILE_REGISTER_ADDRESS, NULL);
+    renderer, "text", PROFILE_REGISTER_ADDRESS, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(profile_register_tree), column);
   gtk_tree_view_column_set_cell_data_func(
     column, renderer,
     address_data_func,
-    GINT_TO_POINTER(PROFILE_REGISTER_ADDRESS), NULL);
+    GINT_TO_POINTER(PROFILE_REGISTER_ADDRESS), nullptr);
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("Register",
-    renderer, "text", PROFILE_REGISTER_REGISTER, NULL);
+    renderer, "text", PROFILE_REGISTER_REGISTER, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(profile_register_tree), column);
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("Read count",
-    renderer, "text", PROFILE_REGISTER_READ, NULL);
+    renderer, "text", PROFILE_REGISTER_READ, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(profile_register_tree), column);
   gtk_tree_view_column_set_cell_data_func(
     column, renderer,
     cycles_data_func,
-    GINT_TO_POINTER(PROFILE_REGISTER_READ), NULL);
+    GINT_TO_POINTER(PROFILE_REGISTER_READ), nullptr);
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("Write count",
-    renderer, "text", PROFILE_REGISTER_WRITE, NULL);
+    renderer, "text", PROFILE_REGISTER_WRITE, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(profile_register_tree), column);
   gtk_tree_view_column_set_cell_data_func(
     column, renderer,
     cycles_data_func,
-    GINT_TO_POINTER(PROFILE_REGISTER_WRITE), NULL);
+    GINT_TO_POINTER(PROFILE_REGISTER_WRITE), nullptr);
 
-  scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+  scrolled_window = gtk_scrolled_window_new(nullptr, nullptr);
 
   gtk_container_add(GTK_CONTAINER(scrolled_window), profile_register_tree);
 
@@ -805,8 +801,8 @@ void Profile_Window::Build()
   gtk_widget_show(scrolled_window);
 
 //  gtk_box_pack_start(GTK_BOX(main_vbox), scrolled_window, TRUE, TRUE, 0);
-  label=gtk_label_new("Register profile");
-  gtk_notebook_append_page(GTK_NOTEBOOK(notebook),scrolled_window,label);
+  label = gtk_label_new("Register profile");
+  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), scrolled_window, label);
 
 
   // Execution time statistics tab
@@ -819,70 +815,70 @@ void Profile_Window::Build()
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("From address",
-    renderer, "text", PROFILE_EXESTATS_FADDRESS, NULL);
+    renderer, "text", PROFILE_EXESTATS_FADDRESS, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(profile_exestats_tree), column);
   gtk_tree_view_column_set_cell_data_func(
     column, renderer,
     address_data_func,
-    GINT_TO_POINTER(PROFILE_EXESTATS_FADDRESS), NULL);
+    GINT_TO_POINTER(PROFILE_EXESTATS_FADDRESS), nullptr);
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("To address",
-    renderer, "text", PROFILE_EXESTATS_TADDRESS, NULL);
+    renderer, "text", PROFILE_EXESTATS_TADDRESS, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(profile_exestats_tree), column);
   gtk_tree_view_column_set_cell_data_func(
     column, renderer,
     address_data_func,
-    GINT_TO_POINTER(PROFILE_EXESTATS_TADDRESS), NULL);
+    GINT_TO_POINTER(PROFILE_EXESTATS_TADDRESS), nullptr);
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("Executions",
-    renderer, "text", PROFILE_EXESTATS_EXECUTIONS, NULL);
+    renderer, "text", PROFILE_EXESTATS_EXECUTIONS, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(profile_exestats_tree), column);
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("Min",
-    renderer, "text", PROFILE_EXESTATS_MIN, NULL);
+    renderer, "text", PROFILE_EXESTATS_MIN, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(profile_exestats_tree), column);
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("Max",
-    renderer, "text", PROFILE_EXESTATS_MAX, NULL);
+    renderer, "text", PROFILE_EXESTATS_MAX, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(profile_exestats_tree), column);
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("Median",
-    renderer, "text", PROFILE_EXESTATS_MEDIAN, NULL);
+    renderer, "text", PROFILE_EXESTATS_MEDIAN, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(profile_exestats_tree), column);
   gtk_tree_view_column_set_cell_data_func(
     column, renderer,
     float_data_func,
-    GINT_TO_POINTER(PROFILE_EXESTATS_MEDIAN), NULL);
+    GINT_TO_POINTER(PROFILE_EXESTATS_MEDIAN), nullptr);
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("Average",
-    renderer, "text", PROFILE_EXESTATS_AVERAGE, NULL);
+    renderer, "text", PROFILE_EXESTATS_AVERAGE, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(profile_exestats_tree), column);
   gtk_tree_view_column_set_cell_data_func(
     column, renderer,
     float_data_func,
-    GINT_TO_POINTER(PROFILE_EXESTATS_AVERAGE), NULL);
+    GINT_TO_POINTER(PROFILE_EXESTATS_AVERAGE), nullptr);
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("Std. Dev.",
-    renderer, "text", PROFILE_EXESTATS_STDDEV, NULL);
+    renderer, "text", PROFILE_EXESTATS_STDDEV, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(profile_exestats_tree), column);
   gtk_tree_view_column_set_cell_data_func(
     column, renderer,
     float_data_func,
-    GINT_TO_POINTER(PROFILE_EXESTATS_STDDEV), NULL);
+    GINT_TO_POINTER(PROFILE_EXESTATS_STDDEV), nullptr);
 
   renderer = gtk_cell_renderer_text_new();
   column = gtk_tree_view_column_new_with_attributes("Total",
-    renderer, "text", PROFILE_EXESTATS_TOTAL, NULL);
+    renderer, "text", PROFILE_EXESTATS_TOTAL, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(profile_exestats_tree), column);
 
-  scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+  scrolled_window = gtk_scrolled_window_new(nullptr, nullptr);
 
   gtk_container_add(GTK_CONTAINER(scrolled_window), profile_exestats_tree);
 
@@ -891,7 +887,7 @@ void Profile_Window::Build()
   gtk_widget_show(scrolled_window);
 
   label=gtk_label_new("Routine profile");
-  gtk_notebook_append_page(GTK_NOTEBOOK(notebook),scrolled_window,label);
+  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), scrolled_window,label);
   ///////////////////////////////////////////////////
 
   gtk_widget_show(window);
@@ -910,7 +906,7 @@ void Profile_Window::Build()
 
 Profile_Window::Profile_Window(GUI_Processor *_gp)
   : GUI_Object("profile"),
-    program(0), histogram_profile_list(0)
+    program(0), histogram_profile_list(nullptr)
 {
   menu = "/menu/Windows/Profile";
 
