@@ -19,11 +19,11 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __GUI_PROFILE_H__
-#define __GUI_PROFILE_H__
+#ifndef GUI_GUI_PROFILE_H_
+#define GUI_GUI_PROFILE_H_
 
 #include "gui_object.h"
-
+#include <glib.h>
 #include <gtk/gtk.h>
 
 class GUI_Processor;
@@ -62,13 +62,13 @@ public:
   GList *histogram_profile_list;
 
   explicit Profile_Window(GUI_Processor *gp);
-  virtual void Build();
-  virtual void Update();
-  virtual void NewProcessor(GUI_Processor *gp);
+  void Build() override;
+  void Update() override;
+  void NewProcessor(GUI_Processor *gp) override;
   virtual void NewProgram(GUI_Processor *gp);
   virtual void StopExe(int address);
   virtual void StartExe(int address);
 };
 
-#endif // __GUI_PROFILE_H__
+#endif // GUI_GUI_PROFILE_H_
 
