@@ -34,12 +34,16 @@ gpsim_la - plug in.
 #include <gdk/gdk.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib.h>
+#include <glib-object.h>
+
+#include <cairo.h>
 
 #include "../src/bitlog.h"
+#include "../src/gpsim_object.h"
+#include "../src/gpsim_time.h"
 #include "../src/symbol.h"
 #include "../src/value.h"
 #include "../src/stimuli.h"
-#include "../src/gpsim_object.h"
 
 #include <cassert>
 #include <cstdio>
@@ -88,7 +92,7 @@ public:
 
   // Override the String::set method so that name assignments can
   // be intercepted.
-  virtual void set(const char *cp, int len = 0);
+  void set(const char *cp, int len = 0) override;
 
 private:
   Waveform *m_pParent;
@@ -102,7 +106,7 @@ private:
 class ZoomAttribute : public Integer {
 public:
   explicit ZoomAttribute(Scope_Window *);
-  virtual void set(gint64 i);
+  void set(gint64 i) override;
 
 private:
   Scope_Window *m_pSW;
@@ -115,7 +119,7 @@ private:
 class PanAttribute : public Integer {
 public:
   explicit PanAttribute(Scope_Window *);
-  virtual void set(gint64 i);
+  void set(gint64 i) override;
 
 private:
   Scope_Window *m_pSW;
@@ -152,6 +156,7 @@ public:
     return yoffset;
   }
   virtual void setSource(const char *) {}
+  virtual void setWidth ( int w )   { width = w; }
 
 protected:
   Scope_Window *sw;          // Parent
@@ -177,8 +182,8 @@ public:
   {
   }
 
-  virtual void Build(gint w, gint h, gint y);
-  virtual void Update(guint64 start = 0, guint64 stop = 0);
+  void Build(gint w, gint h, gint y) override;
+  void Update(guint64 start = 0, guint64 stop = 0) override;
   void draw(cairo_t *cr);
 
 private:
@@ -194,17 +199,19 @@ private:
 class Waveform : public WaveBase {
 public:
   Waveform(Scope_Window *parent, const char *name);
+  Waveform(const Waveform &) = delete;
+  Waveform& operator =(const Waveform &) = delete;
 
   virtual ~Waveform()
   {
   }
 
-  virtual void Update(guint64 start = 0, guint64 stop = 0);
-  virtual void Build(gint w, gint h, gint y);
+  void Update(guint64 start = 0, guint64 stop = 0) override;
+  void Build(gint w, gint h, gint y) override;
   void draw(cairo_t *cr);
 
   void setData(char c);
-  virtual void setSource(const char *);
+  void setSource(const char *) override;
 
 protected:
   void PlotTo(cairo_t *cr, timeMap &left, timeMap &right);
@@ -227,8 +234,8 @@ protected:
 class WaveformSink : public SignalSink {
 public:
   explicit WaveformSink(Waveform *pParent);
-  virtual void setSinkState(char);
-  virtual void release() {}
+  void setSinkState(char) override;
+  void release() override {}
 
 protected:
   Waveform *m_pWaveform;
@@ -639,7 +646,7 @@ void TimeAxis::Build(gint w, gint h, gint y)
 class TimeMarker : public Integer {
 public:
   TimeMarker(Scope_Window *parent, const char *_name, const char *desc);
-  virtual void set(gint64 i);
+  void set(gint64 i) override;
 private:
   Scope_Window *m_pParent;
 };
@@ -913,6 +920,21 @@ gboolean Scope_Window::signal_name_expose(GtkWidget *widget,
 }
 
 
+gboolean Scope_Window::on_configure(GtkWidget *widget,
+      GdkEvent *event, Scope_Window *sw)
+{
+   int x, y, w, h;
+
+   x = event->configure.x;
+   y = event->configure.y;
+   w = event->configure.width;
+   h = event->configure.height;
+   //printf ( "%d, %d, %d, %d\n", x, y, w, h );
+   sw->setWidth ( w );
+   return FALSE;
+}
+
+
 void TimeAxis::draw(cairo_t *cr)
 {
   // Draw major ticks
@@ -1070,7 +1092,6 @@ void Scope_Window::Build()
                    (gpointer) this);
   bIsBuilt = true;
   UpdateMenuItem();
-  gtk_widget_show_all(window);
   m_entry = new SignalNameEntry();
   gtk_layout_put(GTK_LAYOUT(signalDrawingArea),
                  m_entry->m_entry,
@@ -1079,6 +1100,11 @@ void Scope_Window::Build()
                    "key_press_event",
                    G_CALLBACK(signalEntryKeyPress),
                    (gpointer) this);
+  g_signal_connect(waveDrawingArea,
+                   "configure-event",
+                   G_CALLBACK(on_configure),
+                   (gpointer) this);
+  gtk_widget_show_all(window);
 }
 
 
@@ -1125,6 +1151,27 @@ void Scope_Window::Update()
 }
 
 
+/**
+ * Adjust the internal representation to account for a change of the
+ * window size on screen
+ * @bug something more needed - this adjusts the time axis nicely but not
+ *      the background or the traces
+ *
+ * @param   w       New width of the window
+ */
+void Scope_Window::setWidth ( int w )
+{
+    m_PixmapWidth = w;
+    std::vector<Waveform *>::iterator i;
+
+    m_TimeAxis->setWidth(w);
+    for (i = signals.begin(); i != signals.end(); ++i) {
+        (*i)->setWidth(w);
+    }
+    Update();
+}
+
+
 Scope_Window::Scope_Window(GUI_Processor *_gp)
   : GUI_Object("scope"),
     m_pHpaned(nullptr), m_phScrollBar(nullptr), m_PixmapWidth(1024),
