@@ -19,8 +19,8 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __GUI_SRC_H__
-#define __GUI_SRC_H__
+#ifndef GUI_GUI_SRC_H_
+#define GUI_GUI_SRC_H_
 
 #include "../src/modules.h"
 #include "gui_object.h"
@@ -147,16 +147,16 @@ public:
   SourceWindow(GUI_Processor *gp,
                SourceBrowserParent_Window *,
                bool bUseConfig,
-               const char *newName=0);
+               const char *newName = nullptr);
 
-  virtual void Build();
+  void Build() override;
   virtual void SetTitle();
 
   void set_pma(ProgramMemoryAccess *new_pma);
 
   virtual void SelectAddress(int address);
   virtual void SelectAddress(Value *);
-  virtual void Update();
+  void Update() override;
   virtual void UpdateLine(int address);
   virtual void SetPC(int address);
   virtual void CloseSource(void);
@@ -167,7 +167,7 @@ public:
   virtual bool bAddressHasBreak(int address);
   virtual int getOpcode(int address);
   int  AddPage(SourceBuffer *pSourceBuffer, const std::string &fName);
-  void step(int n=1);
+  void step(int n = 1);
   void step_over();
   void stop();
   void run();
@@ -211,8 +211,7 @@ private:
   // Popup Menu
   SearchDialog *stPSearchDialog;
   GtkWidget * BuildPopupMenu();
-  static void PopupMenuHandler(GtkWidget *widget,
-                               gpointer data);
+  static void PopupMenuHandler(GtkWidget *widget, gpointer data);
 
   // Callbacks
   static gboolean KeyPressHandler(GtkWidget *widget,
@@ -235,7 +234,7 @@ protected:
   SourceBrowserParent_Window *m_pParent;
 
 public:
-  const char *name_pub() {return name();}
+  const char *name_pub() { return name(); }
 };
 
 class SourceBrowser_Window : public GUI_Object {
@@ -251,15 +250,15 @@ class SourceBrowser_Window : public GUI_Object {
   void set_pma(ProgramMemoryAccess *new_pma);
 
   void Create();
-  virtual void NewProcessor(GUI_Processor *gp) = 0;
+  void NewProcessor(GUI_Processor *gp) override = 0;
   virtual void SetTitle();
   virtual void SelectAddress(int address) = 0;
   virtual void SelectAddress(Value *);
-  virtual void Update();
+  void Update() override;
   virtual void UpdateLine(int address) = 0;
   virtual void SetPC(int address) = 0;
-  virtual void CloseSource() {};
-  virtual void NewSource(GUI_Processor *) {};
+  virtual void CloseSource() {}
+  virtual void NewSource(GUI_Processor *) {}
 };
 
 //
@@ -270,12 +269,14 @@ class SourceBrowserOpcode_Window : public SourceBrowser_Window
  public:
   explicit SourceBrowserOpcode_Window(GUI_Processor *gp);
   ~SourceBrowserOpcode_Window();
-  virtual void Build();
-  virtual void NewProcessor(GUI_Processor *gp);
-  virtual void SelectAddress(int address);
-  virtual void SetPC(int address);
-  virtual void NewSource(GUI_Processor *gp);
-  virtual void UpdateLine(int address);
+
+  void Build() override;
+  void NewProcessor(GUI_Processor *gp) override;
+  void SelectAddress(int address) override;
+  void SetPC(int address) override;
+  void NewSource(GUI_Processor *gp) override;
+  void UpdateLine(int address) override;
+
   virtual void Fill();
 
   void update_ascii(gint row);
@@ -340,20 +341,20 @@ private:
 
 class SourceBrowserParent_Window : public GUI_Object
 {
- public:
+public:
   explicit SourceBrowserParent_Window(GUI_Processor *gp);
 
-  virtual void Build();
-  virtual void NewProcessor(GUI_Processor *gp);
+  void Build() override;
+  void NewProcessor(GUI_Processor *gp) override;
   virtual void SelectAddress(int address);
   virtual void SelectAddress(Value *);
-  virtual void Update();
+  void Update() override;
   virtual void UpdateLine(int address);
   virtual void SetPC(int address);
   virtual void CloseSource();
   virtual void NewSource(GUI_Processor *gp);
-  virtual void ChangeView(int view_state);
-  virtual int set_config();
+  void ChangeView(int view_state) override;
+  int set_config() override;
 
   GtkTextTagTable *getTagTable() { return mpTagTable; }
   void CreateSourceBuffers(GUI_Processor *gp);
@@ -382,4 +383,4 @@ public:
   std::vector<SourceBuffer *> ppSourceBuffers;
 };
 
-#endif // __GUI_SRC_H__
+#endif // GUI_GUI_SRC_H_
