@@ -20,24 +20,25 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#include <cstdio>
-
 #include "../config.h"
 #ifdef HAVE_GUI
 
 #include <gtk/gtk.h>
-#include <gdk/gdk.h>
 #include <glib.h>
+#include <glib-object.h>
 #include <glib/gprintf.h>
 
 #include <cassert>
+#include <cstring>
+#include <string>
 
-#include "../src/sim_context.h"
-#include "../src/interface.h"
+#include "../src/14bit-registers.h"
 #include "../src/pic-processor.h"
-#include "../src/symbol.h"
+#include "../src/processor.h"
+#include "../src/ui.h"
+#include "../src/value.h"
 
-#include "gui.h"
+#include "gui_processor.h"
 #include "gui_stack.h"
 #include "gui_src.h"
 
@@ -95,7 +96,7 @@ static int get_closest_label(Stack_Window *,
 
   // this function assumes that address symbols are sorted
 
-  Value *closest_symbol = 0;
+  Value *closest_symbol = nullptr;
 
 #if 0
   int minimum_delta=0x2000000;
@@ -121,37 +122,35 @@ static int get_closest_label(Stack_Window *,
     }
   }
 #endif
-   if(verbose)
-       g_print("FIXME gui_stack.cc get closest label\n");
-  if(closest_symbol) {
-    strcpy(name,closest_symbol->name().data());
+  if (verbose)
+    g_print("FIXME gui_stack.cc get closest label\n");
+  if (closest_symbol) {
+    strcpy(name, closest_symbol->name().data());
     int i;
     closest_symbol->get(i);
-    *offset=address-i;
+    *offset = address - i;
     return 1;
   }
 
-
   return 0;
-
 }
 
 void Stack_Window::Update()
 {
   int nrofentries;
 
-  if(!gp || !enabled)
+  if (!gp || !enabled)
     return;
 
   pic_processor *pic = dynamic_cast<pic_processor *>(gp->cpu);
-  if(!pic)
+  if (!pic)
     return;
 
   // Enhanced 14bit processors use 0x1f(31) for empty index which is
   // also P18 max stack slot, so we mask with 0x1f
   nrofentries = pic->stack->pointer & 0x1f;
-  if (nrofentries && ((nrofentries-1) > (int)pic->stack->stack_mask))
-	return;
+  if (nrofentries && ((nrofentries - 1) > (int)pic->stack->stack_mask))
+    return;
 
   // Do if stack has shrunk
   for ( ; last_stacklen > nrofentries; --last_stacklen) {
@@ -186,7 +185,7 @@ static void depth_cell_data_function(
 
   gtk_tree_model_get(model, iter, COLUMN_DEPTH, &depth, -1);
   g_snprintf(buf, sizeof(buf), "#%d", depth);
-  g_object_set(renderer, "text", buf, NULL);
+  g_object_set(renderer, "text", buf, nullptr);
 }
 
 static void retaddr_cell_data_function(
@@ -209,7 +208,7 @@ static void retaddr_cell_data_function(
   else
     g_snprintf(buf, sizeof(buf), "0x%04x", addr);
 
-  g_object_set(renderer, "text", buf, NULL);
+  g_object_set(renderer, "text", buf, nullptr);
 }
 
 void Stack_Window::Build()
@@ -222,8 +221,8 @@ void Stack_Window::Build()
 
   gtk_window_set_title(GTK_WINDOW(window), "Stack Viewer");
 
-  g_signal_connect (window, "destroy",
-                      G_CALLBACK(gtk_widget_destroyed), &window);
+  g_signal_connect(window, "destroy",
+                   G_CALLBACK(gtk_widget_destroyed), &window);
 
   stack_list = gtk_list_store_new(gint(N_COLUMNS), G_TYPE_INT, G_TYPE_INT);
   sort_stack_list = gtk_tree_model_sort_new_with_model(GTK_TREE_MODEL(stack_list));
@@ -241,7 +240,7 @@ void Stack_Window::Build()
   gtk_tree_view_append_column(GTK_TREE_VIEW(tree), col);
   renderer = gtk_cell_renderer_text_new();
   gtk_tree_view_column_pack_start(col, renderer, TRUE);
-  gtk_tree_view_column_set_cell_data_func(col, renderer, depth_cell_data_function, NULL, NULL);
+  gtk_tree_view_column_set_cell_data_func(col, renderer, depth_cell_data_function, nullptr, nullptr);
 
   col = gtk_tree_view_column_new();
   gtk_tree_view_column_set_title(col, "return address");
@@ -250,7 +249,7 @@ void Stack_Window::Build()
   gtk_tree_view_append_column(GTK_TREE_VIEW(tree), col);
   renderer = gtk_cell_renderer_text_new();
   gtk_tree_view_column_pack_start(col, renderer, TRUE);
-  gtk_tree_view_column_set_cell_data_func(col, renderer, retaddr_cell_data_function, this, NULL);
+  gtk_tree_view_column_set_cell_data_func(col, renderer, retaddr_cell_data_function, this, nullptr);
 
   GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(tree));
   gtk_tree_selection_set_mode(selection, GTK_SELECTION_BROWSE);
@@ -258,17 +257,17 @@ void Stack_Window::Build()
   g_signal_connect(selection, "changed", G_CALLBACK(stack_list_row_selected), this);
   g_signal_connect(tree, "row-activated", G_CALLBACK(sigh_button_event), this);
 
-  scrolled_window=gtk_scrolled_window_new(0, 0);
+  scrolled_window = gtk_scrolled_window_new(0, 0);
 
-  vbox = gtk_vbox_new(FALSE,1);
+  vbox = gtk_vbox_new(FALSE, 1);
 
   gtk_container_add(GTK_CONTAINER(scrolled_window), tree);
 
-  gtk_container_add(GTK_CONTAINER(window),vbox);
+  gtk_container_add(GTK_CONTAINER(window), vbox);
 
   gtk_box_pack_start(GTK_BOX(vbox), scrolled_window, TRUE, TRUE, 0);
 
-  gtk_widget_show_all (window);
+  gtk_widget_show_all(window);
 
 
   bIsBuilt = true;
@@ -276,7 +275,6 @@ void Stack_Window::Build()
   UpdateMenuItem();
 
   Update();
-
 }
 
 //------------------------------------------------------------------------
