@@ -23,14 +23,17 @@ Boston, MA 02111-1307, USA.  */
 #ifdef HAVE_GUI
 
 #include <gtk/gtk.h>
-#include <gdk/gdk.h>
 #include <glib.h>
+#include <glib-object.h>
 #include <glib/gprintf.h>
 
-#include "../src/interface.h"
-#include "../src/trace.h"
+#include <stdio.h>
 
+#include "../src/gpsim_time.h"
+#include "../src/trace.h"
+#include "../src/xref.h"
 #include "gui.h"
+#include "gui_processor.h"
 #include "gui_trace.h"
 
 #define MAXTRACES  100
@@ -63,21 +66,21 @@ public:
    * that the trace buffer has changed and needs to be updated
    */
 
-  void Update(int )
+  void Update(int ) override
   {
     Trace_Window *tw  = static_cast<Trace_Window *>(parent_window);
 
-    if(!tw  || !tw->enabled)
+    if (!tw  || !tw->enabled)
       return;
 
-    if(!tw->gp || !tw->gp->cpu)
+    if (!tw->gp || !tw->gp->cpu)
       {
         puts("Warning gp or gp->cpu == NULL in TraceWindow_update");
         return;
       }
 
     // If we're not allowing xref updates then exit
-    if( !(tw->trace_flags & GTF_ENABLE_XREF_UPDATES))
+    if ( !(tw->trace_flags & GTF_ENABLE_XREF_UPDATES))
       return;
 
     if (get_trace().string_buffer[0] && (get_trace().string_cycle >= tw->last_cycle)) {
@@ -86,7 +89,7 @@ public:
       tw->trace_map[tw->trace_map_index].simulation_trace_index = get_trace().string_index;
 
       // Advance the trace_map_index using rollover arithmetic
-      if(++tw->trace_map_index >= MAXTRACES)
+      if (++tw->trace_map_index >= MAXTRACES)
         tw->trace_map_index = 0;
 
       GtkListStore *list = tw->trace_list;
@@ -98,7 +101,7 @@ public:
         TRACE_COLUMN, get_trace().string_buffer,
         -1);
 
-      if (gtk_tree_model_iter_n_children(GTK_TREE_MODEL(list), NULL) > MAXTRACES) {
+      if (gtk_tree_model_iter_n_children(GTK_TREE_MODEL(list), nullptr) > MAXTRACES) {
         gtk_tree_model_get_iter_first(GTK_TREE_MODEL(list), &iter);
         gtk_list_store_remove(list, &iter);
       }
@@ -126,26 +129,25 @@ public:
  * INPUTS: *tw a pointer to a Trace_Window structure.
  */
 
-void Trace_Window::Update(void)
+void Trace_Window::Update()
 {
-
   //guint64 cycle;
 
-  if(!enabled)
+  if (!enabled)
     return;
 
-  if(!gp || !gp->cpu)
+  if (!gp || !gp->cpu)
   {
-      g_print("Warning gp or gp->cpu == NULL in TraceWindow_update");
-      return;
+    g_print("Warning gp or gp->cpu == NULL in TraceWindow_update");
+    return;
   }
 
   trace_flags |= GTF_ENABLE_XREF_UPDATES;
-  if(get_cycles().get()-last_cycle>=MAXTRACES)
+  if (get_cycles().get() - last_cycle >= MAXTRACES)
     // redraw the whole thing
     get_trace().dump(MAXTRACES, 0);
   else
-    get_trace().dump(get_cycles().get()-last_cycle, 0);
+    get_trace().dump(get_cycles().get() - last_cycle, 0);
 
 
   trace_flags &= ~GTF_ENABLE_XREF_UPDATES;
@@ -161,23 +163,21 @@ void Trace_Window::Update(void)
 
 void Trace_Window::NewProcessor(GUI_Processor *)
 {
-
 #define NAME_SIZE 32
 
   TraceXREF *cross_reference;
 
-  if(!gp)
+  if (!gp)
     return;
 
-  if(!enabled)
+  if (!enabled)
     return;
 
   cross_reference = new TraceXREF();
   cross_reference->parent_window = (gpointer) this;
   cross_reference->data = 0;
-  if(get_trace().xref)
+  if (get_trace().xref)
     get_trace().xref->_add((gpointer) cross_reference);
-
 }
 
 void Trace_Window::cycle_cell_data_function(
@@ -192,7 +192,7 @@ void Trace_Window::cycle_cell_data_function(
 
   gtk_tree_model_get(model, iter, gint(CYCLE_COLUMN), &cycle, -1);
   g_snprintf(buf, sizeof(buf),"0x%016" PRINTF_GINT64_MODIFIER "x", cycle);
-  g_object_set(renderer, "text", buf, NULL);
+  g_object_set(renderer, "text", buf, nullptr);
 }
 
 void Trace_Window::Build()
@@ -216,15 +216,15 @@ void Trace_Window::Build()
   renderer = gtk_cell_renderer_text_new();
   col = gtk_tree_view_column_new_with_attributes("Cycle", renderer,
     "text", CYCLE_COLUMN,
-    NULL);
+    nullptr);
   gtk_tree_view_column_set_cell_data_func(col, renderer,
-    Trace_Window::cycle_cell_data_function, NULL, NULL);
+    Trace_Window::cycle_cell_data_function, nullptr, nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(trace_view), col);
 
   renderer = gtk_cell_renderer_text_new();
   col = gtk_tree_view_column_new_with_attributes("Trace", renderer,
     "text", gint(TRACE_COLUMN),
-    NULL);
+    nullptr);
   gtk_tree_view_append_column(GTK_TREE_VIEW(trace_view), col);
 
   GtkWidget *scrolled_window = gtk_scrolled_window_new(0, 0);
@@ -235,12 +235,12 @@ void Trace_Window::Build()
 
   gtk_widget_show_all(window);
 
-  if(!trace_map) {
+  if (!trace_map) {
     trace_map = new TraceMapping[MAXTRACES];
     trace_map_index = 0;
   }
 
-  enabled=1;
+  enabled = 1;
   bIsBuilt = true;
   last_cycle = 0;
 
@@ -248,7 +248,6 @@ void Trace_Window::Build()
 
   Update();
   UpdateMenuItem();
-
 }
 
 //------------------------------------------------------------------------
@@ -258,7 +257,7 @@ void Trace_Window::Build()
 
 Trace_Window::Trace_Window(GUI_Processor *_gp)
   : GUI_Object("trace"),
-    trace_flags(0), trace_map(0)
+    trace_flags(0), trace_map(nullptr)
 {
   menu = "/menu/Windows/Trace";
 
