@@ -19,9 +19,6 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#include <cstdio>
-#include <cstdlib>
-
 #include "../config.h"
 #ifdef HAVE_GUI
 
@@ -29,17 +26,28 @@ Boston, MA 02111-1307, USA.  */
 #include <gdk/gdk.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib.h>
-#include <cstring>
+#include <glib-object.h>
 
+#include <cstdio>
+
+#include <memory>
+#include <string>
+
+#include "../src/breakpoints.h"
 #include "../src/interface.h"
-#include "../src/cmd_gpsim.h"
-
+#include "../src/processor.h"
+#include "../src/registers.h"
+#include "../src/symbol.h"
+#include "../src/ui.h"
+#include "../src/value.h"
 #include "gui.h"
-#include "preferences.h"
+#include "gui_processor.h"
 #include "gui_register.h"
 #include "gui_regwin.h"
 #include "gui_watch.h"
 
+class gpsimObject;
+
 enum {
   NAMECOL,
   ADDRESSCOL,
@@ -57,13 +65,12 @@ static const gchar *watch_titles[]={"name","address","dec","hex","ascii","bits"}
 
 class ColumnData {
 public:
-  ColumnData(GtkTreeViewColumn *_tc, int col, bool visible);
+  ColumnData(GtkTreeViewColumn *_tc, bool visible);
   void SetVisibility(bool bVisibility);
   bool GetVisibility() { return isVisible;}
 
 private:
   GtkTreeViewColumn *tc;
-  int column;
   bool isVisible;
 };
 
@@ -101,7 +108,7 @@ class WatchWindowXREF : public CrossReferenceToGUI
 {
 public:
   virtual ~WatchWindowXREF();
-  void Update(int new_value);
+  void Update(int new_value) override;
 };
 
 WatchWindowXREF::~WatchWindowXREF()
@@ -123,7 +130,7 @@ void WatchWindowXREF::Update(int)
 
 //========================================================================
 WatchEntry::WatchEntry(REGISTER_TYPE _type, Register *_pRegister)
-  : cpu(0), type(_type), pRegister(_pRegister)
+  : cpu(nullptr), type(_type), pRegister(_pRegister)
 {
 }
 
@@ -133,8 +140,8 @@ WatchEntry::~WatchEntry()
 }
 
 //========================================================================
-ColumnData::ColumnData(GtkTreeViewColumn *_tc, int col, bool visible)
-  : tc(_tc), column(col), isVisible(visible)
+ColumnData::ColumnData(GtkTreeViewColumn *_tc, bool visible)
+  : tc(_tc), isVisible(visible)
 {
   int show = isVisible;
   gtk_tree_view_column_set_visible(tc, show);
@@ -158,12 +165,12 @@ void Watch_Window::ClearWatch(GtkTreeIter *iter)
   gtk_list_store_remove(watch_list, iter);
 }
 
-void Watch_Window::UpdateMenus(void)
+void Watch_Window::UpdateMenus()
 {
   GtkTreeSelection *sel =
     gtk_tree_view_get_selection(GTK_TREE_VIEW(watch_tree));
   GtkTreeIter iter;
-  gboolean selected = gtk_tree_selection_get_selected(sel, NULL, &iter);
+  gboolean selected = gtk_tree_selection_get_selected(sel, nullptr, &iter);
   WatchEntry *entry;
   if (selected) {
     gtk_tree_model_get(GTK_TREE_MODEL(watch_list), &iter, ENTRYCOL, &entry, -1);
@@ -172,22 +179,23 @@ void Watch_Window::UpdateMenus(void)
   for (size_t i = 0; i < G_N_ELEMENTS(menu_items); ++i) {
     GtkWidget *item = popup_items[i];
     if (menu_items[i].id != MENU_COLUMNS) {
-      if(menu_items[i].id!=MENU_COLUMNS &&
+      if (menu_items[i].id !=MENU_COLUMNS &&
           (!selected ||
-          (entry->type==REGISTER_EEPROM && menu_items[i].id==MENU_BREAK_CLEAR)||
-          (entry->type==REGISTER_EEPROM && menu_items[i].id==MENU_BREAK_READ)||
-          (entry->type==REGISTER_EEPROM && menu_items[i].id==MENU_BREAK_WRITE)||
-          (entry->type==REGISTER_EEPROM && menu_items[i].id==MENU_BREAK_READ_VALUE)||
-          (entry->type==REGISTER_EEPROM && menu_items[i].id==MENU_BREAK_WRITE_VALUE)
+          (entry->type == REGISTER_EEPROM && menu_items[i].id == MENU_BREAK_CLEAR) ||
+          (entry->type == REGISTER_EEPROM && menu_items[i].id == MENU_BREAK_READ) ||
+          (entry->type == REGISTER_EEPROM && menu_items[i].id == MENU_BREAK_WRITE) ||
+          (entry->type == REGISTER_EEPROM && menu_items[i].id == MENU_BREAK_READ_VALUE) ||
+          (entry->type == REGISTER_EEPROM && menu_items[i].id == MENU_BREAK_WRITE_VALUE)
           ))
-        gtk_widget_set_sensitive (item, FALSE);
+        gtk_widget_set_sensitive(item, FALSE);
       else
-        gtk_widget_set_sensitive (item, TRUE);
+        gtk_widget_set_sensitive(item, TRUE);
     }
   }
 }
 
-int Watch_Window::set_config(void) {
+int Watch_Window::set_config()
+{
   int iRet = GUI_Object::set_config();
   WriteSymbolList();
   return iRet;
@@ -226,7 +234,7 @@ void Watch_Window::DeleteSymbolList()
   char cwv[100];
   for (int i = 0; i < 1000; ++i) {
     g_snprintf(cwv, sizeof(cwv), "WV%d", i);
-    if (config_remove(name(), cwv) == 0 ) {
+    if (config_remove(name(), cwv) == 0) {
       break;
     }
   }
@@ -242,7 +250,7 @@ void Watch_Window::ReadSymbolList()
     vname = 0;
     if (config_get_string(name(), cwv, &vname) ) {
       Value *val = globalSymbolTable().findValue(vname);
-      if(val)
+      if (val)
         Add(val);
     }
     else
@@ -254,14 +262,14 @@ void Watch_Window::ReadSymbolList()
 void Watch_Window::popup_activated(GtkWidget *widget, gpointer data)
 {
   Watch_Window *ww = static_cast<Watch_Window *>(data);
-  WatchEntry *entry = NULL;
+  WatchEntry *entry = nullptr;
 
   int value;
 
   GtkTreeSelection *sel
     = gtk_tree_view_get_selection(GTK_TREE_VIEW(ww->watch_tree));
   GtkTreeIter iter;
-  gboolean selected = gtk_tree_selection_get_selected(sel, NULL, &iter);
+  gboolean selected = gtk_tree_selection_get_selected(sel, nullptr, &iter);
 
   if (selected) {
     gtk_tree_model_get(GTK_TREE_MODEL(ww->watch_list), &iter, ENTRYCOL, &entry, -1);
@@ -277,14 +285,14 @@ void Watch_Window::popup_activated(GtkWidget *widget, gpointer data)
   if (!entry || !entry->cpu)
     return;
 
-  switch(id)
+  switch (id)
     {
     case MENU_REMOVE:
       ww->ClearWatch(&iter);
       break;
     case MENU_SET_VALUE:
       value = gui_get_value("value:");
-      if(value<0)
+      if (value < 0)
         break; // Cancel
       entry->put_value(value);
       break;
@@ -296,13 +304,13 @@ void Watch_Window::popup_activated(GtkWidget *widget, gpointer data)
       break;
     case MENU_BREAK_READ_VALUE:
       value = gui_get_value("value to read for breakpoint:");
-      if(value<0)
+      if (value < 0)
         break; // Cancel
       get_bp().set_read_value_break(entry->cpu,entry->address,value);
       break;
     case MENU_BREAK_WRITE_VALUE:
       value = gui_get_value("value to write for breakpoint:");
-      if(value<0)
+      if (value < 0)
         break; // Cancel
       get_bp().set_write_value_break(entry->cpu,entry->address,value);
       break;
@@ -333,14 +341,14 @@ void Watch_Window::select_columns()
   dialog = gtk_dialog_new_with_buttons("", GTK_WINDOW(window),
     GTK_DIALOG_MODAL,
     "_Close", GTK_RESPONSE_CLOSE,
-    NULL);
+    nullptr);
 
   GtkWidget *area = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
 
   gtk_container_set_border_width(GTK_CONTAINER(dialog), 30);
 
   for (size_t i = 0; i < COLUMNS; ++i) {
-    GtkWidget *button = gtk_check_button_new_with_label((gchar *)watch_titles[i]);
+    GtkWidget *button = gtk_check_button_new_with_label(watch_titles[i]);
     g_object_set_data(G_OBJECT(button), "id", GSIZE_TO_POINTER(i));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),
       coldata[i].GetVisibility());
@@ -379,8 +387,8 @@ gboolean Watch_Window::do_popup(GtkWidget *, GdkEventButton *event,
 {
   GtkWidget *popup = ww->popup_menu;
 
-  if  ((event->type == GDK_BUTTON_PRESS) &&  (event->button == 3)) {
-    gtk_menu_popup(GTK_MENU(popup), 0, 0, 0, 0, 3, event->time);
+  if ((event->type == GDK_BUTTON_PRESS) &&  (event->button == 3)) {
+    gtk_menu_popup(GTK_MENU(popup), nullptr, nullptr, nullptr, nullptr, 3, event->time);
     return TRUE;
   }
 
@@ -396,13 +404,13 @@ key_press(GtkWidget *,
 
   if (!ww || !ww->gp || !ww->gp->cpu) return FALSE;
 
-  switch(key->keyval) {
+  switch (key->keyval) {
 
   case GDK_KEY_Delete:
     GtkTreeSelection *sel
       = gtk_tree_view_get_selection(GTK_TREE_VIEW(ww->watch_tree));
     GtkTreeIter iter;
-    if (gtk_tree_selection_get_selected(sel, NULL, &iter))
+    if (gtk_tree_selection_get_selected(sel, nullptr, &iter))
       ww->ClearWatch(&iter);
     break;
   }
@@ -416,7 +424,7 @@ void Watch_Window::watch_list_row_selected(GtkTreeSelection *sel, Watch_Window *
 
   GtkTreeIter iter;
 
-  if (!gtk_tree_selection_get_selected(sel, NULL, &iter))
+  if (!gtk_tree_selection_get_selected(sel, nullptr, &iter))
     return;
 
   gtk_tree_model_get(GTK_TREE_MODEL(ww->watch_list), &iter, ENTRYCOL, &entry, -1);
@@ -459,7 +467,7 @@ void Watch_Window::UpdateWatch(GtkTreeIter *iter)
 
   entry->put_shadow(rvNewValue);
 
-  if(entry->pRegister) {
+  if (entry->pRegister) {
     rvMaskedNewValue = entry->pRegister->getRV_notrace();
     uBitmask = entry->pRegister->mValidBits; //getBitmask();
   }
@@ -484,7 +492,7 @@ void Watch_Window::UpdateWatch(GtkTreeIter *iter)
 
   // Bit representation
   char sBits[25];
-  rvNewValue.toBitStr(sBits, 25, entry->cpu->register_mask(), NULL);
+  rvNewValue.toBitStr(sBits, 25, entry->cpu->register_mask(), nullptr);
 
   gtk_list_store_set(watch_list, iter,
     DECIMALCOL, str,
@@ -519,11 +527,10 @@ void Watch_Window::Update()
 
 void Watch_Window::Add(REGISTER_TYPE type, GUIRegister *reg, Register * pReg)
 {
-
-  if(!gp || !gp->cpu || !reg || !reg->bIsValid())
+  if (!gp || !gp->cpu || !reg || !reg->bIsValid())
     return;
 
-  if(!enabled)
+  if (!enabled)
     Build();
 
   pReg = pReg ? pReg : reg->get_register();
@@ -533,13 +540,13 @@ void Watch_Window::Add(REGISTER_TYPE type, GUIRegister *reg, Register * pReg)
   unsigned int uAddrMask = 0;
   unsigned int uLastAddr = gp->cpu->register_memory_size() - 1;
   while (uLastAddr) {
-    uLastAddr>>=4;
-    uAddrMask<<=4;
+    uLastAddr >>= 4;
+    uAddrMask <<= 4;
     uAddrMask |= 0xf;
   }
 
   WatchEntry *watch_entry = new WatchEntry(type, pReg);
-  watch_entry->address=reg->address;
+  watch_entry->address = reg->address;
   watch_entry->cpu = gp->cpu;
   watch_entry->rma = reg->rma;
 
@@ -573,17 +580,18 @@ void Watch_Window::Add(REGISTER_TYPE type, GUIRegister *reg, Register * pReg)
 
 void Watch_Window::Add( Value *regSym)
 {
-  if(regSym && gp) {
+  if (regSym && gp) {
 
     Register *reg = dynamic_cast<Register *>(regSym);
 
-    if(reg) 
+    if (reg)
     {
       GUIRegister *greg = gp->m_pGUIRamRegisters->Get(reg->getAddress());
       Add(REGISTER_RAM, greg, reg);
     }
   }
 }
+
 //------------------------------------------------------------------------
 // NewSymbols
 //
@@ -621,7 +629,7 @@ void Watch_Window::Build()
   for (size_t i = 0; i < COLUMNS; i++) {
     GtkCellRenderer *renderer = gtk_cell_renderer_text_new();
     GtkTreeViewColumn *column = gtk_tree_view_column_new_with_attributes(
-      watch_titles[i], renderer, "text", int(i), NULL);
+      watch_titles[i], renderer, "text", int(i), nullptr);
     gtk_tree_view_column_set_resizable(column, TRUE);
     gtk_tree_view_append_column(GTK_TREE_VIEW(watch_tree), column);
 
@@ -629,17 +637,17 @@ void Watch_Window::Build()
     if (!config_get_variable(name(), (gchar *)watch_titles[i], &vis))
       config_set_variable(name(), (gchar *)watch_titles[i], 1);
 
-    coldata.push_back(ColumnData(column, i, vis));
+    coldata.push_back(ColumnData(column, vis));
   }
 
   {
     // Fix a db error in previous versions of gpsim
     int j;
-    while (config_get_variable(name(),"hex",&j))
+    while (config_get_variable(name(), "hex", &j))
       config_remove(name(), "hex");
 
-    const int hexIndex=3;
-    config_set_variable(name(),(gchar *)watch_titles[hexIndex],coldata[hexIndex].GetVisibility());
+    const int hexIndex = 3;
+    config_set_variable(name(), watch_titles[hexIndex], coldata[hexIndex].GetVisibility());
   }
 
   // TODO:No column sorting for now
@@ -651,7 +659,7 @@ void Watch_Window::Build()
   g_signal_connect(watch_tree, "button_press_event", G_CALLBACK(do_popup), this);
   g_signal_connect(watch_tree, "key_press_event", G_CALLBACK(key_press), this);
 
-  scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+  scrolled_window = gtk_scrolled_window_new(nullptr, nullptr);
 
   vbox = gtk_vbox_new(FALSE, 0);
 
@@ -666,21 +674,19 @@ void Watch_Window::Build()
   gtk_widget_show_all(window);
 
 
-  enabled=1;
+  enabled = 1;
 
   bIsBuilt = true;
 
   UpdateMenuItem();
-
 }
 
 Watch_Window::Watch_Window(GUI_Processor *_gp)
-  : GUI_Object("watch_viewer")
+  : GUI_Object("watch_viewer"), watch_list(nullptr)
 {
   menu = "/menu/Windows/Watch";
 
   gp = _gp;
-  watch_list = 0;
 
   if (enabled)
     Build();
