@@ -19,11 +19,22 @@ along with gpsim; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
-#ifndef __GUI_WATCH_H__
-#define __GUI_WATCH_H__
+#ifndef GUI_GUI_WATCH_H_
+#define GUI_GUI_WATCH_H_
 
-#include "gui_register.h"
+#include <gdk/gdk.h>
 #include <gtk/gtk.h>
+#include <glib.h>
+
+#include <vector>
+
+#include "../src/interface.h"
+#include "gui_object.h"
+#include "gui_register.h"
+
+class GUI_Processor;
+class Processor;
+class Register;
 
 class WatchEntry : public GUIRegister {
 public:
@@ -45,23 +56,23 @@ class ColumnData;
 //
 class Watch_Window : public  GUI_Object
 {
- public:
+public:
   GtkListStore *watch_list;
   GtkWidget *watch_tree;
 
   explicit Watch_Window(GUI_Processor *gp);
-  virtual void Build();
+  void Build() override;
   virtual void ClearWatch(GtkTreeIter *iter);
   virtual void UpdateWatch(GtkTreeIter *iter);
 
-  virtual void Add(REGISTER_TYPE type, GUIRegister *reg, Register * pReg=0);
+  virtual void Add(REGISTER_TYPE type, GUIRegister *reg, Register *pReg = nullptr);
   virtual void Add(Value *);
-  virtual void Update();
+  void Update() override;
   virtual void UpdateMenus();
-  virtual void NewProcessor(GUI_Processor *gp);
+  void NewProcessor(GUI_Processor *gp) override;
 
   // Override set_config() to save variable list on app exit
-  virtual int set_config();
+  int set_config() override;
   void         ReadSymbolList();
   void         WriteSymbolList();
   void         DeleteSymbolList();
@@ -86,4 +97,4 @@ private:
 };
 
 
-#endif //__GUI_WATCH_H__
+#endif // GUI_GUI_WATCH_H_
