@@ -44,10 +44,9 @@ support:
 /* IN_MODULE should be defined for modules */
 #define IN_MODULE
 
-#include <iostream>
-#include <cstring>
-
 #include <cstdio>
+#include <cstring>
+#include <iostream>
 
 #include "../config.h"    // get the definition for HAVE_GUI
 
@@ -60,8 +59,8 @@ support:
 #endif
 #include "switch.h"
 #include "logic.h"
-#ifdef HAVE_GUI
 #include "led.h"
+#ifdef HAVE_GUI
 #include "push_button.h"
 #include "video.h"
 #include "encoder.h"
@@ -73,7 +72,7 @@ support:
 #include "i2c2par.h"
 
 
-Module_Types available_modules[] = {
+static Module_Types available_modules[] = {
 
 #ifndef _WIN32
   // Parallel port interface
@@ -93,15 +92,17 @@ Module_Types available_modules[] = {
   { {"xor2", "xor2"}, XOR2Gate::construct},
   { {"not",  "not"},  NOTGate::construct},
 
-#ifdef HAVE_GUI
   // Leds
   { {"led_7segments", "led7s"}, Leds::Led_7Segments::construct},
   { {"led", "led"}, Leds::Led::construct},
+#ifdef HAVE_GUI
   { {"push_button",      "pb"},   PushButton::construct },
 #endif
   { {"PortStimulus",     "ps"},   ExtendedStimuli::PortStimulus::construct8 },
-  { {"PortStimulus16",   "ps"},   ExtendedStimuli::PortStimulus::construct16 },
-  { {"PortStimulus32",   "ps"},   ExtendedStimuli::PortStimulus::construct32 },
+/* these do not make sense RRR 20/9/2020 as registers are 8 bits wide
+  { {"PortStimulus16",   "ps16"},   ExtendedStimuli::PortStimulus::construct16 },
+  { {"PortStimulus32",   "ps32"},   ExtendedStimuli::PortStimulus::construct32 },
+*/
   { {"pullup",           "pu"},   PullupResistor::pu_construct },
   { {"pulldown",         "pd"},   PullupResistor::pd_construct },
   { {"pulsegen",         "pg"},   ExtendedStimuli::PulseGen::construct },
@@ -133,7 +134,7 @@ Module_Types available_modules[] = {
   { {"i2c2par", "I2C2PAR"},   I2C2PAR_Modules::i2c2par::construct },
 
   // No more modules
-  { {0, 0}, 0}
+  { {nullptr, nullptr}, nullptr}
 };
 
 #ifdef __cplusplus
@@ -160,11 +161,12 @@ Module_Types *get_mod_list()
  */
 void mod_list()
 {
-  size_t number_of = sizeof(available_modules) / sizeof(Module_Types);
-  size_t i, j, l;
-  size_t k, longest;
+  const size_t number_of = sizeof(available_modules) / sizeof(Module_Types);
+  size_t i;
+  size_t k;
+  size_t longest = 0;
 
-  for (i = 0, longest = 0; i < number_of; i++) {
+  for (i = 0; i < number_of; i++) {
     k = strlen(available_modules[i].names[1]);
 
     if (k > longest) {
@@ -179,9 +181,9 @@ void mod_list()
       std::cout << available_modules[k].names[1];
 
       if (i < 3) {
-        l = longest + 2 - strlen(available_modules[k].names[1]);
+        const size_t l = longest + 2 - strlen(available_modules[k].names[1]);
 
-        for (j = 0; j < l; j++) {
+        for (size_t j = 0; j < l; j++) {
           std::cout << ' ';
         }
       }
@@ -201,7 +203,7 @@ void mod_list()
 void init()
 {
   //cout << "gpsim modules has been opened\n";
-  printf("%s\n", __FUNCTION__);
+  printf("%s\n", __func__);
 }
 
 
@@ -212,14 +214,14 @@ void init()
 void fini()
 {
   //cout << "gpsim modules has been closed\n";
-  printf("%s\n", __FUNCTION__);
+  printf("%s\n", __func__);
 }
 
 
 void test()
 {
   //cout << "This is a test\n";
-  printf("%s\n", __FUNCTION__);
+  printf("%s\n", __func__);
 }
 
 #ifdef __cplusplus
