@@ -31,6 +31,7 @@ class Processor;
 #include "../src/stimuli.h"
 #include "../src/packages.h"
 
+#include <algorithm>
 #include <string>
 
 namespace I2C_EEPROM_Modules {
@@ -65,10 +66,10 @@ void I2C_ENABLE::setDrivenState(bool bNewState)
 
 
 I2C_EE_Module::I2C_EE_Module(const char *_name)
-  : Module(_name, "EEProm")
+  : Module(_name, "EEProm"),
+    m_eeprom(nullptr), m_wp(nullptr), chip_select(0), att_eeprom(nullptr)
 {
-  //initializeAttributes();
-  chip_select = 0;
+  std::fill_n(m_A, 3, nullptr);
 }
 
 
