@@ -15,13 +15,13 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, see 
+License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
 
-#ifndef __I2C_EEPROM_H__
-#define __I2C_EEPROM_H__
+#ifndef MODULES_I2C_EEPROM_H_
+#define MODULES_I2C_EEPROM_H_
 
 /* IN_MODULE should be defined for modules */
 #define IN_MODULE
@@ -35,28 +35,26 @@ namespace I2C_EEPROM_Modules {
 
 class I2C_ENABLE;
 
-  class I2C_EE_Module : public Module
-  {
-  public:
-    I2C_EE_Module(const char *_name);
-    ~I2C_EE_Module();
-    static Module *construct_2k(const char *new_name);
-    static Module *construct_16k(const char *new_name);
-    static Module *construct_256k(const char *new_name);
+class I2C_EE_Module : public Module {
+public:
+  explicit I2C_EE_Module(const char *_name);
+  ~I2C_EE_Module();
 
-    virtual void create_iopin_map();
-    virtual void setEnable(bool bNewState, unsigned int m_bit);
-  protected:
+  static Module *construct_2k(const char *new_name);
+  static Module *construct_16k(const char *new_name);
+  static Module *construct_256k(const char *new_name);
 
-    I2C_EE *m_eeprom;
-    I2C_ENABLE *m_A[3];
-    I2C_ENABLE *m_wp;
-    unsigned int chip_select;	// Write Protect and A0 - A2 state
-    PromAddress *att_eeprom;   
+  virtual void create_iopin_map();
+  virtual void setEnable(bool bNewState, unsigned int m_bit);
 
-  };
-  
+protected:
+  I2C_EE *m_eeprom;
+  I2C_ENABLE *m_A[3];
+  I2C_ENABLE *m_wp;
+  unsigned int chip_select;	// Write Protect and A0 - A2 state
+  PromAddress *att_eeprom;
+};
 
 } // end of namespace I2C_EEEPROM_Modules
 
-#endif // __I2C_EEPROM_H__
+#endif // MODULES_I2C_EEPROM_H_
