@@ -475,7 +475,10 @@ I2CMaster::I2CMaster(const char *_name)
   : TriggerObject(), Module(_name),
     m_bitCount(0), m_command(0),
     m_xfr_data(0),
+    m_TxData(0),
+    m_nextBit(false),
     future_cycle(0),
+    m_pI2CModule(nullptr),
     m_uState(eI2CIdle),
     m_mState(eI2CIdleBus),
     m_MSBmask(1 << 8)
