@@ -74,6 +74,8 @@ License along with this library; if not, see
 
 #ifdef HAVE_GUI
 #include <gtk/gtk.h>
+#endif
+
 #include <cmath>
 
 #include "../src/stimuli.h"
@@ -102,9 +104,13 @@ public:
   }
   virtual void Update(gpointer /* object */ )
   {
+#ifdef HAVE_GUI
+
     if (led) {
       led->update();
     }
+
+#endif
   }
 
   explicit LED_Interface(Led_base *_led)
@@ -149,6 +155,9 @@ void Led_Input::get(char *return_str, int len)
 
 
 //------------------------------------------------------------------------
+
+#ifdef HAVE_GUI
+
 void Led_7Segments::update()
 {
   if (get_interface().bUsingGUI()) {
@@ -355,17 +364,21 @@ void Led_7Segments::build_window()
   set_widget(darea);
 }
 
+#endif
 
 //--------------------------------------------------------------
 
 Led_7Segments::Led_7Segments(const char *name)
   : Module(name, "7 Segment LED")
 {
+#ifdef HAVE_GUI
+
   if (get_interface().bUsingGUI()) {
     build_segments(100, 110);
     build_window();
   }
 
+#endif
   interface_seq_no = get_interface().add_interface(new LED_Interface(this));
   create_iopin_map();
 }
@@ -625,6 +638,8 @@ bool ActiveStateAttribute::Parse(const char *pValue, ActiveStates &bValue)
 //-------------------------------------------------------------
 // Led (simple)
 //-------------------------------------------------------------
+#ifdef HAVE_GUI
+
 void Led::update()
 {
   if (get_interface().bUsingGUI()) {
@@ -632,15 +647,18 @@ void Led::update()
   }
 }
 
+#endif
 
 void Led::set_on_color(Colors color)
 {
   if (color != on_color) {
     on_color = color;
 
+#ifdef HAVE_GUI
     if (get_interface().bUsingGUI()) {
       update();
     }
+#endif
   }
 }
 
@@ -657,12 +675,15 @@ void Led::set_the_activestate(ActiveStates activestate)
 
     the_activestate = activestate;
 
+#ifdef HAVE_GUI
     if (get_interface().bUsingGUI()) {
       update();
     }
+#endif
   }
 }
 
+#ifdef HAVE_GUI
 
 gboolean Led::led_expose_event(GtkWidget *widget, GdkEvent * ,
                                gpointer user_data)
@@ -727,6 +748,8 @@ void Led::build_window()
 }
 
 
+#endif
+
 //--------------------------------------------------------------
 
 Led::Led(const char *name)
@@ -738,9 +761,11 @@ Led::Led(const char *name)
   m_pin->set_Zth(150.0);
   m_pin->set_Vth(0.0);
 
+#ifdef HAVE_GUI
   if (get_interface().bUsingGUI()) {
     build_window();
   }
+#endif
 
   m_colorAttribute = new ColorAttribute(this);
   addSymbol(m_colorAttribute);
@@ -793,4 +818,3 @@ Module * Led::construct(const char *_new_name = nullptr)
 }
 
 }
-#endif //HAVE_GUI
