@@ -38,9 +38,12 @@ In here you'll find some simple logic devices:
 
 #ifdef HAVE_GUI
 #include <gtk/gtk.h>
+#include <gdk/gdk.h>
+#include <glib.h>
+#include <cairo.h>
 
 /* XPM */
-static const gchar * and2_pixmap[] = {
+static const char * and2_pixmap[] = {
   "32 32 3 1",
   "       c black",
   ".      c None",
@@ -80,7 +83,7 @@ static const gchar * and2_pixmap[] = {
 };
 
 /* XPM */
-static const gchar * or2_pixmap[] = {
+static const char * or2_pixmap[] = {
   "32 32 3 1",
   "       c black",
   ".      c None",
@@ -119,7 +122,7 @@ static const gchar * or2_pixmap[] = {
   "                    ............"
 };
 
-static const gchar * xor2_pixmap[] = {
+static const char * xor2_pixmap[] = {
   "40 32 3 1",
   "       c None",
   ".      c black",
@@ -158,7 +161,7 @@ static const gchar * xor2_pixmap[] = {
   "  ..    ........................        "
 };
 
-static const gchar * not_pixmap[] = {
+static const char * not_pixmap[] = {
   "32 32 3 1",
   "       c black",
   ".      c None",
@@ -204,6 +207,8 @@ static const gchar * not_pixmap[] = {
 #include "logic.h"
 #include "../src/packages.h"
 #include "../src/gpsim_interface.h"
+#include "../src/modules.h"
+#include "../src/stimuli.h"
 #include "../src/ui.h"
 
 //--------------------------------------------------------------
@@ -334,12 +339,12 @@ void LogicGate::update_input_pin(unsigned int pin, bool bValue)
 
 void LogicGate::create_iopin_map()
 {
-  int i;
   // Define the physical package.
   //   The Package class, which is a parent of all of the modules,
   //   is responsible for allocating memory for the I/O pins.
   //
   create_pkg(number_of_pins);
+
   // Define the I/O pins and assign them to the package.
   //   There are two things happening here. First, there is
   //   a new I/O pin that is being created. For the binary
@@ -352,6 +357,7 @@ void LogicGate::create_iopin_map()
   // 0 on the I/O port while the inputs go to positions 1 and above
 #define OUTPUT_BITPOSITION 0
 #define INPUT_FIRST_BITPOSITION (OUTPUT_BITPOSITION + 1)
+
   // Here, we name the port `pin'. So in gpsim, we will reference
   //   the bit positions as U1.pin0, U1.pin1, ..., where U1 is the
   //   name of the logic gate (which is assigned by the user and
@@ -365,24 +371,23 @@ void LogicGate::create_iopin_map()
   // Position pin on middle right side of package
   package->set_pin_position(1, 2.5);
   assign_pin(OUTPUT_BITPOSITION + 1, pOutputPin);
-  Logic_Input *LIP;
-  int j;
-  pInputPins = (IOPIN **) new char[sizeof(IOPIN *) * (number_of_pins - 1)];
-  std::string inname;
+  int i, j;
+
+  pInputPins = new IOPIN *[number_of_pins - 1];
+  char inname[14];
 
   for (i = j = INPUT_FIRST_BITPOSITION; i < number_of_pins; i++) {
-    char pin_number = i - j + '0';
-    //RRRinname = name() + ".in" + pin_number;
-    inname = (std::string)"in" + pin_number;
-    //p[2] = i-j +'0';
-    LIP = new Logic_Input(this, i - INPUT_FIRST_BITPOSITION, inname.c_str());
+    int pin_number = i - j;
+    snprintf(inname, sizeof(inname), "in%d", pin_number);
+
+    auto LIP = new Logic_Input(this, i - INPUT_FIRST_BITPOSITION, inname);
     pInputPins[i - INPUT_FIRST_BITPOSITION] = LIP;
 
     if (number_of_pins == 2) {
-      package->set_pin_position(i + 1, 0.5);  // Left side of package
+      package->set_pin_position(i + 1, 0.5f);  // Left side of package
 
     } else {
-      package->set_pin_position(i + 1, (float)((i - INPUT_FIRST_BITPOSITION) * 0.9999));  // Left side of package
+      package->set_pin_position(i + 1, ((i - INPUT_FIRST_BITPOSITION) * 0.9999f));  // Left side of package
     }
 
     addSymbol(LIP);
@@ -413,7 +418,7 @@ static gboolean expose(GtkWidget *widget, GdkEventExpose * , LogicGate *lg)
 }
 
 
-GtkWidget *LogicGate::create_pixmap(const gchar **pixmap_data)
+GtkWidget *LogicGate::create_pixmap(const char **pixmap_data)
 {
   pixbuf = gdk_pixbuf_new_from_xpm_data(pixmap_data);
   int width = gdk_pixbuf_get_width(pixbuf);
