@@ -32,6 +32,7 @@ License along with this library; if not, see
 
 #ifdef HAVE_GUI
 #include <gtk/gtk.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 #endif
 
 class LogicGate;
@@ -56,19 +57,19 @@ public:
   {
   }
 
-  virtual void setDrivenState(bool new_state);
+  void setDrivenState(bool new_state) override;
   //RRR  virtual void get(char *return_str, int len);
 };
 
 
 class Logic_Output : public IO_bi_directional {
 private:
-  LogicGate *LGParent;
-  unsigned int m_iobit;
+//  LogicGate *LGParent;
+//  unsigned int m_iobit;
 
 public:
   Logic_Output(LogicGate *parent, unsigned int b, const char *opt_name = nullptr)
-    : IO_bi_directional(opt_name), LGParent(parent), m_iobit(b)
+    : IO_bi_directional(opt_name) //, LGParent(parent), m_iobit(b)
   {
   }
 
@@ -125,7 +126,7 @@ public:
     number_of_pins = npins;
   }
 #ifdef HAVE_GUI
-  GtkWidget *create_pixmap(const gchar **pixmap_data);
+  GtkWidget *create_pixmap(const char **pixmap_data);
 #endif
 };
 
@@ -137,7 +138,7 @@ public:
   ANDGate(const char *name, const char * desc);
   ~ANDGate();
 
-  virtual void update_state();
+  void update_state() override;
 };
 
 
@@ -160,7 +161,7 @@ public:
   ORGate(const char *name, const char * desc);
   ~ORGate();
 
-  virtual void update_state();
+  void update_state() override;
 };
 
 
@@ -185,7 +186,7 @@ public:
   XORGate(const char *name, const char * desc);
   ~XORGate();
 
-  virtual void update_state();
+  void update_state() override;
 };
 
 
@@ -216,7 +217,7 @@ public:
   {
     return "not";
   }
-  virtual void update_state();
+  void update_state() override;
 };
 
 
