@@ -1,5 +1,6 @@
 /*
    Copyright (C) 2006 Scott Dattalo
+   Copyright (C) 2020 Roy R. Rankin
 
 This file is part of the libgpsim_modules library of gpsim
 
@@ -64,10 +65,59 @@ License along with this library; if not, see
 
   FileStimulus - time and values are taken from a file.
     .file - Name of input file.
+    .pin  - Output pin
+    .xpos - module x position on breadboard
+    .ypos - module y position on breadboard
+
+    The input file contains two columns of data seperated by
+    one or more tabs and/or spaces.
+
+    The first column is the cycle in base 10.
+    The second column is the pin drive voltage.
+    
 
   FileRecorder - time and values are written to a file.
-    .file - name of file or pipe to write data to
-    .in_digital - is the signal digital (true) or analog (false)
+    .file    - name of file or pipe to write data to
+    .digital - is the signal digital (true) or analog (false)
+    .pin     - Input pin
+    .xpos    - module x position on breadboard
+    .ypos    - module y position on breadboard
+
+    The first column is the cycle that pin state changes.
+    If .digital=true, second column is pin state - high(1) or low(0)
+    If .digital=false (default), second column is the input pin voltage.
+        In this mode the output is suitable for input for FileStimulus.
+
+  PortStimulus - module with 8 IO pins
+    .portAdr - Output port register address
+    .trisAdr - Tristate register address
+    .latAdr  - Output latch address
+    .pullupAdr - Pullup register address
+    .p1-.p8  - IO pins
+    .xpos    - module x position on breadboard
+    .ypos    - module y position on breadboard
+
+    This module acts like a processor port module.
+    Assuming the module is loaded with name P1,
+    first declare data memory resgisters as follows:
+            UDATA 0x10
+	P1_Port RES 1
+	P1_Tris RES 1
+	P1_Lat  RES 1
+	P1_Pullup RES 1
+           GLOBAL P1_Port, P1_Tris, P1_Lat, P1_Pullup
+	...
+
+        ;# specify the PortStimulus addresses.
+        ;  These are the PIC addresses to where the PortStimulus 
+        ;  registers are mapped.
+          .sim "P1.portAdr = &P1_Port"
+          .sim "P1.trisAdr = &P1_Tris"
+          .sim "P1.latAdr  = &P1_Lat"
+          .sim "P1.pullupAdr  = &P1_Pullup"
+
+    Then to access the module register just do operations on the relevant
+    on the data registers. i.e.  movwf P1_Lat
 
 */
 
@@ -80,14 +130,17 @@ License along with this library; if not, see
 #include <sstream>
 #include <iostream>
 
-#include "../config.h"
-#include "../src/gpsim_time.h"
 #include "m_stimuli.h"
+#include "module_attribute.h"
+
+#include "../src/gpsim_time.h"
 #include "../src/pic-ioports.h"
-#include "../src/symbol.h"
+#include "../src/registers.h"
+#include "../src/stimuli.h"
 #include "../src/trace.h"
 #include "../src/processor.h"
 #include "../src/packages.h"
+#include "../src/ui.h"
 
 namespace ExtendedStimuli {
 
@@ -125,7 +178,7 @@ public:
 
 private:
   PulseGen *m_pParent;
-  double    m_voltage;
+//  double    m_voltage;
 };
 
 
@@ -169,7 +222,7 @@ void PulsePeriodAttribute::set(gint64 i)
 PulseInitial::PulseInitial(PulseGen *pParent,
                            const char *_name, const char * desc,
                            double voltage)
-  : Float(_name, 0, desc), m_pParent(pParent), m_voltage(voltage)
+  : Float(_name, 0, desc), m_pParent(pParent) //, m_voltage(voltage)
 {
 }
 
@@ -478,7 +531,6 @@ std::string PulseGen::toString()
     ++si;
   }
 
-  sOut << std::ends;
   return sOut.str();
 }
 
@@ -514,7 +566,8 @@ FileStimulus::FileStimulus(const char *_name)
   : StimulusBase(_name,
       "File Stimulus\n"
       " Attributes:\n"
-      " .file - name of file or pipe supplying data\n")
+      " .file - name of file or pipe supplying data\n"),
+      m_future_value(0.0)
 {
   // Attributes for the pulse generator.
   m_filename = new FileNameAttribute<FileStimulus>(this);
@@ -536,17 +589,15 @@ void FileStimulus::newFile()
   delete m_fp;
   m_fp = nullptr;
 
-  char fname[20] = "";
-  m_filename->get(fname, 20);
-
-  if (fname[0]) {
-    m_fp = new std::ifstream(fname);
-
-    if (m_fp->fail()) {
-      printf("Warning can't open Stimulus file %s\n", fname);
-      delete m_fp;
-      m_fp = nullptr;
-      return;
+  if (m_filename->getVal())
+  {
+    m_fp = new std::ifstream(m_filename->getVal());
+    if (m_fp->fail())
+    {
+	std::cerr << "Warning " << name() << " cannot open " << m_filename->getVal() << std::endl;
+	delete m_fp;
+	m_fp = nullptr;
+	return;
     }
   }
 
@@ -568,7 +619,13 @@ void FileStimulus::parseLine(bool first)
     return;
   }
 
-  if (verbose) {
+  if (m_fp->fail())
+  {
+     std::cerr << "File Error " << name() << " " << m_filename->getVal() << std::endl;
+     return;
+  }
+  if (verbose) 
+  {
     std::cout << this->name() << " read " << std::dec << m_future_value << " @ 0x"
          << std::hex << m_future_cycle << '\n';
   }
@@ -646,7 +703,7 @@ void Recorder_Input::set_nodeVoltage(double v)
 {
   IOPIN::set_nodeVoltage(v);
 
-  if (is_digital()) {
+  if (!is_digital()) {
     m_pParent->record(v);
   }
 }
@@ -674,7 +731,7 @@ FileRecorder::FileRecorder(const char *_name)
       " Attributes:\n"
       " .file - name of file or pipe to write data to\n"
       " .digital - is the signal digital (true) or analog (false)\n"),
-    m_fp(nullptr), m_lastval(99.0)
+    m_fp(nullptr), m_lastval(99.0), int_lastval(99)
 {
   create_pkg(1);
   // Position pin on left side of package
@@ -705,11 +762,16 @@ void FileRecorder::newFile()
   delete m_fp;
 
   m_fp = nullptr;
-  char fname[20] = "";
-  m_filename->get(fname, 20);
 
-  if (fname[0]) {
-    m_fp = new std::ofstream(fname);
+  if (m_filename->getVal())
+  {
+    m_fp = new std::ofstream(m_filename->getVal());
+    if (m_fp->rdstate())
+    {
+	std::cerr << "Warning " << name() << " cannot open " << m_filename->getVal() << std::endl;
+	delete m_fp;
+	m_fp = nullptr;
+    }
   }
 }
 
@@ -718,38 +780,40 @@ void FileRecorder::record(bool NewVal)
 {
   unsigned newvalue = (NewVal ? 1 : 0);
 
-  if (newvalue == m_lastval) {
+
+  if (newvalue == int_lastval) {
     return;
   }
 
   if (m_fp) {
-    gint64 current_cycle = get_cycles().get();
-    *m_fp << std::dec << current_cycle << ' ' << newvalue << '\n';
+    gint64 cur_cycle = get_cycles().get();
+    *m_fp << std::dec << cur_cycle << ' ' << newvalue << std::endl;
 
     if (verbose) {
       std::cout << this->name() << " recording " << newvalue << " @ 0x" << std::hex
-           << current_cycle << '\n';
+           << cur_cycle << '\n';
     }
 
-    m_lastval = newvalue;
+    int_lastval = newvalue;
   }
 }
 
 
 void FileRecorder::record(double NewVal)
 {
+
   if (NewVal == m_lastval) {
     return;
   }
 
   if (m_fp) {
-    gint64 current_cycle = get_cycles().get();
+    gint64 cur_cycle = get_cycles().get();
     m_fp->precision(16);
-    *m_fp << std::dec << current_cycle << ' ' << NewVal << '\n';
+    *m_fp << std::dec << cur_cycle << ' ' << NewVal << std::endl;
 
     if (verbose) {
       std::cout << this->name() << " recording " << NewVal << " @ 0x" << std::hex
-           << current_cycle << '\n';
+           << cur_cycle << '\n';
     }
 
     m_lastval = NewVal;
@@ -937,24 +1001,12 @@ void PortStimulus::callback_print()
 void PortStimulus::create_iopin_map()
 {
   create_pkg(m_nPins);
-  char pinNumber[3];
+  char pinNumber[12];
 
   for (int i = 0; i < m_nPins; i++) {
-    int p = i + 1;
+    snprintf(pinNumber, sizeof(pinNumber), "p%d", i+1);
 
-    if (p < 10) {
-      pinNumber[0] = p + '0';
-      pinNumber[1] = 0;
-
-    } else {
-      pinNumber[0] = (p / 10) + '0';
-      pinNumber[1] = (p % 10) + '0';
-      pinNumber[2] = 0;
-    }
-
-    IO_bi_directional *ppin;
-    //ppin = new IO_bi_directional_pu((name() + ".p" + pinNumber).c_str());
-    ppin = new IO_bi_directional_pu(((std::string)"p" + pinNumber).c_str());
+    auto ppin = new IO_bi_directional_pu(pinNumber);
     ppin->update_direction(IOPIN::DIR_OUTPUT, true);
     assign_pin(i + 1, mPort->addPin(this, ppin, i));
   }
