@@ -22,18 +22,17 @@ License along with this library; if not, see
 #ifndef MODULES_MOD_STIMULI_H_
 #define MODULES_MOD_STIMULI_H_
 
-#ifdef HAVE_GUI
-#include <gtk/gtk.h>
-#endif
 #include <glib.h>
-#include "../src/stimuli.h"
+
 #include "../src/modules.h"
-#include "module_attribute.h"
+#include "../src/trigger.h"
+#include "../src/value.h"
 
 #include <iosfwd>
 #include <list>
 #include <string>
 
+class IO_bi_directional;
 class PicPortRegister;
 class PicTrisRegister;
 class PicLatchRegister;
@@ -111,7 +110,7 @@ private:
 template<typename T>
 class FileNameAttribute : public String {
 public:
-  FileNameAttribute(T *parent);
+  explicit FileNameAttribute(T *parent);
 
   virtual void update();
 
@@ -157,6 +156,7 @@ private:
   Recorder_Input *m_pin;
   std::ofstream *m_fp;
   double m_lastval;
+  unsigned int	 int_lastval;
 };
 
 
