@@ -18,8 +18,8 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
-#if !defined(__MODULE_ATTRIBUTES_H__)
-#define __MODULE_ATTRIBUTES_H__
+#ifndef MODULES_MODULE_ATTRIBUTES_h_
+#define MODULES_MODULE_ATTRIBUTES_h_
 
 #include "../src/value.h"
 
@@ -30,7 +30,7 @@ class BooleanAttribute : public Boolean
 {
 public:
   BooleanAttribute(const char *_name, bool newValue = false,
-		   const char *desc=0)
+		   const char *desc = nullptr)
     : Boolean(_name, newValue, desc)
   {
   }
@@ -39,9 +39,10 @@ public:
 class IntegerAttribute : public Integer
 {
 public:
-  IntegerAttribute(const char *_name, gint64 newValue = 0, const char *desc=0)
+  IntegerAttribute(const char *_name, gint64 newValue = 0, const char *desc = nullptr)
     : Integer(_name, newValue, desc)
   {
   }
 };
-#endif //if !defined(__MODULE_ATTRIBUTES_H__)
+
+#endif // MODULES_MODULE_ATTRIBUTES_h_
