@@ -26,9 +26,6 @@ License along with this library; if not, see
 #define IN_MODULE
 
 #include "../src/modules.h"
-
-#include <gtk/gtk.h>
-
 class IOPIN;
 
 class PushButton : public Module {
@@ -42,7 +39,7 @@ public:
   void update();
 
   // Inheritances from the Package class
-  virtual void create_iopin_map();
+  virtual void create_iopin_map() { _create_iopin_map(); }
 
   // Inheritance from Module class
   const virtual char *type()
@@ -52,6 +49,9 @@ public:
   static Module *construct(const char *new_name);
 
   IOPIN *pshb_pin;
+
+private:
+  void _create_iopin_map();
 };
 
 #endif // MODULES_PSHB_H_
