@@ -47,7 +47,6 @@ License along with this library; if not, see
 #include "../src/stimuli.h"
 #include "../src/value.h"
 #include "../src/ui.h"
-#include "../src/gpsim_interface.h"
 
 //----------------------------------------
 
@@ -64,7 +63,7 @@ public:
     }
   }
 
-  virtual void set(double r)
+  void set(double r) override
   {
     Float::set(r);
 
@@ -74,7 +73,7 @@ public:
     }
   }
 
-  void set(int r)
+  void set(int r) override
   {
     Float::set((double)r);
   }
@@ -96,7 +95,7 @@ public:
     }
   }
 
-  void set(double r)
+  void set(double r) override
   {
     Float::set(r);
 
@@ -106,7 +105,7 @@ public:
     }
   }
 
-  void set(int r)
+  void set(int r) override
   {
     set(double(r));
   }
@@ -128,7 +127,7 @@ public:
     }
   }
 
-  void set(double r)
+  void set(double r) override
   {
     Float::set(r);
 
@@ -138,7 +137,7 @@ public:
     }
   }
 
-  void set(int r)
+  void set(int r) override
   {
     set(double(r));
   }
@@ -149,7 +148,7 @@ public:
 // PullupResistor::create_iopin_map
 //
 
-void PullupResistor::create_iopin_map()
+void PullupResistor::_create_iopin_map()
 {
   //   The PullupResistor has only one pin.
   create_pkg(1);
@@ -200,7 +199,7 @@ PullupResistor::PullupResistor(const char *init_name, const char *desc, float vi
   //rRRres = new IO_bi_directional_pu(s.c_str());
   res = new IO_bi_directional_pu("pin");
   res->set_Vpullup(vinit);
-  create_iopin_map();
+  _create_iopin_map();
   // Default module attributes.
   //initializeAttributes();
   set_description(
