@@ -136,7 +136,7 @@ void SwitchPin::getThevenin(double &v, double &z, double &c)
   } else {
     v = 0.0;
     z = get_Zopen();
-    c = 0;
+    c = 0.0;
   }
 
   set_Vth(v);
@@ -202,7 +202,7 @@ void SwitchPin::Build_List(stimulus *st)
             *sp_pt = nullptr;
 
             if (verbose)
-              std::cout << "\t" << sp_ptr->name() << " other="
+              std::cout << '\t' << sp_ptr->name() << " other="
                    << sp_ptr->other_pin(sp_ptr)->name() << '\n';
 
             // Add stimuli on other pin of closed swich
@@ -290,7 +290,7 @@ void SwitchPin::sumThevenin(double &current, double &conductance,
       std::cout << " N: " << (*sptr)->name() << " V=" << V1
            << " Z=" << Z1 << " C=" << C1 << '\n';
 
-    double Cs = 1 / Z1;
+    double Cs = 1.0 / Z1;
     // The Thevenin current is the Thevenin voltage divided by
     // the Thevenin resistance:
     current += V1 * Cs;
@@ -503,7 +503,7 @@ double SwitchBase::getZclosed()
 
 SwitchPin * SwitchBase::other_pin(SwitchPin *pin)
 {
-  return ((pin == m_pinA) ? m_pinB : m_pinA);
+  return (pin == m_pinA) ? m_pinB : m_pinA;
 }
 
 
@@ -511,7 +511,7 @@ SwitchPin * SwitchBase::other_pin(SwitchPin *pin)
 
 SwitchBase::SwitchBase(const char *_new_name, const char *_desc)
   : Module(_new_name, _desc),
-    m_pinA(0), m_pinB(0), m_bCurrentState(false), m_aState(0)
+    m_pinA(nullptr), m_pinB(nullptr), m_bCurrentState(false), m_aState(0)
 {
   // Default module attributes.
   //initializeAttributes();
