@@ -24,8 +24,10 @@ License along with this library; if not, see
 
 /* IN_MODULE should be defined for modules */
 #define IN_MODULE
-
+#include "../config.h"
 #include "../src/modules.h"
+#include "../src/trigger.h"
+class Float;
 
 #ifdef HAVE_GUI
 #include <gtk/gtk.h>
@@ -84,7 +86,7 @@ public:
   explicit Switch(const char *_name = nullptr);
   ~Switch();
 
-  virtual void setState(bool);
+  void setState(bool) override;
   void buttonToggled();
 
   static Module *construct(const char *new_name);
