@@ -44,19 +44,22 @@ License along with this library; if not, see
 #include "../config.h"    // get the definition for HAVE_GUI
 #ifdef HAVE_GUI
 #include <gtk/gtk.h>
+#include <gdk/gdk.h>
 #endif
 
+#include <glib.h>
+
 #include "usart.h"
 
 #include <assert.h>
 #include <ctype.h>
 #include <cstdio>
+#include <iostream>
 
 #include "../src/gpsim_interface.h"
 #include "../src/modules.h"
 #include "../src/processor.h"
 #include "../src/stimuli.h"
-#include "../src/uart.h"
 #include "../src/trigger.h"
 #include "../src/value.h"
 class PIR_SET;
@@ -131,10 +134,10 @@ public:
     Zpullup = 10e3;
   }
 
-  void setDrivenState(bool new_dstate)
+  void setDrivenState(bool new_dstate) override
   {
     bool diff = new_dstate ^ bDrivenState;
-    Dprintf((" usart module rxpin new state=%d\n", new_dstate));
+    Dprintf((" usart module rxpin new state=%d time:0x%" PRINTF_GINT64_MODIFIER "x=%" PRINTF_GINT64_MODIFIER "d\n", new_dstate, get_cycles().get(), get_cycles().get()));
 
     if (usart && diff) {
       bDrivenState = new_dstate;
@@ -174,28 +177,26 @@ public:
 class TXREG : public TriggerObject {
 private:
   bool empty_flag;
-  double baud;
+  gint64 baud;
 
-  guint64 time_per_bit;
   guint64 last_time;
   guint64 start_time;
   guint64 future_time;
 
-  guint64 start_bit_time;
-  unsigned int start_bit_index;
-  bool last_bit;
   int bits_per_byte;
 
   double  stop_bits;
-  guint64 time_per_packet;
 
   unsigned int txr;    // Transmit register
   int bit_count;       // used while transmitting.
   unsigned int tx_byte;
 
+/*
+ * Unused
   enum TX_STATES {
     TX_TRANSMITTING
   }  transmit_state;
+*/
 
   bool use_parity;
   bool parity;         // 0 = even, 1 = odd
@@ -223,50 +224,42 @@ public:
     txpin = 0;
     usart = 0;
     bits_per_byte = 8;
+    bit_count = 0;
+    txr = 0;
     stop_bits = 1;
     use_parity = 0;
+    parity = false;
     set_baud_rate(DEFAULT_BAUD);
     tx_byte = '0';
-    update_packet_time();
-    empty();
+    empty_flag = 1;
   }
 
-  void update_packet_time()
+  guint64 time_per_bit()
   {
-    if (baud <= 0.0) {
-      baud = 9600;  //arbitrary
-    }
+    guint64 tpb;
+    if (baud <= 0) 
+        baud = DEFAULT_BAUD;  //arbitrary
 
-    // Calculate the total time to send a "packet", i.e. start bit, data, parity, and stop
-    // The stop bit time is included in the total packet time
-
-    if (get_active_cpu()) {
-      time_per_packet =
-        (guint64)(get_cycles().instruction_cps() * (
-                    (1.0 +             // start bit
-                     bits_per_byte +   // data bits
-                     stop_bits  +      // stop bit(s)
-                     use_parity)       //
-                    / baud));
-      time_per_bit = (guint64)(get_cycles().instruction_cps() / baud);
-
-    } else {
-      time_per_packet = time_per_bit = 0;
-    }
-
-    //cout << "update_packet_time ==> 0x" << hex<< time_per_packet << "\n";
+    if (get_active_cpu())
+     tpb = (guint64)(get_cycles().instruction_cps() / baud);
+    else
+     tpb = 0;
+    Dprintf(("TX time_per_bit() tpb=%ld baud=%ld\n", tpb, baud));
+    // A time per bit of zero causes a callback in the past, which is invalid
+    if ( tpb == 0 )
+      tpb = 1;
+    return tpb;
   }
 
+
   void set_bits_per_byte(int num_bits)
   {
     bits_per_byte = num_bits;
-    update_packet_time();
   }
 
-  void set_baud_rate(double new_baud)
+  void set_baud_rate(gint64 new_baud)
   {
     baud = new_baud;
-    update_packet_time();
   }
 
   void set_stop_bits(double new_stop_bits)
@@ -285,7 +278,7 @@ public:
     parity = new_parity;
   }
 
-  virtual void callback()
+  void callback() override
   {
     Dprintf((" usart module TXREG time:0x%" PRINTF_GINT64_MODIFIER "x=%" PRINTF_GINT64_MODIFIER "d txr=0x%x bit_count=%d\n", get_cycles().get(), get_cycles().get(), txr, bit_count));
     last_time = get_cycles().get();
@@ -298,8 +291,7 @@ public:
     if (bit_count) {
       txr >>= 1;
       bit_count--;
-      update_packet_time();
-      future_time = last_time + time_per_bit;
+      future_time = last_time + time_per_bit();
       get_cycles().set_break(future_time, this);
 
     } else {
@@ -323,8 +315,7 @@ public:
 
     mBuildTXpacket(_tx_byte);
     last_time = get_cycles().get();
-    update_packet_time();
-    future_time = last_time + time_per_bit;
+    future_time = last_time + time_per_bit();
     get_cycles().set_break(future_time, this);
     full();
   }
@@ -379,42 +370,29 @@ public:
   void set_bits_per_byte(int num_bits)
   {
     bits_per_byte = num_bits;
-    update_packet_time();
   }
-
-  void update_packet_time()
+  guint64 time_per_bit()
   {
-    // for now the stop bit time is included in the total packet time
-    if (baud <= 0.0) {
-      baud = DEFAULT_BAUD;  //arbitrary
-    }
+      guint64 tpb;
+      if (baud <= 0) 
+          baud = DEFAULT_BAUD;  //arbitrary
 
-    /*
-      Calculate the total time to send a "packet", i.e. start bit, data, parity, and stop
-    */
-
-    if (get_active_cpu()) {
-      time_per_packet =
-        (guint64)(get_cycles().instruction_cps() * (1.0 +     // start bit
-                  bits_per_byte +   // data bits
-                  stop_bits  +      // stop bit(s)
-                  use_parity)       //
-                  / baud);
-      time_per_bit = (guint64)(get_cycles().instruction_cps() / baud);
-
-    } else {
-      time_per_packet = time_per_bit = 0;
-    }
-
-    //cout << "update_packet_time ==> 0x" << hex<< time_per_packet << "\n";
+      if (get_active_cpu())
+        tpb = (guint64)(get_cycles().instruction_cps() / baud + 0.5);
+      else
+        tpb = 0;
+      Dprintf(("RX time_per_bit() tpb=%ld baud=%ld\n", tpb, baud));
+      // A time per bit of zero causes a callback in the past, which is invalid
+      if ( tpb == 0 )
+        tpb = 1;
+      return tpb;
   }
 
-  void set_baud_rate(double new_baud)
+
+  void set_baud_rate(gint64 new_baud)
   {
     baud = new_baud;
-    update_packet_time();
   }
-
   void set_stop_bits(double new_stop_bits)
   {
     stop_bits = new_stop_bits;
@@ -431,7 +409,7 @@ public:
     parity = new_parity;
   }
 
-  virtual void callback();
+  void callback() override;
 
   void start();
   void new_rx_edge(bool bit);
@@ -440,12 +418,6 @@ private:
   USARTModule *m_usart;
 
   char m_cLastRXState;
-  unsigned int start_bit_event;
-
-  guint32 error_flag;
-
-  guint64 time_per_bit;
-  guint64 start_time;
   guint64 future_time;
 
   // Configuration information
@@ -453,23 +425,19 @@ private:
   double  stop_bits;
   bool    use_parity;
   bool    parity;         // 0 = even, 1 = odd
-  double  baud;
+  gint64  baud;
   unsigned int rx_byte;
   int     rx_count;
 
-  guint64 time_per_packet;
-
   bool autobaud;
-
-  IOPIN   *rcpin;
-  unsigned int *fifo;
 };
 
 
 //------------------------------------------------------------------------
 
 RCREG::RCREG(USARTModule *pUsart)
-  : m_usart(pUsart), m_cLastRXState('?'), start_bit_event(0), rcpin(nullptr)
+  : rxpin(nullptr), m_usart(pUsart), m_cLastRXState('?'), parity(false),
+    rx_byte(0), rx_count(0)
 {
   assert(m_usart);
   receive_state = RS_WAITING_FOR_START;
@@ -484,7 +452,7 @@ RCREG::RCREG(USARTModule *pUsart)
 //------------------------------------------------------------------------
 void RCREG::callback()
 {
-  Dprintf((" usart module RCREG time:0x%" PRINTF_GINT64_MODIFIER "x=%" PRINTF_GINT64_MODIFIER "d state=0x%x\n", get_cycles().get(), get_cycles().get(), receive_state));
+  Dprintf((" usart module RCREG time:0x%" PRINTF_GINT64_MODIFIER "x=%" PRINTF_GINT64_MODIFIER "d state=0x%x bit=%d\n", get_cycles().get(), get_cycles().get(), receive_state, bIsHigh(m_cLastRXState)));
 
   switch (receive_state) {
   case RS_WAITING_FOR_START:
@@ -496,7 +464,7 @@ void RCREG::callback()
       receive_state = RS_RECEIVING;
       rx_count = bits_per_byte + use_parity;
       rx_byte = 0;
-      future_time = get_cycles().get() + time_per_bit;
+      future_time = get_cycles().get() + time_per_bit();
 
       if (!autobaud) {
         get_cycles().set_break(future_time, this);
@@ -512,7 +480,7 @@ void RCREG::callback()
     if (rx_count--) {
       rx_byte = (rx_byte >> 1) | (bIsHigh(m_cLastRXState) ?
                                   1 << (bits_per_byte - 1) : 0);
-      future_time = get_cycles().get() + time_per_bit;
+      future_time = get_cycles().get() + time_per_bit();
 
       if (!autobaud) {
         get_cycles().set_break(future_time, this);
@@ -545,11 +513,15 @@ void RCREG::callback()
 void RCREG::start()
 {
   receive_state = RS_START_BIT;
-  update_packet_time();
-  future_time = get_cycles().get() + time_per_bit / 2;
+  future_time = get_cycles().get() + time_per_bit() / 2;
 
   if (!autobaud) {
-    get_cycles().set_break(future_time, this);
+    if ( !get_cycles().set_break(future_time, this) )
+    {
+      // There's a problem, probably Baud rate too high for the CPU clock
+      // best we can do is behave as if the break has happened
+      callback();
+    }
   }
 
   Dprintf((" usart module RCREG current cycle=0x%" PRINTF_GINT64_MODIFIER "x future_cycle=0x%" PRINTF_GINT64_MODIFIER "x\n", get_cycles().get(), future_time));
@@ -559,7 +531,7 @@ void RCREG::start()
 //------------------------------------------------------------------------
 //  new_rx_edge(bool bit)
 //
-//  This routine get's called when there's a change on the
+//  This routine gets called when there's a change on the
 //  RX line. The time the edge occurred is stored into an
 //  event buffer. No effort is made here to decode a byte;
 //  instead, decoding will take place in callback().
@@ -602,21 +574,21 @@ public:
   USARTModule *usart;
 
   USART_IO()
+    : usart(nullptr)
   {
     std::cout << "USART_IO constructor - do nothing\n";
   }
 
   USART_IO(USARTModule *_usart, unsigned int , const char *opt_name)
-    : IO_bi_directional_pu(opt_name)
+    : IO_bi_directional_pu(opt_name), usart(_usart)
   {
-    usart = _usart;
     bDrivenState = true;
     update_direction(0, true);  // Make the RX pin an input.
     bPullUp = true;
     Zpullup = 10e3;
   }
 
-  void setDrivenState(bool new_dstate)
+  void setDrivenState(bool new_dstate) override
   {
     bool diff = new_dstate ^ bDrivenState;
 
@@ -659,7 +631,7 @@ public:
     assert(rcreg);
   }
 
-  void set(Value *v)
+  void set(Value *v) override
   {
     Integer::set(v);
     gint64 b;
@@ -667,7 +639,7 @@ public:
     rcreg->set_baud_rate(b);
     std::cout << "Setting Rx baud rate attribute to " << std::dec << b << "\n";
   }
-  virtual std::string toString()
+  std::string toString() override
   {
     return Integer::toString("%" PRINTF_INT64_MODIFIER "d");
   }
@@ -684,7 +656,7 @@ public:
     assert(txreg);
   }
 
-  void set(Value *v)
+  void set(Value *v) override
   {
     Integer::set(v);
     gint64 b;
@@ -692,7 +664,7 @@ public:
     txreg->set_baud_rate(b);
     std::cout << "Setting Tx baud rate attribute to " << std::dec << b << "\n";
   }
-  virtual std::string toString()
+  std::string toString() override
   {
     return Integer::toString("%" PRINTF_INT64_MODIFIER "d");
   }
@@ -704,14 +676,14 @@ class TxBuffer : public Integer {
 
 public:
   explicit TxBuffer(USARTModule *_usart)
-    : Integer("tx", 0, "UART Transmit Register"), usart(_usart)
+    : Integer("tx", 0, "Add character, byte, or string to TX buffer"), usart(_usart)
   {
   }
-  virtual void set(gint64 i)
+  void set(gint64 i) override
   {
     i &= 0xff;
 
-    //cout << name() << " sending byte 0x" << hex << i << endl;
+    //std::cout << name() << " sending byte 0x" << std::hex << i << std::endl;
 
     if (usart) {
       usart->SendByte(i);
@@ -719,7 +691,46 @@ public:
 
     Integer::set(i);
   }
-  virtual std::string toString()
+
+  void set(Value *v) {
+      if (typeid(*v) == typeid(String)) {
+	  char buf[v->toString().length() + 1];
+	  v->get(buf, sizeof(buf));
+	  set(buf);
+      } else {
+	  Integer::set(v);
+      }
+  }
+
+  void set(const char *buffer) {
+
+      int i = 0;
+      while (char c = buffer[i++]) {
+	  if (c == '\\') {
+	      c = buffer[i];
+	      switch (c) {
+	       case 'n':
+		  c = '\n';
+		  break;
+	       case 'r':
+		  c = '\r';
+		  break;
+	       case 't':
+		  c = '\t';
+		  break;
+	       case '\0':
+		  c = '\\';
+		  break;
+	       default:
+		  break;
+	      }
+	      if (buffer[i]) i++;
+	  }
+	  set(c);
+      }
+  }
+
+  std::string toString() override
   {
     return Integer::toString("%" PRINTF_INT64_MODIFIER "d");
   }
@@ -727,18 +738,16 @@ public:
 
 
 class RxBuffer : public Integer {
-  RCREG *rcreg;
-
 public:
   explicit RxBuffer(RCREG *_rcreg)
-    : Integer("rx", 0, "UART Receive Register"), rcreg(_rcreg)
+    : Integer("rx", 0, "USART Receive Register")
   {
   }
-  virtual void set(gint64 )
+  void set(gint64 ) override
   {
     std::cout << "Receive buffer is read only\n";
   }
-  virtual std::string toString()
+  std::string toString() override
   {
     return Integer::toString("%" PRINTF_INT64_MODIFIER "d");
   }
@@ -883,7 +892,7 @@ Module * USARTModule::USART_construct(const char *_new_name)
 }
 
 
-USARTModule::USARTModule(const char *_name) : Module(_name, "USART")
+USARTModule::USARTModule(const char *_name) : Module(_name, "USART - Universal Synchronous Asynchronous Receiver Transmitter ")
 {
 #ifdef HAVE_TXFIFO
   m_TxFIFO = new unsigned char[64];
@@ -1068,6 +1077,10 @@ void USARTModule::show_tx(unsigned int data)
 {
   data &= 0xff;
   bool IsAscii = true;
+#ifdef HAVE_GUI
+  bool Skip = (m_NewLine && data == '\n');
+  m_NewLine = false;
+#endif //HAVE_GUI
 
   if (m_ShowHex->getVal()) {
     IsAscii = false;
@@ -1076,6 +1089,9 @@ void USARTModule::show_tx(unsigned int data)
     IsAscii = true;
 
   } else if (m_CRLF->getVal() && ('\n' == data || '\r' == data)) {
+#ifdef HAVE_GUI
+    if (data == '\r') m_NewLine = true;
+#endif //HAVE_GUI
     IsAscii = true;
 
   } else {
@@ -1093,7 +1109,7 @@ void USARTModule::show_tx(unsigned int data)
 
 #ifdef HAVE_GUI
 
-  if (get_interface().bUsingGUI()) {
+  if (!Skip && get_interface().bUsingGUI()) {
     GtkTextBuffer *buff = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text));
     GtkTextIter iter;
     GtkTextMark *insert_mark;
