@@ -43,8 +43,12 @@ sync	lume	result
 #ifdef HAVE_GUI
 
 #include <gtk/gtk.h>
+#include <gdk/gdk.h>
+#include <cairo.h>
+#include <glib.h>
 
 #include "../src/gpsim_interface.h"
+#include "../src/gpsim_time.h"
 #include "../src/processor.h"
 
 #include "video.h"
@@ -61,21 +65,21 @@ private:
 
 public:
   explicit Video_Interface(Video *_video)
-    : Interface((gpointer *) _video)
+    : Interface((void *) _video)
   {
     video = _video;
   }
 
   //virtual void UpdateObject (gpointer xref,int new_value);
   //virtual void RemoveObject (gpointer xref);
-  virtual void SimulationHasStopped(gpointer /* object */ )
+  void SimulationHasStopped(gpointer /* object */ ) override
   {
     if (video) {
       video->refresh();
     }
   }
 
-  virtual void NewProcessor(Processor *new_cpu)
+  void NewProcessor(Processor *new_cpu) override
   {
     if (video) {
       video->cpu = new_cpu;
@@ -134,13 +138,14 @@ Video::Video(const char *_name)
   lume_pin = new IOPIN_Monitor(this, "lume");
   addSymbol(sync_pin);
   addSymbol(lume_pin);
-  //cout << "Video base class constructor\n";
+
   memset(line, 0x80, XRES);
   memset(shadow, 0x42, XRES * YRES); // initalize shadow to invalid values
   //  cpu = get_processor(1);
   cpu = get_active_cpu();  //FIXME
-  interface = new Video_Interface(this);
-  get_interface().add_interface(interface);
+
+  get_interface().add_interface(new Video_Interface(this));
+
   window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
   gtk_window_set_default_size(GTK_WINDOW(window), XRES, YRES);
   gtk_window_set_title(GTK_WINDOW(window), "Video");
@@ -199,10 +204,9 @@ void Video::create_iopin_map()
 
 Module *Video::construct(const char *_new_name)
 {
-  //cout << " Video  construct\n";
   Video *video = new Video(_new_name) ;
   video->create_iopin_map();
-  //cout << "Video should be constructed\n";
+
   return video;
 }
 
