@@ -19,14 +19,19 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
-#include<stdio.h>
-#include <iostream>
-#include <iomanip>
+#include <stdio.h>
+#include <string>
 
-#include "../config.h"
-#include "14bit-processors.h"
 #include "14bit-instructions.h"
 
+#include "14bit-processors.h"
+#include "14bit-registers.h"
+#include "gpsim_object.h"
+#include "intcon.h"
+#include "pic-processor.h"
+#include "registers.h"
+
+class Processor;
 
 //#define DEBUG
 #if defined(DEBUG)
@@ -348,9 +353,8 @@ RETFIE::RETFIE (Processor *new_cpu, unsigned int new_opcode, unsigned int addres
 void RETFIE::execute(void)
 {
   cpu14->pc->new_address(cpu14->stack->pop());
-  cpu14->intcon->in_interrupt = false;
   // test for pending intterrupts
-  cpu14->intcon->put_value(cpu14->intcon->value.get());
+  cpu14->intcon->set_gie();
   if(cpu_pic->base_isa() == _14BIT_E_PROCESSOR_)
   {
 	cpu14e->status->put(cpu14e->status_shad.get());
