@@ -19,18 +19,17 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
-class instruction;  // forward declaration for the include files that follow
-
-#ifndef __14BIT_INSTRUCTIONS_H__
-#define __14BIT_INSTRUCTIONS_H__
+#ifndef SRC_14BIT_INSTRUCTIONS_H_
+#define SRC_14BIT_INSTRUCTIONS_H_
 
 #define REG_IN_INSTRUCTION_MASK  0x7f
 #define DESTINATION_MASK         0x80
 
 #include "pic-instructions.h"
 #include "12bit-instructions.h"
-#include "14bit-registers.h"
 
+class Indirect_Addressing14;
+class Processor;
 
 //---------------------------------------------------------
 class ADDFSR : public instruction 
@@ -38,16 +37,16 @@ class ADDFSR : public instruction
 
 public:
   ADDFSR(Processor *new_cpu, unsigned int new_opcode,const char *, unsigned int address);
-  virtual bool isBase() { return true;}
-  virtual void execute();
-  virtual char *name(char *,int);
+  bool isBase() override { return true;}
+  void execute() override;
+  char *name(char *, int) override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new ADDFSR(new_cpu,new_opcode,"addfsr", address);
   }
 protected:
-  unsigned int m_fsr;
-  unsigned int m_lit;
+  unsigned int 	m_fsr;
+  int 		m_lit;
   Indirect_Addressing14 *ia;
 };
 
@@ -58,7 +57,7 @@ class ADDLW : public Literal_op
 
 public:
   ADDLW(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute(void);
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     {return new ADDLW(new_cpu,new_opcode, address);}
 
@@ -70,7 +69,7 @@ class ADDWFC : public Register_op
 public:
 
   ADDWFC(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {return new ADDWFC(new_cpu,new_opcode,address);}
 };
@@ -83,9 +82,9 @@ public:
   unsigned int absolute_destination_index;
 
   BRA(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute();
-  virtual char *name(char *,int);
-  virtual bool isBase() { return true;}
+  void execute() override;
+  char *name(char *, int) override;
+  bool isBase() override { return true;}
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {return new BRA(new_cpu,new_opcode,address);}
 };
@@ -95,12 +94,12 @@ class BRW : public instruction
 {
 public:
   int destination_index;
-  unsigned int absolute_destination_index;
+  unsigned int current_address;
 
   BRW(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute();
-  virtual char *name(char *,int);
-  virtual bool isBase() { return true;}
+  void execute() override;
+  char *name(char *, int) override;
+  bool isBase() override { return true;}
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {return new BRW(new_cpu,new_opcode,address);}
 };
@@ -111,7 +110,7 @@ class ASRF : public Register_op
 public:
 
   ASRF(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {return new ASRF(new_cpu,new_opcode,address);}
 };
@@ -121,9 +120,9 @@ class CALLW : public instruction
 {
 public:
   CALLW(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual bool isBase() { return true;}
-  virtual void execute();
-  virtual char *name(char *,int);
+  bool isBase() override { return true;}
+  void execute() override;
+  char *name(char *, int) override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new CALLW(new_cpu,new_opcode,address);
@@ -136,7 +135,7 @@ class LSLF : public Register_op
 public:
 
   LSLF(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {return new LSLF(new_cpu,new_opcode,address);}
 };
@@ -147,7 +146,7 @@ class LSRF : public Register_op
 public:
 
   LSRF(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {return new LSRF(new_cpu,new_opcode,address);}
 };
@@ -158,11 +157,11 @@ class MOVIW : public instruction
 public:
 
   MOVIW(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute();
-  virtual bool isBase() { return true;}
+  void execute() override;
+  bool isBase() override { return true;}
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {return new MOVIW(new_cpu,new_opcode,address);}
-  virtual char *name(char *,int);
+  virtual char *name(char *, int) override;
 
   enum {
 	PREINC,
@@ -185,11 +184,11 @@ class MOVWI : public instruction
 public:
 
   MOVWI(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute();
-  virtual bool isBase() { return true;}
+  void execute() override;
+  bool isBase() override { return true;}
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {return new MOVWI(new_cpu,new_opcode,address);}
-  virtual char *name(char *,int);
+  char *name(char *, int) override;
 
   enum {
 	PREINC,
@@ -213,8 +212,8 @@ class MOVLB : public Literal_op
 {
 public:
   MOVLB(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute();
-  virtual char *name(char *return_str,int len);
+  void execute() override;
+  char *name(char *return_str, int len) override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {return new MOVLB(new_cpu,new_opcode,address);}
 
@@ -226,8 +225,8 @@ class MOVLP : public Literal_op
 {
 public:
   MOVLP(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute();
-  virtual char *name(char *return_str,int len);
+  void execute() override;
+  char *name(char *return_str, int len) override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {return new MOVLP(new_cpu,new_opcode,address);}
 
@@ -239,8 +238,8 @@ class RESET : public instruction
 public:
 
   RESET(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute();
-  virtual bool isBase() { return true;}
+  void execute() override;
+  bool isBase() override { return true;}
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {return new RESET(new_cpu,new_opcode,address);}
 
@@ -253,8 +252,8 @@ class RETFIE : public instruction
 public:
 
   RETFIE(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute(void);
-  virtual bool isBase() { return true;}
+  void execute() override;
+  bool isBase() override { return true;}
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     {return new RETFIE(new_cpu,new_opcode,address);}
 
@@ -267,8 +266,8 @@ class RETURN : public instruction
 public:
 
   RETURN(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute(void);
-  virtual bool isBase() { return true;}
+  void execute() override;
+  bool isBase() override { return true;}
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     {return new RETURN(new_cpu,new_opcode,address);}
 
@@ -282,7 +281,7 @@ class SUBLW : public Literal_op
 public:
 
   SUBLW(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute(void);
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     {return new SUBLW(new_cpu,new_opcode,address);}
 
@@ -294,11 +293,11 @@ class SUBWFB : public Register_op
 public:
 
   SUBWFB(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {return new SUBWFB(new_cpu,new_opcode,address);}
 };
 
 
 
-#endif //  __14BIT_INSTRUCTIONS_H__
+#endif // SRC_14BIT_INSTRUCTIONS_H_
