@@ -20,20 +20,24 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
+#include <glib.h>
+
 #include <assert.h>
 #include <stdio.h>
 #include <iostream>
 #include <string>
 
-#include "../config.h"
 #include "14bit-processors.h"
 #include "breakpoints.h"
+#include "pic-instructions.h"
 #include "pic-ioports.h"
 #include "pic-registers.h"
+#include "tmr0.h"
 #include "ui.h"
 
 //#define DEBUG
 #if defined(DEBUG)
+#include "../config.h"
 #define Dprintf(arg) {printf("0x%06" PRINTF_GINT64_MODIFIER "X %s() ",cycles.get(),__FUNCTION__); printf arg; }
 #else
 #define Dprintf(arg) {}
@@ -50,7 +54,7 @@ public:
         : ConfigWord("CONFIG", 0x3fff, "Configuration Word", pCpu, 0x2007)
     {
         assert(pCpu);
-        pCpu->wdt.initialize(true);
+        pCpu->wdt->initialize(true);
     }
 
     enum
@@ -61,7 +65,7 @@ public:
         PWRTEN = 1 << 3
     };
 
-    virtual void set(gint64 v)
+    void set(gint64 v) override
     {
         gint64 oldV = getVal();
         Integer::set(v);
@@ -72,7 +76,7 @@ public:
 
             if (diff & WDTEN)
             {
-                m_pCpu->wdt.initialize((v & WDTEN) == WDTEN);
+                m_pCpu->wdt->initialize((v & WDTEN) == WDTEN);
             }
 
             m_pCpu->config_modes->set_fosc01(v & (FOSC0 | FOSC1));
@@ -81,7 +85,7 @@ public:
         }
     }
 
-    virtual std::string toString()
+    std::string toString() override
     {
         gint64 i64;
         get(i64);
@@ -147,7 +151,7 @@ void _14bit_processor :: create()
 void _14bit_processor::interrupt()
 {
     //bp.clear_interrupt();
-    intcon->in_interrupt = true;
+    intcon->clear_gie();
     bp.clear_interrupt();
     stack->push(pc->value);
     pc->interrupt(INTERRUPT_VECTOR);
@@ -182,6 +186,7 @@ unsigned int _14bit_processor::get_program_memory_at_address(unsigned int addres
 {
     unsigned int uIndex = map_pm_address2index(address);
 
+
     if (uIndex < program_memory_size())
     {
         return  program_memory[uIndex] ? program_memory[uIndex]->get_opcode() : 0xffffffff;
@@ -257,9 +262,9 @@ void _14bit_processor::exit_sleep()
     }
 }
 
-bool _14bit_processor::get_intedgx(int index)
+bool _14bit_processor::get_intedgx(int /* index */ )
 {
-    return(option_reg->value.get() & OPTION_REG::INTEDG);
+    return option_reg->value.get() & OPTION_REG::INTEDG;
 }
 
 
@@ -411,8 +416,8 @@ void _14bit_e_processor::create_sfr_map()
     add_sfr_register(pclath,  0x0a, RegisterValue(0, 0));
     add_sfr_registerR(&intcon_reg, 0x0b, RegisterValue(0, 0));
     add_sfr_register(&pcon,   0x96, RegisterValue(0x0c, 0), "pcon");
-    wdt.set_postscale(0);
-    wdt.set_timeout(1.0 / 32000.0);
+    wdt->set_postscale(0);
+    wdt->set_timeout(1.0 / 32000.0);
     add_sfr_registerR(&wdtcon,   0x97, RegisterValue(0x16, 0), "wdtcon");
     // These are copies taken at an interrupt
     add_sfr_register(&status_shad,  0xfe4);
@@ -439,14 +444,14 @@ void _14bit_e_processor::create_sfr_map()
 
 
 //-------------------------------------------------------------------
-//	Similar to pic_processoer version except sets PCON flags
+//	Similar to pic_processor version except sets PCON flags
 //
 void _14bit_e_processor::reset(RESET_TYPE r)
 {
     switch (r)
     {
     case POR_RESET:
-        pcon.put(0x0d);
+   //     pcon.put(0x0d);
         break;
 
     case SOFT_RESET:
@@ -466,6 +471,16 @@ void _14bit_e_processor::reset(RESET_TYPE r)
         pcon.put(pcon.get() | PCON::STKUNF);
         break;
 
+    case WDTWV_RESET:
+        std::cout << "Reset due to WDTWV\n";
+        pcon.put(pcon.get() & ~PCON::WDTWV);
+        break;
+
+    case WDT_RESET:
+        std::cout << "Reset due to WDT\n";
+        pcon.put(pcon.get() & ~PCON::RWDT);
+        break;
+
     default:
         break;
     };
@@ -501,7 +516,7 @@ void _14bit_e_processor::interrupt()
     fsr0h_shad.value = ind0.fsrh.value;
     fsr1l_shad.value = ind1.fsrl.value;
     fsr1h_shad.value = ind1.fsrh.value;
-    intcon->in_interrupt = true;
+    intcon->clear_gie();
     pc->interrupt(INTERRUPT_VECTOR);
 }
 
@@ -513,7 +528,7 @@ void _14bit_e_processor::enter_sleep()
 
     if (wdt_flag == 2)  	// WDT is suspended during sleep
     {
-        wdt.initialize(false);
+        wdt->initialize(false);
     }
 
     pic_processor::enter_sleep();
@@ -536,7 +551,7 @@ void _14bit_e_processor::exit_sleep()
 
         if (wdt_flag == 2)
         {
-            wdt.initialize(true);
+            wdt->initialize(true);
         }
 
         pic_processor::exit_sleep();
@@ -619,7 +634,7 @@ bool _14bit_e_processor::set_config_word(unsigned int address, unsigned int cfg_
         }
         set_pps1way(cfg_word & PPS1WAY);
 
-        wdt.initialize(wdt_flag & 2);
+        wdt->initialize((bool)(wdt_flag & 2));
         oscillator_select(cfg_word, (cfg_word & NOT_CLKOUTEN) != NOT_CLKOUTEN);
 
     }
