@@ -19,12 +19,12 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
-
-#include <stdio.h>
-#include <iostream>
-#include <iomanip>
-#include <string>
 #include <assert.h>
+#include <stdio.h>
+#include <string.h>
+#include <algorithm>
+#include <iostream>
+#include <string>
 
 #include "14bit-processors.h"
 #include "14bit-registers.h"
@@ -32,10 +32,14 @@ License along with this library; if not, see
 
 #include "breakpoints.h"
 #include "gpsim_time.h"
+#include "intcon.h"
 #include "ioports.h"
+#include "pic-ioports.h"
 #include "pic-processor.h"
+#include "pir.h"
 #include "processor.h"
 #include "stimuli.h"
+#include "tmr0.h"
 #include "ui.h"
 
 //#include "xref.h"
@@ -47,6 +51,14 @@ License along with this library; if not, see
 #else
 #define Dprintf(arg) {}
 #endif
+//Debug SR module
+//#define SR_DEBUG
+#if defined(SR_DEBUG)
+#define SRprint(arg) {fprintf(stderr, "%s:%d %s ",__FILE__,__LINE__, __FUNCTION__); fprintf arg;}
+#else
+#define SRprint(arg) {}
+#endif
+
 
 // Debug OSCCON
 //#define CDEBUG
@@ -240,10 +252,61 @@ void OSCCAL::set_freq(float new_base_freq)
 void  OSCTUNE::put(unsigned int new_value)
 {
     trace.raw(write_trace.get() | value.get());
-    value.put(new_value);
+    value.put(new_value&mValidBits);
     osccon->set_rc_frequency();
 }
 
+/// Obtain the oscillator trim factor based on the value in OSCTUNE
+// This is based on how it was done previously in the various OSCCON classes
+// but with some of the hard-coded numbers replaced, since the size of the
+// TUN field is not fixed by the OSCCON type. The total adjustment range is
+// marginally smaller now, but none of the datasheets give any idea how big
+// it really is on an actual PIC.
+float OSCTUNE5::get_freq_trim(void)
+{
+    int tune;
+    const int tune_range = TUN4*2;
+    const int mid_val = TUN4;
+    tune = value.get() & (tune_range - 1);
+    if ( tune >= mid_val )
+        tune -= tune_range;
+    return 1.0 + ( 0.125 * tune ) / 15.0;   // or scale by mid_val;
+}
+
+float OSCTUNE6::get_freq_trim(void)
+{
+    int tune;
+    const int tune_range = TUN5 * 2;
+    const int mid_val = tune_range/2;
+    tune = value.get() & (tune_range - 1);
+    if ( tune >= mid_val )
+        tune -= tune_range;
+    return 1.0 + ( 0.125 * tune ) / 31.0;   // or scale by mid_val;
+}
+
+void  OSCTUNE_2::put(unsigned int new_value)
+{
+    trace.raw(write_trace.get() | value.get());
+    value.put(new_value);
+    adjust_freq();
+}
+
+void OSCTUNE_2::set_freq(double frequency)
+{
+    base_freq = frequency;
+    adjust_freq();
+}
+
+void OSCTUNE_2::adjust_freq()
+{
+    int tune;
+    const int tune_range = TUN4;
+    tune = value.get() & (tune_range - 1);
+    tune = (value.get() & TUN4) ? -tune : tune;
+    cpu_pic->set_RCfreq_active(true);
+    cpu_pic->set_frequency_rc(base_freq * (1.0 + 0.125 * tune / 15.0));
+}
+
 
 // Clock is stable
 void OSCCON::callback()
@@ -432,7 +495,6 @@ void OSCCON::por_wake()
         value.put(new_value);
         CDprintf(("OSCCON internal RC clock_state %u osccon %x\n", clock_state, new_value));
 
-        //RRR	set_rc_frequency();
         if (future_cycle)
         {
             get_cycles().clear_break(future_cycle);
@@ -518,11 +580,14 @@ bool OSCCON::set_rc_frequency(bool override)
 
     if (osctune)
     {
-        int tune;
-        unsigned int osctune_value = osctune->value.get();
-        tune = osctune_value & (OSCTUNE::TUN5 - 1);
-        tune = (OSCTUNE::TUN5 & osctune_value) ? -tune : tune;
-        base_frequency *= 1.0 + 0.125 * tune / 31.0;
+        // Check PLL enable on devices with OSCTUNEPLL, e.g. 18F2321
+        // On the other OSCTUNE variants, isPLLEn always returns false
+        if ( (new_IRCF >= 6) && osctune->isPLLEn() )
+        {
+            base_frequency *= 4;
+        }
+
+        base_frequency *= osctune->get_freq_trim();
     }
 
     cpu_pic->set_RCfreq_active(true);
@@ -555,15 +620,6 @@ bool OSCCON::set_rc_frequency(bool override)
         }
         else
         {
-            /*RRR
-            	    unsigned int current = value.get();
-            	    if (clock_state == HFINTOSC)
-            	    {
-            		if (has_iofs_bit) current &= ~LTS;
-            		current |= HTS;
-            		value.put(current);
-            	    }
-            */
             callback();
         }
     }
@@ -854,11 +910,7 @@ bool OSCCON_2::set_rc_frequency(bool override)
 
     if (osctune)
     {
-        int tune;
-        unsigned int osctune_value = osctune->value.get();
-        tune = osctune_value & (OSCTUNE::TUN5 - 1);
-        tune = (OSCTUNE::TUN5 & osctune_value) ? -tune : tune;
-        base_frequency *= 1.0 + 0.125 * tune / 31.0;
+        base_frequency *= osctune->get_freq_trim();
     }
 
     cpu_pic->set_RCfreq_active(true);
@@ -936,8 +988,7 @@ void  OSCCON_2::put(unsigned int new_value)
 {
     unsigned int old_value = value.get();
     new_value = (new_value & write_mask);
-    unsigned int oscstat_reg = 0;
-    unsigned int oscstat_new = 0;
+
     trace.raw(write_trace.get() | value.get());
     value.put(new_value);
 
@@ -947,8 +998,8 @@ void  OSCCON_2::put(unsigned int new_value)
     }
 
     assert(oscstat);
-    oscstat_reg = oscstat->value.get();
-    oscstat_new = oscstat_reg;
+    unsigned int oscstat_reg = oscstat->value.get();
+    unsigned int oscstat_new = oscstat_reg;
 
     if (((new_value & (SCS0 | SCS1)) == 0) && !cpu_pic->get_int_osc())
     {
@@ -1094,7 +1145,7 @@ bool OSCCON_HS::set_rc_frequency(bool override)
 {
     double base_frequency = 31.e3;
     bool config_pplx4 = cpu_pic->get_pplx4_osc();
-    bool osccon_pplx4 = (osctune) ? osctune->value.get() & OSCTUNE::PLLEN : false;
+    bool osccon_pplx4 = (osctune) ? osctune->isPLLEn() : false;
     bool intsrc	    = (osctune) ? osctune->value.get() & OSCTUNE::INTSRC : false;
     bool mfiosel	    = (osccon2) ? osccon2->value.get() & OSCCON2::MFIOSEL : false;
     unsigned int old_clock_state = clock_state;
@@ -1126,12 +1177,12 @@ bool OSCCON_HS::set_rc_frequency(bool override)
 
     case 1:
         clock_state = mfiosel ? MFINTOSC : HFINTOSC;
-        base_frequency = 125e3;
+        base_frequency = 250e3;
         break;
 
     case 2:
         clock_state = mfiosel ? MFINTOSC : HFINTOSC;
-        base_frequency = 250e3;
+        base_frequency = 500e3;
         break;
 
     case 3:
@@ -1167,11 +1218,7 @@ bool OSCCON_HS::set_rc_frequency(bool override)
 
     if (osctune)
     {
-        int tune;
-        unsigned int osctune_value = osctune->value.get();
-        tune = osctune_value & (OSCTUNE::TUN5 - 1);
-        tune = (OSCTUNE::TUN5 & osctune_value) ? -tune : tune;
-        base_frequency *= 1.0 + 0.125 * tune / 31.0;
+        base_frequency *= osctune->get_freq_trim();
     }
 
     cpu_pic->set_frequency_rc(base_frequency);
@@ -1222,6 +1269,7 @@ bool OSCCON_HS::set_rc_frequency(bool override)
 bool OSCCON_HS::internal_RC()
 {
     bool ret = false;
+    CDprintf (( "OSCCON_HS config_irc=%d osccon=0x%02X\n", config_irc, value.get() ));
 
     if ((value.get() & SCS1) || config_irc)
     {
@@ -1293,7 +1341,7 @@ void  OSCCON_HS2::put(unsigned int new_value)
     unsigned int diff = (new_value ^ org_value);
     trace.raw(write_trace.get() | org_value);
     value.put(new_value);
-    CDprintf(("OSCCON org_value=0x%02x new_value=0x%02x diff=0x%02x state %u\n",
+    CDprintf(("OSCCON_HS2 org_value=0x%02x new_value=0x%02x diff=0x%02x state %u\n",
               org_value, new_value, diff, clock_state));
 
     if (diff == 0)
@@ -1464,7 +1512,7 @@ void OSCCON_HS2::por_wake()
     // internal RC osc
     if (internal_RC())
     {
-        CDprintf(("OSCCON_HS2internal RC clock_state %u osccon %x \n", clock_state, val_osccon));
+        CDprintf (( "OSCCON_HS2 internal RC clock_state %u osccon %x \n", clock_state, value.get() ));
         set_rc_frequency();
 
         if (future_cycle)
@@ -1479,29 +1527,6 @@ void OSCCON_HS2::por_wake()
 }
 
 
-void WDTCON::put(unsigned int new_value)
-{
-    unsigned int masked_value = new_value & valid_bits;
-    trace.raw(write_trace.get() | value.get());
-    value.put(masked_value);
-
-    if (valid_bits > 1)
-    {
-        cpu_pic->wdt.set_prescale(masked_value >> 1);
-    }
-
-    if (cpu_pic->swdten_active())
-    {
-        cpu_pic->wdt.swdten((masked_value & SWDTEN) == SWDTEN);
-    }
-}
-
-
-void WDTCON::reset(RESET_TYPE )
-{
-    putRV(por_value);
-}
-
 
 //
 //--------------------------------------------------
@@ -1884,11 +1909,11 @@ void PCON::put(unsigned int new_value)
 
 Indirect_Addressing14::Indirect_Addressing14(pic_processor *pCpu, const std::string &n)
     : cpu(pCpu),
+      current_cycle((guint64)-1), // Not zero! See bug #3311944
       fsrl(pCpu, (std::string("fsrl") + n).c_str(), "FSR Low", this),
       fsrh(pCpu, (std::string("fsrh") + n).c_str(), "FSR High", this),
       indf(pCpu, (std::string("indf") + n).c_str(), "Indirect Register", this)
 {
-    current_cycle = (guint64)(-1);   // Not zero! See bug #3311944
 }
 
 
@@ -2709,7 +2734,7 @@ void INLVL::put(unsigned int new_value)
 }
 
 CPSCON0::CPSCON0(Processor *pCpu, const char *pName, const char *pDesc)
-    : sfr_register(pCpu, pName, pDesc)
+    : sfr_register(pCpu, pName, pDesc), FVR_ATTACH(pName), DAC_ATTACH(pName)
 {
     mValidBits = 0xcf;
 
@@ -2806,6 +2831,7 @@ void CPSCON0::calculate_freq()
 
     period = (p_cpu->get_frequency() * deltat + 2) / 4;
 
+
     if (period <= 0)
     {
         std::cout << "CPSCON Oscillator > Fosc/4, setting to Fosc/4\n";
@@ -2910,7 +2936,7 @@ void CPSCON0::set_chan(unsigned int _chan)
 }
 
 
-void CPSCON0::set_DAC_volt(double volt)
+void CPSCON0::set_DAC_volt(double volt, unsigned int chan)
 {
     DAC_voltage = volt;
 
@@ -2921,7 +2947,7 @@ void CPSCON0::set_DAC_volt(double volt)
 }
 
 
-void CPSCON0::set_FVR_volt(double volt)
+void CPSCON0::set_FVR_volt(double volt, unsigned int chan)
 {
     FVR_voltage = volt;
 
@@ -2989,16 +3015,20 @@ void SRCON0::put(unsigned int new_value)
 
     if (diff & CLKMASK)
     {
-        m_sr_module->clock_diff((new_value & CLKMASK) >> CLKSHIFT);
+        m_sr_module->clock_diff(1<<((new_value & CLKMASK) >> CLKSHIFT));
     }
 
     if (diff & (SRQEN | SRLEN))
     {
+	m_sr_module->srqen = new_value & SRQEN;
+	m_sr_module->srlen = new_value & SRLEN;
         m_sr_module->Qoutput();
     }
 
     if (diff & (SRNQEN | SRLEN))
     {
+	m_sr_module->srnqen = new_value & SRNQEN;
+	m_sr_module->srlen = new_value & SRLEN;
         m_sr_module->NQoutput();
     }
 
@@ -3023,9 +3053,12 @@ void SRCON1::put(unsigned int new_value)
     {
         return;
     }
+    
 
     if (diff & (SRRCKE | SRSCKE))
     {
+        m_sr_module->srrcke = new_value & SRRCKE;
+        m_sr_module->srscke = new_value & SRSCKE;
         if (!(new_value & (SRRCKE | SRSCKE)))  	// all clocks off
         {
             m_sr_module->clock_disable();  // turn off clock
@@ -3037,10 +3070,174 @@ void SRCON1::put(unsigned int new_value)
         }
     }
 
+    m_sr_module->srsc1e = new_value & SRSC1E;
+    m_sr_module->srsc2e = new_value & SRSC2E;
+    m_sr_module->srspe = new_value & SRSPE;
+    m_sr_module->srrc1e = new_value & SRRC1E;
+    m_sr_module->srrc2e = new_value & SRRC2E;
+    m_sr_module->srrpe = new_value & SRRPE;
     m_sr_module->update();
 }
+// SRCON0 for P16f61x
+SRCON0_V2::SRCON0_V2(Processor *pCpu, const char *pName, const char *pDesc, SR_MODULE *_sr_module)
+    : sfr_register(pCpu, pName, pDesc),
+      m_sr_module(_sr_module)
+{
+    m_sr_module->cxoutput = true; // comparator output goes through SR module
+}
 
 
+void SRCON0_V2::put(unsigned int new_value)
+{
+    new_value &= mValidBits;
+    unsigned int diff = new_value ^ value.get();
+
+    SRprint((stderr, "%s value=0x%x\n", name().c_str(), new_value));
+
+    if (!diff)
+    {
+        return;
+    }
+
+    trace.raw(write_trace.get() | value.get());
+    value.put(new_value  & ~(PULSR | PULSS)); // PULSR AND PULSS not saved
+
+    if ((diff & PULSS) && (new_value & PULSS))
+    {
+        m_sr_module->pulse_set();
+    }
+
+    if ((diff & PULSR) && (new_value & PULSR))
+    {
+        m_sr_module->pulse_reset();
+    }
+
+    // Map C1SEN to srsc1e
+    if (diff & C1SEN)
+	m_sr_module->srsc1e = new_value & C1SEN;
+
+    // Map C2REN to srrc2e
+    if (diff & C2REN)
+	m_sr_module->srrc2e = new_value & C2REN;
+
+    // Map SRCLKEN to srscke
+    if (diff & SRCLKEN)
+    {
+	m_sr_module->srscke = new_value & SRCLKEN;
+	if (m_sr_module->srscke) 
+	    m_sr_module->clock_enable();
+	else
+	    m_sr_module->clock_disable();
+    }
+    // SR0 0, C1OUT to output, 1, SR Q to output
+    if (diff & SR0)
+    {
+	SRprint((stderr, "SR0=%d\n", new_value & SR0));
+        m_sr_module->sr0 = new_value & SR0;
+	m_sr_module->Qoutput();
+    }
+
+    // SR1 0, C2OUT to output, 1, SR NQ to output
+    // Map SR1 to srnqen
+    if (diff & SR1)
+    {
+	SRprint((stderr, "SR1=%d\n", new_value & SR1));
+        m_sr_module->sr1 = new_value & SR1;
+	m_sr_module->NQoutput();
+    }
+
+    m_sr_module->update();
+}
+
+SRCON1_V2::SRCON1_V2(Processor *pCpu, const char *pName, const char *pDesc, SR_MODULE *_sr_module)
+    : sfr_register(pCpu, pName, pDesc), m_sr_module(_sr_module)
+{
+}
+
+
+void SRCON1_V2::put(unsigned int new_value)
+{
+    unsigned int masked_value = new_value & mValidBits;
+    unsigned int diff = masked_value ^ value.get();
+    unsigned int gain;
+    trace.raw(write_trace.get() | value.get());
+    value.put(masked_value);
+
+    if (!diff)
+    {
+        return;
+    }
+    gain = (masked_value & CLKMASK) >> CLKSHIFT;
+    SRprint((stderr, "%s raw=%d divider=%d\n", name().c_str(), gain, 4<<gain));
+    m_sr_module->clock_diff(4<<gain);
+}
+    
+
+// SRCON0 for P16f61x
+SRCON0_V3::SRCON0_V3(Processor *pCpu, const char *pName, const char *pDesc, SR_MODULE *_sr_module)
+    : sfr_register(pCpu, pName, pDesc),
+      m_sr_module(_sr_module)
+{
+    m_sr_module->cxoutput = true; // comparator output goes through SR module
+}
+
+
+void SRCON0_V3::put(unsigned int new_value)
+{
+    new_value &= mValidBits;
+    unsigned int diff = new_value ^ value.get();
+
+    SRprint((stderr, "%s value=0x%x\n", name().c_str(), new_value));
+
+    if (!diff)
+    {
+        return;
+    }
+
+    trace.raw(write_trace.get() | value.get());
+    value.put(new_value  & ~(PULSR | PULSS)); // PULSR AND PULSS not saved
+
+    if ((diff & PULSS) && (new_value & PULSS))
+    {
+        m_sr_module->pulse_set();
+    }
+
+    if ((diff & PULSR) && (new_value & PULSR))
+    {
+        m_sr_module->pulse_reset();
+    }
+
+    // Map C1SEN to srsc1e
+    if (diff & C1SEN)
+	m_sr_module->srsc1e = new_value & C1SEN;
+
+    // Map C2REN to srrc2e
+    if (diff & C2REN)
+	m_sr_module->srrc2e = new_value & C2REN;
+
+    if (diff & FVREN)
+    {
+	    fprintf(stderr, "RRR FIXME FVREN SRCON0_V3\n");
+    }
+    // SR0 0, C1OUT to output, 1, SR Q to output
+    if (diff & SR0)
+    {
+	SRprint((stderr, "SR0=%d\n", new_value & SR0));
+        m_sr_module->sr0 = new_value & SR0;
+	m_sr_module->Qoutput();
+    }
+
+    // SR1 0, C2OUT to output, 1, SR NQ to output
+    // Map SR1 to srnqen
+    if (diff & SR1)
+    {
+	SRprint((stderr, "SR1=%d\n", new_value & SR1));
+        m_sr_module->sr1 = new_value & SR1;
+	m_sr_module->NQoutput();
+    }
+
+    m_sr_module->update();
+}
 class SRinSink : public SignalSink
 {
 public:
@@ -3048,11 +3245,11 @@ public:
         : sr_module(_sr_module)
     {}
 
-    virtual void setSinkState(char new3State)
+    void setSinkState(char new3State) override
     {
         sr_module->setState(new3State);
     }
-    virtual void release()
+    void release() override
     {
         delete this;
     }
@@ -3068,7 +3265,7 @@ public:
         PeripheralSignalSource(_pin), sr_module(_sr_module),
         index(_index)
     {}
-    virtual void release()
+    void release() override
     {
         sr_module->releasePin(index);
     }
@@ -3085,8 +3282,7 @@ enum
 };
 
 SR_MODULE::SR_MODULE(Processor *_cpu) :
-    srcon0(_cpu, "srcon0", "SR Latch Control 0 Register", this),
-    srcon1(_cpu, "srcon1", "SR Latch Control 1 Register", this),
+    srcon0(nullptr), srcon1(nullptr),
     cpu(_cpu)
 {
 }
@@ -3099,16 +3295,38 @@ SR_MODULE::~SR_MODULE()
         SRQ_pin->setSource(0);
     }
 
-    delete  m_SRQsource;
+    if (m_SRQsource) delete  m_SRQsource;
 
     if (m_SRNQsource_active)
     {
         SRNQ_pin->setSource(0);
     }
+    if (srcon0) delete srcon0;
+    if (srcon1) delete srcon1;
 
-    delete  m_SRNQsource;
+    if (m_SRNQsource) delete  m_SRNQsource;
 }
 
+void SR_MODULE::set_cxoen(int cm, bool cxoe)
+{
+    SRprint((stderr, "cm=%d cxoe=%d\n", cm+1, cxoe));
+    if (cm == 0)
+    {
+	if (cxoe != c1oen)
+	{
+	    c1oen = cxoe;
+	    Qoutput();
+	}
+    }
+    else
+    {
+	if (cxoe != c2oen)
+	{
+	    c2oen = cxoe;
+	    NQoutput();
+	}
+    }
+}
 
 // determine output state of RS flip-flop
 // If both state_set and state_reset are true, Q output is 0
@@ -3116,32 +3334,32 @@ SR_MODULE::~SR_MODULE()
 // function prior to its call.
 void SR_MODULE::update()
 {
-    if ((srcon1.value.get() & SRCON1::SRSC1E) && syncc1out)
+    if (srsc1e && syncc1out)
     {
         state_set = true;
     }
 
-    if ((srcon1.value.get() & SRCON1::SRSC2E) && syncc2out)
+    if (srsc2e && syncc2out)
     {
         state_set = true;
     }
 
-    if ((srcon1.value.get() & SRCON1::SRSPE) && SRI_pin->getPin().getState())
+    if (srspe && SRI_pin->getPin().getState())
     {
         state_set = true;
     }
 
-    if ((srcon1.value.get() & SRCON1::SRRC1E) && syncc1out)
+    if (srrc1e && syncc1out)
     {
         state_reset = true;
     }
 
-    if ((srcon1.value.get() & SRCON1::SRRC2E) && syncc2out)
+    if (srrc2e && syncc2out)
     {
         state_reset = true;
     }
 
-    if ((srcon1.value.get() & SRCON1::SRRPE) && SRI_pin->getPin().getState())
+    if (srrpe && SRI_pin->getPin().getState())
     {
         state_reset = true;
     }
@@ -3159,17 +3377,18 @@ void SR_MODULE::update()
 
     state_set = state_reset = false;
 
-    if (!(srcon0.value.get() & SRCON0::SRLEN))
+    if (!srlen && !cxoutput)
     {
         return;
     }
 
-    if ((srcon0.value.get() & SRCON0::SRQEN))
+    if ((srqen || c1oen) && m_SRQsource)
     {
         m_SRQsource->putState(state_Q ? '1' : '0');
     }
 
-    if ((srcon0.value.get() & SRCON0::SRNQEN))
+    SRprint((stderr, "state_Q=%d srlen=%d cxoutput=%d srnqen=%d m_SRNQsource=%p\n", state_Q, srlen, cxoutput, srnqen, m_SRNQsource));
+    if ((srnqen || c2oen) && m_SRNQsource)
     {
         m_SRNQsource->putState(!state_Q ? '1' : '0');
     }
@@ -3197,7 +3416,7 @@ void SR_MODULE::clock_enable()
 {
     if (!future_cycle)
     {
-        future_cycle = get_cycles().get() + (1 << srclk);
+        future_cycle = get_cycles().get() + srclk;
         get_cycles().set_break(future_cycle, this);
     }
 }
@@ -3207,9 +3426,11 @@ void SR_MODULE::clock_enable()
 void SR_MODULE::clock_diff(unsigned int _srclk)
 {
     srclk = _srclk;
+
+    SRprint((stderr, "srscke=%d srrcke=%d srclk=%d\n", srscke, srrcke, srclk));
     clock_disable();
 
-    if (srcon1.value.get() & (SRCON1::SRSCKE | SRCON1::SRRCKE))
+    if (srscke || srrcke)
     {
         clock_enable();
     }
@@ -3220,13 +3441,13 @@ void SR_MODULE::callback()
 {
     bool active = false;
 
-    if (srcon1.value.get() & (SRCON1::SRSCKE))   //Set clock enabled
+    if (srscke)   //Set clock enabled
     {
         active = true;
         pulse_set();
     }
 
-    if (srcon1.value.get() & (SRCON1::SRRCKE))   //Reset clock enabled
+    if (srrcke)   //Reset clock enabled
     {
         active = true;
         pulse_reset();
@@ -3244,13 +3465,13 @@ void SR_MODULE::callback()
 
 void SR_MODULE::setPins(PinModule *sri, PinModule *srq, PinModule *srnq)
 {
-    if (!SRI_pin)
+    if (sri && !SRI_pin)
     {
         m_SRinSink = new SRinSink(this);
         sri->addSink(m_SRinSink);
 
     }
-    else if (SRI_pin != sri)
+    else if (sri && (SRI_pin != sri))
     {
         SRI_pin->removeSink(m_SRinSink);
         sri->addSink(m_SRinSink);
@@ -3265,7 +3486,7 @@ void SR_MODULE::setPins(PinModule *sri, PinModule *srq, PinModule *srnq)
 // If pin chnages and we are looking at it, call update
 void SR_MODULE::setState(char /* IOin */ )
 {
-    if (srcon1.value.get() & (SRCON1::SRSPE | SRCON1::SRRPE))
+    if (srspe || srrpe)
     {
         update();
     }
@@ -3278,7 +3499,14 @@ void SR_MODULE::syncC1out(bool val)
     {
         syncc1out = val;
 
-        if (srcon1.value.get() & (SRCON1::SRSC1E | SRCON1::SRRC1E))
+	SRprint((stderr, " val=%d sr0=%d c1oen=%d\n", val, sr0, c1oen));
+
+	if (!sr0  && c1oen && m_SRQsource)
+	{
+	    m_SRQsource->putState(syncc1out ? '1' : '0');
+	}
+
+        if (srsc1e || srrc1e)
         {
             update();
         }
@@ -3292,10 +3520,15 @@ void SR_MODULE::syncC2out(bool val)
     {
         syncc2out = val;
 
-        if (srcon1.value.get() & (SRCON1::SRSC2E | SRCON1::SRRC2E))
+	SRprint((stderr, "val=%d\n", val));
+        if (srsc2e || srrc2e)
         {
             update();
         }
+	if (!sr1  && c2oen && m_SRNQsource)
+	{
+	    m_SRNQsource->putState(syncc2out ? '1' : '0');
+	}
     }
 }
 
@@ -3304,16 +3537,23 @@ void SR_MODULE::syncC2out(bool val)
 // This is only call if SRLEN OR SRQEN has changed
 void SR_MODULE::Qoutput()
 {
-    if ((srcon0.value.get() & (SRCON0::SRLEN | SRCON0::SRQEN)) ==
-            (SRCON0::SRLEN | SRCON0::SRQEN))
+    SRprint((stderr, "srlen=%d c1oen=%d srqen=%d sr0=%d cxoutput=%d\n", srlen, c1oen, srqen, sr0, cxoutput));
+    if ( (srlen && srqen) ||  c1oen) 
     {
         if (!m_SRQsource)
         {
             m_SRQsource = new SRnSource(SRQ_pin, this, SRQ);
         }
 
-        SRQ_pin->setSource(m_SRQsource);
-        SRQ_pin->getPin().newGUIname("SRQ");
+	if (!m_SRQsource_active)
+            SRQ_pin->setSource(m_SRQsource);
+	if (c1oen && !sr0)
+	{
+            SRQ_pin->getPin().newGUIname("C1OUT");
+            m_SRQsource->putState(syncc1out ? '1' : '0');
+	}
+	else
+            SRQ_pin->getPin().newGUIname("SRQ");
         m_SRQsource_active = true;
 
     }
@@ -3321,8 +3561,9 @@ void SR_MODULE::Qoutput()
     {
         SRQ_pin->setSource(0);
 
-        if (strcmp("SRQ", SRQ_pin->getPin().GUIname().c_str()) == 0)
+//        if (strcmp("SRQ", SRQ_pin->getPin().GUIname().c_str()) == 0)
         {
+	    SRprint((stderr, "Gui=%s name=%s\n", SRQ_pin->getPin().GUIname().c_str(), SRQ_pin->getPin().name().c_str()));
             SRQ_pin->getPin().newGUIname(SRQ_pin->getPin().name().c_str());
         }
     }
@@ -3333,16 +3574,22 @@ void SR_MODULE::Qoutput()
 // This is only call if SRLEN OR SRNQEN has changed
 void SR_MODULE::NQoutput()
 {
-    if ((srcon0.value.get() & (SRCON0::SRLEN | SRCON0::SRNQEN)) ==
-            (SRCON0::SRLEN | SRCON0::SRNQEN))
+    if ( (srlen && srnqen) ||  c2oen) 
     {
         if (!m_SRNQsource)
         {
             m_SRNQsource = new SRnSource(SRNQ_pin, this, SRNQ);
         }
 
-        SRNQ_pin->setSource(m_SRNQsource);
-        SRNQ_pin->getPin().newGUIname("SRNQ");
+	if (!m_SRNQsource_active)
+            SRNQ_pin->setSource(m_SRNQsource);
+	if (c2oen && !sr1)
+	{
+            SRNQ_pin->getPin().newGUIname("C2OUT");
+            m_SRNQsource->putState(syncc2out ? '1' : '0');
+	}
+	else
+            SRNQ_pin->getPin().newGUIname("SRNQ");
         m_SRNQsource_active = true;
 
     }
