@@ -20,20 +20,13 @@ License along with this library; if not, see
 
 // T. Scott Dattalo 16bit core routines
 
-#include <iostream>
-#include <iomanip>
-#include <string>
-#include <list>
-
-#include "../config.h"
 #include "16bit-processors.h"
 #include "pic-instructions.h"
 #include "12bit-instructions.h"
+#include "14bit-instructions.h"
 #include "16bit-instructions.h"
 
-#include "gpsim_def.h"
 #include "pic-processor.h"
-#include "stimuli.h"
 
 
 /* PIC 16-bit instruction set */
@@ -187,19 +180,16 @@ const int NUM_OP_18CXX	= sizeof(op_18cxx) / sizeof(op_18cxx[0]);
 const int NUM_OP_17CXX	= sizeof(op_17cxx) / sizeof(op_17cxx[0]);
 
 
-instruction * disasm16 (pic_processor *cpu, unsigned int address, unsigned int inst)
+instruction * disasm16(pic_processor *cpu, unsigned int address, unsigned int inst)
 {
-  instruction *pi;
+    cpu16->setCurrentDisasmAddress(address);
 
-  cpu16->setCurrentDisasmAddress(address);
+    for (int i = 0; i < NUM_OP_18CXX; i++)
+    {
+        if ((op_18cxx[i].inst_mask & inst) == op_18cxx[i].opcode)
+            return op_18cxx[i].inst_constructor(cpu, inst, address);
+    }
 
-  pi = 0;
-  for(int i =0; i<NUM_OP_18CXX && !pi; i++)
-    if((op_18cxx[i].inst_mask & inst) == op_18cxx[i].opcode)
-      pi = op_18cxx[i].inst_constructor(cpu, inst,address);
 
-  if(pi == 0)
-    pi = invalid_instruction::construct(cpu, inst, address);
-
-  return (pi);
+    return new invalid_instruction(cpu, inst, address);
 }
