@@ -18,21 +18,22 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
-#include <stdio.h>
-#include <iostream>
-#include <iomanip>
 #include <cstdio>
+#include <iostream>
+#include <string>
 
-#include "../config.h"
-#include "pic-processor.h"
-#include "14bit-registers.h"
+#include "16bit-instructions.h"
 
 #include "12bit-instructions.h"
-#include "16bit-instructions.h"
+#include "14bit-registers.h"
 #include "16bit-processors.h"
 #include "16bit-registers.h"
 #include "breakpoints.h"
+#include "gpsim_object.h"
+#include "intcon.h"
 #include "pic-instructions.h"
+#include "pic-processor.h"
+#include "processor.h"
 #include "registers.h"
 
 //--------------------------------------------------
@@ -393,11 +394,14 @@ void ADDWF16::execute()
     source = cpu_pic->registers[register_address];
   }
 
-  new_value = (src_value = source->get_value()) + (w_value = cpu16->Wget());
+  /* RP - removed special case for PCL as it was highly broken */
+  new_value = (src_value = source->get()) + (w_value = cpu16->Wget());
 
   // Store the result
 
   if (destination) {
+    if (source == cpu16->status)
+	new_value &= 0xe0;
     source->put(new_value & 0xff);      // Result goes to source
     cpu16->status->put_Z_C_DC_OV_N(new_value, src_value, w_value);
 
@@ -433,6 +437,8 @@ void ADDWFC16::execute()
   // Store the result
 
   if (destination) {
+    if (source == cpu16->status)
+	new_value &= 0xe0;
     source->put(new_value & 0xff);  // Result goes to source
 
   } else {
@@ -475,6 +481,8 @@ void ANDWF16::execute()
   new_value = source->get() & cpu16->Wget();
 
   if (destination) {
+    if (source == cpu16->status)
+	new_value &= 0xe0;
     source->put(new_value);  // Result goes to source
 
   } else {
@@ -863,6 +871,8 @@ void COMF16::execute()
   // Store the result
 
   if (destination) {
+    if (source == cpu16->status)
+	new_value &= 0xe0;
     source->put(new_value);  // Result goes to source
 
   } else {
@@ -970,14 +980,16 @@ void CPFSLT::execute()
 void CLRF16::execute()
 {
   if (access) {
-    cpu_pic->register_bank[register_address]->put(0);
+    source = cpu_pic->register_bank[register_address];
 
   } else if (cpu16->extended_instruction() && register_address < 0x60) {
-    cpu_pic->registers[register_address + cpu16->ind2.fsr_value]->put(0);
+    source = cpu_pic->registers[register_address + cpu16->ind2.fsr_value];
 
   } else {
-    cpu_pic->registers[register_address]->put(0);
+    source = cpu_pic->registers[register_address];
   }
+  if (source != cpu16->status)
+      source->put(0);
 
   cpu16->status->put_Z(1);
   cpu16->pc->increment();
@@ -1038,7 +1050,10 @@ void DECF16::execute()
   unsigned int new_value = src_value - 1;
 
   if (destination) {
-    source->put(new_value & 0xff);  // Result goes to source
+    if (source == cpu16->status)
+	new_value &= 0xe0;
+    else
+        source->put(new_value & 0xff);  // Result goes to source
 
   } else {
     cpu16->Wput(new_value & 0xff);
@@ -1069,7 +1084,10 @@ void DECFSZ16::execute()
   new_value = (source->get() - 1) & 0xff;
 
   if (destination) {
-    source->put(new_value);  // Result goes to source
+    if (source == cpu16->status)
+	new_value &= 0xe0;
+    else
+        source->put(new_value);  // Result goes to source
 
   } else {
     cpu16->Wput(new_value);
@@ -1167,7 +1185,10 @@ void INCF16::execute()
   new_value = (src_value + 1);
 
   if (destination) {
-    source->put(new_value & 0xff);      // Result goes to source
+    if (source == cpu16->status)
+	new_value &= 0xe0;
+    else
+        source->put(new_value & 0xff);      // Result goes to source
     cpu16->status->put_Z_C_DC_OV_N(new_value, src_value, 1);
 
   } else {
@@ -1286,7 +1307,10 @@ void IORWF16::execute()
   new_value = source->get() | cpu16->Wget();
 
   if (destination) {
-    source->put(new_value);  // Result goes to source
+    if (source == cpu16->status)
+	new_value &= 0xe0;
+    else
+        source->put(new_value);  // Result goes to source
 
   } else {
     cpu16->Wput(new_value);
@@ -1428,7 +1452,10 @@ void MOVF16::execute()
   // Store the result
 
   if (destination) {
-    source->put(source_value);
+    if (source == cpu16->status)
+	source_value &= 0xe0;
+    else
+        source->put(source_value);
 
   } else {
     cpu16->Wput(source_value);
@@ -1764,7 +1791,10 @@ void NEGF::execute()
 
   src_value = source->get();
   new_value = 1 + ~src_value;        // two's complement
-  source->put(new_value & 0xff);
+  if (source == cpu16->status)
+	new_value &= 0xe0;
+  else
+      source->put(new_value & 0xff);
   cpu16->status->put_Z_C_DC_OV_N_for_sub(new_value, 0, src_value);
   cpu16->pc->increment();
 }
@@ -1871,8 +1901,7 @@ void RETFIE16::execute()
   }
 
   //cout << "retfie: need to enable interrupts\n";
-  cpu16->intcon.in_interrupt = false;
-  cpu16->intcon.put_value(cpu16->intcon.value.get()); //test for new interrupts
+  cpu16->intcon.set_gie();
 }
 
 
@@ -1940,7 +1969,10 @@ void RLCF::execute()
   new_value = (source->get() << 1) | cpu16->status->get_C();
 
   if (destination) {
-    source->put(new_value & 0xff);  // Result goes to source
+    if (source == cpu16->status)
+	new_value &= 0xe0;
+    else
+        source->put(new_value & 0xff);  // Result goes to source
 
   } else {
     cpu16->Wput(new_value & 0xff);
@@ -1979,7 +2011,10 @@ void RLNCF::execute()
   new_value = (src_value << 1) | ((src_value & 0x80) ? 1 : 0);
 
   if (destination) {
-    source->put(new_value & 0xff);  // Result goes to source
+    if (source == cpu16->status)
+	new_value &= 0xe0;
+    else
+        source->put(new_value & 0xff);  // Result goes to source
 
   } else {
     cpu16->Wput(new_value & 0xff);
@@ -2018,7 +2053,10 @@ void RRCF::execute()
   new_value = (src_value >> 1) | (cpu16->status->get_C() ? 0x80 : 0);
 
   if (destination) {
-    source->put(new_value & 0xff);  // Result goes to source
+    if (source == cpu16->status)
+	new_value &= 0xe0;
+    else
+        source->put(new_value & 0xff);  // Result goes to source
 
   } else {
     cpu16->Wput(new_value & 0xff);
@@ -2057,7 +2095,10 @@ void RRNCF::execute()
   new_value = (src_value >> 1) | ((src_value & 1) ? 0x80 : 0);
 
   if (destination) {
-    source->put(new_value & 0xff);  // Result goes to source
+    if (source == cpu16->status)
+	new_value &= 0xe0;
+    else
+        source->put(new_value & 0xff);  // Result goes to source
 
   } else {
     cpu16->Wput(new_value & 0xff);
@@ -2143,7 +2184,10 @@ void SUBFWB::execute()
               (1 - cpu16->status->get_C());
 
   if (destination) {
-    source->put(new_value & 0xff);
+    if (source == cpu16->status)
+	new_value &= 0xe0;
+    else
+        source->put(new_value & 0xff);
 
   } else {
     cpu16->Wput(new_value & 0xff);
@@ -2173,7 +2217,10 @@ void SUBWF16::execute()
   new_value = (src_value = source->get()) - (w_value = cpu16->Wget());
 
   if (destination) {
-    source->put(new_value & 0xff);
+    if (source == cpu16->status)
+	new_value &= 0xe0;
+    else
+        source->put(new_value & 0xff);
 
   } else {
     cpu16->Wput(new_value & 0xff);
@@ -2203,7 +2250,10 @@ void SUBWFB16::execute()
               (1 - cpu16->status->get_C());
 
   if (destination) {
-    source->put(new_value & 0xff);
+    if (source == cpu16->status)
+	new_value &= 0xe0;
+    else
+        source->put(new_value & 0xff);
 
   } else {
     cpu16->Wput(new_value & 0xff);
@@ -2451,7 +2501,10 @@ void XORWF16::execute()
   new_value = source->get() ^ cpu16->Wget();
 
   if (destination) {
-    source->put(new_value);  // Result goes to source
+    if (source == cpu16->status)
+	new_value &= 0xe0;
+    else
+        source->put(new_value);  // Result goes to source
 
   } else {
     cpu16->Wput(new_value);
