@@ -22,8 +22,12 @@ License along with this library; if not, see
 #ifndef SRC_16BIT_INSTRUCTIONS_H_
 #define SRC_16BIT_INSTRUCTIONS_H_
 
+#include "12bit-instructions.h"
 #include "14bit-instructions.h"
-#include "16bit-registers.h"
+#include "pic-instructions.h"
+
+class Indirect_Addressing;
+class Processor;
 
 /*---------------------------------------------------------
  * 16bit-instructions.h
@@ -44,10 +48,10 @@ class Branching : public instruction {
 public:
   Branching(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute() {}
-  virtual void debug() {}
-  virtual char *name(char *, int);
-  virtual bool isBase()
+  void execute() override {}
+  void debug() override {}
+  char *name(char *, int) override;
+  bool isBase() override
   {
     return true;
   }
@@ -64,19 +68,19 @@ class multi_word_instruction : public instruction {
 public:
   multi_word_instruction(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual int instruction_size()
+  int instruction_size() override
   {
     return 2;
   }
-  virtual enum INSTRUCTION_TYPES isa()
+  enum INSTRUCTION_TYPES isa() override
   {
     return MULTIWORD_INSTRUCTION;
   }
-  virtual bool isBase()
+  bool isBase() override
   {
     return true;
   }
-  virtual void initialize(bool init_state)
+  void initialize(bool init_state) override
   {
     initialized = init_state;
   }
@@ -94,8 +98,8 @@ public:
   multi_word_branch(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
   void runtime_initialize();
-  virtual void execute() {}
-  virtual char *name(char *, int);
+  void execute() override {}
+  char *name(char *, int) override;
 
   unsigned int destination_index = 0;
 };
@@ -107,12 +111,12 @@ class ADDULNK : public instruction {
 public:
   ADDULNK(Processor *new_cpu, unsigned int new_opcode, const char *, unsigned int address);
 
-  virtual bool isBase()
+  bool isBase() override
   {
     return true;
   }
-  virtual void execute();
-  virtual char *name(char *, int);
+  void execute() override;
+  char *name(char *, int) override;
 
 protected:
   unsigned int m_lit;
@@ -124,12 +128,12 @@ class ADDFSR16 : public instruction {
 public:
   ADDFSR16(Processor *new_cpu, unsigned int new_opcode, const char *, unsigned int address);
 
-  virtual bool isBase()
+  bool isBase() override
   {
     return true;
   }
-  virtual void execute();
-  virtual char *name(char *, int);
+  void execute() override;
+  char *name(char *, int) override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     if (((new_opcode >> 6) & 3) == 3) {
@@ -161,11 +165,11 @@ public:
   CALLW16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : CALLW(new_cpu, new_opcode, address) {}
 
-  virtual bool isBase()
+  bool isBase() override
   {
     return true;
   }
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new CALLW16(new_cpu, new_opcode, address);
@@ -178,8 +182,8 @@ class MOVSF : public multi_word_instruction {
 public:
   MOVSF(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
-  virtual char *name(char *, int);
+  void execute() override;
+  char *name(char *, int) override;
   void runtime_initialize();
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
@@ -197,12 +201,12 @@ class PUSHL : public instruction {
 public:
   PUSHL(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual bool isBase()
+  bool isBase() override
   {
     return true;
   }
-  virtual void execute();
-  virtual char *name(char *, int);
+  void execute() override;
+  char *name(char *, int) override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new PUSHL(new_cpu, new_opcode, address);
@@ -219,7 +223,7 @@ public:
   ADDLW16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : ADDLW(new_cpu,  new_opcode, address)
   {}
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new ADDLW16(new_cpu, new_opcode, address);
@@ -233,7 +237,7 @@ public:
   ADDWF16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : ADDWF(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new ADDWF16(new_cpu, new_opcode, address);
@@ -249,7 +253,7 @@ public:
   ADDWFC16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : ADDWFC(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new ADDWFC16(new_cpu, new_opcode, address);
@@ -263,7 +267,7 @@ public:
   ANDLW16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : ANDLW(new_cpu,  new_opcode, address)
   {}
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new ANDLW16(new_cpu, new_opcode, address);
@@ -277,7 +281,7 @@ public:
   ANDWF16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : ANDWF(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new ANDWF16(new_cpu, new_opcode, address);
@@ -290,7 +294,7 @@ class BC : public Branching {
 public:
   BC(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new BC(new_cpu, new_opcode, address);
@@ -303,7 +307,7 @@ class BN : public Branching {
 public:
   BN(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new BN(new_cpu, new_opcode, address);
@@ -316,7 +320,7 @@ class BNC : public Branching {
 public:
   BNC(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new BNC(new_cpu, new_opcode, address);
@@ -329,7 +333,7 @@ class BNN : public Branching {
 public:
   BNN(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new BNN(new_cpu, new_opcode, address);
@@ -342,7 +346,7 @@ class BNOV : public Branching {
 public:
   BNOV(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new BNOV(new_cpu, new_opcode, address);
@@ -355,7 +359,7 @@ class BNZ : public Branching {
 public:
   BNZ(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new BNZ(new_cpu, new_opcode, address);
@@ -368,7 +372,7 @@ class BOV : public Branching {
 public:
   BOV(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new BOV(new_cpu, new_opcode, address);
@@ -381,9 +385,9 @@ class BRA16 : public instruction {
 public:
   BRA16(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
-  virtual char *name(char *, int);
-  virtual bool isBase()
+  void execute() override;
+  char *name(char *, int) override;
+  bool isBase() override
   {
     return true;
   }
@@ -403,7 +407,7 @@ public:
   BSF16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : BSF(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new BSF16(new_cpu, new_opcode, address);
@@ -419,7 +423,7 @@ public:
   BCF16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : BCF(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new BCF16(new_cpu, new_opcode, address);
@@ -435,7 +439,7 @@ public:
   BTFSC16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : BTFSC(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new BTFSC16(new_cpu, new_opcode, address);
@@ -451,7 +455,7 @@ public:
   BTFSS16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : BTFSS(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new BTFSS16(new_cpu, new_opcode, address);
@@ -466,7 +470,7 @@ class BTG : public Bit_op {
 public:
   BTG(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new BTG(new_cpu, new_opcode, address);
@@ -479,7 +483,7 @@ class BZ : public Branching {
 public:
   BZ(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new BZ(new_cpu, new_opcode, address);
@@ -492,12 +496,12 @@ class CALL16 : public multi_word_branch {
 public:
   CALL16(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new CALL16(new_cpu, new_opcode, address);
   }
-  virtual char *name(char *, int);
+  char *name(char *, int) override;
 
   bool fast;
 };
@@ -509,7 +513,7 @@ public:
   CLRF16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : CLRF(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new CLRF16(new_cpu, new_opcode, address);
@@ -523,7 +527,7 @@ public:
   COMF16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : COMF(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new COMF16(new_cpu, new_opcode, address);
@@ -536,7 +540,7 @@ class CPFSEQ : public Register_op {
 public:
   CPFSEQ(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new CPFSEQ(new_cpu, new_opcode, address);
@@ -549,7 +553,7 @@ class CPFSGT : public Register_op {
 public:
   CPFSGT(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new CPFSGT(new_cpu, new_opcode, address);
@@ -562,7 +566,7 @@ class CPFSLT : public Register_op {
 public:
   CPFSLT(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new CPFSLT(new_cpu, new_opcode, address);
@@ -575,8 +579,8 @@ class DAW : public instruction {
 public:
   DAW(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
-  virtual bool isBase()
+  void execute() override;
+  bool isBase() override
   {
     return true;
   }
@@ -593,7 +597,7 @@ public:
   DECF16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : DECF(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new DECF16(new_cpu, new_opcode, address);
@@ -607,7 +611,7 @@ public:
   DECFSZ16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : DECFSZ(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new DECFSZ16(new_cpu, new_opcode, address);
@@ -620,7 +624,7 @@ class DCFSNZ : public Register_op {
 public:
   DCFSNZ(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new DCFSNZ(new_cpu, new_opcode, address);
@@ -633,7 +637,7 @@ class GOTO16 : public multi_word_branch {
 public:
   GOTO16(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new GOTO16(new_cpu, new_opcode, address);
@@ -647,7 +651,7 @@ public:
   INCF16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : INCF(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new INCF16(new_cpu, new_opcode, address);
@@ -661,7 +665,7 @@ public:
   INCFSZ16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : INCFSZ(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new INCFSZ16(new_cpu, new_opcode, address);
@@ -674,7 +678,7 @@ class INFSNZ : public Register_op {
 public:
   INFSNZ(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new INFSNZ(new_cpu, new_opcode, address);
@@ -689,7 +693,7 @@ public:
   IORLW16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : IORLW(new_cpu,  new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new IORLW16(new_cpu, new_opcode, address);
@@ -703,7 +707,7 @@ public:
   IORWF16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : IORWF(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new IORWF16(new_cpu, new_opcode, address);
@@ -716,12 +720,12 @@ class LCALL16 : public multi_word_branch {
 public:
   LCALL16(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new LCALL16(new_cpu, new_opcode, address);
   }
-  virtual char *name(char *, int);
+  char *name(char *, int) override;
 
   bool fast = false;
 };
@@ -732,8 +736,8 @@ class LFSR : public multi_word_instruction {
 public:
   LFSR(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
-  virtual char *name(char *, int);
+  void execute() override;
+  char *name(char *, int) override;
   void runtime_initialize();
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
@@ -752,7 +756,7 @@ public:
   MOVF16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : MOVF(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new MOVF16(new_cpu, new_opcode, address);
@@ -765,8 +769,8 @@ class MOVFF : public multi_word_instruction {
 public:
   MOVFF(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
-  virtual char *name(char *, int);
+  void execute() override;
+  char *name(char *, int) override;
   void runtime_initialize();
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
@@ -783,8 +787,8 @@ class MOVFP : public multi_word_instruction {
 public:
   MOVFP(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
-  virtual char *name(char *, int);
+  void execute() override;
+  char *name(char *, int) override;
   void runtime_initialize();
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
@@ -803,7 +807,7 @@ class MOVLB16 : public Literal_op {
 public:
   MOVLB16(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new MOVLB16(new_cpu, new_opcode, address);
@@ -817,7 +821,7 @@ class MOVLR : public Literal_op {
 public:
   MOVLR(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new MOVLR(new_cpu, new_opcode, address);
@@ -830,8 +834,8 @@ class MOVPF : public multi_word_instruction {
 public:
   MOVPF(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
-  virtual char *name(char *, int);
+  void execute() override;
+  char *name(char *, int) override;
   void runtime_initialize();
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
@@ -849,7 +853,7 @@ class MOVWF16 : public MOVWF {
 public:
   MOVWF16(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
@@ -865,7 +869,7 @@ class MOVWF16a : public MOVWF {
 public:
   MOVWF16a(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
@@ -881,7 +885,7 @@ class MULLW : public Literal_op {
 public:
   MULLW(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new MULLW(new_cpu, new_opcode, address);
@@ -894,7 +898,7 @@ class MULWF : public Register_op {
 public:
   MULWF(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new MULWF(new_cpu, new_opcode, address);
@@ -907,7 +911,7 @@ class NEGF : public Register_op {
 public:
   NEGF(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new NEGF(new_cpu, new_opcode, address);
@@ -920,7 +924,7 @@ class NEGW : public Register_op {
 public:
   NEGW(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new NEGW(new_cpu, new_opcode, address);
@@ -933,8 +937,8 @@ class POP : public instruction {
 public:
   POP(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
-  virtual bool isBase()
+  void execute() override;
+  bool isBase() override
   {
     return true;
   }
@@ -950,8 +954,8 @@ class PUSH : public instruction {
 public:
   PUSH(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
-  virtual bool isBase()
+  void execute() override;
+  bool isBase() override
   {
     return true;
   }
@@ -967,9 +971,9 @@ class RCALL : public instruction {
 public:
   RCALL(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
-  virtual char *name(char *, int);
-  virtual bool isBase()
+  void execute() override;
+  char *name(char *, int) override;
+  bool isBase() override
   {
     return true;
   }
@@ -992,8 +996,8 @@ public:
     fast = (new_opcode & 1);
   }
 
-  virtual void execute();
-  virtual char *name(char *, int);
+  void execute() override;
+  char *name(char *, int) override;
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
@@ -1013,8 +1017,8 @@ public:
     fast = (new_opcode & 1);
   }
 
-  virtual void execute();
-  virtual char *name(char *, int);
+  void execute() override;
+  char *name(char *, int) override;
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
@@ -1029,7 +1033,7 @@ public:
 class RLCF : public Register_op {
 public:
   RLCF(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
-  virtual void execute();
+  void execute() override;
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
@@ -1043,7 +1047,7 @@ class RLNCF : public Register_op {
 public:
   RLNCF(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
@@ -1057,7 +1061,7 @@ class RRCF : public Register_op {
 public:
   RRCF(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
@@ -1071,7 +1075,7 @@ class RRNCF : public Register_op {
 public:
   RRNCF(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
@@ -1085,7 +1089,7 @@ class SETF : public Register_op {
 public:
   SETF(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new SETF(new_cpu, new_opcode, address);
@@ -1098,7 +1102,7 @@ class SLEEP16 : public SLEEP {
 public:
   SLEEP16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : SLEEP(new_cpu, new_opcode, address) {}
-  virtual void execute();
+  void execute() override;
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
@@ -1112,7 +1116,7 @@ class SUBFWB : public Register_op {
 public:
   SUBFWB(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
@@ -1127,7 +1131,7 @@ class SUBLW16 : public SUBLW {
 public:
   SUBLW16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : SUBLW(new_cpu, new_opcode, address) {}
-  virtual void execute();
+  void execute() override;
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
@@ -1143,7 +1147,7 @@ public:
   SUBWF16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : SUBWF(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
@@ -1158,7 +1162,7 @@ public:
   SUBWFB16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : SUBWFB(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
@@ -1172,7 +1176,7 @@ class SWAPF16 : public SWAPF {
 public:
   SWAPF16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : SWAPF(new_cpu, new_opcode, address) {}
-  virtual void execute();
+  void execute() override;
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
@@ -1186,9 +1190,9 @@ class TBLRD : public instruction {
 public:
   TBLRD(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
-  virtual char *name(char *, int);
-  virtual bool isBase()
+  void execute() override;
+  char *name(char *, int) override;
+  bool isBase() override
   {
     return true;
   }
@@ -1205,9 +1209,9 @@ class TBLWT : public instruction {
 public:
   TBLWT(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
-  virtual char *name(char *, int);
-  virtual bool isBase()
+  void execute() override;
+  char *name(char *, int) override;
+  bool isBase() override
   {
     return true;
   }
@@ -1224,9 +1228,9 @@ class TLRD : public instruction {
 public:
   TLRD(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
-  virtual char *name(char *, int);
-  virtual bool isBase()
+  void execute() override;
+  char *name(char *, int) override;
+  bool isBase() override
   {
     return true;
   }
@@ -1243,9 +1247,9 @@ class TLWT : public instruction {
 public:
   TLWT(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
-  virtual char *name(char *, int);
-  virtual bool isBase()
+  void execute() override;
+  char *name(char *, int) override;
+  bool isBase() override
   {
     return true;
   }
@@ -1262,7 +1266,7 @@ class TSTFSZ : public Register_op {
 public:
   TSTFSZ(Processor *new_cpu, unsigned int new_opcode, unsigned int address);
 
-  virtual void execute();
+  void execute() override;
 
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
@@ -1277,7 +1281,7 @@ public:
   XORLW16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : XORLW(new_cpu,  new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new XORLW16(new_cpu, new_opcode, address);
@@ -1291,7 +1295,7 @@ public:
   XORWF16(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
     : XORWF(new_cpu, new_opcode, address) {}
 
-  virtual void execute();
+  void execute() override;
   static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int address)
   {
     return new XORWF16(new_cpu, new_opcode, address);
