@@ -19,21 +19,25 @@ License along with this library; if not, see
 */
 
 #include <stdio.h>
+#include <algorithm>
 #include <iostream>
-#include <iomanip>
+#include <list>
 #include <string>
 
-#include "../config.h"
-#include "packages.h"
 #include "16bit-processors.h"
 
-//#include "stimuli.h"
-//#include "symbol.h"
-#include "eeprom.h"
-
+#include "a2d_v2.h"
+#include "a2dconverter.h"
 #include "breakpoints.h"
+#include "eeprom.h"
+#include "ioports.h"
+#include "packages.h"
+#include "pic-instructions.h"
 #include "pic-ioports.h"
+#include "processor.h"
+#include "symbol.h"
 #include "ui.h"
+
 class IOPIN;
 
 //------------------------------------------------------------------------
@@ -126,18 +130,18 @@ public:
     {
         set(CONFIG2H_default);
     }
-    virtual void set(gint64 v)
+    void set(gint64 v) override
     {
         Integer::set(v);
         if (m_pCpu)
         {
             int postscale = (int)((v & (WDTPS0|WDTPS1|WDTPS2|WDTPS3)) >> 1);
-            m_pCpu->wdt.set_postscale(postscale);
-            m_pCpu->wdt.initialize((v & WDTEN) == WDTEN);
+            m_pCpu->wdt->set_postscale(postscale);
+            m_pCpu->wdt->initialize((bool)(v & WDTEN));
         }
     }
 
-    virtual std::string toString()
+    std::string toString() override
     {
         gint64 i64;
         get(i64);
@@ -154,6 +158,7 @@ public:
 };
 
 
+
 //------------------------------------------------------------------------
 // Config4L - default
 //  The default Config4L register controls the 18F series WDT.
@@ -175,7 +180,7 @@ public:
     }
 
 #define Cpu16 ((_16bit_processor *)m_pCpu)
-    virtual void set(gint64 v)
+    void set(gint64 v) override
     {
         Integer::set(v);
 
@@ -190,7 +195,7 @@ public:
         }
     }
 
-    virtual std::string toString()
+    std::string toString() override
     {
         gint64 i64;
         get(i64);
@@ -556,7 +561,9 @@ void _16bit_processor :: create_sfr_map()
     add_sfr_register(&t0con,	  0xfd5, RegisterValue(0xff, 0), "t0con");
     add_sfr_register(&tmr0l,	  0xfd6, porv, "tmr0l");
     add_sfr_register(&tmr0h,	  0xfd7, porv, "tmr0h");
+#ifdef RRR
     t0con.put(0xff);  /**FIXME - need a way to set this to 0xff at reset*/
+#endif
     add_sfr_register(status,       0xfd8);
     status->set_rcon(&rcon);
     add_sfr_register(&ind2.fsrl,	  0xfd9, porv, "fsr2l");
@@ -715,7 +722,7 @@ void _16bit_processor :: create()
     intcon.set_intcon2(&intcon2);
     intcon.set_pir_set(&pir_set_def);
     //tbl.initialize(this);
-    tmr0l.start(0);
+    //RRR tmr0l.start(0);
 
     if (pma)
     {
@@ -757,7 +764,7 @@ void _16bit_processor::interrupt()
     stack->push(pc->value);
     // Save W,status, and BSR if this is a high priority interrupt.
     fast_stack.push();
-    intcon.in_interrupt = true; // Mask interrupts
+    intcon.clear_gie();
     pc->interrupt(intcon.get_interrupt_vector());
 }
 
