@@ -21,13 +21,14 @@ License along with this library; if not, see
 
 #include <assert.h>
 #include <stdio.h>
+#include <algorithm>
+#include <iostream>
 #include <string>
 
 #include "a2dconverter.h"
 
 #include "14bit-processors.h"
-#include "14bit-registers.h"
-#include "comparator.h"
+#include "gpsim_time.h"
 #include "intcon.h"
 #include "ioports.h"
 #include "pir.h"
@@ -487,7 +488,7 @@ void ADCON0_DIF::put_conversion(void)
 
 
 ADCON1_16F::ADCON1_16F(Processor *pCpu, const char *pName, const char *pDesc)
-    : ADCON1(pCpu, pName, pDesc), FVR_chan(99)
+    : ADCON1(pCpu, pName, pDesc)
 {
     valid_bits = 0x70;
 }
@@ -563,35 +564,38 @@ double ADCON1_16F::getVrefHi()
     {
         unsigned int mode = value.get() & (ADPREF1 | ADPREF0);
 
+	// Positive reference voltage
         switch (mode)
         {
-        case 0:
+        case 0:	//Vdd
             return ((Processor *)cpu)->get_Vdd();
 
-        case 1:
-            std::cerr << "WARNING reserved value for ADPREF\n";
+        case 1:  // reserved
+            std::cerr << "*** WARNING " << __FUNCTION__ <<" reserved value for ADPREF\n";
             return -1.0;
 
-        case 2:
+        case 2:  // Vref+ IO pin
             if (Vrefhi_position[cfg_index] < m_nAnalogChannels)
             {
                 return getChannelVoltage(Vrefhi_position[cfg_index]);
             }
 
-            std::cerr << "WARNING Vrefhi pin not configured\n";
+            std::cerr << "*** WARNING Vrefhi pin not configured\n";
             return -1.0;
 
-        case 3:
+        case 3:	// FVR buffer 1
             if (FVR_chan < m_nAnalogChannels)
             {
+                Dprintf(("%s FVR_chan =%u V=%.3f\n", __FUNCTION__, FVR_chan, getChannelVoltage(FVR_chan)));
                 return getChannelVoltage(FVR_chan);
             }
 
-            std::cerr << "WARNING FVR_chan not set\n";
+            std::cerr << "*** WARNING " << __FUNCTION__ <<" FVR_chan not set " << FVR_chan << " "<< name() <<"\n";
             return -1.0;
         };
     }
 
+
     if (Vrefhi_position[cfg_index] < m_nAnalogChannels)
     {
         return getChannelVoltage(Vrefhi_position[cfg_index]);
@@ -599,13 +603,19 @@ double ADCON1_16F::getVrefHi()
 
     return ((Processor *)cpu)->get_Vdd();
 }
+void ADCON1_16F::setVoltRef(unsigned int chan, float v)
+{
+    if (chan != FVR_chan)
+	m_voltageRef[chan] = v;
+}
 
 
 //------------------------------------------------------
 // ADCON1
 //
 ADCON1::ADCON1(Processor *pCpu, const char *pName, const char *pDesc)
-    : sfr_register(pCpu, pName, pDesc), valid_bits(0xff)
+    : sfr_register(pCpu, pName, pDesc), FVR_ATTACH(pName), DAC_ATTACH(pName),
+	valid_bits(0xff), FVR_chan(99)
 {
     for (int i = 0; i < (int)cMaxConfigurations; i++)
     {
@@ -618,6 +628,7 @@ ADCON1::ADCON1(Processor *pCpu, const char *pName, const char *pDesc)
 
 ADCON1::~ADCON1()
 {
+
     delete [] m_voltageRef;
 
     if (m_AnalogPins)
@@ -834,7 +845,9 @@ int ADCON1::get_cfg(unsigned int reg)
 void ADCON1::setIOPin(unsigned int channel, PinModule *newPin)
 {
     if (channel < m_nAnalogChannels &&
-            m_AnalogPins[channel] == &AnInvalidAnalogInput && newPin != 0)
+            // SB Why should it not be allowed to change the pin assignment?
+            // m_AnalogPins[channel] == &AnInvalidAnalogInput && 
+            newPin != 0)
     {
         m_AnalogPins[channel] = newPin;
 
@@ -845,12 +858,11 @@ void ADCON1::setIOPin(unsigned int channel, PinModule *newPin)
     }
 }
 
-
-void ADCON1::setVoltRef(unsigned int channel, float value)
+void ADCON1::setVoltRef(unsigned int channel, float in_value)
 {
     if (channel < m_nAnalogChannels)
     {
-        m_voltageRef[channel] = value;
+        m_voltageRef[channel] = in_value;
 
     }
     else
@@ -859,6 +871,20 @@ void ADCON1::setVoltRef(unsigned int channel, float value)
     }
 }
 
+void ADCON1::set_FVR_volt(double in_value, unsigned int channel)
+{
+    Dprintf(("set_FVR_volt %s %.3f %u\n", name().c_str(), in_value, channel));
+    if (channel < m_nAnalogChannels)
+    {
+        m_voltageRef[channel] = in_value;
+
+    }
+    else
+    {
+        fprintf(stderr, "ADCON1::%s invalid channel number %u\n", __FUNCTION__, channel);
+    }
+}
+
 
 //------------------------------------------------------
 double ADCON1::getChannelVoltage(unsigned int channel)
@@ -958,6 +984,11 @@ void ADCON1::set_channel_in(unsigned int channel, bool on)
     m_AnalogPins[channel]->updatePinModule();
 }
 
+void ADCON1::set_DAC_volt(double voltage, unsigned int chan)
+{
+    Dprintf(("ADCON1::set_DAC_volt v=%.3f chan=%u\n", voltage, chan));
+    m_voltageRef[chan] = voltage;
+}
 
 ANSEL::ANSEL(Processor *pCpu, const char *pName, const char *pDesc)
     : sfr_register(pCpu, pName, pDesc), valid_bits(0x7f)
@@ -973,6 +1004,7 @@ void ANSEL::setAdcon1(ADCON1 *new_adcon1)
 
 void ANSEL::put(unsigned int new_value)
 {
+    assert(adcon1);
     unsigned int cfgmax = adcon1->getNumberOfChannels();
     unsigned int i;
     unsigned int mask = (new_value & valid_bits);
@@ -1012,7 +1044,6 @@ void ANSEL_H::setAdcon1(ADCON1 *new_adcon1)
 void ANSEL_H::put(unsigned int new_value)
 {
     unsigned int cfgmax = adcon1->getNumberOfChannels();
-    unsigned int i;
     unsigned int mask = ((new_value & valid_bits) << 8) ;
     trace.raw(write_trace.get() | value.get());
 
@@ -1024,7 +1055,7 @@ void ANSEL_H::put(unsigned int new_value)
     /*
     Generate ChannelConfiguration from ansel register
     */
-    for (i = 0; i < cfgmax; i++)
+    for (unsigned int i = 0; i < cfgmax; i++)
     {
         adcon1->setChannelConfiguration(i, mask);
     }
@@ -1048,25 +1079,17 @@ void ANSEL_P::setAdcon1(ADCON1 *new_adcon1)
 void ANSEL_P::setAnsel(ANSEL_P *new_ansel)
 {
     ansel = new_ansel;
-    if (!ansel_list.empty())
+    auto it = std::find(ansel_list.begin(), ansel_list.end(), new_ansel);
+    if (it == ansel_list.end())
     {
-        for(auto it=ansel_list.begin(); it!=ansel_list.end(); it++)
-        {
-            if (*it == new_ansel)
-            {
-                return;
-            }
-        }
+        ansel_list.push_back(new_ansel);
     }
-    ansel_list.push_back(new_ansel);
 }
 
 
 void ANSEL_P::put(unsigned int new_value)
 {
-    unsigned int cfgmax = adcon1->getMaxCfg();
     unsigned int i;
-    unsigned int mask;
     unsigned int chan = first_channel;
     trace.raw(write_trace.get() | value.get());
     new_value &= valid_bits;
@@ -1086,20 +1109,21 @@ void ANSEL_P::put(unsigned int new_value)
         }
     }
 
-    mask = cfg_mask;
-    for(auto it=ansel_list.begin(); it!=ansel_list.end(); it++)
-    {
-        mask |= (*it)->get_mask();
-    }
-
     if (!adcon1)
     {
         return;
     }
 
+    unsigned int mask = cfg_mask;
+    for (auto &an_ansel : ansel_list)
+    {
+        mask |= an_ansel->get_mask();
+    }
+
     /*
     Generate ChannelConfiguration from ansel register
     */
+    unsigned int cfgmax = adcon1->getMaxCfg();
     for (i = 0; i < cfgmax; i++)
     {
         adcon1->setChannelConfiguration(i, mask);
@@ -1404,19 +1428,42 @@ void   a2d_stimulus::set_nodeVoltage(double v)
 // member functions for the FVRCON class
 //--------------------------------------------------
 //
-FVRCON::FVRCON(Processor *pCpu, const char *pName, const char *pDesc, unsigned int bitMask, unsigned int alwaysOne)
-    : sfr_register(pCpu, pName, pDesc)
+FVRCON::FVRCON(Processor *pCpu, const char *pName, const char *pDesc, unsigned int bitMask)
+    : sfr_register(pCpu, pName, pDesc), node_cvref(nullptr), 
+       node_adcvref(nullptr), volt_cvref(nullptr), volt_adcvref(nullptr)
 {
     mask_writable = bitMask;
-    always_one = alwaysOne;
+    node_cvref = new Stimulus_Node("n_cvref");
+    volt_cvref = new stimulus("cdafvr_src", 0.0, 48000.0);
+    node_cvref->attach_stimulus(volt_cvref);
+    node_adcvref = new Stimulus_Node("n_adcvref");
+    volt_adcvref = new stimulus("adcfvr_src", 0.0, 48000.0);
+    node_adcvref->attach_stimulus(volt_adcvref);
+    node_Vtref = new Stimulus_Node("n_Vtref");
+    volt_Vtref = new stimulus("Vtfvr_src", 0.0, 48000.0);
+    node_Vtref->attach_stimulus(volt_Vtref);
+}
+
+FVRCON::~FVRCON()
+{
+    node_cvref->detach_stimulus(volt_cvref);
+    delete(volt_cvref);
+    delete(node_cvref);
+    node_adcvref->detach_stimulus(volt_adcvref);
+    delete(volt_adcvref);
+    delete(node_adcvref);
+    node_Vtref->detach_stimulus(volt_Vtref);
+    delete(volt_Vtref);
+    delete(node_Vtref);
 }
 
 
 void FVRCON::put(unsigned int new_value)
 {
-    unsigned int masked_value = (new_value & mask_writable) | always_one;
+    unsigned int masked_value = (new_value & mask_writable);
     trace.raw(write_trace.get() | value.get());
-    value.put(masked_value);
+    put_value(masked_value);
+
     compute_VTemp(masked_value);
     compute_FVR_AD(masked_value);
     compute_FVR_CDA(masked_value);
@@ -1425,21 +1472,54 @@ void FVRCON::put(unsigned int new_value)
 
 void FVRCON::put_value(unsigned int new_value)
 {
-    unsigned int masked_value = (new_value & mask_writable) | always_one;
-    put(masked_value);
+     unsigned int diff = value.get() ^ new_value;
+
+  if (diff) {
+    if (diff &  FVREN) {
+      new_value &= ~FVRRDY;  // Clear FVRRDY regardless of ON or OFF
+    }
+
+    if (new_value & FVREN) {    // Enable ON?
+      future_cycle = get_cycles().get() + 25e-6 / get_cycles().seconds_per_cycle();
+      get_cycles().set_break(future_cycle, this);
+
+    } else if (future_cycle) {
+      get_cycles().clear_break(this);
+      future_cycle = 0;
+    }
+  }
+  value.put(new_value);
+  compute_VTemp(new_value);
+  compute_FVR_AD(new_value);
+  compute_FVR_CDA(new_value);
+
     update();
 }
 
+// Set FVRRDY bit after timeout
+void FVRCON::callback()
+{
+  future_cycle = 0;
+  put_value(value.get() | FVRRDY);
+}
+
+void FVRCON::callback_print()
+{
+    std::cout <<  name() << " has callback, ID = " << CallBackID << '\n';
+}
+
 
 double FVRCON::compute_VTemp(unsigned int fvrcon)
 {
     double ret = -1.0;
 
-    if ((fvrcon & TSEN) && cpu14->m_cpu_temp)
+    if (!cpu14->m_cpu_temp)
+	fprintf(stderr, "*** Warning m_cpu_temp not defined\n");
+    if ((fvrcon&TSEN) && cpu14->m_cpu_temp)
     {
         //Transister junction threshold voltage at core temperature
         double Vt = 0.659 - (cpu14->m_cpu_temp->getVal() + 40.0) * 0.00132;
-        ret = ((Processor *)cpu)->get_Vdd() - ((fvrcon & TSRNG) ? 4.0 : 2.0) * Vt;
+        ret = ((Processor *)cpu)->get_Vdd() - ((fvrcon&TSRNG) ? 4.0 : 2.0) * Vt;
 
         if (ret < 0.0)
         {
@@ -1448,9 +1528,13 @@ double FVRCON::compute_VTemp(unsigned int fvrcon)
         }
     }
 
-    if (adcon1)
+    if (node_Vtref)
     {
-        adcon1->setVoltRef(VTemp_AD_chan, ret);
+	if (ret != node_Vtref->get_nodeVoltage())
+        {
+            volt_Vtref->set_Vth(ret);
+	    node_Vtref->set_nodeVoltage(ret);
+	}
     }
 
     return ret;
@@ -1460,9 +1544,10 @@ double FVRCON::compute_VTemp(unsigned int fvrcon)
 double FVRCON::compute_FVR_AD(unsigned int fvrcon)
 {
     double ret = -1.;
-    unsigned int gain = (fvrcon & (ADFVR0 | ADFVR1));
+    unsigned int gain = fvrcon & (ADFVR1|ADFVR0);
+    bool on = fvrcon & FVREN;
 
-    if ((fvrcon & FVREN) && gain)
+    if (on && gain)
     {
         ret = 1.024 * (1 << (gain - 1));
     }
@@ -1473,9 +1558,13 @@ double FVRCON::compute_FVR_AD(unsigned int fvrcon)
         ret = -1.0;
     }
 
-    if (adcon1)
+    if (node_adcvref)
     {
-        adcon1->setVoltRef(FVRAD_AD_chan, ret);
+	if (ret != node_adcvref->get_nodeVoltage())
+        {
+            volt_adcvref->set_Vth(ret);
+	    node_adcvref->set_nodeVoltage(ret);
+	}
     }
 
     return ret;
@@ -1485,31 +1574,124 @@ double FVRCON::compute_FVR_AD(unsigned int fvrcon)
 double FVRCON::compute_FVR_CDA(unsigned int fvrcon)
 {
     double ret = 0.0;
-    unsigned int gain = (fvrcon & (CDAFVR0 | CDAFVR1)) >> 2;
+    unsigned int gain = (fvrcon & (CDAFVR1|CDAFVR0)) >> 2;
+    bool on = fvrcon & FVREN;
 
-    if ((fvrcon & FVREN) && gain)
+    if (on && gain)
     {
         ret = 1.024 * (1 << (gain - 1));
     }
 
-    for (unsigned int i = 0; i < daccon0_list.size(); i++)
+    if (node_cvref)
     {
-        daccon0_list[i]->set_FVR_CDA_volt(ret);
+	if (ret != node_cvref->get_nodeVoltage())
+	{
+            volt_cvref->set_Vth(ret);
+	    node_cvref->set_nodeVoltage(ret);
+	}
     }
-
-    if (cmModule)
-    {
-        cmModule->set_FVR_volt(ret);
-    }
-
-    if (cpscon0)
-    {
-        cpscon0->set_FVR_volt(ret);
-    }
-
     return ret;
 }
 
+//
+//--------------------------------------------------
+// member functions for the FVRCON_V2 class
+// with one set of gains and FVRST set after delay
+//--------------------------------------------------
+//
+FVRCON_V2::FVRCON_V2(Processor *pCpu, const char *pName, const char *pDesc, unsigned int bitMask)
+   : sfr_register(pCpu, pName, pDesc)
+{
+    mask_writable = bitMask;
+    node_cvref = new Stimulus_Node("n_cvref");
+    volt_cvref = new stimulus("cdafvr_src", 0.0, 48000.0);
+    node_cvref->attach_stimulus(volt_cvref);
+}
+FVRCON_V2::~FVRCON_V2()
+{
+    node_cvref->detach_stimulus(volt_cvref);
+    delete(volt_cvref);
+    delete(node_cvref);
+}
+
+void FVRCON_V2::put(unsigned int new_value)
+{
+    unsigned int masked_value = (new_value & mask_writable);
+    trace.raw(write_trace.get() | value.get());
+    put_value(masked_value);
+
+    compute_FVR_CDA(masked_value);
+}
+
+
+void FVRCON_V2::put_value(unsigned int new_value)
+{
+     unsigned int diff = value.get() ^ new_value;
+
+  if (diff) {
+    if (diff &  FVREN) {
+      new_value &= ~FVRRDY;  // Clear FVRRDY regardless of ON or OFF
+    }
+
+    if (new_value & FVREN) {    // Enable ON?
+      future_cycle = get_cycles().get() + 25e-6 / get_cycles().seconds_per_cycle();
+      get_cycles().set_break(future_cycle, this);
+
+    } else if (future_cycle) {
+      get_cycles().clear_break(this);
+      future_cycle = 0;
+    }
+  }
+  value.put(new_value);
+  compute_FVR_CDA(new_value);
+
+  update();
+}
+
+// Set FVRRDY bit after timeout
+void FVRCON_V2::callback()
+{
+  future_cycle = 0;
+  put_value(value.get() | FVRRDY);
+}
+
+
+void FVRCON_V2::callback_print()
+{
+    std::cout <<  name() << " has callback, ID = " << CallBackID << '\n';
+}
+
+
+double FVRCON_V2::compute_FVR_CDA(unsigned int fvrcon)
+{
+    double ret = -1.0;
+    unsigned int gain = (fvrcon & (FVRS1|FVRS0)) >> 4;
+    bool on = fvrcon & FVREN;
+
+    if (on && gain)
+    {
+        ret = 1.024 * (1 << (gain - 1));
+    }
+
+
+  if (ret > ((Processor *)cpu)->get_Vdd()) {
+    std::cerr << "warning FVRCON FVRAD(" << ret << ") > Vdd("
+         << ((Processor *)cpu)->get_Vdd() << ")\n";
+    ret = -1.0;
+  }
+
+  if (node_cvref)
+  {
+ 	if (ret != node_cvref->get_nodeVoltage())
+	{
+            volt_cvref->set_Vth(ret);
+            node_cvref->set_nodeVoltage(ret);
+	}
+  }
+
+
+  return ret;
+}
 
 //
 //--------------------------------------------------
@@ -1517,8 +1699,9 @@ double FVRCON::compute_FVR_CDA(unsigned int fvrcon)
 //--------------------------------------------------
 //
 DACCON0::DACCON0(Processor *pCpu, const char *pName, const char *pDesc, unsigned int bitMask, unsigned int bit_res)
-    : sfr_register(pCpu, pName, pDesc),
-      bit_mask(bitMask), bit_resolution(bit_res)
+    : sfr_register(pCpu, pName, pDesc), FVR_ATTACH(pName),
+      bit_mask(bitMask), bit_resolution(bit_res),
+      name_dacout("n_")
 {
     Pin_Active[0] = false;
     Pin_Active[1] = false;
@@ -1530,14 +1713,33 @@ DACCON0::DACCON0(Processor *pCpu, const char *pName, const char *pDesc, unsigned
     driving[1] = false;
     output_pin[0] = nullptr;
     output_pin[1] = nullptr;
+
+    name_dacout += pName;
+    node_dacout = new Stimulus_Node(name_dacout.c_str());
+    std::string wname = pName;
+    wname += "_src";
+    volt_dacout = new stimulus(wname.c_str(), 0.0, 48000.0);
+    node_dacout->attach_stimulus(volt_dacout);
+    volt_dacout->set_Vth(-1.0);
+    node_dacout->set_nodeVoltage(-1.0);
 }
 
+DACCON0::~DACCON0()
+{
+    // remove DAC src stimulus
+    if (node_dacout)
+    {
+        node_dacout->detach_stimulus(volt_dacout);
+        delete volt_dacout;
+    }
+}
 
 void  DACCON0::put(unsigned int new_value)
 {
     unsigned int masked_value = (new_value & bit_mask);
     trace.raw(write_trace.get() | value.get());
     value.put(masked_value);
+
     compute_dac(masked_value);
 }
 
@@ -1558,19 +1760,19 @@ void DACCON0::set_dcaccon1_reg(unsigned int reg)
 }
 
 
-void  DACCON0::compute_dac(unsigned int value)
+void  DACCON0::compute_dac(unsigned int reg_value)
 {
-    double Vhigh = get_Vhigh(value);
+    double Vhigh = get_Vhigh(reg_value);
     double Vlow = 0.0;
     double Vout;
 
-    if (value & DACEN)  	// DAC is enabled
+    if (reg_value & DACEN)  	// DAC is enabled
     {
         // Max Vout will be 1 step below Vhigh.
         Vout = (Vhigh - Vlow) * daccon1_reg / bit_resolution + Vlow;
 
     }
-    else if (value & DACLPS)
+    else if (reg_value & DACLPS)
     {
         Vout = Vhigh;
 
@@ -1580,30 +1782,22 @@ void  DACCON0::compute_dac(unsigned int value)
         Vout = Vlow;
     }
 
-    set_dacoutpin(value & DACOE, 0, Vout);
-    set_dacoutpin(value & DACOE2, 1, Vout);
+    set_dacoutpin(reg_value & DACOE, 0, Vout);
+    set_dacoutpin(reg_value & DACOE2, 1, Vout);
 
     if (verbose)
     {
-        printf("%s-%d adcon1 %p FVRCDA_AD_chan %u Vout %.2f\n", __FUNCTION__, __LINE__, adcon1, FVRCDA_AD_chan, Vout);
+        printf("%s-%d Vout %.2f\n", __FUNCTION__, __LINE__, Vout);
     }
 
-    Dprintf(("DAC DACEN %d output %.2f adcon1=%p Vhigh %.2f bit_res %u daccon1_reg %u\n", (bool)(value & DACEN), Vout, adcon1, Vhigh, bit_resolution, daccon1_reg));
+    Dprintf(("DAC DACEN %d output %.2f Vhigh %.2f bit_res %u daccon1_reg %u\n", (bool)(reg_value & DACEN), Vout, Vhigh, bit_resolution, daccon1_reg));
 
-    if (adcon1)
+    if (Vout != node_dacout->get_nodeVoltage())
     {
-        adcon1->setVoltRef(FVRCDA_AD_chan, Vout);
+        volt_dacout->set_Vth(Vout);
+        node_dacout->set_nodeVoltage(Vout);
     }
 
-    if (cmModule)
-    {
-        cmModule->set_DAC_volt(Vout);
-    }
-
-    if (cpscon0)
-    {
-        cpscon0->set_DAC_volt(Vout);
-    }
 }
 
 
@@ -1667,9 +1861,9 @@ void DACCON0::set_dacoutpin(bool output_enabled, int chan, double Vout)
 }
 
 
-double DACCON0::get_Vhigh(unsigned int value)
+double DACCON0::get_Vhigh(unsigned int reg_value)
 {
-    unsigned int mode = (value & (DACPSS0 | DACPSS1)) >> 2;
+    unsigned int mode = (reg_value & (DACPSS0 | DACPSS1)) >> 2;
 
     switch (mode)
     {
@@ -1682,14 +1876,14 @@ double DACCON0::get_Vhigh(unsigned int value)
             return (adcon1->getChannelVoltage(adcon1->getVrefHiChannel(0)));
         }
 
-        std::cerr << "ERROR DACCON0 DACPSS=01b adcon1 not set\n";
+        std::cerr << "ERROR DACCON0 DACPSS=1 adcon1 not set\n";
         return 0.0;
 
     case 2:	// Fixed Voltage Reference
         return FVR_CDA_volt;
 
     case 3:	// Reserved value
-        std::cerr << "ERROR DACCON0 DACPSS=11b is reserved value\n";
+        std::cerr << "ERROR DACCON0 DACPSS=3 is reserved value\n";
         return 0.0;
     }
 
@@ -1697,6 +1891,8 @@ double DACCON0::get_Vhigh(unsigned int value)
 }
 
 
+
+
 DACCON1::DACCON1(Processor *pCpu, const char *pName, const char *pDesc, unsigned int bitMask, DACCON0 *_daccon0)
     : sfr_register(pCpu, pName, pDesc),
       bit_mask(bitMask), daccon0(_daccon0)
@@ -1839,10 +2035,7 @@ void ADCON0_32::put_conversion()
 ADCON2_TRIG::ADCON2_TRIG(Processor *pCpu, const char *pName, const char *pDesc)
     : sfr_register(pCpu, pName, pDesc), valid_bits(0xf0)
 {
-    for (auto &a: CMxsync)
-    {
-        a = false;
-    }
+    std::fill_n(CMxsync, 4, false);
 }
 
 
@@ -1882,3 +2075,109 @@ void ADCON2_TRIG::t0_overflow()
     }
 }
 
+
+void FVR_STIMULUS::set_nodeVoltage(double v)
+{
+    pt_base_function->set_FVR_volt(v, chan);
+}
+
+void FVR_ATTACH::attach_cda_fvr(Stimulus_Node *_fvr_node, unsigned int chan)
+{
+    if (!fvr_node)
+    {
+	fvr_name = "Cdafvr_" + reg_name;
+        fvr_node = _fvr_node;
+        fvr_stimulus = new FVR_STIMULUS(this, chan, fvr_name.c_str());
+        fvr_node->attach_stimulus(fvr_stimulus);
+	Dprintf(("FVR_ATTACH::attach_cda_fvr fvr_node=%p %s\n", fvr_node, fvr_name.c_str()));
+    }
+}
+
+void FVR_ATTACH::attach_ad_fvr(Stimulus_Node *_fvr_node, unsigned int _chan)
+{
+    Dprintf(("FVR_ATTACH::attach_ad_fvr %s fvr_node=%p chan=%u\n", reg_name.c_str(),_fvr_node, _chan));
+    if (!fvr_ad_node)
+    {
+	fvr_ad_name = "Adfvr_" + reg_name;
+        fvr_ad_node = _fvr_node;
+        fvr_ad_stimulus = new FVR_STIMULUS(this, _chan, fvr_ad_name.c_str());
+        fvr_ad_node->attach_stimulus(fvr_ad_stimulus);
+    }
+    else
+    {
+	fprintf(stderr, "*** FVR_ATTACH::attach_ad_fvr reg %s already defined %p\n", reg_name.c_str(), fvr_ad_node);
+    }
+}
+
+void FVR_ATTACH::attach_Vt_fvr(Stimulus_Node *_fvr_node, unsigned int chan)
+{
+    Dprintf(("FVR_ATTACH::attach_Vt_fvr %s fvr_node=%p chan=%d\n", reg_name.c_str(),_fvr_node, chan));
+    if (!fvr_Vt_node)
+    {
+	fvr_Vt_name = "Vtfvr_" + reg_name;
+        fvr_Vt_node = _fvr_node;
+        fvr_Vt_stimulus = new FVR_STIMULUS(this, chan, fvr_Vt_name.c_str());
+        fvr_Vt_node->attach_stimulus(fvr_Vt_stimulus);
+    }
+}
+
+void FVR_ATTACH::detach_fvr()
+{
+    if (fvr_node)
+    {
+        fvr_node->detach_stimulus(fvr_stimulus);
+        fvr_node = nullptr;
+	fvr_stimulus = nullptr;
+    }
+    if (fvr_ad_node)
+    {
+        fvr_ad_node->detach_stimulus(fvr_ad_stimulus);
+        fvr_ad_node = nullptr;
+	fvr_ad_stimulus = nullptr;
+    }
+    if (fvr_Vt_node)
+    {
+        fvr_Vt_node->detach_stimulus(fvr_Vt_stimulus);
+        fvr_Vt_node = nullptr;
+	fvr_Vt_stimulus = nullptr;
+    }
+}
+
+void DAC_ATTACH::attach_DAC(Stimulus_Node *_DAC_node, unsigned int chan, unsigned int n)
+{
+    unsigned int index = n - 1;
+
+    assert(index < 8);
+    if (!DAC_node[index])
+    {
+        char prefix[6];
+        snprintf(prefix, sizeof(prefix), "dac%u_", n);
+        DAC_name[index] = prefix + reg_name;
+        DAC_node[index] = _DAC_node;
+        DAC_stimulus[index] = new DAC_STIMULUS(this, chan, DAC_name[index].c_str());
+        DAC_node[index]->attach_stimulus(DAC_stimulus[index]);
+    }
+    else
+    {
+        fprintf(stderr, "***DAC_ATTACH::attach_DAC %s n=%u chan=%u already defined***\n", DAC_name[index].c_str(), n, chan);
+    }
+}
+
+void DAC_ATTACH::detach_DAC()
+{
+    for(int i = 0; i < 8; i++)
+    {
+        if (DAC_node[i])
+        {
+            DAC_node[i]->detach_stimulus(DAC_stimulus[i]);
+    	    delete DAC_stimulus[i];
+    	    DAC_stimulus[i] = nullptr;
+    	    DAC_node[i] = nullptr;
+        }
+    }
+}
+
+void DAC_STIMULUS::set_nodeVoltage(double v)
+{
+    pt_base_function->set_DAC_volt(v, chan);
+}
