@@ -161,7 +161,7 @@ int Breakpoints::set_breakpoint(BREAKPOINT_TYPES break_type,
       // pic_processor should not be referenced here
       // Should have a GetStack() virtual function in Processor class.
       // Of course then the Stack class needs to be a virtual class.
-      ((_14bit_processor *)cpu)->wdt.set_breakpoint(BREAK_ON_WDT_TIMEOUT | breakpoint_number);
+      ((_14bit_processor *)cpu)->wdt->set_breakpoint(BREAK_ON_WDT_TIMEOUT | breakpoint_number);
       return breakpoint_number;
 
     } else {
@@ -541,7 +541,7 @@ int  Breakpoints::set_wdt_break(Processor *cpu)
   if ((cpu->GetCapabilities() & Processor::eBREAKONWATCHDOGTIMER)
       == Processor::eBREAKONWATCHDOGTIMER) {
     // Set a wdt break only if one is not already set.
-    if (!cpu14->wdt.hasBreak()) {
+    if (!cpu14->wdt->hasBreak()) {
       return set_breakpoint(Breakpoints::BREAK_ON_WDT_TIMEOUT, cpu, 0, 0);
     }
 
@@ -813,7 +813,7 @@ void Breakpoints::clear(unsigned int b)
     if ((bs.cpu->GetCapabilities() & Processor::eBREAKONWATCHDOGTIMER)
         == Processor::eBREAKONWATCHDOGTIMER) {
       std::cout << "Cleared wdt timeout breakpoint number " << b << '\n';
-      ((_14bit_processor *)bs.cpu)->wdt.set_breakpoint(0);
+      ((_14bit_processor *)bs.cpu)->wdt->set_breakpoint(0);
     }
 
     break;
@@ -972,7 +972,7 @@ Breakpoints::Breakpoints()
 bool Breakpoint_Instruction::eval_Expression()
 {
   if (bHasExpression()) {
-    return !TriggerObject::eval_Expression();
+    return TriggerObject::eval_Expression();
   }
 
   return true;
@@ -2175,20 +2175,16 @@ CommandAssertion::CommandAssertion(Processor *new_cpu,
                                    unsigned int bp,
                                    const char *_command,
                                    bool _bPostAssertion)
-  : Breakpoint_Instruction(new_cpu, instAddress, bp), bPostAssertion(_bPostAssertion)
+  : Breakpoint_Instruction(new_cpu, instAddress, bp),
+    bPostAssertion(_bPostAssertion),
+    command(_command)
 {
-  size_t len = strlen(_command);
-  command = new char[len + 3];
-  strcpy(command, _command);
-  command[len]   = '\n';
-  command[len + 1] = 0;
-  command[len + 2] = 0;
+  command += '\n';
 }
 
 
 CommandAssertion::~CommandAssertion()
 {
-  delete [] command;
 }
 
 
@@ -2202,7 +2198,7 @@ void CommandAssertion::execute()
   ICommandHandler *pCli = CCommandManager::GetManager().find("gpsimCLI");
 
   if (pCli) {
-    pCli->Execute(command, 0);
+    pCli->Execute(command.c_str(), 0);
   }
 
   if (!bPostAssertion && getReplaced()) {
