@@ -20,25 +20,22 @@ License along with this library; if not, see
 
 
 #include "bytelog.h"
-
+#include <memory>
 
 namespace gpsim {
 
   ByteLogger::ByteLogger(int _bufsize) 
-    : bufsize(_bufsize)
+    : index(0), bufsize(_bufsize), buffer(_bufsize)
   {
-    index = 0;
-    buffer = (TimedByte *) new char[bufsize * sizeof(TimedByte)];
-
   }
 
   int ByteLogger::modIndex(int i)
   {
-    if(i<0) {
-      i+=bufsize;
-      if(i<0)
+    if (i < 0) {
+      i += bufsize;
+      if (i < 0)
         return index;
-    } else  if(i>=bufsize)
+    } else if (i >= bufsize)
       return index;
 
     return i;
@@ -49,21 +46,25 @@ namespace gpsim {
   {
     buffer[index].start = t;
   }
+
   void ByteLogger::stop(unsigned long long t) 
   {
     buffer[index].stop = t;
 
-    if(++index > bufsize)
-      index  = 0;
+    if (++index > bufsize)
+      index = 0;
   }
+
   void ByteLogger::byte(unsigned int b) 
   {
-    buffer[index].b = b&0xff;
+    buffer[index].b = b & 0xff;
   }
+
   void ByteLogger::rts(unsigned long long r) 
   {
     buffer[index].rts = r;
   }
+
   /*
     void ByteLogger::statistics(int i=-1)
     {
@@ -78,16 +79,15 @@ namespace gpsim {
     << td  << " uS\n";
     }
   */
+
   unsigned long long ByteLogger::getStart(int i)
   {
-
-    return buffer[modIndex(i+index)].start;
+    return buffer[modIndex(i + index)].start;
   }
 
   void ByteLogger::get(int i, TimedByte &b)
   {
-
-    b = buffer[modIndex(i+index)];
+    b = buffer[modIndex(i + index)];
   }
 
 } // end of namespace gpsim
