@@ -18,15 +18,16 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
-
 #include "clock_phase.h"
 
-#include "processor.h"
+#include "breakpoints.h"
 #include "gpsim_time.h"
+#include "processor.h"
+#include "trace.h"
 
 //========================================================================
 ClockPhase::ClockPhase()
-  : m_pNextPhase(this)
+    : m_pNextPhase(this)
 {
 }
 
@@ -38,10 +39,10 @@ ClockPhase::~ClockPhase()
 //========================================================================
 
 ProcessorPhase::ProcessorPhase(Processor *pcpu)
-  : ClockPhase(), 
-    m_pcpu(pcpu)
+    : ClockPhase(), m_pcpu(pcpu)
 {
 }
+
 ProcessorPhase::~ProcessorPhase()
 {
 }
@@ -49,9 +50,10 @@ ProcessorPhase::~ProcessorPhase()
 //========================================================================
 
 phaseExecute1Cycle::phaseExecute1Cycle(Processor *pcpu)
-  : ProcessorPhase(pcpu)
+    : ProcessorPhase(pcpu)
 {
 }
+
 phaseExecute1Cycle::~phaseExecute1Cycle()
 {
 }
@@ -63,29 +65,30 @@ phaseExecute1Cycle::~phaseExecute1Cycle()
 
 ClockPhase *phaseExecute1Cycle::advance()
 {
-  setNextPhase(this);
-  m_pcpu->step_one(false);
-  if (bp.global_break & GLOBAL_LOG)
-  {
-      if (GetTraceLog().log_file)
-      {
-	   trace.cycle_counter(get_cycles().get());
+    setNextPhase(this);
+    m_pcpu->step_one(false);
+    if (bp.global_break & GLOBAL_LOG)
+    {
+        if (GetTraceLog().log_file)
+        {
+            trace.cycle_counter(get_cycles().get());
             trace.dump(1, GetTraceLog().log_file);
-	  GetTraceLog().items_logged++;
-      }
-      bp.global_break &= ~GLOBAL_LOG;
-  }
-  if (!bp.global_break)
-      get_cycles().increment();
-  return m_pNextPhase;
+            GetTraceLog().items_logged++;
+        }
+        bp.global_break &= ~GLOBAL_LOG;
+    }
+    if (!bp.global_break)
+        get_cycles().increment();
+    return m_pNextPhase;
 }
 
 //========================================================================
 
 phaseIdle::phaseIdle(Processor *pcpu)
-  : ProcessorPhase(pcpu)
+    : ProcessorPhase(pcpu)
 {
 }
+
 phaseIdle::~phaseIdle()
 {
 }
@@ -97,10 +100,57 @@ phaseIdle::~phaseIdle()
 
 ClockPhase *phaseIdle::advance()
 {
-  setNextPhase(this);
-  get_cycles().increment();
-  return m_pNextPhase;
+    setNextPhase(this);
+    get_cycles().increment();
+    return m_pNextPhase;
 }
+
+//========================================================================
+
+phaseSkip::phaseSkip(Processor *pcpu)
+    : ProcessorPhase(pcpu)
+{
+}
+
+phaseSkip::~phaseSkip()
+{
+}
+
+/*
+  phaseSkip::advance() - Execute NOP instead of the actual command
+ */
+
+ClockPhase *phaseSkip::advance()
+{
+    m_pcpu->pc->increment();
+    if (mCount > 1) {
+        setNextPhase(this);
+        mCount--;
+    } else {
+        mCount = 0;
+    }
+
+    if (bp.global_break & GLOBAL_LOG)
+    {
+        if (GetTraceLog().log_file)
+        {
+            trace.cycle_counter(get_cycles().get());
+            trace.dump(1, GetTraceLog().log_file);
+            GetTraceLog().items_logged++;
+        }
+        bp.global_break &= ~GLOBAL_LOG;
+    }
+    if (!bp.global_break)
+        get_cycles().increment();
+    return m_pNextPhase;
+}
+
+ClockPhase *phaseSkip::arm(int count) {
+    mCount = count;
+    setNextPhase(this);
+    return m_pNextPhase;
+}
+
 #if 0
 const char* phaseDesc(ClockPhase *pPhase)
 {
@@ -112,62 +162,67 @@ const char* phaseDesc(ClockPhase *pPhase)
     return ("mExecute2ndHalf");
   if (pPhase == mCaptureInterrupt)
     return ("mCaptureInterrupt");
+  if (pPhase == mSkip)
+    return ("mSkip");
   return "unknown phase";
 }
 #endif
 
 
 phaseCaptureInterrupt::phaseCaptureInterrupt(Processor *pcpu)
-  :  ProcessorPhase(pcpu), m_pCurrentPhase(0),m_pNextNextPhase(0)
+    : ProcessorPhase(pcpu), m_pCurrentPhase(nullptr), m_pNextNextPhase(nullptr)
 {
 }
+
 phaseCaptureInterrupt::~phaseCaptureInterrupt()
-{}
+{
+}
+
 #define Rprintf(arg) {printf("0x%06X %s() ",cycles.get(),__FUNCTION__); printf arg; }
+
 ClockPhase *phaseCaptureInterrupt::advance()
 {
+    //Rprintf (("phaseCaptureInterrupt\n"));
+    if (m_pNextPhase == m_pcpu->mExecute2ndHalf)
+        m_pNextPhase->advance();
 
-  //Rprintf (("phaseCaptureInterrupt\n"));
-  if (m_pNextPhase == m_pcpu->mExecute2ndHalf)
-    m_pNextPhase->advance();
-
-  if (m_pCurrentPhase == m_pcpu->mIdle) { // Interrupted sleep
-
-    // complete sleeping phase
-    m_pNextPhase = m_pNextNextPhase->advance();
-    
-    if (m_pNextPhase == m_pcpu->mIdle)
+    if (m_pCurrentPhase == m_pcpu->mIdle) // Interrupted sleep
     {
-        m_pNextPhase = m_pcpu->mExecute1Cycle;
-	do 
-	{
-	    m_pNextPhase = m_pcpu->mExecute1Cycle->advance();
-	}while (m_pNextPhase != m_pcpu->mExecute1Cycle);
+        // complete sleeping phase
+        m_pNextPhase = m_pNextNextPhase->advance();
+
+        if (m_pNextPhase == m_pcpu->mIdle)
+        {
+            m_pNextPhase = m_pcpu->mExecute1Cycle;
+            do
+            {
+                m_pNextPhase = m_pcpu->mExecute1Cycle->advance();
+            } while (m_pNextPhase != m_pcpu->mExecute1Cycle);
+        }
+
+        m_pcpu->mCurrentPhase = this;
+
+        if (bp.global_break)
+            m_pNextNextPhase = m_pNextPhase;
+        else
+            m_pCurrentPhase = nullptr;
+
+        m_pcpu->exit_sleep();
+        return this;
     }
-    m_pcpu->mCurrentPhase = this;
-    if (bp.global_break)
-	m_pNextNextPhase = m_pNextPhase;
-    else
-      m_pCurrentPhase = NULL;
-    
-    m_pcpu->exit_sleep();
-    return this;
-  }
 
-  m_pcpu->interrupt();
+    m_pcpu->interrupt();
 
-  return m_pNextPhase;
+    return m_pNextPhase;
 }
 
 void phaseCaptureInterrupt::firstHalf()
 {
-  m_pCurrentPhase = m_pcpu->mCurrentPhase;
+    m_pCurrentPhase = m_pcpu->mCurrentPhase;
 
-  m_pNextPhase = this;
-  m_pNextNextPhase = m_pcpu->mCurrentPhase->getNextPhase();
-  m_pcpu->mCurrentPhase->setNextPhase(this);
-  m_pcpu->mCurrentPhase = this;
+    m_pNextPhase = this;
+    m_pNextNextPhase = m_pcpu->mCurrentPhase->getNextPhase();
+    m_pcpu->mCurrentPhase->setNextPhase(this);
+    m_pcpu->mCurrentPhase = this;
 }
 
-
-
