@@ -1,11 +1,11 @@
 #ifndef SRC_CMD_MANAGER_H_
 #define SRC_CMD_MANAGER_H_
 
-#include "cmd_gpsim.h"
 #include "gpsim_interface.h"
+#include "ui.h"
 
 #include <string.h>
-
+#include <algorithm>
 #include <list>
 #include <vector>
 #include <string>
@@ -13,15 +13,19 @@
 
 class CommandHandlerKey : public ICommandHandler {
 public:
-  CommandHandlerKey(const char *name)
+  explicit CommandHandlerKey(const char *name)
     : m_name(name)
   {
   }
-  virtual const char *GetName() {return m_name; }
-  virtual int Execute(const char * /* commandline */ ,  ISimConsole * /* out */) {
-    return CMD_ERR_COMMANDNOTDEFINED;}
-  virtual int ExecuteScript(std::list<std::string *> & /* script */ , ISimConsole * /* out */ )
-  { return CMD_ERR_ERROR;}
+  const char *GetName() override { return m_name; }
+  int Execute(const char * /* commandline */ ,  ISimConsole * /* out */) override
+  {
+    return CMD_ERR_COMMANDNOTDEFINED;
+  }
+  int ExecuteScript(const std::list<std::string> & /* script */ , ISimConsole * /* out */ ) override
+  {
+    return CMD_ERR_ERROR;
+  }
   const char * m_name;
 };
 
