@@ -25,6 +25,9 @@ License along with this library; if not, see
 //  The file contains the code for reading Byte Craft's .cod
 // formatted symbol files.
 //
+
+#include <glib.h>
+
 #include <algorithm>
 #include <iostream>
 #include <string>
@@ -43,16 +46,17 @@ License along with this library; if not, see
 #include "breakpoints.h"
 #include "cod.h"
 #include "exports.h"
-#include "fopen-path.h"
+//#include "fopen-path.h"
 #include "gpsim_classes.h"
 #include "pic-instructions.h"
 #include "processor.h"
 #include "registers.h"
 #include "sim_context.h"
 #include "ui.h"
+#include "value.h"
 
 PicCodProgramFileType::PicCodProgramFileType()
-  : codefile(0), temp_block(0), ignore_case_in_cod(1), gputils_recent(0)
+  : codefile(nullptr), temp_block(nullptr), ignore_case_in_cod(1), gputils_recent(0)
 {
   memset(&main_dir, 0, sizeof(main_dir));
 
@@ -173,8 +177,13 @@ void PicCodProgramFileType::read_hex_from_cod(Processor *cpu)
     int i = get_short_int(&dbi->dir.block[COD_DIR_MEMMAP]);
     int j = get_short_int(&dbi->dir.block[COD_DIR_MEMMAP + 2]);
 
-    if ((i != j) || (i == 0)) {
-      std::cout << ".cod range error \n";
+    if ((j < i) || (i == 0)) {
+      std::cout << ".cod range error - memory block defs invalid\n";
+      return;
+    }
+    if ( j != i ) {
+      /// @todo fix this limitation by iterating over blocks, as elsewhere
+      std::cout << ".cod range limit - can only handle 128 code segments\n";
       return;
     }
 
@@ -479,7 +488,7 @@ void PicCodProgramFileType::read_message_area(Processor *cpu)
           {
             std::string script("directive");
             char buff[276];
-            snprintf(buff, sizeof(buff), "break e %d, %s\n", laddress, DebugMessage);
+            snprintf(buff, sizeof(buff), "break asrt %d, %s\n", laddress, DebugMessage);
             std::string cmd(buff);
             cpu->add_command(script, cmd);
           }
@@ -553,19 +562,25 @@ void PicCodProgramFileType::read_symbols(Processor *cpu)
         int value = get_be_int(&s[length + 3]);
 
         switch(type) {
-        case COD_ST_C_SHORT: {
+        case COD_ST_C_SHORT:
           // Change the register name to its symbolic name
           get_string(b, s, sizeof b);
-          cpu->registers[value]->new_name(b);
+	  if (value < (int)(cpu->register_memory_size()))
+	  {
+              cpu->registers[value]->new_name(b);
           }
+	  else
+	  {
+              cpu->addSymbol(new Integer(b, value));
+	  }
           break;
 
         case COD_ST_ADDRESS: {
           get_string(b, s, sizeof b);
           instruction *pI = cpu->pma->getFromAddress(value);
           if (pI) {
-            std::string s(b);
-            pI->addLabel(s);
+            std::string str(b);
+            pI->addLabel(str);
           }
           }
           break;
@@ -726,6 +741,7 @@ void PicCodProgramFileType::read_hll_line_numbers_from_asm(Processor *cpu)
   int nfiles = cpu->files.nsrc_files();
   for (file_index = 0; file_index < nfiles; file_index++) {
     char text_buffer[256];
+    *text_buffer = 0;
     // If asm file
     if (!cpu->files[file_index]->name().compare(cpu->files[file_index]->name().length() -4 , 4, ".asm")) {
       int current_hll_file_id;
@@ -736,7 +752,7 @@ void PicCodProgramFileType::read_hll_line_numbers_from_asm(Processor *cpu)
       while (cpu->files[file_index]->gets(text_buffer, sizeof(text_buffer)) != 0) {
         asmsrc_line++;
         std::string fn;
-        if (0 == strncmp(text_buffer, ";\t.line\t", 8)) { // \t.line\t12345\t"filename"
+        if (!strncmp(text_buffer, ";\t.line\t", 8)) { // \t.line\t12345\t"filename"
           char *lineendpos = strchr(text_buffer, ';');
           if (!lineendpos)
             continue;
@@ -841,7 +857,7 @@ int PicCodProgramFileType::LoadProgramFile(Processor **pcpu,
                                            const char *pProcessorName)
 {
   int error_code= SUCCESS;
-  Processor *ccpu = 0;
+  Processor *ccpu = nullptr;
 
   codefile = pFile;
   if (!codefile) {
@@ -927,7 +943,7 @@ _Cleanup:
   delete_directory();
   delete [] temp_block;
 
-  if (*pcpu != NULL) {
+  if (*pcpu != nullptr) {
     (*pcpu)->reset(POR_RESET);
     bp.clear_global();
     std::string script("directive");
