@@ -22,13 +22,16 @@ License along with this library; if not, see
 #ifndef SRC_COMPARATOR_H_
 #define SRC_COMPARATOR_H_
 
-#include "14bit-tmrs.h"
+#include <glib.h>
 
 #include <cstdio>
 #include <string>
 
+#include "ioports.h"
+#include "processor.h"
 #include "registers.h"
 #include "stimuli.h"
+#include "a2dconverter.h"
 
 class ADCON2_TRIG;
 class CLC_BASE;
@@ -45,8 +48,6 @@ class ComparatorModule2;
 class ECCPAS;
 class InterruptSource;
 class PIR_SET;
-class PinModule;
-class Processor;
 class SR_MODULE;
 class T1GCON;
 class TMRL;
@@ -101,7 +102,7 @@ public:
         VREN = 1 << 7	// Enable Vref
     };
 
-    virtual void put(unsigned int new_value);
+    void put(unsigned int new_value) override;
     virtual void setIOpin(PinModule *);
     virtual double get_Vref();
     void setValidBits(unsigned int mask)
@@ -133,6 +134,8 @@ class VRCON_2 : public sfr_register
 {
 public:
     VRCON_2(Processor *pCpu, const char *pName, const char *pDesc);
+    VRCON_2(const VRCON_2 &) = delete;
+    VRCON_2& operator = (const VRCON_2 &) = delete;
     ~VRCON_2();
 
     enum VRCON_bits
@@ -147,7 +150,7 @@ public:
         C1VREN = 1 << 7	// Comparator 1 Reference enable
     };
 
-    virtual void put(unsigned int new_value);
+    void put(unsigned int new_value) override;
 
     CMCON *_cmcon = nullptr;
 
@@ -165,28 +168,41 @@ protected:
 class CM_stimulus : public stimulus
 {
 public:
-    CM_stimulus(CMCON *arg, const char *n = nullptr,
+    explicit CM_stimulus(CMCON *arg, const char *n = nullptr,
                 double _Vth = 0.0, double _Zth = 1e12
                );
     ~CM_stimulus();
 
     CMCON *_cmcon;
 
-    virtual void   set_nodeVoltage(double v);
+    void set_nodeVoltage(double v) override;
+};
+
+class VREF_stimulus : public stimulus
+{
+public:
+    explicit VREF_stimulus(ComparatorModule2 *arg, const char *n = nullptr,
+                double _Vth = 0.0, double _Zth = 1e12
+               );
+    ~VREF_stimulus();
+
+    ComparatorModule2 *comp;
+
+    void set_nodeVoltage(double v) override;
 };
 
 
 class CMv2_stimulus : public stimulus
 {
 public:
-    CMv2_stimulus(CM2CON1_V2 *arg, const char *n = nullptr,
+    explicit CMv2_stimulus(CM2CON1_V2 *arg, const char *n = nullptr,
                   double _Vth = 0.0, double _Zth = 1e12
                  );
     ~CMv2_stimulus();
 
     CM2CON1_V2 *_cm2con1;
 
-    virtual void   set_nodeVoltage(double v);
+    void set_nodeVoltage(double v) override;
 };
 
 
@@ -202,7 +218,7 @@ public:
         T1GSS  = 1 << 1
     };
 
-    virtual void put(unsigned int);
+    void put(unsigned int) override;
 
     void set_tmrl(TMRL *arg)
     {
@@ -234,14 +250,14 @@ public:
     };
 
     virtual void setINpin(int i, PinModule *, const char *an);
-    virtual void setIOpin(PinModule *, int i);
+    void setIOpin(PinModule *, int i) override;
     virtual void assign_pir_set(PIR_SET *new_pir_set);
-    virtual unsigned int get();
+    unsigned int get() override;
     virtual void rename_pins(unsigned int)
     {
         puts("CMCON::rename_pins() should not be called");
     }
-    virtual void put(unsigned int);
+    void put(unsigned int) override;
     virtual void set_configuration(int comp, int mode, int il1, int ih1, int il2, int ih2, int out);
     virtual double comp_voltage(int ind, int invert);
 
@@ -324,7 +340,8 @@ public:
     bool set;
     bool reset;
 
-    virtual void put(unsigned int new_value);
+    void put(unsigned int new_value) override;
+    void set_sr_out(int cm, bool output, bool out_enable, bool output_enable, CMxSignalSource   *cm_source);
 };
 
 
@@ -350,7 +367,10 @@ public:
     CM1CON0 *m_cm1con0;
     CM2CON0 *m_cm2con0;
 
-    virtual void put(unsigned int new_value);
+
+
+
+    void put(unsigned int new_value) override;
     void link_cm12con0(CM1CON0 *_cm1con0, CM2CON0 *_cm2con0);
 };
 
@@ -358,7 +378,7 @@ public:
 // The following classes are for comparators which have 3 registers
 //
 
-class CMxCON0_base : public sfr_register
+class CMxCON0_base : public sfr_register, public apfpin
 {
 public:
     CMxCON0_base(Processor *pCpu, const char *pName, const char *pDesc,
@@ -370,60 +390,26 @@ public:
         ON = 1 << 7,
         OE = 1 << 5
     };
-    virtual unsigned int get();
-    virtual double get_Vpos()
-    {
-        return 0.0;
-    }
-    virtual double get_Vneg()
-    {
-        return 0.0;
-    }
-    virtual void put(unsigned int)
-    {
-        puts("Help");
-    }
+    unsigned int get() override;
+    virtual double get_Vpos() { return 0.0; }
+    virtual double get_Vneg() { return 0.0; }
+    void put(unsigned int) override { puts("Help"); }
     //    virtual int get(){return 0;}
-    virtual void setBitMask(unsigned int bm)
-    {
-        mValidBits = bm;
-    }
-    virtual void setIntSrc(InterruptSource *_IntSrc)
-    {
-        IntSrc = _IntSrc;
-    }
-    virtual double CVref()
-    {
-        return 0.0;
-    }
+    virtual void setBitMask(unsigned int bm) { mValidBits = bm; }
+    virtual void setIntSrc(InterruptSource *_IntSrc) { IntSrc = _IntSrc; }
+    virtual double CVref() { return 0.0; }
     virtual void notify() {}
-    virtual bool output_active()
-    {
-        return value.get() & (ON | OE);
-    }
-    virtual double get_hysteresis()
-    {
-        return 0.0;
-    }
-    virtual bool output_high()
-    {
-        return false;
-    }
+    virtual bool output_active() { return value.get() & (ON | OE); }
+    virtual double get_hysteresis() { return 0.0; }
+    virtual bool output_high() { return false; }
     virtual void set_output(bool /* output */ ) {}
-    virtual bool is_on()
-    {
-        return false;
-    }
-    virtual bool out_invert()
-    {
-        return true;
-    }
-    virtual void releasePin()
-    {
-        cm_source_active = false;
-    }
+    virtual bool is_on() { return false; }
+    virtual bool out_invert() { return true; }
+    virtual void releasePin() { cm_source_active = false; }
+    virtual bool old_invert() { return true; }
 
     unsigned int mValidBits = 0;
+    unsigned int  old_value = 0;
     PinModule     *cm_input[5];
     PinModule     *cm_output = nullptr;
     CM2CON1       *m_cm2con1 = nullptr;
@@ -460,27 +446,38 @@ public:
         CxON  	= 1 << 7,	// Enable bit
     };
 
-    void put(unsigned int);
-    virtual double get_Vpos();
-    virtual double get_Vneg();
-    void setBitMask(unsigned int bm)
+    void put(unsigned int) override;
+    double get_Vpos() override;
+    double get_Vneg() override;
+    void setBitMask(unsigned int bm) override { mValidBits = bm; }
+    bool is_on() override { return value.get() & CxON; }
+    bool out_invert() override { return value.get() & CxPOL; }
+    double get_hysteresis() override;
+    void set_output(bool output) override;
+    bool output_high() override { return value.get() & CxOUT; }
+};
+
+class CMxCON0_PPS : public CMxCON0
+{
+public:
+    CMxCON0_PPS(Processor *pCpu, const char *pName, const char *pDesc, unsigned int x, ComparatorModule2 *);
+    ~CMxCON0_PPS(){}
+
+    enum
     {
-        mValidBits = bm;
-    }
-    virtual bool is_on()
-    {
-        return (value.get() & CxON);
-    }
-    virtual bool out_invert()
-    {
-        return value.get() & CxPOL;
-    }
-    virtual double get_hysteresis();
-    virtual void set_output(bool output);
-    virtual bool output_high()
-    {
-        return value.get() & CxOUT;
-    }
+        CxSYNC 	= 1 << 0,	// Output Synchronous Mode bit
+        CxHYS 	= 1 << 1,	// Hysteresis Enable bit
+        CxSP   	= 1 << 2,	// Speed/Power Select bit
+        CxZLF	= 1 << 3, // Zero Latency Filter Enable bit
+        CxPOL 	= 1 << 4,	// Output polarity select bit
+        CxOUT 	= 1 << 6,	// Output bit
+        CxON  	= 1 << 7,	// Enable bit
+    };
+
+    void put(unsigned int) override;
+    void setIOpin(PinModule *pin_cm0, int arg) override;
+    void new_pin(PinModule *old_pin, PinModule *new_pin);
+    void set_output(bool output) override;
 };
 
 
@@ -504,27 +501,16 @@ public:
         POS	= 1,
     };
 
-    virtual void put(unsigned int);
-    virtual double get_Vpos();
-    virtual double get_Vneg();
-    void setBitMask(unsigned int bm)
-    {
-        mValidBits = bm;
-    }
-    virtual bool is_on()
-    {
-        return (value.get() & CxON);
-    }
-    virtual bool out_invert()
-    {
-        return value.get() & CxPOL;
-    }
-    virtual double get_hysteresis();
-    virtual void set_output(bool output);
-    virtual bool output_high()
-    {
-        return value.get() & CxOUT;
-    }
+    void   put(unsigned int) override;
+    double get_Vpos() override;
+    double get_Vneg() override;
+    void   setBitMask(unsigned int bm) override { mValidBits = bm; }
+    bool   is_on() override { return value.get() & CxON; }
+    bool   out_invert() override { return value.get() & CxPOL; }
+    bool   old_invert() override { return old_value & CxPOL; }
+    double get_hysteresis() override;
+    void   set_output(bool output) override;
+    bool   output_high() override { return value.get() & CxOUT; }
 
     PinModule		*stimulus_pin[2];
 };
@@ -540,18 +526,11 @@ public:
     {
         NEG	= 0,
         POS	= 1
-
     };
 
-    void setBitMask(unsigned int bm)
-    {
-        mValidBits = bm;
-    }
-    PinModule *output_pin(int cm = 0)
-    {
-        return cm_output[cm];
-    }
-    virtual void put(unsigned int /* new_value */ ) {}
+    void setBitMask(unsigned int bm) { mValidBits = bm; }
+    PinModule *output_pin(int cm = 0) { return cm_output[cm]; }
+    void put(unsigned int /* new_value */ ) override {}
     virtual double get_Vpos(unsigned int arg = 0, unsigned int arg2 = 0)
     {
         (void)arg;
@@ -570,14 +549,11 @@ public:
                               PinModule *pin_cm4 = nullptr);
     virtual void set_OUTpin(PinModule *pin_cm0, PinModule *pin_cm1 = nullptr);
     virtual void set_INpinPos(PinModule *pin_cm0, PinModule *pin_cm1 = nullptr);
-    virtual void setIOpin(PinModule *pin_cm0, int arg);
-    virtual bool hyst_active(unsigned int /* cm */ )
-    {
-        return false;
-    }
+    void setIOpin(PinModule *pin_cm0, int arg) override;
+    virtual bool hyst_active(unsigned int /* cm */ ) { return false; }
     virtual void set_vrcon(VRCON * ) {}
     virtual void set_vrcon(VRCON_2 * ) {}
-    virtual void tmr_gate(unsigned int /* cm */, bool /* output */ ) {}
+    virtual void tmr_gate(unsigned int, bool) {}
 
 protected:
     unsigned int cm;	// comparator number
@@ -591,7 +567,7 @@ protected:
 };
 
 
-// CMxCON1 only uses 1 0r 2 of Negative select bits and 2 Positive select bits
+// CMxCON1 only uses 1 or 2 of Negative select bits and 2 Positive select bits
 class CMxCON1 : public CMxCON1_base
 {
 public:
@@ -600,23 +576,36 @@ public:
 
     enum
     {
-        CxNCH0 	= 1 << 0,	//  Negative Input Channel Select bits
-        CxNCH1 	= 1 << 1,	//  Negative Input Channel Select bits
-        CxNCH2 	= 1 << 2,	//  Negative Input Channel Select bits
+        CxNCH0 	= 1 << 0, //  Negative Input Channel Select bits
+        CxNCH1 	= 1 << 1, //  Negative Input Channel Select bits
+        CxNCH2 	= 1 << 2, //  Negative Input Channel Select bits
         CxPCH0	= 1 << 3, //  Positive Input Channel Select bits
         CxPCH1	= 1 << 4, //  Positive Input Channel Select bits
         CxPCH2	= 1 << 5, //  Positive Input Channel Select bits
-        CxINTN 	= 1 << 6,	//  Interrupt on Negative Going Edge Enable bits
-        CxINTP  	= 1 << 7,	//  Interrupt on Positive Going Edge Enable bits
+        CxINTN 	= 1 << 6, //  Interrupt on Negative Going Edge Enable bits
+        CxINTP 	= 1 << 7, //  Interrupt on Positive Going Edge Enable bits
         CxNMASK = (CxNCH0 | CxNCH1 | CxNCH2),
         CxPMASK = (CxPCH0 | CxPCH1 | CxPCH2)
     };
 
-    virtual void put(unsigned int new_value);
-    virtual double get_Vpos(unsigned int arg = 0, unsigned int arg2 = 0);
-    virtual double get_Vneg(unsigned int arg = 0, unsigned int arg2 = 0);
-};
+    enum
+    {
+	CM_AGND = 0,
+	CM_VDD,
+	CM_FVR,
+	CM_DAC1,
+	CM_DAC2,
+	CM_DAC3,
+	CM_DAC4,
+	CM_DAC5,
+	CM_PIN,
+	CM_UNUSED
+    };
 
+    void put(unsigned int new_value) override;
+    double get_Vpos(unsigned int arg = 0, unsigned int arg2 = 0) override;
+    double get_Vneg(unsigned int arg = 0, unsigned int arg2 = 0) override;
+};
 
 /*  two comparators with common CM2CON1 and no COUT register, hyteresis,
     C1, C2 possible T1,3,5  gate, FVR or  DAC for voltage reference,
@@ -641,11 +630,11 @@ public:
         MC1OUT = 1 << 7
     };
 
-    virtual void put(unsigned int new_value);
-    virtual double get_Vpos(unsigned int cm, unsigned int cmxcon0);
-    virtual double get_Vneg(unsigned int cm, unsigned int cmxcon0);
-    virtual bool hyst_active(unsigned int cm);
-    virtual void tmr_gate(unsigned int cm, bool output);
+    void put(unsigned int new_value) override;
+    double get_Vpos(unsigned int cm, unsigned int cmxcon0) override;
+    double get_Vneg(unsigned int cm, unsigned int cmxcon0) override;
+    bool hyst_active(unsigned int cm) override;
+    void tmr_gate(unsigned int cm, bool output) override;
     void set_ctmu_stim(stimulus *_ctmu_stim, CTMU *_ctmu_module);
     void attach_ctmu_stim();
     void detach_ctmu_stim();
@@ -653,7 +642,7 @@ public:
 private:
     stimulus          *ctmu_stim = nullptr;
     stimulus          *comp_input_cap = nullptr;
-    bool	            ctmu_attached = false;
+    bool	       ctmu_attached = false;
 };
 
 
@@ -666,9 +655,8 @@ class CM2CON1_V3 : public CMxCON1_base
 {
 public:
     CM2CON1_V3(Processor *pCpu, const char *pName, const char *pDesc,
-               unsigned int _cm, ComparatorModule2 * cmModule) :
-        CMxCON1_base(pCpu, pName, pDesc, _cm, cmModule) {}
-    ~CM2CON1_V3() {}
+               ComparatorModule2 * cmModule);
+    ~CM2CON1_V3();
 
     enum
     {
@@ -680,28 +668,23 @@ public:
         MC1OUT = 1 << 7
     };
 
-    virtual void put(unsigned int new_value);
-    virtual double get_Vpos(unsigned int cm, unsigned int cmxcon0);
-    virtual double get_Vneg(unsigned int cm, unsigned int cmxcon0);
-    virtual bool hyst_active(unsigned int /* cm */ )
-    {
-        return false;
-    }
-    void set_vrcon(VRCON * _vrcon)
-    {
-        m_vrcon = _vrcon;
-    }
-    virtual void tmr_gate(unsigned int cm, bool output);
+    void put(unsigned int new_value) override;
+    double get_Vpos(unsigned int cm, unsigned int cmxcon0) override;
+    double get_Vneg(unsigned int cm, unsigned int cmxcon0) override;
+    bool hyst_active(unsigned int /* cm */ ) override { return false; }
+    void set_vrcon(VRCON * _vrcon) override { m_vrcon = _vrcon;}
+    void set_vrcon(VRCON_2 * _vrcon) override { m_vrcon = (VRCON *)_vrcon;}
+    void tmr_gate(unsigned int cm, bool output) override;
 
 protected:
     VRCON 	*m_vrcon = nullptr;
 };
 
 
-/*  two comparators, no hyteresis, cm2con1 controls t1 gate,
+/*  two comparators, possible  hyteresis, cm2con1 controls t1 gate,
     C2 possible T1 gate, VRCON for voltage reference
     Like CM2CON1_V3 without C1RSEL, C2RSEL
-    used by 16f690.
+    used by 16f690, 16f610, 16f616.
 */
 
 class CM2CON1_V4 : public CM2CON1_V3
@@ -709,15 +692,25 @@ class CM2CON1_V4 : public CM2CON1_V3
 public:
     CM2CON1_V4(Processor *pCpu, const char *pName, const char *pDesc,
                unsigned int _cm, ComparatorModule2 * cmModule);
+    CM2CON1_V4(const CM2CON1_V4 &) = delete;
+    CM2CON1_V4& operator = (const CM2CON1_V4 &) = delete;
     ~CM2CON1_V4();
 
-    virtual void put(unsigned int new_value);
-    virtual double get_Vpos(unsigned int cm, unsigned int cmxcon0);
-    void set_vrcon(VRCON_2 * _vrcon)
-    {
-        m_vrcon = _vrcon;
-    }
+    void put(unsigned int new_value) override;
+    double get_Vpos(unsigned int cm, unsigned int cmxcon0) override;
+    void set_vrcon(VRCON_2 * _vrcon) { m_vrcon = _vrcon; }
+    bool hyst_active(unsigned int cm) override;
 
+    enum
+    {
+        C2SYNC = 1 << 0,
+        T1GSS  = 1 << 1,
+        C2HYS  = 1 << 2,
+        C1HYS  = 1 << 3,
+        T1ACS  = 1 << 4,
+        MC2OUT = 1 << 6,
+        MC1OUT = 1 << 7
+    };
 protected:
     VRCON_2 	*m_vrcon = nullptr;
     CM_stimulus 	*cm1_cvref;
@@ -733,7 +726,7 @@ public:
     CMOUT(Processor *pCpu, const char *pName, const char *pDesc)
         : sfr_register(pCpu, pName, pDesc) {}
 
-    void put(unsigned int /* val */ )
+    void put(unsigned int /* val */ ) override
     {
         // Read only by user
     }
@@ -741,19 +734,17 @@ public:
 
 
 // uses CMxCON0, CMxCON1, CMOUT
-class ComparatorModule2
+class ComparatorModule2 : public FVR_ATTACH, public DAC_ATTACH
 {
 public:
     explicit ComparatorModule2(Processor *);
     ~ComparatorModule2();
 
-    void run_get(unsigned int comp)
-    {
-        cmxcon0[comp]->get();
-    }
+    void run_get(unsigned int comp) { cmxcon0[comp]->get(); }
 
-    void set_DAC_volt(double);
-    void set_FVR_volt(double);
+    DATA_SERVER  *get_CM_data_server() { return data_server;}
+    void set_DAC_volt(double, unsigned int) override;
+    void set_FVR_volt(double, unsigned int) override;
     void set_cmout(unsigned int bit, bool value);
     void set_if(unsigned int);
     void assign_pir_set(PIR_SET *new_pir_set) { pir_set = new_pir_set; }
@@ -783,18 +774,26 @@ public:
     CMOUT		*cmout = nullptr;
 
     //protected:
+    int 	Pmask[8];
+    int 	Nmask[8];
+    double 	IN_voltage[8];
     double 	DAC_voltage = 0.0;
     double 	FVR_voltage = 0.0;
     PIR_SET 	*pir_set = nullptr;
-    TMRL		*tmr1l[3];
+    TMRL	*tmr1l[3];
     T1GCON	*t1gcon[3];
     SR_MODULE	*sr_module = nullptr;
-    CTMU		*ctmu_module = nullptr;
+    CTMU	*ctmu_module = nullptr;
     ECCPAS 	*eccpas[3];
-    ADCON2_TRIG   *m_adcon2 = nullptr;
+    ADCON2_TRIG *m_adcon2 = nullptr;
     CLC_BASE	*m_clc[4];
     COG		*p_cog = nullptr;
+    Stimulus_Node *node_cvref = nullptr;
+    VREF_stimulus *vref_stimulus = nullptr;
+    FVRCON	*fvrcon = nullptr;
+    DATA_SERVER *data_server = nullptr;
+
 };
 
 
-#endif // __COMPARATOR_H__
+#endif // SRC_COMPARATOR_H_
