@@ -1,13 +1,22 @@
 #include "dsm_module.h"
 
+#include <string>
+#include "ioports.h"
+#include "processor.h"
+#include "stimuli.h"
+#include "trace.h"
+#include "uart.h"
 
 class minSink : public SignalSink
 {
 public:
-    minSink(DSM_MODULE *dsm) : m_dsm(dsm) {}
-    virtual void setSinkState(char new3State)
-		{ m_dsm->minEdge(new3State);}
-    virtual void release() {}
+    explicit minSink(DSM_MODULE *dsm) : m_dsm(dsm) {}
+    void setSinkState(char new3State) override
+    {
+        m_dsm->minEdge(new3State);
+    }
+    void release() override {}
+
 private:
     DSM_MODULE *m_dsm;
 };
@@ -15,10 +24,13 @@ private:
 class carhSink : public SignalSink
 {
 public:
-    carhSink(DSM_MODULE *dsm) : m_dsm(dsm) {}
-    virtual void setSinkState(char new3State)
-		{ m_dsm->carhEdge(new3State);}
-    virtual void release() { delete this;}
+    explicit carhSink(DSM_MODULE *dsm) : m_dsm(dsm) {}
+    void setSinkState(char new3State) override
+    {
+        m_dsm->carhEdge(new3State);
+    }
+    void release() override { delete this; }
+
 private:
     DSM_MODULE *m_dsm;
 };
@@ -26,10 +38,13 @@ private:
 class carlSink : public SignalSink
 {
 public:
-    carlSink(DSM_MODULE *dsm) : m_dsm(dsm) {}
-    virtual void setSinkState(char new3State)
-		{ m_dsm->carlEdge(new3State);}
-    virtual void release() { delete this;}
+    explicit carlSink(DSM_MODULE *dsm) : m_dsm(dsm) {}
+    void setSinkState(char new3State) override
+    {
+        m_dsm->carlEdge(new3State);
+    }
+    void release() override { delete this; }
+
 private:
     DSM_MODULE *m_dsm;
 };
@@ -37,12 +52,12 @@ private:
 class MDoutSignalSource : public SignalControl
 {
 public:
-    MDoutSignalSource(DSM_MODULE *dsm) : m_dsm(dsm) {}
-    virtual char getState() { return m_dsm->mdout; }
-    virtual void release() {}
+    explicit MDoutSignalSource(DSM_MODULE *dsm) : m_dsm(dsm) {}
+    char getState() override { return m_dsm->mdout; }
+    void release() override {}
+
 private:
     DSM_MODULE *m_dsm;
-
 };
 
 
@@ -51,26 +66,26 @@ DSM_MODULE::DSM_MODULE(Processor *pCpu) :
     mdsrc(pCpu, "mdsrc", "Modulation Source Control Register", this),
     mdcarh(pCpu, "mdcarh", "Modulation High Carrier Control Register", this),
     mdcarl(pCpu, "mdcarl", "Modulation Low Carrier Control Register", this),
-    m_mdout(0), m_mdmin(0), m_minSink(0),
-    m_mdcin1(0), cin1Sink_cnt(0), m_carlSink(0),
-    m_mdcin2(0), m_carhSink(0), out_source(0), mdout('?'),
-    usart_mod(0), ssp_mod1(0), ssp_mod2(0),
+    m_mdout(nullptr), m_mdmin(nullptr), m_minSink(nullptr),
+    m_mdcin1(nullptr), cin1Sink_cnt(0), m_carlSink(nullptr),
+    m_mdcin2(nullptr), m_carhSink(nullptr), out_source(nullptr), mdout('?'),
+    usart_mod(nullptr), ssp_mod1(nullptr), ssp_mod2(nullptr),
     mdmin_state(false), mdcarl_state(false), mdcarh_state(false),
-    dflipflopH(false), dflipflopL(false), dsmSrc_pin(0), monitor_pin(0),
-    monitor_mod(0)
+    dflipflopH(false), dflipflopL(false), dsmSrc_pin(nullptr), monitor_pin(nullptr),
+    monitor_mod(nullptr)
 {
 }
 
 
 DSM_MODULE::~DSM_MODULE()
 {
-  if (monitor_pin)
-  {
-	delete monitor_mod;
-	delete monitor_pin;
-	monitor_pin = 0;
-	if (m_carhSink)
-	{
+    if (monitor_pin)
+    {
+        delete monitor_mod;
+        delete monitor_pin;
+
+        if (m_carhSink)
+        {
 /*RRR
 	     if (m_mdcin1)
              {
@@ -81,27 +96,29 @@ DSM_MODULE::~DSM_MODULE()
 	         m_mdcin2->removeSink(m_carhSink);
 	     }
 RRR */
-	     delete m_carhSink;
+            delete m_carhSink;
         }
-  }
+    }
 }
+
 void DSM_MODULE::dsm_logic(bool carl_neg_edge, bool carh_neg_edge)
 {
     bool out, outh, outl;
     unsigned int con_reg = mdcon.get_value();
 
+    // FIXME: Something is wrong with the logic below.
     if (carl_neg_edge && carl_neg_edge)
     {
-	dflipflopL = !mdmin_state & !mdcarh_state;
-	dflipflopH = mdmin_state & !mdcarl_state;
+        dflipflopL = !mdmin_state & !mdcarh_state;
+        dflipflopH = mdmin_state & !mdcarl_state;
     }
     else if (carl_neg_edge)
     {
-	dflipflopL = !mdmin_state & !dflipflopH;
+        dflipflopL = !mdmin_state & !dflipflopH;
     }
     else if (carh_neg_edge)
     {
-	dflipflopH = mdmin_state & !dflipflopL;
+        dflipflopH = mdmin_state & !dflipflopL;
     }
 
     if (mdcarl.get_value() & MDCLSYNC)
@@ -112,6 +129,7 @@ void DSM_MODULE::dsm_logic(bool carl_neg_edge, bool carh_neg_edge)
     {
        outl = !mdmin_state && mdcarl_state;
     }
+
     if (mdcarh.get_value() & MDCHSYNC)
     {
        outh = mdcarh_state && dflipflopH;
@@ -125,12 +143,13 @@ void DSM_MODULE::dsm_logic(bool carl_neg_edge, bool carh_neg_edge)
     out = (con_reg & MDOPOL)? !out : out;
     if (out)
     {
-	con_reg |= MDOUT;
+        con_reg |= MDOUT;
     }
     else
     {
-	con_reg &= ~MDOUT;
+        con_reg &= ~MDOUT;
     }
+
     mdcon.put_value(con_reg);
     putMDout(out);
 }
@@ -143,45 +162,40 @@ void DSM_MODULE::putMDout(bool out)
 
 void DSM_MODULE::releaseMDout()
 {
-   if (out_source)
-   {
-    //   m_mdout->setSource(0);
-       delete out_source;
-	out_source = 0;
-   }
-
+    delete out_source;
+    out_source = nullptr;
 }
+
 void DSM_MODULE::new_mdcon(unsigned int old_value, unsigned int new_value)
 {
-
-   if (((old_value ^ new_value) & MDOE) && m_mdout)
-   {
-       if (new_value & MDOE)
-       {
-	  m_mdout->getPin().newGUIname("MDOUT");
-	  if (!out_source)
-	  {
-	      out_source = new MDoutSignalSource(this);
-	  }
-	  m_mdout->setSource(out_source);
-       }
-       else
-       {
-	  m_mdout->setSource(0);
-	  out_source = 0;
-	  m_mdout->getPin().newGUIname(m_mdout->getPin().name().c_str());
-       }
-   }
-   if (((old_value ^ new_value) & MDBIT) && (mdsrc.get_value() & 0x0f) == 0)
-   {
-	mdmin_state = new_value & MDBIT;
-	if (new_value & MDEN)
-	    dsm_logic(false, false);
-   }
-   else if (((old_value ^ new_value) & MDOPOL))
-	dsm_logic(false, false);
-
+    if (((old_value ^ new_value) & MDOE) && m_mdout)
+    {
+        if (new_value & MDOE)
+        {
+            m_mdout->getPin().newGUIname("MDOUT");
+            if (!out_source)
+            {
+                out_source = new MDoutSignalSource(this);
+            }
+            m_mdout->setSource(out_source);
+        }
+        else
+        {
+            m_mdout->setSource(0);
+            out_source = nullptr;
+            m_mdout->getPin().newGUIname(m_mdout->getPin().name().c_str());
+        }
+    }
+    if (((old_value ^ new_value) & MDBIT) && (mdsrc.get_value() & 0x0f) == 0)
+    {
+        mdmin_state = new_value & MDBIT;
+        if (new_value & MDEN)
+            dsm_logic(false, false);
+    }
+    else if (((old_value ^ new_value) & MDOPOL))
+        dsm_logic(false, false);
 }
+
 // remove Old modulator source
 void DSM_MODULE::rmModSrc(unsigned int old_value)
 {
@@ -431,13 +445,17 @@ void DSM_MODULE::new_mdcarl(unsigned int old_value, unsigned int new_value)
     if (mdcarl_state != old)
 	dsm_logic(old, false);
 }
+
 void DSM_MODULE::carlEdge(char new3State)
 {
-   bool old_state = mdcarl_state;
-   mdcarl_state = (new3State == '1' || new3State == 'W');
-   mdcarl_state = (mdcarl.get_value() & MDCLPOL) ? ! mdcarl_state : mdcarl_state;
-   if (old_state != mdcarl_state)
-	dsm_logic(false, old_state);  // old_state true on falling edge
+    bool old_state = mdcarl_state;
+    mdcarl_state = (new3State == '1' || new3State == 'W');
+    mdcarl_state = (mdcarl.get_value() & MDCLPOL) ? ! mdcarl_state : mdcarl_state;
+
+    if (old_state != mdcarl_state)
+    {
+        dsm_logic(false, old_state);  // old_state true on falling edge
+    }
 }
 
 _MDCON::_MDCON(Processor *pCpu, const char *pName, const char *pDesc, DSM_MODULE *_mDSM):
@@ -445,37 +463,40 @@ _MDCON::_MDCON(Processor *pCpu, const char *pName, const char *pDesc, DSM_MODULE
     mDSM(_mDSM)
 {
 }
+
 void _MDCON::put(unsigned int new_value)
 {
-  new_value &= mask;
-  trace.raw(write_trace.get() | value.get());
-  put_value(new_value);
+    new_value &= mask;
+    trace.raw(write_trace.get() | value.get());
+    put_value(new_value);
 }
+
 void _MDCON::put_value(unsigned int new_value)
 {
-  unsigned int old_value = value.get();
-  new_value &= (mask | DSM_MODULE::MDOUT);
-  value.put(new_value);
-  mDSM->new_mdcon(old_value, new_value);
-
+    unsigned int old_value = value.get();
+    new_value &= (mask | DSM_MODULE::MDOUT);
+    value.put(new_value);
+    mDSM->new_mdcon(old_value, new_value);
 }
 
 _MDSRC::_MDSRC(Processor *pCpu, const char *pName, const char *pDesc, DSM_MODULE *_mDSM):
-    sfr_register(pCpu, pName, pDesc),mask(0x8f),
+    sfr_register(pCpu, pName, pDesc), mask(0x8f),
     mDSM(_mDSM)
 {
 }
+
 void _MDSRC::put(unsigned int new_value)
 {
-  new_value &= mask;
-  trace.raw(write_trace.get() | value.get());
-  put_value(new_value);
+    new_value &= mask;
+    trace.raw(write_trace.get() | value.get());
+    put_value(new_value);
 }
+
 void _MDSRC::put_value(unsigned int new_value)
 {
-  unsigned int old_value = value.get();
-  value.put(new_value);
-  mDSM->new_mdsrc(old_value, new_value);
+    unsigned int old_value = value.get();
+    value.put(new_value);
+    mDSM->new_mdsrc(old_value, new_value);
 }
 
 _MDCARH::_MDCARH(Processor *pCpu, const char *pName, const char *pDesc, DSM_MODULE *_mDSM):
@@ -486,30 +507,34 @@ _MDCARH::_MDCARH(Processor *pCpu, const char *pName, const char *pDesc, DSM_MODU
 
 void _MDCARH::put(unsigned int new_value)
 {
-  new_value &= mask;
-  trace.raw(write_trace.get() | value.get());
-  put_value(new_value);
+    new_value &= mask;
+    trace.raw(write_trace.get() | value.get());
+    put_value(new_value);
 }
+
 void _MDCARH::put_value(unsigned int new_value)
 {
-  unsigned int old_value = value.get();
-  value.put(new_value);
-  mDSM->new_mdcarh(old_value, new_value);
+    unsigned int old_value = value.get();
+    value.put(new_value);
+    mDSM->new_mdcarh(old_value, new_value);
 }
+
 _MDCARL::_MDCARL(Processor *pCpu, const char *pName, const char *pDesc, DSM_MODULE *_mDSM):
     sfr_register(pCpu, pName, pDesc), mask(0xef),
     mDSM(_mDSM)
 {
 }
+
 void _MDCARL::put(unsigned int new_value)
 {
-  new_value &= mask;
-  trace.raw(write_trace.get() | value.get());
-  put_value(new_value);
+    new_value &= mask;
+    trace.raw(write_trace.get() | value.get());
+    put_value(new_value);
 }
+
 void _MDCARL::put_value(unsigned int new_value)
 {
-  unsigned int old_value = value.get();
-  value.put(new_value);
-  mDSM->new_mdcarl(old_value, new_value);
+    unsigned int old_value = value.get();
+    value.put(new_value);
+    mDSM->new_mdcarl(old_value, new_value);
 }
