@@ -24,6 +24,14 @@ License along with this library; if not, see
 #include "dspic-instructions.h"
 
 #include <assert.h>
+#include <stdio.h>
+#include <string>
+#include "../gpsim_object.h"
+#include "dspic-registers.h"
+
+class Cycle_Counter;
+class Processor;
+class Trace;
 
 using namespace dspic;
 using namespace dspic_instructions;
@@ -37,7 +45,7 @@ namespace dspic {
 struct dsPicInstructionConstructor {
   unsigned int inst_mask;
   unsigned int opcode;
-  instruction * (*inst_constructor) (Processor *cpu, unsigned int inst,unsigned int addr);
+  instruction * (*inst_constructor) (Processor *cpu, unsigned int inst, unsigned int addr);
 };
 
 
@@ -272,23 +280,15 @@ struct dsPicInstructionConstructor op_dsPic[] = {
 const int NUM_OP_DSPIC = sizeof(op_dsPic) / sizeof(op_dsPic[0]);
 
 
-instruction * dsPicProcessor::disasm (unsigned int address, unsigned int inst)
+instruction * dsPicProcessor::disasm(unsigned int address, unsigned int inst)
 {
+    for (int i = 0; i < NUM_OP_DSPIC; i++)
+    {
+        if ((op_dsPic[i].inst_mask & inst) == op_dsPic[i].opcode)
+            return op_dsPic[i].inst_constructor(this, inst, address);
+    }
 
-  //printf("dspic disasm addr 0x%x, opcode 0x%x\n",address,inst);
-
-  instruction *pi;
-
-  pi = 0;
-  for(int i =0; i<NUM_OP_DSPIC; i++)
-    if((op_dsPic[i].inst_mask & inst) == op_dsPic[i].opcode)
-      pi = op_dsPic[i].inst_constructor(this, inst, address);
-
-  if(pi == 0)
-    pi = invalid_instruction::construct(this, inst, address);
-
-  return (pi);
-
+    return new invalid_instruction(this, inst, address);
 }
 
 
