@@ -18,11 +18,13 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
-#if !defined(__DSPIC_INSTRUCTIONS_H__)
-#define __DSPIC_INSTRUCTIONS_H__
+#ifndef SRC_DSPIC_DSPIC_INSTRUCTIONS_H_
+#define SRC_DSPIC_DSPIC_INSTRUCTIONS_H_
 
+#include "../registers.h"
 #include "../pic-instructions.h"
 
+class Processor;
 namespace dspic
 {
   class dsPicProcessor;
@@ -163,9 +165,9 @@ namespace dspic_instructions
     {
     }
 
-    virtual RegisterValue get() {return m_rv;}
-    virtual void put(RegisterValue &) {} // maybe we should throw an error?
-    virtual char *name(char *buff, int len);
+    RegisterValue get() override {return m_rv;}
+    void put(RegisterValue &) override {} // maybe we should throw an error?
+    char *name(char *buff, int len) override;
   private:
     RegisterValue m_rv;
   };
@@ -181,7 +183,7 @@ namespace dspic_instructions
     {
     }
 
-    virtual char *name(char *buff, int len);
+    char *name(char *buff, int len) override;
   protected:
     const char *m_cPformat;
   };
@@ -195,8 +197,8 @@ namespace dspic_instructions
     {
     }
 
-    virtual RegisterValue get();
-    virtual void put(RegisterValue &);
+    RegisterValue get() override;
+    void put(RegisterValue &) override;
   };
   //----------------------------------------------------------------------
   class RegIndirectAddrMode : public RegisterAddressingMode
@@ -208,8 +210,8 @@ namespace dspic_instructions
     {
     }
 
-    virtual RegisterValue get();
-    virtual void put(RegisterValue &);
+    RegisterValue get() override;
+    void put(RegisterValue &) override;
   };
 
   //----------------------------------------------------------------------
@@ -222,8 +224,8 @@ namespace dspic_instructions
     {
     }
 
-    virtual RegisterValue get();
-    virtual void put(RegisterValue &);
+    RegisterValue get() override;
+    void put(RegisterValue &) override;
   };
   //----------------------------------------------------------------------
   class RegIndirectPostIncAddrMode : public RegisterAddressingMode
@@ -235,8 +237,8 @@ namespace dspic_instructions
     {
     }
 
-    virtual RegisterValue get();
-    virtual void put(RegisterValue &);
+    RegisterValue get() override;
+    void put(RegisterValue &) override;
   };
   //----------------------------------------------------------------------
   class RegIndirectPreDecAddrMode : public RegisterAddressingMode
@@ -248,8 +250,8 @@ namespace dspic_instructions
     {
     }
 
-    virtual RegisterValue get();
-    virtual void put(RegisterValue &);
+    RegisterValue get() override;
+    void put(RegisterValue &) override;
   };
 
   //----------------------------------------------------------------------
@@ -262,8 +264,8 @@ namespace dspic_instructions
     {
     }
 
-    virtual RegisterValue get();
-    virtual void put(RegisterValue &);
+    RegisterValue get() override;
+    void put(RegisterValue &) override;
   };
 
   //----------------------------------------------------------------------
@@ -648,7 +650,7 @@ namespace dspic_instructions
   {
   public:
     GOTO(Processor *new_cpu, unsigned int new_opcode, unsigned int addr);
-    virtual void execute();
+    void execute() override;
     static instruction *construct(Processor *new_cpu, unsigned int new_opcode, unsigned int addr)
     {return new GOTO(new_cpu,new_opcode, addr);}
   };
@@ -1010,4 +1012,4 @@ namespace dspic_instructions
 
 };
 
-#endif // __DSPIC_INSTRUCTIONS_H__
+#endif // SRC_DSPIC_DSPIC_INSTRUCTIONS_H_
