@@ -27,8 +27,9 @@ License along with this library; if not, see
 
 #include <glib.h>
 
-#include "../config.h"
 #include "breakpoints.h"
+#include "gpsim_interface.h"
+#include "gpsim_time.h"
 #include "trace.h"
 #include "pic-processor.h"
 #include "eeprom.h"
@@ -252,10 +253,10 @@ void EEPROM_PIR::start_write()
 
 void EEPROM_PIR::write_is_complete()
 {
-  assert(m_pir != nullptr);
   eecon1.value.put(eecon1.value.get()  & (~eecon1.WR));
   Dprintf(("eecon1 0x%x\n", eecon1.value.get()));
-  m_pir->set_eeif();
+  if (m_pir)
+      m_pir->set_eeif();
 }
 
 
@@ -556,6 +557,8 @@ void EEPROM_WIDE::start_program_memory_read()
 {
   rd_adr = eeadr.value.get() | (eeadrh.value.get() << 8);
   get_cycles().set_break(get_cycles().get() + 2, this);
+  // The next 2 commands are executed as NOPs as program memory is read.
+  cpu_pic->inattentive(2);
 }
 
 
@@ -747,21 +750,26 @@ void EEPROM_EXTND::initialize(
 
 void EEPROM_EXTND::start_program_memory_read()
 {
-  rd_adr = eeadr.value.get() | (eeadrh.value.get() << 8);
+  // Bit 7 of EEADRH reads back as 1
+  rd_adr = eeadr.value.get() | ((eeadrh.value.get() & 0x7f) << 8);
   get_cycles().set_break(get_cycles().get() + 2, this);
-  cpu_pic->pc->increment();
+  // The next 2 commands are executed as NOPs as program memory is read.
+  // SB: The data sheet implies that the first instruction is executed, and
+  // only the second instruction will be a forced NOP. But that is not how
+  // it works on a real PIC (verified on a PIC16F1847).
+  cpu_pic->inattentive(2);
 }
 
 
 void EEPROM_EXTND::start_write()
 {
   eecon1.value.put(eecon1.value.get()  | eecon1.WRERR);
-  wr_adr = eeadr.value.get() + (eeadrh.value.get() << 8);
+  wr_adr = eeadr.value.get() + ((eeadrh.value.get() & 0x7f) << 8);
   wr_data = eedata.value.get() + (eedatah.value.get() << 8);
   eecon2.start_write();
 
   if (eecon1.value.get() & (EECON1::EEPGD | EECON1::CFGS)) {
-    // stop execution fo 2 ms
+    // stop execution for 2 ms
     get_cycles().set_break(get_cycles().get() + (guint64)(0.002 * get_cycles().instruction_cps()), this);
     cpu_pic->pc->increment();
     bp.set_pm_write();
@@ -804,7 +812,7 @@ void EEPROM_EXTND::callback()
 
     } else {	// read eeprom data
       if (eeadr.value.get() < rom_size) {
-        eedata.value.put(rom[eeadr.value.get()]->get());
+        eedata.value.put(rom[eeadr.value.get()]->get_value());
 
       } else {
         std::cout << "EXTND_EEPROM read address is out of range " << std::hex << eeadr.value.get() << '\n';
