@@ -39,7 +39,6 @@ License along with this library; if not, see
 #include <unistd.h>
 #endif
 
-#include "../config.h"
 #include "value.h"
 #include "fopen-path.h"
 #include "symbol.h"
@@ -52,25 +51,29 @@ static std::vector<std::string> searchPath;
 class CSourceSearchPath : public String
 {
 public:
-  CSourceSearchPath() : String("SourcePath", nullptr, "Search path for source files")
+  CSourceSearchPath()
+    : String("SourcePath", nullptr, "Search path for source files")
   {
   }
-  virtual void set(const char *cP, int len = 0) {
+  void set(const char *cP, int len = 0) override
+  {
     (void)len;
     set_search_path(cP);
   }
-  virtual void set(Value *pValue) {
+  void set(Value *pValue) override
+  {
     String *pString = dynamic_cast<String*>(pValue);
     if (pString) {
       set_search_path(pString->getVal());
     }
   }
 
-  std::string toString()
+  std::string toString() override
   {
     std::string str_path;
     for (const auto &path : searchPath) {
-      str_path += path + ':';
+      str_path += path;
+      str_path += ':';
     }
     // Remove the final ':' character
     if (!str_path.empty()) {
