@@ -31,11 +31,11 @@ extern "C" {
 #endif /* __cplusplus */
 
 LIBGPSIM_EXPORT void InitSourceSearchAsSymbol();
-LIBGPSIM_EXPORT void set_search_path (const char *path);
-LIBGPSIM_EXPORT FILE *fopen_path (const char *filename, const char *perms);
+LIBGPSIM_EXPORT void set_search_path(const char *path);
+LIBGPSIM_EXPORT FILE *fopen_path(const char *filename, const char *perms);
 
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
 
-#endif // SRC_FOPEN_PAT_H_
+#endif // SRC_FOPEN_PATH_H_
