@@ -15,7 +15,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, see 
+License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
@@ -32,7 +32,7 @@ License along with this library; if not, see
 //========================================================================
 
 gpsimObject::gpsimObject()
-: cpDescription(0)
+  : cpDescription(nullptr)
 {
 }
 
@@ -45,16 +45,12 @@ gpsimObject::gpsimObject(const char *_name, const char *desc)
 
 gpsimObject::~gpsimObject()
 {
-  name_str.clear();
-  cpDescription = 0;
 }
 
 // The 'type' of any Viewable object is equivalent to the class name.
-string gpsimObject::showType()
+std::string gpsimObject::showType()
 {
-  const char* name;
-
-  name = typeid(*this).name();
+  const char* name = typeid(*this).name();
 
   /* Unfortunately, the class name string returned by typeid() is
    * implementation-specific.  If a particular compiler produces
@@ -70,9 +66,8 @@ string gpsimObject::showType()
     name++;
     buf[0] = 0;
 
-    while (isdigit(*name))
-    {
-      for(cnt = 0; isdigit(*name); name++)
+    while (isdigit(*name)) {
+      for (cnt = 0; isdigit(*name); name++)
         cnt = cnt * 10 + *name - '0';
       strncat(buf, name, cnt);
       name += cnt;
@@ -100,31 +95,30 @@ string gpsimObject::showType()
   #warning --->You might want to clean up the result of typeid() here...
 #endif
 
-  return string(name);
+  return name;
 }
 
-
-string gpsimObject::show()
+std::string gpsimObject::show()
 {
   return showType() + ":" + toString();
 }
 
 void gpsimObject::new_name(const char *s)
 {
-
-  if(s)
-    name_str = string(s);
+  if (s)
+    name_str = s;
 }
 
-void gpsimObject::new_name(string &new_name)
+// FIXME: The argument should be const std::string &
+void gpsimObject::new_name(std::string &new_name)
 {
   name_str = new_name;
 }
 
 char *gpsimObject::name(char *return_str, int len)
 {
-  if(return_str)
-    snprintf(return_str,len,"%s",name_str.c_str());
+  if (return_str)
+    snprintf(return_str, len, "%s", name_str.c_str());
 
   return return_str;
 }
@@ -137,54 +131,56 @@ unsigned int gpsimObject::get_value()
 
 char *gpsimObject::toString(char *return_str, int len)
 {
-  if(return_str)
-    snprintf(return_str,len,"%s",toString().c_str());
-
-  return return_str;
-}
-char *gpsimObject::toBitStr(char *return_str, int len)
-{
-  if(return_str)
-    *return_str = 0;
+  if (return_str)
+    snprintf(return_str, len, "%s", toString().c_str());
 
   return return_str;
 }
 
-string &gpsimObject::name(void) const
+char *gpsimObject::toBitStr(char *return_str, int )
 {
-  return (string &)name_str;
+  if (return_str)
+    *return_str = '\0';
+
+  return return_str;
 }
 
-string gpsimObject::toString()
+// FIXME: Should not cast away constness
+std::string &gpsimObject::name() const
+{
+  return (std::string &)name_str;
+}
+
+std::string gpsimObject::toString()
 {
   //return showType();
 
   char buff[64];
-  snprintf(buff,sizeof(buff), " = 0x%x",get_value());
-  string s = name() + string(buff);
+  snprintf(buff, sizeof(buff), " = 0x%x", get_value());
+  std::string s = name() + std::string(buff);
   return s;
-
 }
 
 // If derived classes don't redefine set_break and clear_break then
 // the default behavior is to not support these capabilities.
-int gpsimObject::set_break(ObjectBreakTypes bt, ObjectActionTypes at, Expression *expr)
+int gpsimObject::set_break(ObjectBreakTypes , ObjectActionTypes , Expression *)
 {
   //cout << showType() << " objects do not support break points\n";
   return -1;
 }
+
 int gpsimObject::clear_break()
 {
   //cout << showType() << " objects do not support break points\n";
   return -1;
 }
 
-string gpsimObject::description()
+std::string gpsimObject::description()
 {
-  if(cpDescription)
-    return string(cpDescription);
+  if (cpDescription)
+    return cpDescription;
   else
-    return string("no description");
+    return "no description";
 }
 
 void  gpsimObject::set_description(const char *new_description)
