@@ -18,20 +18,17 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
-#include <stdio.h>
 #include <iostream>
 #include <iomanip>
 
-#include "14bit-processors.h"
-#include "interface.h"
-
-#include <string>
-#include "stimuli.h"
-#include "errors.h"
-#include "../config.h"
-#include "xref.h"
-
-#include "protocol.h"
+#include "breakpoints.h"
+#include "gpsim_object.h"
+#include "gpsim_time.h"
+#include "symbol.h"
+#include "trace.h"
+#include "ui.h"
+#include "value.h"
+class Expression;
 
 //#define __DEBUG_CYCLE_COUNTER__
 
@@ -765,13 +762,10 @@ void Cycle_Counter::dump_breakpoints()
 Cycle_Counter::~Cycle_Counter()
 {
   Cycle_Counter_breakpoint_list  *l1, *l2;
-  int cactive = 0;
-  int cinactive = 0;
 
   l1 = (&active)->next;
 
   while (l1) {
-    cactive++;
     l2 = l1->next;
     l1->next = nullptr;
     delete l1;
@@ -781,7 +775,6 @@ Cycle_Counter::~Cycle_Counter()
   l1 = (&inactive)->next;
 
   while (l1) {
-    cinactive++;
     l2 = l1->next;
     l1->next = nullptr;
     delete l1;
@@ -825,7 +818,7 @@ public:
   {
   }
 
-  virtual void set(Value *v)
+  void set(Value *v) override
   {
     Integer::set(v);
 
@@ -833,14 +826,14 @@ public:
       sw->update();
     }
   }
-  virtual void get(gint64 &i)
+  void get(gint64 &i) override
   {
     i = (sw) ? sw->get() : 0;
     Integer::set(i);
   }
-  virtual int set_break(ObjectBreakTypes bt = eBreakAny,
-                        ObjectActionTypes at = eActionHalt,
-                        Expression *expr = nullptr)
+  int set_break(ObjectBreakTypes bt = eBreakAny,
+                ObjectActionTypes at = eActionHalt,
+                Expression *expr = nullptr) override
   {
     (void) bt;
     (void) at;
@@ -852,7 +845,7 @@ public:
 
     return -1;  // FIXME
   }
-  virtual int clear_break()
+  int clear_break() override
   {
     if (sw) {
       sw->set_break(false);
@@ -875,7 +868,7 @@ public:
       sw(_sw)
   {
   }
-  virtual void set(Value *v)
+  void set(Value *v) override
   {
     Integer::set(v);
 
@@ -897,7 +890,7 @@ public:
       sw(_sw)
   {
   }
-  virtual void set(Value *v)
+  void set(Value *v) override
   {
     if (sw) {
       sw->update();
@@ -921,7 +914,7 @@ public:
   {
   }
 
-  virtual void set(Value *v)
+  void set(Value *v) override
   {
     if (!v) {
       return;
