@@ -27,13 +27,18 @@ License along with this library; if not, see
 /* Copyright (c) 1994 Ian King */
 
 #include <stdio.h>
-#include <ctype.h>
+#include <iostream>
+
+#include "hexutils.h"
 
 #include "exports.h"
-#include "pic-processor.h"
-#include "hexutils.h"
+#include "gpsim_classes.h"
+#include "gpsim_time.h"
+#include "modules.h"
+#include "processor.h"
 #include "program_files.h"
-
+#include "registers.h"
+#include "ui.h"
 
 //------------------------------------------------------------------------
 // IntelHexProgramFileType -- constructor
@@ -127,12 +132,10 @@ int IntelHexProgramFileType::read_le_word(FILE * file)
 unsigned int IntelHexProgramFileType::getword(FILE *file)
 {
   unsigned char lo = getbyte(file);
-  return ((getbyte(file) << 8) | lo);
+  return (getbyte(file) << 8) | lo;
 }
 
 
-#include "cmd_gpsim.h"
-
 int IntelHexProgramFileType::LoadProgramFile(Processor **pProcessor,
     const char * /* pFilename*/ ,
     FILE *inputfile, const char * /* pProcessorName */ )
