@@ -33,22 +33,27 @@ Boston, MA 02111-1307, USA.  */
 
 */
 
-#include <assert.h>
-#include <stdio.h>
 #include <unistd.h>
-#include <iostream>
-#include <iomanip>
-#include <string>
-#include <list>
+#include <cassert>
+#include <cstdarg>
 #include <cstdio>
+#include <cstring>
+#include <ctime>
+#include <iostream>
+#include <string>
+
 #include <sys/ioctl.h>
 #include <fcntl.h>
 #include <termios.h>
-#include <time.h>
-#include <assert.h>
 
-#include "../config.h"
+#include "14bit-registers.h"
+#include "errors.h"
+#include "gpsim_interface.h"
+#include "gpsim_object.h"
 #include "pic-processor.h"
+#include "processor.h"
+#include "registers.h"
+#include "ui.h"
 
 #include "icd.h"
 
@@ -84,7 +89,7 @@ public:
 
   explicit icd_Register(Processor *);
 
-  virtual REGISTER_TYPES isa()
+  REGISTER_TYPES isa() override
   {
     return replaced->isa();
   }
@@ -98,10 +103,10 @@ public:
     }
   }
 
-  virtual void put_value(unsigned int new_value);
-  virtual void put(unsigned int new_value);
-  virtual unsigned int get_value();
-  virtual unsigned int get();
+  void put_value(unsigned int new_value) override;
+  void put(unsigned int new_value) override;
+  unsigned int get_value() override;
+  unsigned int get() override;
 };
 
 
@@ -112,7 +117,7 @@ public:
 
   explicit icd_StatusReg(Processor *);
 
-  virtual REGISTER_TYPES isa()
+  REGISTER_TYPES isa() override
   {
     return replaced->isa();
   }
@@ -126,10 +131,10 @@ public:
     }
   }
 
-  virtual void put_value(unsigned int new_value);
-  virtual void put(unsigned int new_value);
-  virtual unsigned int get_value();
-  virtual unsigned int get();
+  void put_value(unsigned int new_value) override;
+  void put(unsigned int new_value) override;
+  unsigned int get_value() override;
+  unsigned int get() override;
 };
 
 
@@ -140,7 +145,7 @@ public:
 
   explicit icd_WREG(Processor *);
 
-  virtual REGISTER_TYPES isa()
+  REGISTER_TYPES isa() override
   {
     return replaced->isa();
   }
@@ -154,10 +159,10 @@ public:
     }
   }
 
-  virtual void put_value(unsigned int new_value);
-  virtual void put(unsigned int new_value);
-  virtual unsigned int get_value();
-  virtual unsigned int get();
+  void put_value(unsigned int new_value) override;
+  void put(unsigned int new_value) override;
+  unsigned int get_value() override;
+  unsigned int get() override;
 };
 
 
@@ -168,7 +173,7 @@ public:
 
   explicit icd_PCLATH(Processor *);
 
-  virtual REGISTER_TYPES isa()
+  REGISTER_TYPES isa() override
   {
     return replaced->isa();
   }
@@ -182,10 +187,10 @@ public:
     }
   }
 
-  virtual void put_value(unsigned int new_value);
-  virtual void put(unsigned int new_value);
-  virtual unsigned int get_value();
-  virtual unsigned int get();
+  void put_value(unsigned int new_value) override;
+  void put(unsigned int new_value) override;
+  unsigned int get_value() override;
+  unsigned int get() override;
 };
 
 
@@ -196,7 +201,7 @@ public:
 
   explicit icd_FSR(Processor *);
 
-  virtual REGISTER_TYPES isa()
+  REGISTER_TYPES isa() override
   {
     return replaced->isa();
   }
@@ -210,10 +215,10 @@ public:
     }
   }
 
-  virtual void put_value(unsigned int new_value);
-  virtual void put(unsigned int new_value);
-  virtual unsigned int get_value();
-  virtual unsigned int get();
+  void put_value(unsigned int new_value) override;
+  void put(unsigned int new_value) override;
+  unsigned int get_value() override;
+  unsigned int get() override;
 };
 
 
@@ -224,8 +229,8 @@ public:
 
   explicit icd_PC(Processor *);
 
-  virtual void put_value(unsigned int new_value);
-  virtual unsigned int get_value();
+  void put_value(unsigned int new_value) override;
+  unsigned int get_value() override;
 };
 
 
