@@ -19,15 +19,16 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
-#include <glib.h>	// for guint64
 #include <assert.h>
 #include <iostream>
+#include <memory>
 
 #include "intcon.h"
 #include "gpsim_classes.h"
 #include "pic-ioports.h"
 #include "pic-processor.h"
 #include "pir.h"
+#include "processor.h"
 #include "rcon.h"
 #include "trace.h"
 
@@ -87,6 +88,7 @@ void INTCON::put(unsigned int new_value)
 void INTCON::put_value(unsigned int new_value)
 {
     unsigned int diff = new_value ^ value.get();
+    fprintf(stderr, "RRR INTCON::%s value %02x diff %02x\n", __FUNCTION__, new_value, diff);
     Dprintf((" INTCON::%s value %02x\n", __FUNCTION__, new_value));
     value.put(new_value);
 
@@ -108,7 +110,7 @@ void INTCON::put_value(unsigned int new_value)
     // note: bit6 is not handled here because it is processor
     // dependent (e.g. EEIE for x84 and ADIE for x7x).
 
-    if (!in_interrupt)
+    if (value.get() & GIE) 
     {
         if ((value.get() >> 3)&value.get() & (T0IF | INTF | RBIF))
         {
@@ -145,7 +147,7 @@ void INTCON::peripheral_interrupt(bool hi_pri)
             cpu_pic->exit_sleep();
         }
 
-        if ((reg_val & GIE) &&  !in_interrupt)
+        if ((reg_val & GIE) )
         {
             cpu_pic->BP_set_interrupt();
         }
@@ -160,23 +162,42 @@ INTCON2::INTCON2(Processor *pCpu, const char *pName, const char *pDesc)
 {
 }
 
+INTCON2::~INTCON2()
+{
+    bitsink_list.clear();
+}
+
 
 bool INTCON2::assignBitSink(unsigned int bitPosition, BitSink *pBS)
 {
     if (bitPosition == 7)
     {
-        m_bsRBPU = pBS;
+  	for(int i=0; i<(int)bitsink_list.size(); i++)
+	{
+	    if (bitsink_list[i] == pBS)
+	    {
+		fprintf(stderr, "INTCON2::assignBitSink pBS=%p already exists\n", pBS);
+		return true;
+	    }
+        }
+	bitsink_list.push_back(pBS);
     }
 
     return true;
 }
 
 
-bool INTCON2::releaseBitSink(unsigned int bitPosition, BitSink *)
+bool INTCON2::releaseBitSink(unsigned int bitPosition, BitSink *pBS)
 {
     if (bitPosition == 7)
     {
-        m_bsRBPU = 0;
+  	for(int i=0; i<(int)bitsink_list.size(); i++)
+	{
+	    if (bitsink_list[i] == pBS)
+	    {
+		bitsink_list.erase(bitsink_list.begin() + i);
+	    }
+        }
     }
 
     return true;
@@ -190,9 +211,12 @@ void INTCON2::put_value(unsigned int new_value)
     unsigned int old_value = value.get();
     value.put(new_value);
 
-    if ((old_value ^ new_value) & RBPU  && m_bsRBPU)
+    if ((old_value ^ new_value) & RBPU  && bitsink_list.size())
     {
-        m_bsRBPU->setSink((new_value & RBPU) != 0);
+  	for(int i=0; i<(int)bitsink_list.size(); i++)
+	{
+	    bitsink_list[i]->setSink((new_value & RBPU) != 0);
+	}
     }
 }
 
@@ -280,7 +304,7 @@ void INTCON_14_PIR::put_value(unsigned int new_value)
         portGReg->setIOCif();
     }
 
-    if (value.get() & GIE  &&  !in_interrupt &&
+    if (value.get() & GIE  && 
             (((value.get() >> 3) & value.get() & (T0IF | INTF | IOCIF)) ||
              (value.get() & PEIE && check_peripheral_interrupt())))
     {
@@ -326,9 +350,10 @@ void INTCON_14_PIR::aocxf_val(IOCxF *ptr, unsigned int val)
 
     if (!found)
     {
-        aocxf_list.push_back(aocxf());
-        aocxf_list[i].ptr_iocxf = ptr;
-        aocxf_list[i].val = val;
+        aocxf ao;
+        ao.ptr_iocxf = ptr;
+        ao.val = val;
+        aocxf_list.push_back(ao);
     }
 
     set_rbif(sum);
@@ -373,7 +398,7 @@ void INTCON_16::peripheral_interrupt(bool hi_pri)
         //      cout << "peripheral interrupt, priority " << hi_pri << "\n";
         if (hi_pri)
         {
-            if (value.get() & GIEH &&  !in_interrupt)
+            if (value.get() & GIEH ) 
             {
                 set_interrupt_vector(INTERRUPT_VECTOR_HI);
                 cpu_pic->BP_set_interrupt();
@@ -382,7 +407,7 @@ void INTCON_16::peripheral_interrupt(bool hi_pri)
         }
         else
         {
-            if ((value.get() & (GIEH | GIEL)) == (GIEH | GIEL) &&  !in_interrupt)
+            if ((value.get() & (GIEH | GIEL)) == (GIEH | GIEL) )
             {
                 set_interrupt_vector(INTERRUPT_VECTOR_LO);
                 cpu_pic->BP_set_interrupt();
@@ -392,7 +417,7 @@ void INTCON_16::peripheral_interrupt(bool hi_pri)
     }
     else
     {
-        if ((value.get() & (GIE | XXIE)) == (GIE | XXIE) &&  !in_interrupt)
+        if ((value.get() & (GIE | XXIE)) == (GIE | XXIE) ) 
         {
             cpu_pic->BP_set_interrupt();
         }
@@ -408,7 +433,7 @@ void INTCON_16::general_interrupt(bool hi_pri)
 
     if (hi_pri || !(rcon->value.get() & RCON::IPEN))
     {
-        if (value.get() & GIEH &&  !in_interrupt)
+        if (value.get() & GIEH ) 
         {
             set_interrupt_vector(INTERRUPT_VECTOR_HI);
             cpu_pic->BP_set_interrupt();
@@ -416,7 +441,7 @@ void INTCON_16::general_interrupt(bool hi_pri)
     }
     else
     {
-        if ((value.get() & (GIEH | GIEL)) == (GIEH | GIEL)  &&  !in_interrupt)
+        if ((value.get() & (GIEH | GIEL)) == (GIEH | GIEL)) 
         {
             set_interrupt_vector(INTERRUPT_VECTOR_LO);
             cpu_pic->BP_set_interrupt();
@@ -546,7 +571,7 @@ void INTCON_16::put_value(unsigned int new_value)
         // Use interrupt priorities
         // %%%FIXME%%% ***BUG*** - does not attempt to look for peripheral interrupts
 
-        if (0 == (value.get() & GIEH) ||  in_interrupt)
+        if (0 == (value.get() & GIEH)) 
         {
             return;  // Interrupts are disabled
         }
@@ -591,7 +616,7 @@ void INTCON_16::put_value(unsigned int new_value)
         // ignore interrupt priorities
         set_interrupt_vector(INTERRUPT_VECTOR_HI);
 
-        if (value.get() & GIE &&  !in_interrupt)
+        if (value.get() & GIE) 
         {
             if (((value.get() >> 3)&value.get()) & (T0IF | INTF | RBIF))
             {
