@@ -30,24 +30,29 @@ License along with this library; if not, see
 //
 //-------------------------------------------------------------------
 
-#include <stdio.h>
+#include <glib.h>
+#include <string.h>
+#include <iostream>
+#include <list>
+
+#include "interface.h"
 
 #include "../config.h"
 #define GPSIM_VERSION VERSION
-#include "gpsim_def.h"
-
-#include "sim_context.h"
-#include "processor.h"
-#include "xref.h"
-#include "interface.h"
-#include "trace.h"
-#include "eeprom.h"
-#include "icd.h"
 
 #include "cmd_manager.h"
-#include "clock_phase.h"
+#include "gpsim_classes.h"
+#include "gpsim_interface.h"
+#include "gpsim_time.h"
+#include "icd.h"
+#include "processor.h"
+#include "sim_context.h"
+#include "trace.h"
+#include "ui.h"
 
-#include <iostream>
+class Integer;
+class Module;
+class Stimulus_Node;
 
 extern Integer *verbosity;  // in ../src/init.cc
 
@@ -64,7 +69,7 @@ unsigned int gpsim_is_initialized = 0;
 gpsimInterface gi;
 
 // create an instance of inline get_interface() method by taking its address
-gpsimInterface &(*dummy_gi)(void) = get_interface;
+gpsimInterface &(*dummy_gi)() = get_interface;
 
 //------------------------------------------------------------------------
 // Temporary -- provide a flag to inihibit multithreaded support.
@@ -72,6 +77,7 @@ bool gUsingThreads()
 {
   return false;
 }
+
 //---------------------------------------------------------------------------
 //   void gpsim_set_bulk_mode(int flag)
 //---------------------------------------------------------------------------
@@ -127,7 +133,7 @@ ProcessorInterface::ProcessorInterface(Processor *new_cpu)
 //
 //
 //--------------------------------------------------------------------------
-Interface::Interface(gpointer new_object)
+Interface::Interface(void * new_object)
   : interface_id(0), objectPTR(new_object)
 {
 }
@@ -156,17 +162,8 @@ Interface::Interface(gpointer new_object)
 
 void gpsimInterface::update()
 {
-  GSList *external_interfaces = interfaces;
-
-  while (external_interfaces) {
-
-    if (external_interfaces->data) {
-      Interface *an_interface = (Interface *)(external_interfaces->data);
-
-      an_interface->Update(an_interface->objectPTR);
-    }
-
-    external_interfaces = external_interfaces->next;
+  for (const auto &an_interface : interfaces) {
+    an_interface->Update(an_interface->objectPTR);
   }
 }
 
@@ -200,13 +197,9 @@ void update_gui()
 }
 
 gpsimInterface::gpsimInterface()
+  : socket_interface(nullptr), interface_seq_number(0),
+    future_cycle(0), mbSimulating(false), mbUseGUI(false)
 {
-  interfaces = nullptr;
-  future_cycle = 0;
-  interface_seq_number = 0;
-  socket_interface = nullptr;
-  mbSimulating = false;
-  mbUseGUI = false;
 }
 
 ISimConsole & gpsimInterface::GetConsole()
@@ -227,51 +220,26 @@ ISimConsole & gpsimInterface::GetConsole()
 // if there's a xref object associated with the register gpsim will
 // then notify the gui (or module) through the xref.
 
-void gpsimInterface::update_object(gpointer xref, int new_value)
+void gpsimInterface::update_object(void *xref, int new_value)
 {
-  GSList *interface_list = interfaces;
-
-  while (interface_list) {
-
-    if (interface_list->data) {
-      Interface *an_interface = (Interface *)(interface_list->data);
-      an_interface->UpdateObject(xref, new_value);
-    }
-
-    interface_list = interface_list->next;
+  for (const auto &an_interface : interfaces) {
+    an_interface->UpdateObject(xref, new_value);
   }
 }
 
-void gpsimInterface::remove_object(gpointer xref)
+void gpsimInterface::remove_object(void *xref)
 {
-  GSList *interface_list = interfaces;
-
-  while (interface_list) {
-
-    if (interface_list->data) {
-      Interface *an_interface = (Interface *)(interface_list->data);
-
-      an_interface->RemoveObject(xref);
-    }
-
-    interface_list = interface_list->next;
+  for (const auto &an_interface : interfaces) {
+    an_interface->RemoveObject(xref);
   }
 }
 
 void gpsimInterface::simulation_has_stopped()
 {
-  GSList *interface_list = interfaces;
-
   profile_keeper.catchup();     // FIXME: remove this!
 
-  while (interface_list) {
-
-    if (interface_list->data) {
-      Interface *an_interface = (Interface *)(interface_list->data);
-      an_interface->SimulationHasStopped(an_interface->objectPTR);
-    }
-
-    interface_list = interface_list->next;
+  for (const auto &an_interface : interfaces) {
+    an_interface->SimulationHasStopped(an_interface->objectPTR);
   }
 }
 
@@ -302,19 +270,19 @@ void gpsimInterface::advance_simulation(eAdvancementModes nAdvancement)
 {
   switch (nAdvancement)
   {
-  case eAdvanceNextInstruction:
-    {
-      Processor *cpu = get_active_cpu();
+    case eAdvanceNextInstruction:
+      {
+        Processor *cpu = get_active_cpu();
 
-      if (cpu)
-        cpu->step_over();
+        if (cpu)
+          cpu->step_over();
 
-    }
-    break;
-  case eAdvanceNextCycle:
-  case eAdvanceNextCall:
-  case eAdvanceNextReturn:
-    break;
+      }
+      break;
+    case eAdvanceNextCycle:
+    case eAdvanceNextCall:
+    case eAdvanceNextReturn:
+      break;
   }
 }
 
@@ -341,65 +309,29 @@ void gpsimInterface::setGUImode(bool bnewGUImode)
 
 void gpsimInterface::new_processor(Processor *new_cpu)
 {
-  GSList *interface_list = interfaces;
-
-  while (interface_list) {
-
-    if (interface_list->data) {
-      Interface *an_interface = (Interface *)(interface_list->data);
-
-      an_interface->NewProcessor(new_cpu);
-    }
-
-    interface_list = interface_list->next;
+  for (const auto &an_interface : interfaces) {
+    an_interface->NewProcessor(new_cpu);
   }
 }
 
 void gpsimInterface::new_module(Module *module)
 {
-  GSList *interface_list = interfaces;
-
-  while (interface_list) {
-
-    if (interface_list->data) {
-      Interface *an_interface = (Interface *)(interface_list->data);
-
-      an_interface->NewModule(module);
-    }
-
-    interface_list = interface_list->next;
+  for (const auto &an_interface : interfaces) {
+    an_interface->NewModule(module);
   }
 }
 
 void gpsimInterface::node_configuration_changed(Stimulus_Node *node)
 {
-  GSList *interface_list = interfaces;
-
-  while (interface_list) {
-
-    if (interface_list->data) {
-      Interface *an_interface = (Interface *)(interface_list->data);
-
-      an_interface->NodeConfigurationChanged(node);
-    }
-
-    interface_list = interface_list->next;
+  for (const auto &an_interface : interfaces) {
+    an_interface->NodeConfigurationChanged(node);
   }
 }
 
 void gpsimInterface::new_program(Processor *cpu)
 {
-  GSList *interface_list = interfaces;
-
-  while (interface_list) {
-
-    if (interface_list->data) {
-      Interface *an_interface = (Interface *)(interface_list->data);
-
-      an_interface->NewProgram(cpu);
-    }
-
-    interface_list = interface_list->next;
+  for (const auto &an_interface : interfaces) {
+    an_interface->NewProgram(cpu);
   }
 }
 
@@ -408,8 +340,7 @@ unsigned int gpsimInterface::add_interface(Interface *new_interface)
   interface_seq_number++;
 
   new_interface->set_id(interface_seq_number);
-
-  gi.interfaces = g_slist_append(gi.interfaces, new_interface);
+  interfaces.push_back(new_interface);
 
   return interface_seq_number;
 }
@@ -419,8 +350,7 @@ unsigned int gpsimInterface::prepend_interface(Interface *new_interface)
   interface_seq_number++;
 
   new_interface->set_id(interface_seq_number);
-
-  gi.interfaces = g_slist_prepend(gi.interfaces, new_interface);
+  interfaces.push_front(new_interface);
 
   return interface_seq_number;
 }
@@ -435,28 +365,17 @@ unsigned int gpsimInterface::add_socket_interface(Interface *new_interface)
 
 void gpsimInterface::remove_interface(unsigned int interface_id)
 {
-  GSList *interface_list = interfaces;
+  for (auto iter = interfaces.begin(); iter != interfaces.end(); ++iter) {
+    Interface *an_interface = *iter;
+    if (an_interface->get_id() == interface_id) {
+      if (an_interface == socket_interface)
+        socket_interface = nullptr;
 
-  while (interface_list) {
-
-    if (interface_list->data) {
-      Interface *an_interface = (Interface *)(interface_list->data);
-
-      if (an_interface->get_id() == interface_id) {
-
-        gi.interfaces = g_slist_remove(gi.interfaces, an_interface);
-        if (an_interface == socket_interface)
-          socket_interface = nullptr;
-
-        delete an_interface;
-        an_interface = nullptr;
-        return;
-      }
+      interfaces.erase(iter);
+      delete an_interface;
+      return;
     }
-
-    interface_list = interface_list->next;
   }
-  return;
 }
 
 void gpsimInterface::set_update_rate(guint64 _update_rate)
