@@ -21,16 +21,13 @@ License along with this library; if not, see
 
 #include "modules.h"
 
-#include <ctype.h>
-#include <stdlib.h>
-#include <string>
-#include <list>
 #include <iostream>
-
-#include "../config.h"
+#include <list>
+#include <string>
+#include <utility>
 
 #ifndef _WIN32
-#include <dlfcn.h>
+
 #if !defined(_MAX_PATH)
 #define _MAX_PATH 1024
 #endif
@@ -47,10 +44,10 @@ License along with this library; if not, see
 #undef interface
 #endif
 
-#include "error.h"
+#include "errors.h"
 #include "gpsim_interface.h"
-#include "stimuli.h"
 #include "symbol.h"
+#include "value.h"
 #include "xref.h"
 #include "packages.h"
 #include "cmd_manager.h"
@@ -72,17 +69,12 @@ ModuleLibraries_t ModuleLibraries;
 
 static void AddModuleType(const char *pName, Module_Types *pType)
 {
-  std::string sName = pName;
-  ModuleTypeInfo_t::iterator mti = ModuleTypes.find(sName);
-
-  if (mti == ModuleTypes.end()) {
-    ModuleTypes[sName] = pType;
-  }
+  ModuleTypes.emplace(pName, pType);
 }
 
 
-DynamicModuleLibraryInfo::DynamicModuleLibraryInfo(std::string &sCanonicalName,
-    std::string &sUserSuppliedName,
+DynamicModuleLibraryInfo::DynamicModuleLibraryInfo(const std::string &sCanonicalName,
+    const std::string &sUserSuppliedName,
     void   *pHandle)
   : m_sCanonicalName(sCanonicalName),
     m_sUserSuppliedName(sUserSuppliedName),
@@ -132,7 +124,7 @@ DynamicModuleLibraryInfo::DynamicModuleLibraryInfo(std::string &sCanonicalName,
 
 //========================================================================
 
-void MakeCanonicalName(std::string &sPath, std::string &sName)
+void MakeCanonicalName(const std::string &sPath, std::string &sName)
 {
 #ifdef _WIN32
   sName = sPath;
@@ -142,7 +134,7 @@ void MakeCanonicalName(std::string &sPath, std::string &sName)
 }
 
 
-int ModuleLibrary::LoadFile(std::string &fName)
+int ModuleLibrary::LoadFile(const std::string &fName)
 {
   const char *pszError;
   bool bReturn = false;
@@ -154,8 +146,8 @@ int ModuleLibrary::LoadFile(std::string &fName)
 
   if (mli == ModuleLibraries.end()) {
     void *handle = ::load_library(sPath.c_str(), &pszError);
+
     if (handle == nullptr) {
-//#ifdef THROW
       char cw[_MAX_PATH];
       getcwd(cw, sizeof(cw));
 
@@ -165,7 +157,6 @@ int ModuleLibrary::LoadFile(std::string &fName)
 
       free_error_message(pszError);
       throw Error(error_string);
-//#endif //THROW
 
     } else {
       ModuleLibraries[sName] = new DynamicModuleLibraryInfo(fName, sName, handle);
@@ -181,7 +172,7 @@ int ModuleLibrary::LoadFile(std::string &fName)
 }
 
 
-int ModuleLibrary::InstantiateObject(std::string &sObjectName, std::string &sInstantiatedName)
+int ModuleLibrary::InstantiateObject(const std::string &sObjectName, const std::string &sInstantiatedName)
 {
   ModuleTypeInfo_t::iterator mti = ModuleTypes.find(sObjectName);
 
@@ -192,7 +183,7 @@ int ModuleLibrary::InstantiateObject(std::string &sObjectName, std::string &sIns
     // Tell the gui or any modules that are interfaced to gpsim
     // that a new module has been added.
     gi.new_module(pModule);
-    return pModule != 0;
+    return pModule != nullptr;
   }
 
   return 0;
@@ -201,7 +192,7 @@ int ModuleLibrary::InstantiateObject(std::string &sObjectName, std::string &sIns
 
 void ModuleLibrary::ListLoadableModules()
 {
-  for (auto &mt : ModuleTypes) {
+  for (const auto &mt : ModuleTypes) {
     std::cout << ' ' << mt.first << '\n';
   }
 }
@@ -257,11 +248,6 @@ static void dumpOneSymbol(const SymbolEntry_t &sym)
 
 Module::~Module()
 {
-  for (auto &si : m_scripts) {
-    ModuleScript *pMS = si.second;
-    delete pMS;
-  }
-
   deleteSymbol("xpos");
   deleteSymbol("ypos");
   /*
@@ -423,16 +409,11 @@ IOPIN *Module::get_pin(unsigned int pin_number)
 //
 // Add a command line command to a Module Script.
 //-------------------------------------------------------------------
-void Module::add_command(std::string &script_name, std::string &command)
+void Module::add_command(const std::string &script_name, const std::string &command)
 {
-  ModuleScript *script = m_scripts[script_name];
+  auto script = m_scripts.emplace(script_name, ModuleScript(script_name)).first;
 
-  if (!script) {
-    script = new ModuleScript(script_name);
-    m_scripts[script_name] = script;
-  }
-
-  script->add_command(command);
+  script->second.add_command(command);
 }
 
 
@@ -440,15 +421,15 @@ void Module::add_command(std::string &script_name, std::string &command)
 // Module::run_script - execute a gpsim command line script
 //
 //-------------------------------------------------------------------
-void Module::run_script(std::string &script_name)
+void Module::run_script(const std::string &script_name)
 {
-  ModuleScript *script = m_scripts[script_name];
+  auto script = m_scripts.find(script_name);
 
-  if (script) {
+  if (script != m_scripts.end()) {
     ICommandHandler *pCli = CCommandManager::GetManager().find("gpsimCLI");
 
     if (pCli) {
-      script->run(pCli);
+      script->second.run(*pCli);
     }
   }
 }
@@ -457,51 +438,23 @@ void Module::run_script(std::string &script_name)
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
 Module::ModuleScript::ModuleScript(const std::string &name_)
-  : name(name_)
+//  : name(name_)
 {
 }
 
 
-//-------------------------------------------------------------------
-//-------------------------------------------------------------------
-Module::ModuleScript::~ModuleScript()
-{
-  for (auto & command : m_commands) {
-    delete command;
-  }
-}
-
-
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
 void Module::ModuleScript::add_command(const std::string &command)
 {
-  std::string *new_command = new std::string(command);
-  m_commands.push_back(new_command);
+  m_commands.push_back(command);
 }
 
 
 //-------------------------------------------------------------------
 //-------------------------------------------------------------------
-void Module::ModuleScript::run(ICommandHandler *pCommandHandler)
+void Module::ModuleScript::run(ICommandHandler &pCommandHandler)
 {
-  if (!pCommandHandler) {
-    return;
-  }
-
-  pCommandHandler->ExecuteScript(m_commands, nullptr);
+  pCommandHandler.ExecuteScript(m_commands, nullptr);
 }
 
-
-//-------------------------------------------------------------------
-//-------------------------------------------------------------------
-void Module::ModuleScript::concatenate(ModuleScript *pOtherScript)
-{
-  if (!pOtherScript) {
-    return;
-  }
-
-  for (auto &command : pOtherScript->m_commands) {
-    m_commands.push_back(command);
-  }
-}
