@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017,2018 Roy R. Rankin
+   Copyright (C) 2017,2018, 2020 Roy R. Rankin
 This file is part of the libgpsim library of gpsim
 
 This library is free software; you can redistribute it and/or
@@ -30,8 +30,9 @@ License along with this library; if not, see
 
 #include <assert.h>
 #include <stdio.h>
+#include <algorithm>
 
-#include "pic-processor.h"
+#include "gpsim_time.h"
 #include "nco.h"
 #include "clc.h"
 #include "cwg.h"
@@ -45,15 +46,15 @@ class NCO_Interface: public Interface
 {
 public:
     explicit NCO_Interface(NCO * _nco)
-        : Interface((gpointer *) _nco), nco(_nco)
+        : Interface((void **) _nco), nco(_nco)
     {
     }
 
-    virtual void SimulationHasStopped(gpointer /* object */)
+    void SimulationHasStopped(void * /* object */) override
     {
         nco->current_value();
     }
-    virtual void Update(gpointer object)
+    void Update(void *object) override
     {
         SimulationHasStopped(object);
     }
@@ -79,11 +80,11 @@ public:
     {
         m_state = _state;
     }
-    virtual char getState()
+    char getState() override
     {
         return m_state;
     }
-    virtual void release()
+    void release() override
     {
         m_nco->releasePinSource(m_pin);
     }
@@ -104,11 +105,11 @@ public:
     {
     }
 
-    virtual void setSinkState(char new3State)
+    void setSinkState(char new3State) override
     {
         m_nco->setState(new3State);
     }
-    virtual void release()
+    void release() override
     {
         delete this;
     }
@@ -117,6 +118,25 @@ private:
     NCO * m_nco;
 };
 
+class NCO_DATA_RECEIVER : public DATA_RECEIVER
+{
+public:
+    explicit NCO_DATA_RECEIVER(NCO *pt, const char *_name) :
+        DATA_RECEIVER(_name), pt_nco(pt)
+    {}
+    virtual ~NCO_DATA_RECEIVER(){}
+    void rcv_data(int v1, int v2) override;
+
+private:
+    NCO *pt_nco;
+};
+
+void NCO_DATA_RECEIVER::rcv_data(int v1, int v2)
+{
+        pt_nco->link_nco(v1, v2);
+}
+
+
 
 NCO::NCO(Processor * pCpu):
     nco1con(this, pCpu, "nco1con", "NCOx Control Register"),
@@ -129,11 +149,8 @@ NCO::NCO(Processor * pCpu):
     cpu(pCpu), inc(1)
 {
     acc_hold[0] = acc_hold[1] = acc_hold[2] = 0;
-
-    for (int i = 0; i < 4; i++)
-    {
-        m_clc[i] = nullptr;
-    }
+    std::fill_n(m_clc, 4, nullptr);
+    pt_nco_data_receiver = new NCO_DATA_RECEIVER(this, "nco_data_rcv");
 }
 
 
@@ -141,6 +158,7 @@ NCO::~NCO()
 {
     delete NCO1src;
     delete nco_interface;
+    delete pt_nco_data_receiver;
 }
 
 
@@ -154,6 +172,12 @@ void NCO::update_ncocon(unsigned int diff)
     {
         Dprintf(("NCO::update_ncocon ON nco1con=0x%x nco1clk=0x%x\n", value,
                  nco1clk.value.get()));
+
+        if (clock_src() == LC1_OUT)
+        {
+	    assert(clc_data_server);
+	    clc_data_server->attach_data(pt_nco_data_receiver);
+        }
         pulseWidth = 0;
 
         if (!nco_interface)
@@ -175,6 +199,11 @@ void NCO::update_ncocon(unsigned int diff)
     {
         Dprintf(("NCO::update_ncocon OFF nco1con=0x%x nco1clk=0x%x acc=0x%x\n", value,
                  nco1clk.value.get(), acc));
+        if (clock_src() == LC1_OUT)
+        {
+	    assert(clc_data_server);
+	    clc_data_server->detach_data(pt_nco_data_receiver);
+        }
         pulseWidth = 0;
         oeNCO1(false);
         current_value();
@@ -360,7 +389,7 @@ void NCO::callback()
 // Use callback to simulate NCO driven by internal clock
 void NCO::simulate_clock(bool on)
 {
-    Dprintf(("on=%d inc=%u clock=%s\n", on, inc, clock_src() ? "Fosc" : "HFINTOSC"));
+    Dprintf(("on=%d inc=%u clock=%s\n", on, inc, clk_src_name()));
 
     if (on && inc)
     {
@@ -545,7 +574,9 @@ void NCO::update_ncoclk(unsigned int diff)
             simulate_clock(false);
         }
 
-        Dprintf(("clk=%d\n", clock_src()));
+        Dprintf(("clock_src=%s\n", clk_src_name()));
+        assert(clc_data_server);
+	clc_data_server->detach_data(pt_nco_data_receiver);
 
         switch (clock_src())
         {
@@ -558,6 +589,7 @@ void NCO::update_ncoclk(unsigned int diff)
             break;
 
         case LC1_OUT:
+	    clc_data_server->attach_data(pt_nco_data_receiver);
             break;
 
         case NCO1CLK:
@@ -645,15 +677,16 @@ void NCO::setNCOxPin(PinModule * pNCOx)
 
 
 // link from Configurable Logic Cell
-void NCO::link_nco(bool level, char /* index */)
+void NCO::link_nco(bool level, char  index )
 {
+
     // Active?
-    if (clock_src() == LC1_OUT)
+    if (clock_src() == LC1_OUT && index == 0)
     {
         Dprintf(("NCO::link_nco level=%d index=%d edge=%d\n", level, index,
-                 (bool)(level & !CLKstate)));
+                 (bool)(level && !CLKstate)));
 
-        if (level & !CLKstate)  	// new edge
+        if (level && !CLKstate)  	// new edge
         {
             NCOincrement();
         }
@@ -709,7 +742,7 @@ void NCO::set_acc_buf()
 */
 void NCO::newINCL()
 {
-    Dprintf(("newINCL clock=%d\n", clock_src()));
+    Dprintf(("newINCL clock_src=%s\n", clk_src_name()));
 
     // If NCO is not enables, inc buffer loaded immediately
     if (!(nco1con.value.get() & NxEN))
@@ -782,6 +815,29 @@ void NCO::releasePinSource(PinModule * pin)
     }
 }
 
+const char *NCO::clk_src_name()
+{
+    switch(clock_src())
+    {
+    case HFINTOSC:
+        return "HFINTOSC";
+        break;
+
+    case FOSC:
+        return "FOSC";
+        break;
+
+    case LC1_OUT:
+        return "LC1_OUT";
+        break;
+
+    case NCO1CLK:
+        return "NCO1CLK";
+        break;
+    }
+    return "UNKNOWN";
+}
+
 
 NCOxCON::NCOxCON(NCO * pt, Processor * pCpu, const char *pName,
                  const char *pDesc)
