@@ -1,9 +1,11 @@
 
+#include <glib.h>
+
 #include <cstdio>
 
 #include "operator.h"
+#include "breakpoints.h"
 #include "errors.h"
-#include "symbol.h"
 #include "processor.h"
 #include "registers.h"
 #include "value.h"
@@ -82,17 +84,14 @@ std::string BinaryOperator::toString()
 
 Value *BinaryOperator::evaluate()
 {
+  leftExpr->get_address = get_address;
+  rightExpr->get_address = get_address;
   Value *left = leftExpr->evaluate();
   Value *right = rightExpr->evaluate();
   Value *out = applyOp(left, right);
 
-  if (left) {
-    delete left;
-  }
-
-  if (right) {
-    delete right;
-  }
+  delete left;
+  delete right;
 
   return out;
 }
@@ -205,13 +204,12 @@ OpAbstractRange::~OpAbstractRange()
 
 Value* OpAbstractRange::applyOp(Value* lVal, Value* rVal)
 {
-  Value* result = nullptr;
   Integer* lInteger = Integer::typeCheck(lVal, showOp());
   Integer* rInteger = Integer::typeCheck(rVal, showOp());
   int left = (int)lInteger->getVal();
   int right = (int)rInteger->getVal();
-  result = new AbstractRange(left, right);
-  return result;
+
+  return new AbstractRange(left, right);
 }
 
 
