@@ -18,6 +18,14 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
+/** \author G.Schielke
+ * \version 0.31.1gs
+ * \date 2022-01-26
+ * 
+ * PIE1 -> pie1
+ * PIR1v1:: -> PIR1v12f::
+ * add CCP1IF to PIR1v12f
+*/
 
 //
 // p12f6xx
@@ -92,22 +100,24 @@ public:
         CMIF	= 1 << 3,
         CLC1IF  = 1 << 3,	// For 10F32x
         NCO1IF  = 1 << 4,	// For 10F32x
+        /* 0.31.1gs */
+        CCP1IF  = 1 << 5,   // for 12F683
         ADIF	= 1 << 6,
         EEIF	= 1 << 7
     };
 
     //------------------------------------------------------------------------
 
-    virtual void set_tmr1if()
+    virtual void set_tmr1if() override
     {
         put(get() | TMR1IF);
     }
-    virtual void set_tmr2if()
+    virtual void set_tmr2if() override
     {
         put(get() | TMR2IF);
     }
 
-    virtual void set_cmif()
+    virtual void set_cmif() override
     {
         trace.raw(write_trace.get() | value.get());
         value.put(value.get() | CMIF);
@@ -129,7 +139,7 @@ public:
         }
     }
 
-    virtual void set_nco1if()
+    virtual void set_nco1if() override
     {
         unsigned int pievalue = value.get();
 
@@ -145,12 +155,12 @@ public:
         }
     }
 
-    virtual void set_c1if()
+    virtual void set_c1if() override
     {
         set_cmif();
     }
 
-    virtual void set_eeif()
+    virtual void set_eeif() override
     {
         trace.raw(write_trace.get() | value.get());
         value.put(value.get() | EEIF);
@@ -161,7 +171,7 @@ public:
         }
     }
 
-    virtual void set_adif()
+    virtual void set_adif() override
     {
         trace.raw(write_trace.get() | value.get());
         value.put(value.get() | ADIF);
@@ -213,7 +223,7 @@ bool P12F629::set_config_word(unsigned int address, unsigned int cfg_word)
             unassignMCLRPin();
         }
 
-        wdt.initialize((cfg_word & WDTEN) == WDTEN);
+        wdt->initialize((cfg_word & WDTEN) == WDTEN);
 
         if ((cfg_word & (FOSC2 | FOSC1)) == 0x04)   // internal RC OSC
         {
@@ -231,7 +241,8 @@ P12F629::P12F629(const char *_name, const char *desc)
     : _14bit_processor(_name, desc),
       intcon_reg(this, "intcon", "Interrupt Control"),
       comparator(this),
-      pie1(this, "PIE1", "Peripheral Interrupt Enable"),
+      /* 0.31.1gs */
+      pie1(this, "pie1", "Peripheral Interrupt Enable"),
       t1con(this, "t1con", "TMR1 Control"),
       tmr1l(this, "tmr1l", "TMR1 Low"),
       tmr1h(this, "tmr1h", "TMR1 High"),
@@ -323,7 +334,8 @@ void P12F629::create_sfr_map()
     add_sfr_register(pir1,   0x0c, RegisterValue(0, 0), "pir1");
     tmr1l.tmrh = &tmr1h;
     tmr1l.t1con = &t1con;
-    tmr1l.setInterruptSource(new InterruptSource(pir1, PIR1v1::TMR1IF));
+    /* 0.31.1gs */
+    tmr1l.setInterruptSource(new InterruptSource(pir1, PIR1v12f::TMR1IF));
     tmr1h.tmrl  = &tmr1l;
     t1con.tmrl  = &tmr1l;
     tmr1l.setIOpin(&(*m_gpio)[5]);
@@ -541,6 +553,9 @@ P12F683::P12F683(const char *_name, const char *desc)
     internal_osc = false;
     pir1->valid_bits |= PIR1v12f::TMR2IF;
     pir1->writable_bits |= PIR1v12f::TMR2IF;
+    /* 0.31.1gs */
+    pir1->valid_bits |= PIR1v12f::CCP1IF;
+    pir1->writable_bits |= PIR1v12f::CCP1IF;
 }
 
 
@@ -593,7 +608,8 @@ void P12F683::create_sfr_map()
     tmr2.t2con  = &t2con;
     tmr2.add_ccp(&ccp1con);
     pr2.tmr2    = &tmr2;
-    ccp1con.setCrosslinks(&ccpr1l, pir1, PIR1v1::CCP1IF, &tmr2);
+    /* 0.31.1gs */
+    ccp1con.setCrosslinks(&ccpr1l, pir1, PIR1v12f::CCP1IF, &tmr2);
     ccp1con.setIOpin(&((*m_gpio)[2]));
     ccpr1l.ccprh  = &ccpr1h;
     ccpr1l.tmrl   = &tmr1l;
@@ -602,20 +618,21 @@ void P12F683::create_sfr_map()
     comparator.cmcon.set_tmrl(&tmr1l);
     comparator.cmcon1.set_tmrl(&tmr1l);
     add_sfr_register(&comparator.cmcon1, 0x1a, RegisterValue(2, 0), "cmcon1");
-    wdt.set_timeout(1.0 / 31000.0);
+    wdt->set_timeout(1.0 / 31000.0);
 }
 
 
 P10F32X::P10F32X(const char *_name, const char *desc)
     : _14bit_processor(_name, desc),
       intcon_reg(this, "intcon", "Interrupt Control"),
-      pie1(this, "PIE1", "Peripheral Interrupt Enable"),
+      /* 0.31.1gs */
+      pie1(this, "pie1", "Peripheral Interrupt Enable"),
       t2con(this, "t2con", "TMR2 Control"),
       tmr2(this, "tmr2", "TMR2 Register"),
       pr2(this, "pr2", "Timer2 Period Register"),
       pcon(this, "pcon", "pcon"),
       ansela(this, "ansela", "Analog Select"),
-      fvrcon(this, "fvrcon", "Voltage reference control register", 0xf3, 0x00),
+      fvrcon(this, "fvrcon", "Voltage reference control register", 0xf3),
       borcon(this, "borcon", "Brown-out reset control register"),
       wdtcon(this, "wdtcon", "WDT Control", 0x3f),
       adcon0(this, "adcon", "A2D Control 0"),
@@ -629,7 +646,8 @@ P10F32X::P10F32X(const char *_name, const char *desc)
       pwm2dch(this, "pwm2dch", "PWM DUTY CYCLE HIGH BITS"),
       pm_rw(this), cwg(this), nco(this), clcdata(this),
       clc1(this, 0, &clcdata),
-      vregcon(this, "vregcon", "Voltage Regulator Control Register")
+      vregcon(this, "vregcon", "Voltage Regulator Control Register"),
+      lfintosc(31000., CLC::LFINTOSC)
 
 {
     m_iocaf = new IOCxF(this, "iocaf", "Interrupt-On-Change flag Register", 0x0f);
@@ -657,6 +675,7 @@ P10F32X::P10F32X(const char *_name, const char *desc)
 P10F32X::~P10F32X()
 {
     delete_file_registers(0x40, ram_top);
+    adcon1.detach_fvr();
     remove_sfr_register(&tmr2);
     remove_sfr_register(&t2con);
     remove_sfr_register(&pr2);
@@ -795,9 +814,9 @@ void P10F32X::create_sfr_map()
     add_sfr_registerR(&nco.nco1clk,  0x2e, RegisterValue(0, 0));
     add_sfr_registerR(&wdtcon,   0x30, RegisterValue(0x16, 0));
     add_sfr_registerR(&clc1.clcxcon, 0x31, RegisterValue(0, 0), "clc1con");
-    add_sfr_register(&clc1.clcxpol, 0x32, RegisterValue(0, 0), "clc1pol");
-    add_sfr_register(&clc1.clcxsel0, 0x33, RegisterValue(0, 0), "clc1sel0");
-    add_sfr_register(&clc1.clcxsel1, 0x34, RegisterValue(0, 0), "clc1sel1");
+    add_sfr_register(&clc1.clcxsel0, 0x32, RegisterValue(0, 0), "clc1sel0");
+    add_sfr_register(&clc1.clcxsel1, 0x33, RegisterValue(0, 0), "clc1sel1");
+    add_sfr_register(&clc1.clcxpol, 0x34, RegisterValue(0, 0), "clc1pol");
     add_sfr_register(&clc1.clcxgls0, 0x35, RegisterValue(0, 0), "clc1gls0");
     add_sfr_register(&clc1.clcxgls1, 0x36, RegisterValue(0, 0), "clc1gls1");
     add_sfr_register(&clc1.clcxgls2, 0x37, RegisterValue(0, 0), "clc1gls2");
@@ -810,6 +829,9 @@ void P10F32X::create_sfr_map()
     add_sfr_registerR(&vregcon, 0x3e, RegisterValue(1, 0));
     add_sfr_register(&borcon,   0x3f, RegisterValue(0x80, 0));
 
+     clc1.lfintosc = &lfintosc;
+     lfintosc.set_clc(&clc1);
+
     if (pir1)
     {
         pir1->set_intcon(&intcon_reg);
@@ -828,12 +850,11 @@ void P10F32X::create_sfr_map()
     adcon0.setPir(pir1);
     adcon0.setChannel_Mask(7);
     adcon0.setChannel_shift(2);
+    adcon1.attach_ad_fvr(fvrcon.get_node_adcvref(), 7);
+    adcon1.attach_Vt_fvr(fvrcon.get_node_Vtref(), 6);
     adcon1.setIOPin(0, &(*m_porta)[0]);
     adcon1.setIOPin(1, &(*m_porta)[1]);
     adcon1.setIOPin(2, &(*m_porta)[2]);
-    fvrcon.set_adcon1(&adcon1);
-    fvrcon.set_VTemp_AD_chan(6);
-    fvrcon.set_FVRAD_AD_chan(7);
     t2con.tmr2  = &tmr2;
     tmr2.pir_set   = get_pir_set();
     tmr2.pr2    = &pr2;
@@ -842,12 +863,12 @@ void P10F32X::create_sfr_map()
     tmr2.add_ccp(&pwm2con);
     pr2.tmr2    = &tmr2;
     pwm1con.set_pwmdc(&pwm1dcl, &pwm1dch);
-    pwm1con.setIOPin1(&(*m_porta)[0]);
+    pwm1con.setIOpin(&(*m_porta)[0], CCPCON::CCP_PIN);
     pwm1con.set_tmr2(&tmr2);
     pwm1con.set_cwg(&cwg);
     pwm1con.set_clc(&clc1, 0);
     pwm2con.set_pwmdc(&pwm2dcl, &pwm2dch);
-    pwm2con.setIOPin1(&(*m_porta)[1]);
+    pwm2con.setIOpin(&(*m_porta)[1], CCPCON::CCP_PIN);
     pwm2con.set_tmr2(&tmr2);
     pwm2con.set_cwg(&cwg);
     pwm2con.set_clc(&clc1, 0);
@@ -857,7 +878,9 @@ void P10F32X::create_sfr_map()
     tmr0.set_clc(&clc1, 0);
     clc1.setInterruptSource(new InterruptSource(pir1, (1 << 3)));
     nco.setIOpins(&(*m_porta)[1], &(*m_porta)[2]);
+    nco.set_clc_data_server(clc1.get_CLC_data_server());
     nco.pir = pir1;
+    wdt->set_timeout(1.0 / 31000.0);
 }
 
 
@@ -913,8 +936,8 @@ bool P10F32X::set_config_word(unsigned int address, unsigned int cfg_word)
         }
 
         wdt_flag = (cfg_word & (WDTEN0 | WDTEN1)) >> 3;
-        wdt.set_timeout(1.0 / 31000.0);
-        wdt.initialize(wdt_flag & 2, false);
+        wdt->set_timeout(1.0 / 31000.0);
+        wdt->initialize(wdt_flag & 2, false);
 
         if (cfg_word & FOSC)   // EC on CLKIN
         {
@@ -943,7 +966,7 @@ void P10F32X::enter_sleep()
 
     if (wdt_flag == 2)          // WDT is suspended during sleep
     {
-        wdt.initialize(false);
+        wdt->initialize(false);
     }
 
     pic_processor::enter_sleep();
@@ -958,7 +981,7 @@ void P10F32X::exit_sleep()
 
         if (wdt_flag == 2)
         {
-            wdt.initialize(true);
+            wdt->initialize(true);
         }
 
         pic_processor::exit_sleep();
@@ -993,6 +1016,7 @@ Processor * P10LF320::construct(const char *name)
     p->create();
     p->create_invalid_registers();
     p->create_symbols();
+    p->set_Vdd(3.3);
     return p;
 }
 
@@ -1024,5 +1048,6 @@ Processor * P10LF322::construct(const char *name)
     p->create();
     p->create_invalid_registers();
     p->create_symbols();
+    p->set_Vdd(3.3);
     return p;
 }
