@@ -29,20 +29,26 @@ License along with this library; if not, see
 //    PIC10F220 PIC10F222
 //
 
+#include <glib.h>
+
+#include <assert.h>
 #include <stdio.h>
 #include <iostream>
 #include <string>
 
-#include "../config.h"
-
-#include "packages.h"
-#include "stimuli.h"
+#include "14bit-registers.h"
 #include "i2c-ee.h"
+#include "modules.h"
+#include "packages.h"
+#include "pic-registers.h"
+#include "stimuli.h"
+#include "tmr0.h"
+#include "trace.h"
+#include "ui.h"
+#include "value.h"
 
 #include "p12x.h"
 
-#include "symbol.h"
-
 
 //========================================================================
 // Generic Configuration word for the midrange family.
@@ -55,7 +61,7 @@ public:
           m_pCpu(pCpu)
     {
         assert(pCpu);
-        pCpu->wdt.initialize(true);
+        pCpu->wdt->initialize(true);
     }
 
     enum
@@ -67,7 +73,7 @@ public:
         MCLRE  = 1 << 4
     };
 
-    virtual void set(gint64 v)
+    virtual void set(gint64 v) override
     {
         gint64 oldV = getVal();
         Integer::set(v);
@@ -79,7 +85,7 @@ public:
         }
     }
 
-    virtual std::string toString()
+    virtual std::string toString() override
     {
         gint64 i64;
         get(i64);
@@ -349,7 +355,7 @@ void  P12bitBase::setConfigWord(unsigned int val, unsigned int diff)
 
     if (diff & WDTEN)
     {
-        wdt.initialize((val & WDTEN) == WDTEN);
+        wdt->initialize((val & WDTEN) == WDTEN);
     }
 
     if ((val & MCLRE) == MCLRE)
@@ -993,11 +999,11 @@ public:
     COUT_SignalControl() {}
     ~COUT_SignalControl() {}
 
-    virtual char getState()
+    virtual char getState() override
     {
         return '0';
     }
-    virtual void release()
+    virtual void release() override
     {
         delete this;
     }
@@ -1005,6 +1011,7 @@ public:
 
 
 class CIN_SignalSink;
+
 class CMCON0 : public sfr_register
 {
 public:
@@ -1022,13 +1029,15 @@ public:
 
     CMCON0(P10F204 *pCpu, const char *pName, const char *pDesc,
            PinModule *CInP, PinModule *CInM, PinModule *COut);
+    CMCON0(const CMCON0 &) = delete;
+    CMCON0 & operator =(const CMCON0 &) = delete;
     ~CMCON0();
 
-    virtual void put(unsigned int new_value);
-    virtual void put_value(unsigned int new_value);
+    virtual void put(unsigned int new_value) override;
+    virtual void put_value(unsigned int new_value) override;
     bool isEnabled()
     {
-        return ((value.get() & COUTEN) == 0);
+        return (value.get() & COUTEN) == 0;
     }
 
     char getState()
@@ -1095,11 +1104,11 @@ public:
     {}
     ~COUT_SignalSource() {}
 
-    virtual char getState()
+    virtual char getState() override
     {
         return m_cmcon0->getState();
     }
-    virtual void release() {}
+    virtual void release() override {}
 
 private:
     CMCON0 *m_cmcon0;
@@ -1114,7 +1123,7 @@ public:
           m_binput(binput)  // true==+input
     {}
 
-    virtual void setSinkState(char new3State)
+    virtual void setSinkState(char new3State) override
     {
         if (verbose)
             std::cout << "CIN_SignalSink::setSinkState  " << (m_binput ? "POS " : "NEG ")
@@ -1122,7 +1131,7 @@ public:
 
         m_cmcon0->setInputState(new3State, m_binput);
     }
-    virtual void release()
+    virtual void release() override
     {
         delete this;
     }
@@ -1425,7 +1434,7 @@ void  P10F220::setConfigWord(unsigned int val, unsigned int diff)
 
     if (diff & WDTEN)
     {
-        wdt.initialize((val & WDTEN) == WDTEN);
+        wdt->initialize((val & WDTEN) == WDTEN);
     }
 
     if ((val & MCLRE))
@@ -1502,10 +1511,10 @@ public:
           m_pCpu(pCpu)
     {
         assert(pCpu);
-        pCpu->wdt.initialize(true);
+        pCpu->wdt->initialize(true);
     }
 
-    virtual void set(gint64 v)
+    virtual void set(gint64 v) override
     {
         gint64 oldV = getVal();
         Integer::set(v);
@@ -1517,7 +1526,7 @@ public:
         }
     }
 
-    virtual std::string toString()
+    virtual std::string toString() override
     {
         gint64 i64;
         get(i64);
@@ -1726,7 +1735,7 @@ void  P16F505::setConfigWord(unsigned int val, unsigned int diff)
 
     if (diff & WDTEN)
     {
-        wdt.initialize((val & WDTEN) == WDTEN);
+        wdt->initialize((val & WDTEN) == WDTEN);
     }
 
     if ((val & MCLRE) == MCLRE)
