@@ -1,6 +1,6 @@
 /*
  *
-   Copyright (C) 2010,2015 Roy R. Rankin
+   Copyright (C) 2010,2015,2022 Roy R. Rankin
 
 This file is part of the libgpsim library of gpsim
 
@@ -90,7 +90,7 @@ public:
 
         if (m_pCpu)
         {
-            m_pCpu->wdt.initialize((v & WDTEN) == WDTEN);
+            m_pCpu->wdt->initialize((v & WDTEN) == WDTEN);
         }
     }
 };
@@ -101,6 +101,7 @@ public:
 P16F88x::P16F88x(const char *_name, const char *desc)
     : _14bit_processor(_name, desc),
       intcon_reg(this, "intcon", "Interrupt Control"),
+      int_pin(this, &intcon_reg, 0),
       t1con(this, "t1con", "TMR1 Control"),
       pie1(this, "PIE1", "Peripheral Interrupt Enable"),
       pie2(this, "PIE2", "Peripheral Interrupt Enable"),
@@ -109,21 +110,19 @@ P16F88x::P16F88x(const char *_name, const char *desc)
       tmr2(this, "tmr2", "TMR2 Register"),
       tmr1l(this, "tmr1l", "TMR1 Low"),
       tmr1h(this, "tmr1h", "TMR1 High"),
-      ccp1con(this, "ccp1con", "Capture Compare Control"),
       ccpr1l(this, "ccpr1l", "Capture Compare 1 Low"),
       ccpr1h(this, "ccpr1h", "Capture Compare 1 High"),
-      ccp2con(this, "ccp2con", "Capture Compare Control"),
       ccpr2l(this, "ccpr2l", "Capture Compare 2 Low"),
       ccpr2h(this, "ccpr2h", "Capture Compare 2 High"),
       pcon(this, "pcon", "pcon"),
       ssp(this),
       osccon(0),
       osctune(this, "osctune", "OSC Tune"),
-      wdtcon(this, "wdtcon", "WDT Control", 1),
+      wdtcon(this, "wdtcon", "WDT Control", 0x1f),
       usart(this),
       comparator(this),
       vrcon(this, "vrcon", "Voltage Reference Control Register"),
-      srcon(this, "srcon", "SR Latch Control Resgister"),
+      sr_module(this),
       ansel(this, "ansel", "Analog Select"),
       anselh(this, "anselh", "Analog Select high"),
       adcon0(this, "adcon0", "A2D Control 0"),
@@ -134,6 +133,8 @@ P16F88x::P16F88x(const char *_name, const char *desc)
       adresh(this, "adresh", "A2D Result High"),
       adresl(this, "adresl", "A2D Result Low")
 {
+    m_ccp1con = new CCPCON(this, "ccp1con", "Capture Compare Control"),
+    m_ccp2con = new CCPCON(this, "ccp2con", "Capture Compare Control"),
     m_porta = new PicPortRegister(this, "porta", "", 8, 0x1f);
     m_trisa = new PicTrisRegister(this, "trisa", "", m_porta, false);
     m_ioc = new IOC(this, "iocb", "Interrupt-On-Change B Register");
@@ -141,6 +142,8 @@ P16F88x::P16F88x(const char *_name, const char *desc)
     m_trisb = new PicTrisRegister(this, "trisb", "", m_portb, false);
     m_portc = new PicPortRegister(this, "portc", "", 8, 0xff);
     m_trisc = new PicTrisRegister(this, "trisc", "", m_portc, false);
+    m_portd = nullptr;
+    m_trisd = nullptr;
     m_porte = new PicPortRegister(this, "porte", "", 8, 0x0f);
     m_trise =  new PicPSP_TrisRegister(this, "trise", "", m_porte, false);
     pir1_2_reg = new PIR1v2(this, "pir1", "Peripheral Interrupt Register", &intcon_reg, &pie1);
@@ -151,17 +154,21 @@ P16F88x::P16F88x(const char *_name, const char *desc)
     tmr0.set_cpu(this, m_porta, 4, option_reg);
     tmr0.start(0);
     comparator.cmxcon0[0] = new CMxCON0_V2(this, "cm1con0",
-                                           " Comparator C1 Control Register 0", 0, &comparator);
+                        " Comparator C1 Control Register 0", 0, &comparator);
+    comparator.cmxcon0[0]->m_eccpas = &eccpas;
     comparator.cmxcon0[1] = new CMxCON0_V2(this, "cm2con0",
-                                           " Comparator C2 Control Register 0", 1, &comparator);
+                        " Comparator C2 Control Register 0", 1, &comparator);
+    comparator.cmxcon0[1]->m_eccpas = &eccpas;
     comparator.cmxcon1[0] = new CM2CON1_V3(this, "cm2con1",
-                                           " Comparator C1 Control Register 1", 0, &comparator);
+                        " Comparator Control Register 1", &comparator);
     comparator.cmxcon1[1] = comparator.cmxcon1[0];
+    comparator.assign_sr_module(&sr_module);
 }
 
 
 P16F88x::~P16F88x()
 {
+
     unassignMCLRPin();
     delete_file_registers(0x20, 0x7f);
     delete_file_registers(0xa0, 0xbf);
@@ -192,11 +199,10 @@ P16F88x::~P16F88x()
     remove_sfr_register(&usart.spbrgh);
     remove_sfr_register(&usart.baudcon);
     remove_sfr_register(&vrcon);
-    remove_sfr_register(&srcon);
     remove_sfr_register(&wdtcon);
     remove_sfr_register(&ccpr2l);
     remove_sfr_register(&ccpr2h);
-    remove_sfr_register(&ccp2con);
+    remove_sfr_register(sr_module.srcon0);
     remove_sfr_register(&adresl);
     remove_sfr_register(&adresh);
     remove_sfr_register(&ansel);
@@ -205,10 +211,10 @@ P16F88x::~P16F88x()
     remove_sfr_register(&adcon1);
     remove_sfr_register(&ccpr1l);
     remove_sfr_register(&ccpr1h);
-    remove_sfr_register(&ccp1con);
+    delete_sfr_register(m_ccp1con);
     remove_sfr_register(&ccpr2l);
     remove_sfr_register(&ccpr2h);
-    remove_sfr_register(&ccp2con);
+    delete_sfr_register(m_ccp2con);
     remove_sfr_register(&pwm1con);
     remove_sfr_register(&pstrcon);
     remove_sfr_register(&eccpas);
@@ -230,6 +236,8 @@ P16F88x::~P16F88x()
     delete_sfr_register(m_trise);
     delete_sfr_register(m_portc);
     delete_sfr_register(m_trisc);
+    if (m_portd) delete_sfr_register(m_portd);
+    if (m_trisd) delete_sfr_register(m_trisd);
     delete_sfr_register(pir1);
     delete_sfr_register(pir2);
     delete_sfr_register(m_wpu);
@@ -259,7 +267,7 @@ void P16F88x::create_sfr_map()
     add_sfr_register(m_trisb, 0x86, RegisterValue(0xff, 0));
     add_sfr_register(pclath,  0x0a, RegisterValue(0, 0));
     add_sfr_register(&intcon_reg, 0x0b, RegisterValue(0, 0));
-    //alias_file_registers(0x0a,0x0b,0x80); //Already donw
+    //alias_file_registers(0x0a,0x0b,0x80); //Already done
     intcon = &intcon_reg;
     pir_set_2_def.set_pir1(pir1);
     pir_set_2_def.set_pir2(pir2);
@@ -323,7 +331,8 @@ void P16F88x::create_sfr_map()
     add_sfr_register(comparator.cmxcon0[1], 0x108, RegisterValue(0, 0), "cm2con0");
     add_sfr_register(comparator.cmxcon1[1], 0x109, RegisterValue(2, 0), "cm2con1");
     add_sfr_register(&vrcon, 0x97, RegisterValue(0, 0), "vrcon");
-    add_sfr_register(&srcon, 0x185, RegisterValue(0, 0), "srcon");
+    sr_module.srcon0 = (SRCON0 *)new SRCON0_V3(this, "srcon", "SR Latch Control Register", &sr_module);
+    add_sfr_register(sr_module.srcon0, 0x185, RegisterValue(0, 0), "srcon");
     add_sfr_register(&wdtcon, 0x105, RegisterValue(0x08, 0), "wdtcon");
     add_sfr_register(&adresl,  0x9e, RegisterValue(0, 0));
     add_sfr_register(&adresh,  0x1e, RegisterValue(0, 0));
@@ -369,15 +378,15 @@ void P16F88x::create_sfr_map()
     vrcon.setValidBits(0xff); // All bits settable
     add_sfr_register(&ccpr1l, 0x15, RegisterValue(0, 0));
     add_sfr_register(&ccpr1h, 0x16, RegisterValue(0, 0));
-    add_sfr_register(&ccp1con, 0x17, RegisterValue(0, 0));
+    add_sfr_register(m_ccp1con, 0x17, RegisterValue(0, 0));
     add_sfr_register(&ccpr2l, 0x1b, RegisterValue(0, 0));
     add_sfr_register(&ccpr2h, 0x1c, RegisterValue(0, 0));
-    add_sfr_register(&ccp2con, 0x1d, RegisterValue(0, 0));
+    add_sfr_register(m_ccp2con, 0x1d, RegisterValue(0, 0));
     add_sfr_register(&pwm1con, 0x9b, RegisterValue(0, 0));
     add_sfr_register(&pstrcon, 0x9d, RegisterValue(1, 0));
     add_sfr_register(&eccpas, 0x9c, RegisterValue(0, 0));
     eccpas.setIOpin(0, 0, &(*m_portb)[0]);
-    eccpas.link_registers(&pwm1con, &ccp1con);
+    eccpas.link_registers(&pwm1con, m_ccp1con);
     ssp.sspmsk = new _SSPMSK(this, "ssp1msk");
     add_sfr_register(&ssp.sspbuf,  0x13, RegisterValue(0, 0), "sspbuf");
     add_sfr_register(&ssp.sspcon,  0x14, RegisterValue(0, 0), "sspcon");
@@ -403,19 +412,20 @@ void P16F88x::create_sfr_map()
     tmr2.pir_set   = get_pir_set();
     tmr2.pr2    = &pr2;
     tmr2.t2con  = &t2con;
-    tmr2.add_ccp(&ccp1con);
-    tmr2.add_ccp(&ccp2con);
+    tmr2.add_ccp(m_ccp1con);
+    tmr2.add_ccp(m_ccp2con);
     pr2.tmr2    = &tmr2;
     tmr1l.setIOpin(&(*m_portc)[0]);
-    ccp1con.setBitMask(0xff);
-    ccp1con.pstrcon = &pstrcon;
-    ccp1con.pwm1con = &pwm1con;
-    ccp1con.setCrosslinks(&ccpr1l, pir1, PIR1v2::CCP1IF, &tmr2, &eccpas);
+    tmr1l.setInterruptSource(new InterruptSource(pir1, PIR1v3::TMR1IF));
+    m_ccp1con->setBitMask(0xff);
+    m_ccp1con->pstrcon = &pstrcon;
+    m_ccp1con->pwm1con = &pwm1con;
+    m_ccp1con->setCrosslinks(&ccpr1l, pir1, PIR1v2::CCP1IF, &tmr2, &eccpas);
     ccpr1l.ccprh  = &ccpr1h;
     ccpr1l.tmrl   = &tmr1l;
     ccpr1h.ccprl  = &ccpr1l;
-    ccp2con.setIOpin(&(*m_portc)[1]);
-    ccp2con.setCrosslinks(&ccpr2l, pir2, PIR2v3::CCP2IF, &tmr2);
+    m_ccp2con->setIOpin(&(*m_portc)[1]);
+    m_ccp2con->setCrosslinks(&ccpr2l, pir2, PIR2v3::CCP2IF, &tmr2);
     ccpr2l.ccprh  = &ccpr2h;
     ccpr2l.tmrl   = &tmr1l;
     ccpr2h.ccprl  = &ccpr2l;
@@ -436,6 +446,8 @@ void P16F88x::create_sfr_map()
     comparator.cmxcon0[0]->setIntSrc(new InterruptSource(pir2, PIR2v2::C1IF));
     comparator.cmxcon0[1]->setBitMask(0xb7);
     comparator.cmxcon0[1]->setIntSrc(new InterruptSource(pir2, PIR2v2::C2IF));
+    sr_module.setPins(nullptr, &(*m_porta)[4], &(*m_porta)[5]);
+    int_pin.setIOpin(&(*m_portb)[0]);
 }
 
 
@@ -570,8 +582,8 @@ void P16F88x::create_config_memory()
     m_configMemory = new ConfigMemory(this, 2);
     m_configMemory->addConfigWord(0, new Config188x(this));
     m_configMemory->addConfigWord(1, new ConfigWord("CONFIG2", 0, "Configuration Word", this, 0x2008));
-    wdt.initialize(true); // default WDT enabled
-    wdt.set_timeout(0.000035);
+    wdt->initialize(true); // default WDT enabled
+    wdt->set_timeout(1./31000.);
     set_config_word(0x2007, 0x3fff);
 }
 
@@ -676,7 +688,7 @@ void P16F882::create_symbols()
 
 void P16F882::create_sfr_map()
 {
-    ccp1con.setIOpin(&(*m_portc)[2], &(*m_portb)[2], &(*m_portb)[1], &(*m_portb)[4]);
+    m_ccp1con->setIOpin(&(*m_portc)[2], &(*m_portb)[2], &(*m_portb)[1], &(*m_portb)[4]);
 }
 
 
@@ -732,7 +744,7 @@ void P16F883::create_sfr_map()
 {
     add_file_registers(0xc0, 0xef, 0);
     add_file_registers(0x120, 0x16f, 0);
-    ccp1con.setIOpin(&(*m_portc)[2], &(*m_portb)[2], &(*m_portb)[1], &(*m_portb)[4]);
+    m_ccp1con->setIOpin(&(*m_portc)[2], &(*m_portb)[2], &(*m_portb)[1], &(*m_portb)[4]);
 }
 
 
@@ -790,7 +802,7 @@ void P16F886::create_sfr_map()
     add_file_registers(0xc0, 0xef, 0);
     add_file_registers(0x120, 0x16f, 0);
     add_file_registers(0x190, 0x1ef, 0);
-    ccp1con.setIOpin(&(*m_portc)[2], &(*m_portb)[2], &(*m_portb)[1], &(*m_portb)[4]);
+    m_ccp1con->setIOpin(&(*m_portc)[2], &(*m_portb)[2], &(*m_portb)[1], &(*m_portb)[4]);
 }
 
 
@@ -848,7 +860,7 @@ void P16F887::create_sfr_map()
     add_file_registers(0x190, 0x1ef, 0);
     add_sfr_register(m_portd, 0x08);
     add_sfr_register(m_trisd, 0x88, RegisterValue(0xff, 0));
-    ccp1con.setIOpin(&(*m_portc)[2], &(*m_portd)[5], &(*m_portd)[6], &(*m_portd)[7]);
+    m_ccp1con->setIOpin(&(*m_portc)[2], &(*m_portd)[5], &(*m_portd)[6], &(*m_portd)[7]);
     adcon1.setIOPin(5, &(*m_porte)[0]);
     adcon1.setIOPin(6, &(*m_porte)[1]);
     adcon1.setIOPin(7, &(*m_porte)[2]);
@@ -891,8 +903,6 @@ P16F884::~P16F884()
 {
     delete_file_registers(0xc0, 0xef);
     delete_file_registers(0x120, 0x16f);
-    delete_sfr_register(m_portd);
-    delete_sfr_register(m_trisd);
 }
 
 
@@ -967,7 +977,7 @@ void P16F884::create_sfr_map()
     add_file_registers(0x120, 0x16f, 0);
     add_sfr_register(m_portd, 0x08);
     add_sfr_register(m_trisd, 0x88, RegisterValue(0xff, 0));
-    ccp1con.setIOpin(&(*m_portc)[2], &(*m_portd)[5], &(*m_portd)[6], &(*m_portd)[7]);
+    m_ccp1con->setIOpin(&(*m_portc)[2], &(*m_portd)[5], &(*m_portd)[6], &(*m_portd)[7]);
     adcon1.setIOPin(5, &(*m_porte)[0]);
     adcon1.setIOPin(6, &(*m_porte)[1]);
     adcon1.setIOPin(7, &(*m_porte)[2]);
@@ -1329,8 +1339,8 @@ void P16F631::create_config_memory()
 {
     m_configMemory = new ConfigMemory(this, 1);
     m_configMemory->addConfigWord(0, new ConfigF631(this));
-    wdt.initialize(true); // default WDT enabled
-    wdt.set_timeout(0.000035);
+    wdt->initialize(true); // default WDT enabled
+    wdt->set_timeout(0.000035);
     set_config_word(0x2007, 0x3fff);
 }
 
@@ -1362,7 +1372,7 @@ bool P16F631::set_config_word(unsigned int address, unsigned int cfg_word)
             unassignMCLRPin();
         }
 
-        wdt.initialize((cfg_word & CFG_WDTE) == CFG_WDTE);
+        wdt->initialize((cfg_word & CFG_WDTE) == CFG_WDTE);
         set_int_osc(false);
         // AnalogReq is used so ADC does not change clock names
         // set_config_word is first called with default and then
@@ -1748,8 +1758,8 @@ void P16F684::create_config_memory()
 {
     m_configMemory = new ConfigMemory(this, 1);
     m_configMemory->addConfigWord(0, new ConfigF631((P16F631*)this));
-    wdt.initialize(true); // default WDT enabled
-    wdt.set_timeout(0.000035);
+    wdt->initialize(true); // default WDT enabled
+    wdt->set_timeout(0.000035);
     set_config_word(0x2007, 0x3fff);
 }
 
@@ -1790,7 +1800,7 @@ bool P16F684::set_config_word(unsigned int address, unsigned int cfg_word)
             unassignMCLRPin();
         }
 
-        wdt.initialize((cfg_word & CFG_WDTE) == CFG_WDTE);
+        wdt->initialize((cfg_word & CFG_WDTE) == CFG_WDTE);
         set_int_osc(false);
         // AnalogReq is used so ADC does not change clock names
         // set_config_word is first called with default and then
