@@ -30,15 +30,23 @@ License along with this library; if not, see
 //    PIC16F819
 //
 
-#include <stdio.h>
+#include <glib.h>
+
 #include <iostream>
-#include <iomanip>
-#include <string>
 
 #include "p16f8x.h"
-#include "pic-ioports.h"
+
+#include "14bit-processors.h"
+#include "14bit-tmrs.h"
+#include "intcon.h"
+#include "ioports.h"
 #include "packages.h"
+#include "pic-ioports.h"
+#include "pie.h"
+#include "ssp.h"
+#include "stimuli.h"
 #include "ui.h"
+#include "value.h"
 
 //========================================================================
 //
@@ -71,12 +79,12 @@ public:
     CP     = 1 << 13
   };
 
-  virtual void set(gint64 v)
+  void set(gint64 v) override
   {
     Integer::set(v);
 
     if (m_pCpu) {
-      m_pCpu->wdt.initialize((v & WDTEN) == WDTEN);
+      m_pCpu->wdt->initialize((v & WDTEN) == WDTEN);
     }
   }
 };
@@ -219,7 +227,7 @@ void P16F8x::create_sfr_map()
   comparator.cmcon.set_configuration(1, 2, AN0, VREF, AN3, VREF, NO_OUT);
   comparator.cmcon.set_configuration(2, 2, AN1, VREF, AN2, VREF, NO_OUT);
   comparator.cmcon.set_configuration(1, 3, AN0, AN2, AN0, AN2, NO_OUT);
-  comparator.cmcon.set_configuration(2, 3, AN1, AN2, AN1, AN3, NO_OUT);
+  comparator.cmcon.set_configuration(2, 3, AN1, AN2, AN1, AN2, NO_OUT);
   comparator.cmcon.set_configuration(1, 4, AN0, AN3, AN0, AN3, NO_OUT);
   comparator.cmcon.set_configuration(2, 4, AN1, AN2, AN1, AN2, NO_OUT);
   comparator.cmcon.set_configuration(1, 5, NO_IN, NO_IN, NO_IN, NO_IN, ZERO);
@@ -363,8 +371,8 @@ void P16F8x::create_config_memory()
   m_configMemory = new ConfigMemory(this, 2);
   m_configMemory->addConfigWord(0, new Config1(this));
   m_configMemory->addConfigWord(1, new ConfigWord("CONFIG2", 0, "Configuration Word", this, 0x2008));
-  wdt.initialize(true); // default WDT enabled
-  wdt.set_timeout(0.000035);
+  wdt->initialize(true); // default WDT enabled
+  wdt->set_timeout(0.000035);
   set_config_word(0x2007, 0x3fff);
 }
 
@@ -379,6 +387,7 @@ void  P16F8x::create(int eesize)
   EEPROM_WIDE *e = new EEPROM_WIDE(this, pir2);
   e->initialize(eesize);
   e->set_intcon(&intcon_reg);
+  e->get_reg_eecon1()->set_valid_bits(0x9f);
   set_eeprom_wide(e);
   P16X6X_processor::create_sfr_map();
   status->rp_mask = 0x60;  // rp0 and rp1 are valid.
@@ -678,8 +687,8 @@ void P16F81x::create_config_memory()
   m_configMemory = new ConfigMemory(this, 2);
   m_configMemory->addConfigWord(0, new Config1(this));
   m_configMemory->addConfigWord(1, new ConfigWord("CONFIG2", 0, "Configuration Word", this, 0x2008));
-  wdt.initialize(true); // default WDT enabled
-  wdt.set_timeout(0.000035);
+  wdt->initialize(true); // default WDT enabled
+  wdt->set_timeout(0.000035);
   set_config_word(0x2007, 0x3fff);
 }
 
