@@ -30,9 +30,14 @@ License along with this library; if not, see
 #include <iostream>
 
 #include "p16f91x.h"
-#include "pic-ioports.h"
+
+#include "ioports.h"
 #include "packages.h"
+#include "pic-ioports.h"
 #include "pic-registers.h"
+#include "processor.h"
+#include "stimuli.h"
+#include "tmr0.h"
 #include "ui.h"
 
 P16F91X::P16F91X(const char *_name, const char *_desc)
