@@ -24,21 +24,31 @@ License along with this library; if not, see
 //
 //  This file supports:
 //    P16C61
+//    P16C63
+//    P16C64
+//    P16C65
+//    P16F630
+//    P16F676
+//    P16F610
+//    P16F616
 
-
+#include <glib.h>
 
 #include <stdio.h>
 #include <iostream>
 #include <string>
 
-
-#include "packages.h"
-#include "stimuli.h"
-#include "symbol.h"
-
 #include "p16x6x.h"
-#include "pic-ioports.h"
+
 #include "intcon.h"
+#include "packages.h"
+#include "pic-ioports.h"
+#include "pic-registers.h"
+#include "stimuli.h"
+#include "tmr0.h"
+#include "ui.h"
+
+class Processor;
 
 void P16C61::create()
 {
@@ -841,7 +851,7 @@ public:
         CPD =    1 << 8
     };
 
-    std::string toString()
+    std::string toString() override
     {
         gint64 i64;
         get(i64);
@@ -989,6 +999,7 @@ void P16F630::create(int eesize)
     e = new EEPROM_WIDE(this, pir1);
     e->initialize(eesize);
     e->set_intcon(&intcon_reg);
+    e->get_reg_eecon1()->set_valid_bits(0x0f);
     set_eeprom_wide(e);
     P16F630::create_sfr_map();
 }
@@ -1121,7 +1132,7 @@ bool P16F630::set_config_word(unsigned int address, unsigned int cfg_word)
             unassignMCLRPin();
         }
 
-        wdt.initialize((cfg_word & CFG_WDTE) == CFG_WDTE);
+        wdt->initialize((cfg_word & CFG_WDTE) == CFG_WDTE);
         set_int_osc(false);
         // AnalogReq is used so ADC does not change clock names
         // set_config_word is first called with default and then
@@ -1264,3 +1275,542 @@ void P16F676::create_sfr_map()
     adcon1.setVrefHiConfiguration(2, 1);
     /* Channel Configuration done dynamiclly based on ansel */
 }
+
+
+//------------------------------------------------------------------------
+//
+//
+
+class ConfigF610 : public ConfigWord
+{
+public:
+    explicit ConfigF610(P16F610 *pCpu)
+        : ConfigWord("CONFIG", 0x3fff, "Configuration Word", pCpu, 0x2007)
+    {
+        //Dprintf(("ConfigF610::ConfigF610 %p\n", m_pCpu));
+        if (m_pCpu)
+        {
+            m_pCpu->set_config_word(0x2007, 0x3fff);
+        }
+    }
+
+    enum
+    {
+        FOSC0  = 1 << 0,
+        FOSC1  = 1 << 1,
+        FOSC2  = 1 << 2,
+        WDTEN  = 1 << 3,
+        PWRTEN = 1 << 4,
+        MCLRE =  1 << 5,
+        CP =     1 << 6,
+        IOSCFS = 1 << 7,
+        BOREN0=  1 << 8,
+        BOREN1=  1 << 9
+    };
+
+    std::string toString() override
+    {
+        gint64 i64;
+        get(i64);
+        int i = i64 & 0xfff;
+        char buff[356];
+        const char *OSCdesc[8] =
+        {
+            "LP oscillator",
+            "XT oscillator",
+            "HS oscillator",
+            "EC oscillator w/ OSC2 configured as I/O",
+            "INTOSC oscillator: I/O on RA4 pin, I/O on RA5",
+            "INTOSC oscillator: CLKOUT on RA4 pin, I/O on RA5",
+            "RC oscillator: I/O on RA4 pin, RC on RA5",
+            "RC oscillator: CLKOUT on RA4 pin, RC on RA5"
+        };
+        const char *BORENdesc[4] =
+        {
+            "disabled",
+            "disabled",
+            "enabled except in Sleep",
+            "enabled always"
+        };
+        snprintf(buff, sizeof(buff),
+                 " $%04x\n"
+                 " FOSC=%d - Clk source = %s\n"
+                 " WDTEN=%d - WDT is %s\n"
+                 " PWRTEN=%d - Power up timer is %s\n"
+                 " MCLRE=%d - RA3 Pin %s\n"
+                 " CP=%d - Code Protection %s\n"
+                 " IOSCFS=%d - Internal Oscillator Frequency %s\n"
+                 " BOREN=%d -  Brown-out Detect %s\n",
+                 i,
+                 i & (FOSC0 | FOSC1 | FOSC2), OSCdesc[i & (FOSC0 | FOSC1 | FOSC2)],
+                 ((i & WDTE) ? 1 : 0), ((i & WDTE) ? "enabled" : "disabled"),
+                 ((i & PWRTEN) ? 1 : 0), ((i & PWRTEN) ? "disabled" : "enabled"),
+                 ((i & MCLRE) ? 1 : 0), ((i & MCLRE) ? "MCLR" : "Input"),
+                 ((i & CP) ? 1 : 0), ((i & CP) ? "disabled" : "enabled"),
+                 ((i & IOSCFS) ? 1 : 0), ((i & IOSCFS) ? "8 MHz" : "4 MHz"),
+                 i & (BOREN0 | BOREN1), BORENdesc[i & (BOREN0 | BOREN1)]
+                );
+        return buff;
+    }
+};
+
+P16F610::P16F610(const char *_name, const char *desc)
+    : _14bit_processor(_name, desc),
+      t1con(this, "t1con", "TMR1 Control"),
+      tmr1l(this, "tmr1l", "TMR1 Low"),
+      tmr1h(this, "tmr1h", "TMR1 High"),
+      pcon(this, "pcon", "pcon"),
+      osctune(this, "osctune", "Oscillator Tuning Register"),
+      intcon_reg(this, "intcon", "Interrupt Control"),
+      pie1(this, "pie1", "Peripheral Interrupt Enable"),
+      pir1(this, "pir1", "Peripheral Interrupt Register", &intcon_reg, &pie1),
+      ansel(this, "ansel", "Analog Select"),
+      adcon1(this, "adcon1", "A2D Control 1"),
+      ioca(this, "ioca", "Interrupt-On-Change GPIO Register"),
+      porta(this, "porta", "", &intcon_reg, &ioca, 6, 0x3f),
+      trisa(this, "trisa", "", &porta, false),
+      wpua(this, "wpua", "Weak Pull-up Register", &porta, 0x37),
+      portc(this, "portc", "", 6, 0x3f),
+      trisc(this, "trisc", "", &portc, false),
+      comparator(this),
+      vrcon(this, "vrcon", "Voltage Reference Control Register"),
+      sr_module(this),
+
+      int_pin(this, &intcon_reg, 0)
+{
+    if (verbose)
+    {
+        std::cout << "P16F610 constructor, type = " << isa() << '\n';
+    }
+
+    osctune.valid_bits=0x1f;
+
+    tmr0.set_cpu(this, &porta, 4, option_reg);
+    tmr0.start(0);
+    comparator.cmxcon0[0] = new CMxCON0_V2(this, "cm1con0",
+                        " Comparator C1 Control Register 0", 0, &comparator);
+    comparator.cmxcon0[1] = new CMxCON0_V2(this, "cm2con0",
+                        " Comparator C2 Control Register 0", 1, &comparator);
+    comparator.cmxcon1[0] = new CM2CON1_V4(this, "cm2con1",
+                        " Comparator Control Register 2", 1, &comparator);
+    comparator.cmxcon1[1] = comparator.cmxcon1[0];
+    comparator.cmxcon1[0]->set_vrcon(&vrcon);
+    comparator.cmxcon1[1]->set_vrcon(&vrcon);
+
+}
+
+
+P16F610::~P16F610()
+{
+    if (verbose)
+    {
+        std::cout << __FUNCTION__ << '\n';
+    }
+    unassignMCLRPin();
+    adcon1.detach_fvr();
+    delete_file_registers(0x70, 0x7f);
+    delete_file_registers(0x40, 0x6f);
+    remove_sfr_register(&portc);
+    remove_sfr_register(&trisc);
+    remove_sfr_register(&porta);
+    remove_sfr_register(&trisa);
+    remove_sfr_register(&ioca);
+    remove_sfr_register(&wpua);
+    remove_sfr_register(&pir1);
+    remove_sfr_register(&tmr0);
+    remove_sfr_register(&intcon_reg);
+    remove_sfr_register(&tmr1l);
+    remove_sfr_register(&tmr1h);
+    remove_sfr_register(&t1con);
+    remove_sfr_register(&osctune);
+    remove_sfr_register(&pcon);
+    remove_sfr_register(&pie1);
+    remove_sfr_register(&ansel);
+    remove_sfr_register(&vrcon);
+    remove_sfr_register(comparator.cmxcon0[0]);
+    remove_sfr_register(comparator.cmxcon0[1]);
+    remove_sfr_register(comparator.cmxcon1[1]);
+    remove_sfr_register(sr_module.srcon0);
+    remove_sfr_register(sr_module.srcon1);
+
+}
+
+
+void P16F610::create_iopin_map()
+{
+    package = new Package(14);
+
+    package->assign_pin(1, 0);	// Vdd
+    package->assign_pin(2, porta.addPin(new IO_bi_directional_pu("porta5"), 5));
+    package->assign_pin(3, porta.addPin(new IO_bi_directional_pu("porta4"), 4));
+    package->assign_pin(4, porta.addPin(new IOPIN("porta3"), 3));
+    package->assign_pin(5, portc.addPin(new IO_bi_directional("portc5"), 5));
+    package->assign_pin(6, portc.addPin(new IO_bi_directional("portc4"), 4));
+    package->assign_pin(7, portc.addPin(new IO_bi_directional("portc3"), 3));
+    package->assign_pin(8, portc.addPin(new IO_bi_directional("portc2"), 2));
+    package->assign_pin(9, portc.addPin(new IO_bi_directional("portc1"), 1));
+    package->assign_pin(10, portc.addPin(new IO_bi_directional("portc0"), 0));
+    package->assign_pin(11, porta.addPin(new IO_bi_directional_pu("porta2"), 2));
+    package->assign_pin(12, porta.addPin(new IO_bi_directional_pu("porta1"), 1));
+    package->assign_pin(13, porta.addPin(new IO_bi_directional_pu("porta0"), 0));
+    package->assign_pin(14, 0); //VSS
+}
+
+
+Processor * P16F610::construct(const char *name)
+{
+    P16F610 *p = new P16F610(name);
+
+    if (verbose)
+    {
+        std::cout << " P16F610 construct\n";
+    }
+
+    p->create();
+    p->create_invalid_registers();
+    p->create_symbols();
+    return p;
+}
+
+
+void P16F610::create(void)
+{
+    create_iopin_map();
+    _14bit_processor::create();
+    P16F610::create_sfr_map();
+}
+
+
+void P16F610::create_symbols()
+{
+    pic_processor::create_symbols();
+    addSymbol(Wreg);
+}
+
+
+//-------------------------------------------------------------------
+void P16F610::create_sfr_map()
+{
+    pir_set_def.set_pir1(&pir1);
+    add_file_registers(0x40, 0x6f, 0);
+    add_file_registers(0x70, 0x7f, 0);
+    alias_file_registers(0x70, 0x7f, 0x80);
+    add_sfr_register(indf, 0x00);
+    alias_file_registers(0x00, 0x00, 0x80);
+    add_sfr_register(&tmr0, 0x01);
+    add_sfr_register(option_reg, 0x81, RegisterValue(0xff, 0));
+    add_sfr_register(pcl, 0x02, RegisterValue(0, 0));
+    add_sfr_register(status, 0x03, RegisterValue(0x18, 0));
+    add_sfr_register(fsr, 0x04);
+    alias_file_registers(0x02, 0x04, 0x80);
+    add_sfr_register(&porta, 0x05);
+    add_sfr_register(&trisa, 0x85, RegisterValue(0x3f, 0));
+    add_sfr_register(&portc, 0x07);
+    add_sfr_register(&trisc, 0x87, RegisterValue(0x3f, 0));
+    add_sfr_register(pclath,  0x0a, RegisterValue(0, 0));
+    add_sfr_register(&intcon_reg, 0x0b, RegisterValue(0, 0));
+    alias_file_registers(0x0a, 0x0b, 0x80);
+
+    add_sfr_register(&pir1, 0x0c, RegisterValue(0, 0));
+    add_sfr_register(&pie1, 0x8c, RegisterValue(0, 0));
+    pir1.valid_bits = PIR1v3::TMR1IF | PIR1v3::C1IF | PIR1v3::C2IF;
+    pir1.writable_bits = pir1.valid_bits;
+    pir1.set_intcon(&intcon_reg);
+    pir1.set_pie(&pie1);
+    pie1.setPir(&pir1);
+    intcon = &intcon_reg;
+    intcon_reg.set_pir_set(get_pir_set());
+    int_pin.setIOpin(&porta[2], 0);
+
+    add_sfr_register(&tmr1l, 0x0e, RegisterValue(0, 0));
+    add_sfr_register(&tmr1h, 0x0f, RegisterValue(0, 0));
+    add_sfr_register(&t1con, 0x10, RegisterValue(0, 0));
+    tmr1l.tmrh = &tmr1h;
+    tmr1l.t1con = &t1con;
+    tmr1l.setInterruptSource(new InterruptSource(&pir1, PIR1v3::TMR1IF));
+    tmr1h.tmrl = &tmr1l;
+    t1con.tmrl = &tmr1l;
+    tmr1l.setIOpin(&porta[5]);
+    tmr1l.setGatepin(&porta[4]);
+
+    comparator.assign_tmr1l(&tmr1l);
+    comparator.cmxcon1[1]->set_vrcon(&vrcon);
+    add_sfr_register(&vrcon, 0x19, RegisterValue(0, 0), "vrcon");
+    add_sfr_register(comparator.cmxcon0[0], 0x1a, RegisterValue(0, 0), "cm1con0");
+    add_sfr_register(comparator.cmxcon0[1], 0x1b, RegisterValue(0, 0), "cm2con0");
+    add_sfr_register(comparator.cmxcon1[1], 0x1c, RegisterValue(2, 0), "cm2con1");
+
+    add_sfr_register(&pcon, 0x8e, RegisterValue(0x03, 0));
+    add_sfr_register(&osctune, 0x90, RegisterValue(0x00, 0), "osctune");
+    add_sfr_register(&ansel, 0x91, RegisterValue(0xff, 0));
+    add_sfr_register(&wpua, 0x95, RegisterValue(0x37, 0));
+    add_sfr_register(&ioca, 0x96, RegisterValue(0, 0));
+
+    sr_module.srcon0 = (SRCON0 *)new SRCON0_V2(this, "srcon0", "SR Latch Control 0 Register", &sr_module);
+    sr_module.srcon1 = (SRCON1 *)new SRCON1_V2(this, "srcon1", "SR Latch Control 1 Register", &sr_module);
+    add_sfr_register(sr_module.srcon0, 0x99, RegisterValue(0x00, 0));
+    add_sfr_register(sr_module.srcon1, 0x9a, RegisterValue(0x00, 0));
+
+    ansel.setAdcon1(&adcon1);
+    ansel.setValidBits(0xff);
+    adcon1.setNumberOfChannels(15);
+    adcon1.setIOPin(0, &porta[0]);
+    adcon1.setIOPin(1, &porta[1]);
+    adcon1.setIOPin(2, &porta[2]);
+    adcon1.setIOPin(3, &porta[4]);
+    adcon1.setIOPin(4, &portc[0]);
+    adcon1.setIOPin(5, &portc[1]);
+    adcon1.setIOPin(6, &portc[2]);
+    adcon1.setIOPin(7, &portc[3]);
+
+    comparator.cmxcon1[1]->set_OUTpin(&porta[2], &portc[4]);
+    comparator.cmxcon1[1]->set_INpinNeg(&(porta)[1], &portc[1],
+                                        &portc[2], &portc[3]);
+    comparator.cmxcon1[1]->set_INpinPos(&porta[0], &portc[0]);
+    comparator.cmxcon1[1]->setBitMask(0x1f);
+    comparator.cmxcon0[0]->setBitMask(0xb7);
+    comparator.cmxcon0[0]->setIntSrc(new InterruptSource(&pir1, PIR1v3::C1IF));
+    comparator.cmxcon0[1]->setBitMask(0xb7);
+    comparator.cmxcon0[1]->setIntSrc(new InterruptSource(&pir1, PIR1v3::C2IF));
+    comparator.assign_sr_module(&sr_module);
+    sr_module.setPins(nullptr, &porta[2], &portc[4]);
+}
+
+
+//-------------------------------------------------------------------
+void P16F610::option_new_bits_6_7(unsigned int bits)
+{
+    wpua.set_wpu_pu((bits & OPTION_REG::BIT7) != OPTION_REG::BIT7);
+    porta.setIntEdge((bits & OPTION_REG::BIT6) == OPTION_REG::BIT6);
+}
+
+
+//-------------------------------------------------------------------
+void P16F610::create_config_memory()
+{
+    m_configMemory = new ConfigMemory(this, 1);
+    m_configMemory->addConfigWord(0, new ConfigF610(this));
+}
+
+
+//-------------------------------------------------------------------
+bool P16F610::set_config_word(unsigned int address, unsigned int cfg_word)
+{
+    enum
+    {
+        CFG_FOSC0  = 1 << 0,
+        CFG_FOSC1  = 1 << 1,
+        CFG_FOSC2  = 1 << 2,
+        CFG_WDTE   = 1 << 3,
+        CFG_MCLRE  = 1 << 5,
+        CFG_IOSCFS = 1 << 7,
+    };
+
+    if (address == config_word_address())
+    {
+        unsigned int valid_pins = porta.getEnableMask();
+
+        if ((cfg_word & CFG_MCLRE) == CFG_MCLRE)
+        {
+            assignMCLRPin(4);
+
+        }
+        else
+        {
+            unassignMCLRPin();
+        }
+
+        wdt->initialize((cfg_word & CFG_WDTE) == CFG_WDTE);
+        set_int_osc(false);
+        // AnalogReq is used so ADC does not change clock names
+        // set_config_word is first called with default and then
+        // often called a second time. the following call is to
+        // reset porta so next call to AnalogReq sill set the pin name
+        //
+        (&porta[4])->AnalogReq((Register *)this, false, "porta4");
+        valid_pins |= 0x20;
+
+        switch (cfg_word & (CFG_FOSC0 | CFG_FOSC1 | CFG_FOSC2))
+        {
+        case 0:  // LP oscillator: low power crystal is on RA4 and RA5
+        case 1:     // XT oscillator: crystal/resonator is on RA4 and RA5
+        case 2:     // HS oscillator: crystal/resonator is on RA4 and RA5
+            (&porta[4])->AnalogReq((Register *)this, true, "OSC2");
+            porta.getPin(5)->newGUIname("OSC1");
+            valid_pins &= 0xcf;
+            break;
+
+        case 3:	// EC I/O on RA4 pin, CLKIN on RA5
+            porta.getPin(5)->newGUIname("CLKIN");
+            valid_pins &= 0xef;
+            break;
+
+        case 5: // INTOSC CLKOUT on RA4 pin
+            (&porta[4])->AnalogReq((Register *)this, true, "CLKOUT");
+
+        case 4: // INTOSC
+            porta.getPin(5)->newGUIname("porta5");
+            set_int_osc(true);
+            osctune.set_freq((cfg_word & CFG_IOSCFS) ? 8e6 : 4e6);
+            break;
+
+        case 6: //RC oscillator: I/O on RA4 pin, RC on RA5
+            porta.getPin(5)->newGUIname("RC");
+            valid_pins &= 0xdf;
+            break;
+
+        case 7: // RC oscillator: CLKOUT on RA4 pin, RC on RA5
+            (&porta[4])->AnalogReq((Register *)this, true, "CLKOUT");
+            (porta.getPin(5))->newGUIname("RC");
+            valid_pins &= 0xdf;
+            break;
+        };
+
+        if (valid_pins != porta.getEnableMask())   // enable new pins for IO
+        {
+            porta.setEnableMask(valid_pins);
+            trisa.setEnableMask(valid_pins);
+        }
+
+        return (true);
+    }
+
+    return false;
+}
+
+
+//------------------------------------------------------------------------
+//
+//
+
+P16F616::P16F616(const char *_name, const char *desc)
+    : P16F610(_name, desc),
+      t2con(this, "t2con", "TMR2 Control"),
+      pr2(this, "pr2", "TMR2 Period Register"),
+      tmr2(this, "tmr2", "TMR2 Register"),
+      eccp1as(this, "eccpas", "ECCP Auto-Shutdown Control Register"),
+      pwm1con(this, "pwm1con", "Enhanced PWM 1 Control Register"),
+      ccp1con(this, "ccp1con", "Enhanced Capture Compare Control"),
+      ccpr1l(this, "ccpr1l", "Capture Compare 3 Low"),
+      ccpr1h(this, "ccpr1h", "Capture Compare 3 High"),
+      adcon0(this, "adcon0", "A2D Control 0"),
+      adresh(this, "adresh", "A2D Result High"),
+      adresl(this, "adresl", "A2D Result Low")
+{
+}
+
+
+P16F616::~P16F616()
+{
+    if (verbose)
+    {
+        std::cout << __FUNCTION__ << '\n';
+    }
+
+    delete_file_registers(0x20, 0x3f);
+    delete_file_registers(0xa0, 0xbf);
+    remove_sfr_register(&pwm1con);
+    remove_sfr_register(&eccp1as);
+    remove_sfr_register(&ccpr1l);
+    remove_sfr_register(&ccpr1h);
+    remove_sfr_register(&ccp1con);
+    remove_sfr_register(&adresl);
+    remove_sfr_register(&adresh);
+    remove_sfr_register(&adcon0);
+    remove_sfr_register(&adcon1);
+    remove_sfr_register(&tmr2);
+    remove_sfr_register(&pr2);
+    remove_sfr_register(&t2con);
+}
+
+
+Processor * P16F616::construct(const char *name)
+{
+    P16F616 *p = new P16F616(name);
+
+    if (verbose)
+    {
+        std::cout << " P16F616 construct\n";
+    }
+
+    p->create();
+    p->create_invalid_registers();
+    p->create_symbols();
+    return p;
+}
+
+
+void P16F616::create(void)
+{
+    P16F610::create();
+    create_sfr_map();
+}
+
+
+void P16F616::create_sfr_map()
+{
+
+    pir1.valid_bits |= PIR1v3::TMR2IF | PIR1v3::CCP1IF | PIR1v3::ADIF;
+    pir1.writable_bits = pir1.valid_bits;
+
+    add_file_registers(0x20, 0x3f, 0);
+    add_file_registers(0xa0, 0xbf, 0);
+
+    // TODO: CCPR1L, CCPR1H, CCP1CON, PWM1CON, ECCPAS @ 0x13-0x17
+
+    add_sfr_register(&tmr2,     0x11, RegisterValue(0, 0));
+    add_sfr_register(&t2con,    0x12, RegisterValue(0, 0));
+    add_sfr_register(&ccpr1l,   0x13, RegisterValue(0, 0));
+    add_sfr_register(&ccpr1h,   0x14, RegisterValue(0, 0));
+    add_sfr_register(&ccp1con,  0x15, RegisterValue(0, 0));
+
+    add_sfr_register(&pwm1con, 0x16, RegisterValue(0, 0));
+    add_sfr_register(&eccp1as, 0x17, RegisterValue(0, 0));
+    add_sfr_register(&pr2, 0x92, RegisterValue(0xff, 0));
+    t2con.tmr2  = &tmr2;
+    tmr2.pir_set = get_pir_set();
+    tmr2.pr2 = &pr2;
+    tmr2.t2con = &t2con;
+    tmr2.add_ccp(&ccp1con);
+    pr2.tmr2 = &tmr2;
+    ccp1con.setADCON(&adcon0);
+    ccp1con.setIOpin(&portc[5], &portc[4], &portc[3], &portc[2]);
+    eccp1as.link_registers(&pwm1con, &ccp1con);
+    ccpr1l.ccprh  = &ccpr1h;
+    ccpr1l.tmrl = &tmr1l;
+    ccpr1h.ccprl = &ccpr1l;
+    ccp1con.pwm1con = &pwm1con;
+
+
+    add_sfr_register(&adresl, 0x9e, RegisterValue(0, 0));
+    add_sfr_register(&adresh, 0x1e, RegisterValue(0, 0));
+    add_sfr_register(&adcon0, 0x1f, RegisterValue(0, 0));
+    add_sfr_register(&adcon1, 0x9f, RegisterValue(0, 0));
+    ansel.setValidBits(0xff);
+    //  ansel.setAdcon0(&adcon0);
+    adcon0.setAdresLow(&adresl);
+    adcon0.setAdres(&adresh);
+    adcon0.setAdcon1(&adcon1);
+    adcon0.setIntcon(&intcon_reg);
+    adcon0.setA2DBits(10);
+    adcon0.setPir(&pir1);
+    adcon0.setChannel_Mask(0xf);
+    adcon0.setChannel_shift(2);
+    adcon0.setValidBits(0xff);
+    adcon1.setAdcon0(&adcon0);
+    /*
+    adcon1.setIOPin(2, &porta[2]);
+    adcon1.setIOPin(3, &porta[4]);
+    */
+    adcon1.attach_ad_fvr(((Processor *)this)->CVREF, 12);
+    adcon1.setVoltRef(13, 0.6);
+    adcon1.setVoltRef(14, 1.2);
+    adcon1.setVrefHiConfiguration(2, 1);
+
+    eccp1as.setBitMask(0xff);
+    eccp1as.link_registers(&pwm1con, &ccp1con);
+    eccp1as.setIOpin(0, 0, &porta[2]);
+    ccp1con.setBitMask(0xff);
+    ccp1con.setCrosslinks(&ccpr1l, &pir1, PIR1v3::CCP1IF, &tmr2, &eccp1as);
+
+}
