@@ -32,19 +32,20 @@ License along with this library; if not, see
 //    P16C74
 
 
-#include <stdio.h>
 #include <iostream>
-#include <string>
-
-#include "../config.h"
-#include "symbol.h"
 
 #include "packages.h"
-#include "p16x7x.h"
 #include "pic-ioports.h"
-#include "stimuli.h"
+#include "pic-registers.h"
 #include "pm_rd.h"
+#include "stimuli.h"
+#include "symbol.h"
+#include "tmr0.h"
+#include "ui.h"
 
+#include "p16x7x.h"
+
+class Processor;
 
 //#define DEBUG_AD
 
