@@ -30,10 +30,15 @@ License along with this library; if not, see
 //    PIC16CR83
 //
 
-#include "../config.h"
-#include "eeprom.h"
 #include "p16x8x.h"
+
+#include "eeprom.h"
+#include "intcon.h"
+#include "ioports.h"
 #include "packages.h"
+#include "pic-ioports.h"
+#include "registers.h"
+#include "stimuli.h"
 
 P16X8X::P16X8X(const char *_name, const char *desc)
     : Pic14Bit(_name, desc), ram_top(0)
