@@ -18,16 +18,16 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
-
-#include <stdio.h>
 #include <iostream>
 #include <string>
 
-#include "symbol.h"
+#include "intcon.h"
+#include "ui.h"
 
-#include "../config.h"
 #include "p17c75x.h"
 
+class Processor;
+
 #if 0
 void _68pins::create_iopin_map(void)
 {
