@@ -19,20 +19,23 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
-
+#include <glib.h>
 #include <stdio.h>
 #include <iostream>
 #include <string>
 
-#include "../config.h"
+#include "16bit-registers.h"
+#include "a2d_v2.h"
+#include "a2dconverter.h"
+#include "intcon.h"
+#include "ioports.h"
 #include "p18x.h"
 #include "pic-ioports.h"
 #include "packages.h"
+#include "ssp.h"
 #include "stimuli.h"
-#include "symbol.h"
-#include "a2d_v2.h"
-#include "a2dconverter.h"
 #include "ui.h"
+#include "value.h"
 
 /* Config Word defines */
 #define MCLRE 	(1<<7)
@@ -65,7 +68,7 @@ public:
         }
     }
 
-    virtual void set(gint64 v)
+    virtual void set(gint64 v) override
     {
         gint64 i64;
         get(i64);
@@ -103,7 +106,7 @@ public:
         }
     }
 
-    virtual std::string toString()
+    std::string toString() override
     {
         gint64 i64;
         get(i64);
@@ -138,7 +141,7 @@ public:
         set(def_val);
     }
 
-    virtual void set(gint64 v)
+    void set(gint64 v) override
     {
         gint64 i64;
         get(i64);
@@ -154,7 +157,7 @@ public:
         }
     }
 
-    virtual std::string toString()
+    std::string toString() override
     {
         gint64 i64;
         get(i64);
@@ -1016,8 +1019,6 @@ void P18F2455::create_sfr_map()
     }
 
     P18F2x21::create_sfr_map();
-    package->destroy_pin(14);
-    package->assign_pin(14, 0, false);          // Vusb
     /* The MSSP/I2CC pins are different on this chip. */
     ssp.initialize(&pir_set_def,         // PIR
                    & (*m_portb)[1],      // SCK
@@ -1154,8 +1155,6 @@ void P18F2550::create_sfr_map()
     }
 
     P18F2x21::create_sfr_map();
-    package->destroy_pin(14);
-    package->assign_pin(14, 0, false);          // Vusb
     /* The MSSP/I2CC pins are different on this chip. */
     ssp.initialize(&pir_set_def,         // PIR
                    & (*m_portb)[1],      // SCK
@@ -1203,7 +1202,7 @@ Processor * P18F2550::construct(const char *name)
         std::cout << " 18F2550 construct\n";
     }
 
-    p->create();
+    p->create(true);
     p->create_invalid_registers();
     p->create_symbols();
     return p;
@@ -1295,15 +1294,13 @@ P18F4455::~P18F4455()
 
 void P18F4455::create()
 {
-    P18F4x21::create();
+    P18F4x21::create(true);
 
     if (verbose)
     {
         std::cout << " 18f4455 create \n";
     }
 
-    package->destroy_pin(18);
-    package->assign_pin(18, 0, false);          // Vusb
     /* The MSSP/I2CC pins are different on this chip. */
     ssp.initialize(&pir_set_def,         // PIR
                    & (*m_portb)[1],      // SCK
@@ -1357,9 +1354,6 @@ void P18F4455::create()
     add_sfr_register(&uep13, 0x0F7D, RegisterValue(0, 0));
     add_sfr_register(&uep14, 0x0F7E, RegisterValue(0, 0));
     add_sfr_register(&uep15, 0x0F7F, RegisterValue(0, 0));
-    // Initialize the register cross linkages
-    init_pir2(pir2, PIR2v4::TMR3IF);
-    //new InterruptSource(pir2, PIR2v4::USBIF);
 }
 
 
@@ -1464,15 +1458,13 @@ P18F4550::~P18F4550()
 
 void P18F4550::create()
 {
-    P18F4x21::create();
+    P18F4x21::create(true);
 
     if (verbose)
     {
         std::cout << " 18f4550 create \n";
     }
 
-    package->destroy_pin(18);
-    package->assign_pin(18, 0, false);          // Vusb
     /* The MSSP/I2CC pins are different on this chip. */
     ssp.initialize(&pir_set_def,         // PIR
                    & (*m_portb)[1],      // SCK
@@ -1810,7 +1802,7 @@ Processor * P18F1320::construct(const char *name)
 //
 
 
-void P18F2x21::create()
+void P18F2x21::create(bool has_usb)
 {
     if (verbose)
     {
@@ -1825,7 +1817,7 @@ void P18F2x21::create()
     tbl.set_pir(pir2);
     tbl.eecon1.set_valid_bits(0xbf);
     _16bit_processor::create();
-    create_iopin_map();
+    create_iopin_map(has_usb);
     create_sfr_map();
 
     m_configMemory->addConfigWord(CONFIG3H-CONFIG1L,new Config3H_2x21(this, CONFIG3H, 0x83));
@@ -1850,7 +1842,7 @@ void P18F2x21::create()
 
 
 //------------------------------------------------------------------------
-void P18F2x21::create_iopin_map()
+void P18F2x21::create_iopin_map(bool has_usb)
 {
     package = new Package(28);
 
@@ -1868,7 +1860,10 @@ void P18F2x21::create_iopin_map()
     package->assign_pin(11, m_portc->addPin(new IO_bi_directional("portc0"), 0));
     package->assign_pin(12, m_portc->addPin(new IO_bi_directional("portc1"), 1));
     package->assign_pin(13, m_portc->addPin(new IO_bi_directional("portc2"), 2));
-    package->assign_pin(14, m_portc->addPin(new IO_bi_directional("portc3"), 3));
+    if (has_usb)
+        package->assign_pin(14, 0, false);          // Vusb
+    else
+        package->assign_pin(14, m_portc->addPin(new IO_bi_directional("portc3"), 3));
     package->assign_pin(15, m_portc->addPin(new IO_bi_directional("portc4"), 4));
     package->assign_pin(16, m_portc->addPin(new IO_bi_directional("portc5"), 5));
     package->assign_pin(17, m_portc->addPin(new IO_bi_directional("portc6"), 6));
@@ -1991,6 +1986,8 @@ void P18F2x21::create_sfr_map()
     ccpr2l.ccprh  = &ccpr2h;
     ccpr2l.tmrl   = &tmr1l;
     ccpr2h.ccprl  = &ccpr2l;
+    // Link the A/D converter to the Capture Compare Module
+    //ccp2con.setADCON(adcon0);     // Not yet supported for this type of ADC
     //1 usart16.initialize_16(this,&pir_set_def,&portc);
     add_sfr_register(&usart.spbrgh,   0xfb0, porv, "spbrgh");
     add_sfr_register(&usart.baudcon,  0xfb8, porv, "baudcon");
@@ -2304,7 +2301,7 @@ Processor * P18F2620::construct(const char *name)
 // Pic 18F4x21
 //
 
-void P18F4x21::create()
+void P18F4x21::create(bool has_usb)
 {
     if (verbose)
     {
@@ -2317,9 +2314,9 @@ void P18F4x21::create()
     tbl.set_intcon(&intcon);
     set_eeprom_pir(&tbl);
     tbl.set_pir(pir2);
-    tbl.eecon1.set_valid_bits(0xbf);
+    tbl.eecon1.set_valid_bits(0xdf);
     _16bit_processor::create();
-    create_iopin_map();
+    create_iopin_map(has_usb);
     create_sfr_map();
 
 
@@ -2342,7 +2339,7 @@ void P18F4x21::create()
 
 
 //------------------------------------------------------------------------
-void P18F4x21::create_iopin_map()
+void P18F4x21::create_iopin_map(bool has_usb)
 {
     package = new Package(40);
 
@@ -2365,7 +2362,10 @@ void P18F4x21::create_iopin_map()
     package->assign_pin(15, m_portc->addPin(new IO_bi_directional("portc0"), 0));
     package->assign_pin(16, m_portc->addPin(new IO_bi_directional("portc1"), 1));
     package->assign_pin(17, m_portc->addPin(new IO_bi_directional("portc2"), 2));
-    package->assign_pin(18, m_portc->addPin(new IO_bi_directional("portc3"), 3));
+    if (has_usb)
+        package->assign_pin(18, 0, false);          // Vusb
+    else
+        package->assign_pin(18, m_portc->addPin(new IO_bi_directional("portc3"), 3));
     package->assign_pin(23, m_portc->addPin(new IO_bi_directional("portc4"), 4));
     package->assign_pin(24, m_portc->addPin(new IO_bi_directional("portc5"), 5));
     package->assign_pin(25, m_portc->addPin(new IO_bi_directional("portc6"), 6));
