@@ -22,6 +22,7 @@ License along with this library; if not, see
 #ifndef SRC_PIC_INSTRUCTIONS_H_
 #define SRC_PIC_INSTRUCTIONS_H_
 
+#include <glib.h>
 #include <string>
 
 #include "gpsim_object.h"
@@ -31,17 +32,16 @@ class Expression;
 class Processor;
 class Register;
 
-
 // FIXME get rid of AddressSymbol and LineNumberSymbol classes
 
 class AddressSymbol : public Integer {
 public:
   AddressSymbol(Processor *pCpu, const char *, unsigned int);
-  virtual std::string toString();
-  virtual Value* evaluate();
-  virtual int set_break(ObjectBreakTypes bt = eBreakAny,
-                        ObjectActionTypes at = eActionHalt,
-                        Expression *expr = nullptr);
+  std::string toString() override;
+  Value* evaluate() override;
+  int set_break(ObjectBreakTypes bt = eBreakAny,
+                ObjectActionTypes at = eActionHalt,
+                Expression *expr = nullptr) override;
 };
 
 
@@ -103,6 +103,8 @@ public:
   };
 
   instruction(Processor *pProcessor, unsigned int uOpCode, unsigned int uAddrOfInstr);
+  instruction(const instruction &) = delete;
+  instruction& operator = (const instruction &) = delete;
   virtual ~instruction();
 
   virtual void execute() = 0;
@@ -115,7 +117,7 @@ public:
   {
     return opcode;
   }
-  virtual unsigned int get_value()
+  unsigned int get_value() override
   {
     return opcode;
   }
@@ -172,9 +174,9 @@ public:
   virtual char *ReadLstLine(char *buf, int nBytes);
   virtual char *ReadHLLLine(char *buf, int nBytes);
 
-  virtual int set_break(ObjectBreakTypes bt = eBreakAny,
-                        ObjectActionTypes at = eActionHalt,
-                        Expression *expr = nullptr);
+  int set_break(ObjectBreakTypes bt = eBreakAny,
+                ObjectActionTypes at = eActionHalt,
+                Expression *expr = nullptr) override;
   virtual void addLabel(std::string &rLabel);
 
   // Some instructions require special initialization after they've
@@ -228,26 +230,26 @@ public:
   void setReplaced(instruction *);
   virtual instruction *getReplaced();
 
-  virtual void execute();
-  virtual void debug();
-  virtual int instruction_size();
-  virtual unsigned int get_opcode();
-  virtual unsigned int get_value();
-  virtual void put_value(unsigned int new_value);
-  virtual int get_src_line();
-  virtual int get_hll_src_line();
-  virtual int get_lst_line();
-  virtual int get_file_id();
-  virtual int get_hll_file_id();
-  virtual void update_line_number(int file, int sline, int lline, int hllfile, int hllsline);
-  virtual enum INSTRUCTION_TYPES isa();
-  virtual void initialize(bool init_state);
-  virtual char *name(char *, int len);
-  virtual bool isBase();
+  void execute() override;
+  void debug() override;
+  int instruction_size() override;
+  unsigned int get_opcode() override;
+  unsigned int get_value() override;
+  void put_value(unsigned int new_value) override;
+  int get_src_line() override;
+  int get_hll_src_line() override;
+  int get_lst_line() override;
+  int get_file_id() override;
+  int get_hll_file_id() override;
+  void update_line_number(int file, int sline, int lline, int hllfile, int hllsline) override;
+  enum INSTRUCTION_TYPES isa() override;
+  void initialize(bool init_state) override;
+  char *name(char *, int len) override;
+  bool isBase() override;
 
-  virtual void update();
-  virtual void add_xref(void *xref);
-  virtual void remove_xref(void *xref);
+  void update() override;
+  void add_xref(void *xref) override;
+  void remove_xref(void *xref) override;
 
 protected:
   instruction *m_replaced;
@@ -261,14 +263,14 @@ public:
                       unsigned int new_opcode,
                       unsigned int address);
 
-  virtual void execute();
+  void execute() override;
 
-  virtual void debug()
+  void debug() override
   {
     //cout << "*** INVALID INSTRUCTION ***\n";
   }
 
-  virtual enum INSTRUCTION_TYPES isa()
+  enum INSTRUCTION_TYPES isa() override
   {
     return INVALID_INSTRUCTION;
   }
@@ -277,8 +279,8 @@ public:
   {
     return new invalid_instruction(new_cpu, new_opcode, address);
   }
-  virtual void addLabel(std::string &rLabel);
-  virtual bool isBase()
+  void addLabel(std::string &rLabel) override;
+  bool isBase() override
   {
     return true;
   }
@@ -292,9 +294,9 @@ public:
 
   unsigned int L;
 
-  virtual void debug() {}
-  virtual char *name(char *, int);
-  virtual bool isBase()
+  void debug() override {}
+  char *name(char *, int) override;
+  bool isBase() override
   {
     return true;
   }
@@ -312,9 +314,9 @@ public:
   bool access = false;
   Register *reg = nullptr;
 
-  virtual void debug() {}
-  virtual char *name(char *, int);
-  virtual bool isBase()
+  void debug() override {}
+  char *name(char *, int) override;
+  bool isBase() override
   {
     return true;
   }
@@ -335,9 +337,9 @@ public:
 
   /*  Register *destination;*/
 
-  virtual void debug() {}
-  virtual char *name(char *, int);
-  virtual bool isBase()
+  void debug() override {}
+  char *name(char *, int) override;
+  bool isBase() override
   {
     return true;
   }
