@@ -21,12 +21,14 @@ License along with this library; if not, see
 
 #include <assert.h>
 #include <stdio.h>
-#include <iostream>
 
+#include "14bit-registers.h"
 #include "pic-processor.h"
 #include "pic-ioports.h"
 #include "intcon.h"
+#include "processor.h"
 #include "psp.h"
+#include "stimuli.h"
 #include "trace.h"
 #include "ui.h"
 
@@ -66,7 +68,7 @@ public:
         : m_register(_reg), m_bitMask(1 << bitPosition)
     {
     }
-    char getState()
+    char getState() override
     {
 
         char r = m_register ? (((m_register->getDriving() & m_bitMask) != 0) ? '1' : '0') : 'Z';
@@ -77,7 +79,7 @@ public:
 
         return r;
     }
-    void release()
+    void release() override
     {
         delete this;
     }
@@ -110,11 +112,11 @@ public:
     {
     }
 
-    virtual char getState()
+    virtual char getState() override
     {
         return m_register ? m_register->get3StateBit(m_bitMask) : '?';
     }
-    virtual void release()
+    virtual void release() override
     {
         delete this;
     }
@@ -162,7 +164,7 @@ void PicTrisRegister::put(unsigned int new_value)
 
 void PicTrisRegister::put_value(unsigned int new_value)
 {
-    value.put(new_value & m_EnableMask);
+    value.put((value.get() & ~m_EnableMask) | (new_value & m_EnableMask));
 
     if (m_port)
         m_port->updatePort();
@@ -324,7 +326,6 @@ void PicPortBRegister::setINTif(unsigned int bit_number, bool bNewValue)
 {
 //  lastDrivenValue = rvDrivenValue;
     bool OldValue = (lastDrivenValue.data&(1 << bit_number)) ;
-    bool level;
 
     if (OldValue == bNewValue) return;
     if (m_pIntcon3)
@@ -332,6 +333,7 @@ void PicPortBRegister::setINTif(unsigned int bit_number, bool bNewValue)
         int intcon = m_pIntcon->value.get();
         int intcon2 = m_pIntcon2->value.get();
         int intcon3 = m_pIntcon3->value.get();
+        bool level;
         switch (bit_number)
         {
         case 0:
@@ -415,7 +417,7 @@ public:
         : m_pPortB(pPortB)
     {}
 
-    void setSink(bool b)
+    void setSink(bool b) override
     {
         if (m_pPortB)
             m_pPortB->setRBPU(b);
@@ -430,7 +432,7 @@ void PicPortBRegister::assignRBPUSink(unsigned int bitPos, sfr_register *pSFR)
         if (!pSFR->assignBitSink(bitPos, m_bsRBPU))
         {
             delete m_bsRBPU;
-            m_bsRBPU = 0;
+            m_bsRBPU = nullptr;
         }
     }
 }
