@@ -22,7 +22,6 @@ License along with this library; if not, see
 #ifndef SRC_PIC_IOPORTS_H_
 #define SRC_PIC_IOPORTS_H_
 
-#include "processor.h"
 #include "gpsim_classes.h"
 #include "ioports.h"
 #include "registers.h"
@@ -33,6 +32,7 @@ class INTCON;
 class IOC;
 class IOCxF;
 class PSP;
+class Processor;
 
 ///------------------------------------------------------------
 class PicTrisRegister;
@@ -56,13 +56,14 @@ public:
   PicTrisRegister(Processor *pCpu, const char *pName, const char *pDesc,
                   /*const char *tris_name, */
                   PicPortRegister *, bool bIgnoreWDTResets, unsigned int nEnableMask = 0xff);
-  virtual void put(unsigned int new_value);
-  virtual void put_value(unsigned int new_value);
-  virtual unsigned int get();
-  virtual char get3StateBit(unsigned int bitMask);
+
+  void put(unsigned int new_value) override;
+  void put_value(unsigned int new_value) override;
+  unsigned int get() override;
+  char get3StateBit(unsigned int bitMask) override;
   void setEnableMask(unsigned int);
   unsigned int getEnableMask() { return m_EnableMask; }
-  void reset(RESET_TYPE r);
+  void reset(RESET_TYPE r) override;
 protected:
   PicPortRegister *m_port;
   unsigned int m_EnableMask;
@@ -77,14 +78,14 @@ public:
   PicPortBRegister(Processor *pCpu, const char *pName, const char *pDesc,
                    INTCON *pIntcon,
                    unsigned int numIopins,
-                   unsigned int enableMask=0xff,
+                   unsigned int enableMask = 0xff,
                    INTCON2 *pIntcon2 = nullptr,
                    INTCON3 *pIntcon3 = nullptr);
   ~PicPortBRegister();
 
-  virtual void put(unsigned int new_value);
-  virtual unsigned int get();
-  virtual void setbit(unsigned int bit_number, char new_value);
+  void put(unsigned int new_value) override;
+  unsigned int get() override;
+  void setbit(unsigned int bit_number, char new_value) override;
   virtual void setINTif(unsigned int bit_number, bool bNewValue);
   void setRBPU(bool);
   void setIntEdge(bool);
@@ -96,8 +97,8 @@ protected:
 
   Processor *cpu;
   enum {
-    eIntEdge = 1<<6,
-    eRBPU    = 1<<7
+    eIntEdge = 1 << 6,
+    eRBPU    = 1 << 7
   };
   bool m_bRBPU;
   bool m_bIntEdge;
@@ -128,9 +129,8 @@ public:
                    INTCON2 *pIntcon2 = nullptr,
                    INTCON3 *pIntcon3 = nullptr);
 
-  virtual void setbit(unsigned int bit_number, char new3State);
+  void setbit(unsigned int bit_number, char new3State) override;
   virtual void setIOCif();
-
 };
 
 class PicPortIOCRegister : public PicPortBRegister
@@ -149,7 +149,7 @@ public:
   {
   }
 
-  virtual void setbit(unsigned int bit_number, char new3State);
+  void setbit(unsigned int bit_number, char new3State) override;
 };
 
 class PicPSP_PortRegister : public PortRegister
@@ -158,8 +158,8 @@ public:
   PicPSP_PortRegister(Processor *pCpu, const char *pName, const char *pDesc,
                       /*const char *port_name, */
                       unsigned int numIopins, unsigned int enableMask);
-  virtual void put(unsigned int new_value);
-  virtual unsigned int get();
+  void put(unsigned int new_value) override;
+  unsigned int get() override;
   void setPSP(PSP *pspReg) { m_psp = pspReg;}
   void setTris(PicTrisRegister *new_tris);
   Register *getTris();
@@ -175,9 +175,9 @@ public:
   PicPSP_TrisRegister(Processor *pCpu, const char *pName, const char *pDesc,
                       /*const char *tris_name, */
                       PicPortRegister *,bool bIgnoreWDTResets);
-  virtual void put(unsigned int new_value);
-  virtual void put_value(unsigned int new_value);
-  virtual unsigned int get();
+  void put(unsigned int new_value) override;
+  void put_value(unsigned int new_value) override;
+  unsigned int get() override;
 };
 
 //------------------------------------------------------------------------
@@ -185,9 +185,9 @@ public:
 class PicLatchRegister : public sfr_register
 {
 public:
-  virtual void put(unsigned int new_value);
-  virtual void put_value(unsigned int new_value);
-  virtual unsigned int get();
+  void put(unsigned int new_value) override;
+  void put_value(unsigned int new_value) override;
+  unsigned int get() override;
   virtual void setbit(unsigned int bit_number, char new_value);
 
   virtual void setEnableMask(unsigned int nEnableMask);
@@ -201,4 +201,4 @@ protected:
   unsigned int m_EnableMask;
 };
 
-#endif  // __PIC_IOPORTS_H__
+#endif  // SRC_PIC_IOPORTS_H_
