@@ -29,13 +29,20 @@ License along with this library; if not, see
 #include <sys/time.h>
 #endif
 #include <time.h>
+
+#include <algorithm>
 #include <iostream>
-#include <iomanip>
+#include <list>
 #include <string>
+#include <typeinfo>
 #include <utility>
+#include <vector>
 
 #include "../config.h"
-
+#include "14bit-registers.h"
+#include "breakpoints.h"
+#include "clock_phase.h"
+#include "eeprom.h"
 #include "exports.h"
 #include "pic-processor.h"
 #include "pic-registers.h"
@@ -62,22 +69,26 @@ License along with this library; if not, see
 #include "p18x.h"
 #include "p18fk.h"
 #include "icd.h"
-
+#include "packages.h"
+#include "pic-instructions.h"
 #include "pic-ioports.h"
 #include "program_files.h"
 #include "stimuli.h"
 #include "trace.h"
 #include "ui.h"
+#include "wdt.h"
+
+#define DEBUG 2
+// debug window WDT
+#if DEBUG & 1
+#define WINprintf(arg) {printf("%s:%d %s ",__FILE__,__LINE__, __FUNCTION__); printf arg; }
+#else
+#define WINprintf(arg) {}
+#endif
+
 
 guint64 simulation_start_cycle;
 
-#include "cod.h"
-
-
-#include "clock_phase.h"
-
-
-
 //================================================================================
 //
 // pic_processor
@@ -199,6 +210,10 @@ ProcessorConstructor pP16F886(P16F886::construct,
                               "__16F886",    "pic16f886",     "p16f886",   "16f886");
 ProcessorConstructor pP16F887(P16F887::construct,
                               "__16F887",    "pic16f887",     "p16f887",   "16f887");
+ProcessorConstructor pP16F610(P16F610::construct,
+                              "__16F610",   "pic16f610",    "p16f610",  "16f610");
+ProcessorConstructor pP16F616(P16F616::construct,
+                              "__16F616",   "pic16f616",    "p16f616",  "16f616");
 ProcessorConstructor pP16F627(P16F627::construct,
                               "__16F627",   "pic16f627",    "p16f627",  "16f627");
 ProcessorConstructor pP16F627A(P16F627::construct,
@@ -260,29 +275,33 @@ ProcessorConstructor pP16F916(P16F916::construct,
 ProcessorConstructor pP16F917(P16F917::construct,
                               "__16F917",  "pic16f917",   "p16f917", "16f917");
 ProcessorConstructor pP16F1503(P16F1503::construct,
-                               "__16F1503", "pic16f1503", "p16f1503", "16f1503");
+                         "__16F1503", "pic16f1503", "p16f1503", "16f1503");
 ProcessorConstructor pP16LF1503(P16LF1503::construct,
-                                "__16LF1503", "pic16lf1503", "p16lf1503", "16lf1503");
+                         "__16LF1503", "pic16lf1503", "p16lf1503", "16lf1503");
 ProcessorConstructor pP16F1705(P16F1705::construct,
-                               "__16F1705", "pic16f1705", "p16f1705", "16f1705");
+                         "__16F1705", "pic16f1705", "p16f1705", "16f1705");
 ProcessorConstructor pP16LF1705(P16LF1705::construct,
-                                "__16LF1705", "pic16lf1705", "p16lf1705", "16lf1705");
+                         "__16LF1705", "pic16lf1705", "p16lf1705", "16lf1705");
 ProcessorConstructor pP16F1709(P16F1709::construct,
-                               "__16F1709", "pic16f1709", "p16f1709", "16f1709");
+                         "__16F1709", "pic16f1709", "p16f1709", "16f1709");
 ProcessorConstructor pP16LF1709(P16LF1709::construct,
-                                "__16LF1709", "pic16lf1709", "p16lf1709", "16lf1709");
+                         "__16LF1709", "pic16lf1709", "p16lf1709", "16lf1709");
 ProcessorConstructor pP16F1788(P16F1788::construct,
-                               "__16F1788", "pic16f1788", "p16f1788", "16f1788");
+                         "__16F1788", "pic16f1788", "p16f1788", "16f1788");
 ProcessorConstructor pP16LF1788(P16LF1788::construct,
-                                "__16LF1788", "pic16lf1788", "p16lf1788", "16lf1788");
+                         "__16LF1788", "pic16lf1788", "p16lf1788", "16lf1788");
 ProcessorConstructor pP16F1823(P16F1823::construct,
-                               "__16F1823", "pic16f1823", "p16f1823", "16f1823");
+                          "__16F1823", "pic16f1823", "p16f1823", "16f1823");
 ProcessorConstructor pP16LF1823(P16LF1823::construct,
-                                "__16LF1823", "pic16lf1823", "p16lf1823", "16lf1823");
+                          "__16LF1823", "pic16lf1823", "p16lf1823", "16lf1823");
 ProcessorConstructor pP16F1825(P16F1825::construct,
-                               "__16F1825", "pic16f1825", "p16f1825", "16f1825");
+                          "__16F1825", "pic16f1825", "p16f1825", "16f1825");
 ProcessorConstructor pP16LF1825(P16F1825::construct,
-                                "__16LF1825", "pic16lf1825", "p16lf1825", "16lf1825");
+                          "__16LF1825", "pic16lf1825", "p16lf1825", "16lf1825");
+ProcessorConstructor pP16F1847(P16F1847::construct,
+                          "__16F1847", "pic16f1847", "p16f1847", "16f1847");
+ProcessorConstructor pP16LF1847(P16F1847::construct,
+                          "__16LF1847", "pic16lf1847", "p16lf1847", "16lf1847");
 #ifdef P17C7XX  // code no longer works
 ProcessorConstructor pP17C7xx(P17C7xx::construct,
                               "__17C7xx", "pic17c7xx",  "p17c7xx", "17c7xx");
@@ -372,7 +391,7 @@ class InterruptTraceObject : public ProcessorTraceObject
 {
 public:
     explicit InterruptTraceObject(Processor *_cpu);
-    virtual void print(FILE *fp);
+    void print(FILE *fp) override;
 };
 
 
@@ -380,9 +399,9 @@ class InterruptTraceType : public ProcessorTraceType
 {
 public:
     explicit InterruptTraceType(Processor *_cpu);
-    TraceObject *decode(unsigned int tbi);
+    TraceObject *decode(unsigned int tbi) override;
     void record();
-    int dump_raw(Trace *pTrace, unsigned int tbi, char *buf, int bufsize);
+    int dump_raw(Trace *pTrace, unsigned int tbi, char *buf, int bufsize) override;
 
     unsigned int m_uiTT;
 };
@@ -480,7 +499,7 @@ void pic_processor::enter_sleep()
     status->put_TO(1);
     status->put_PD(0);
     sleep_time = get_cycles().get();
-    wdt.update();
+    wdt->update();
     pc->increment();
     save_pNextPhase = mCurrentPhase->getNextPhase();
     save_CurrentPhase = mCurrentPhase;
@@ -513,6 +532,18 @@ void pic_processor::exit_sleep()
 }
 
 
+//-------------------------------------------------------------------
+//
+// inattentive - In some situations, the processor will execute a few
+// instructions as NOPs. For example when it is reading flash memory.
+
+void pic_processor::inattentive(unsigned int count) {
+    mSkip->arm(count);
+    mCurrentPhase->setNextPhase(mSkip);
+    mCurrentPhase = mSkip;
+}
+
+
 //-------------------------------------------------------------------
 //
 // is_sleeping
@@ -577,14 +608,9 @@ public:
     struct timeval stat_start;
 
     RealTimeBreakPoint()
+        : cpu(nullptr), future_cycle(0), warntimer(1), period(1),
+          diffmax(0), diffsum(0), diffsumct(0)
     {
-        cpu = nullptr;
-        warntimer = 1;
-        period = 1;
-        future_cycle = 0;
-        diffsum = 0;
-        diffsumct = 0;
-        diffmax = 0;
     }
 
     void start(Processor *active_cpu)
@@ -673,7 +699,7 @@ public:
     }
 #endif
 
-    void callback()
+    void callback() override
     {
         guint64 system_time;	// wall clock time since datum in micro seconds
         guint64 simulation_time;	// simulation time since datum in micro seconds
@@ -946,6 +972,18 @@ void pic_processor::step_cycle()
     mCurrentPhase = mCurrentPhase->advance();
 }
 
+void pic_processor::step_one(bool)
+{
+    if (pc->value < program_memory_size())
+    {
+        program_memory[pc->value]->execute();
+    }
+    else
+    {
+        std::cout << "Program counter not valid " << std::hex << pc->value << '\n';
+        get_bp().halt();
+    }
+}
 
 //
 //-------------------------------------------------------------------
@@ -1069,7 +1107,7 @@ void pic_processor::reset(RESET_TYPE r)
     m_pResetTT->record(r);
     rma.reset(r);
     stack->reset(r);
-    wdt.reset(r);
+    wdt->reset(r);
     pc->reset();
     bp.clear_global();
 
@@ -1118,9 +1156,16 @@ void pic_processor::reset(RESET_TYPE r)
         m_ActivityState = ePAActive;
         break;
 
+    case WDTWV_RESET:
+        std::cout << "Reset on Watch Dog Timer window violation\n";
+        mCurrentPhase = mCurrentPhase ? mCurrentPhase : mExecute1Cycle;
+        mCurrentPhase->setNextPhase(mExecute1Cycle);
+        m_ActivityState = ePAActive;
+        break;
+
     case EXIT_RESET:	// MCLR reset has cleared
         std::cout << "MCLR low, resume execution\n";
-        mCurrentPhase = mCurrentPhase ? mCurrentPhase : mExecute1Cycle;
+        mCurrentPhase = mExecute1Cycle;
         mCurrentPhase->setNextPhase(mExecute1Cycle);
         m_ActivityState = ePAActive;
         return;
@@ -1163,13 +1208,14 @@ void pic_processor::reset(RESET_TYPE r)
 
 pic_processor::pic_processor(const char *_name, const char *_desc)
     : Processor(_name, _desc),
-      wdt(this, 18.0e-3),
       tmr0(this, "tmr0", "Timer 0")
 {
+    wdt = new WDT(this, 18.0e-3);
     mExecute1Cycle    = new phaseExecute1Cycle(this);
     mExecute2ndHalf   = new phaseExecute2ndHalf(this);
     mCaptureInterrupt = new phaseCaptureInterrupt(this);
     mIdle             = new phaseIdle(this);
+    mSkip             = new phaseSkip(this);
     mCurrentPhase   = mExecute1Cycle;
     std::fill_n(m_osc_Monitor, 4, nullptr);
     m_Capabilities = eSTACK | eWATCHDOGTIMER;
@@ -1209,6 +1255,7 @@ pic_processor::~pic_processor()
         }
     }
 
+    delete wdt;
     delete m_pResetTT;
     delete m_pInterruptTT;
     delete_sfr_register(Wreg);
@@ -1288,7 +1335,7 @@ void pic_processor::create()
 // placed in the file register map.
 
 // FIXME It doesn't make any sense to initialize the por_value here!
-// FIXME The preferred way is to initialize all member data in their
+// FIXME The preferred 
 // FIXME parent's constructor.
 
 void pic_processor::add_sfr_register(Register *reg, unsigned int addr,
@@ -1375,6 +1422,7 @@ void pic_processor::delete_sfr_register(Register *pReg)
         else
         {
             delete pReg;
+	    pReg = nullptr;
         }
     }
 }
@@ -1456,7 +1504,7 @@ void pic_processor::create_symbols()
 
     pc->set_description("Program Counter");  // Fixme put this in the pc constructor.
     addSymbol(pc);
-    addSymbol(&wdt);
+    addSymbol(wdt);
 }
 
 
@@ -1652,6 +1700,26 @@ void ProgramMemoryAccess::callback()
     }
 }
 
+// Catch stopped simulation and update value 
+class WDT_Interface : public Interface
+{
+public:
+    explicit WDT_Interface(WDT *_pt_wdt)
+        : Interface((void **)_pt_wdt), pt_wdt(_pt_wdt)
+    {
+    }
+    void SimulationHasStopped(void * /* object */ ) override
+    {
+	pt_wdt->WDT_counter();
+    }
+    void Update(void * /* object */ ) override
+    {
+        pt_wdt->WDT_counter();
+    }
+
+private:
+    WDT *pt_wdt;
+};
 
 //--------------------------------------------------
 WDT::WDT(pic_processor *p_cpu, double _timeout)
@@ -1669,12 +1737,33 @@ void WDT::update()
         // FIXME - the WDT should not be tied to the instruction counter...
         guint64 delta_cycles;
 
-        if (!use_t0_prescale)
+	if (wdttmr)
         {
-            postscale = 1;
+	    WINprintf(("has_window low_window=%d\n", low_window));
+	    wdttmr->value.put((low_window == 0)?WDTTMR::STATE:0);
+	    // reset prescale to original value
+	    prescale = 1 << (wdtcon0->value.get() >> 1);
+	    if (low_window == 0)
+	    {
+		postscale = 1;
+		prescale = prescale * 32;
+	    }
+	    else
+	    {
+		postscale = 8;
+		prescale = prescale * 4;
+	    }
+	}
+        else if (!use_t0_prescale)
+        {
+            postscale = 32;
         }
 
-        delta_cycles = (guint64)(postscale * prescale * timeout / get_cycles().seconds_per_cycle());
+
+	    
+
+        delta_cycles = (guint64)(prescale * timeout / get_cycles().seconds_per_cycle());
+	postscale_cnt = 0;
 
         if (verbose)
         {
@@ -1683,7 +1772,10 @@ void WDT::update()
             std::cout << "CPU frequency " << (cpu->get_frequency()) << '\n';
         }
 
-        guint64 fc = get_cycles().get() + delta_cycles ;
+        last = get_cycles().get();
+     WINprintf(("last=%ld delta=%ld prescale=%ld postscale=%d timeout=%f cps=%.1f\n", last, delta_cycles, prescale, postscale, timeout, 1./get_cycles().seconds_per_cycle()));  
+
+        guint64 fc = last + delta_cycles ;
 
         if (future_cycle)
         {
@@ -1704,6 +1796,34 @@ void WDT::update()
     }
 }
 
+// 
+void WDT::WDT_counter()
+{
+    union 
+    {
+	guint32  word;
+	guint8   byte[4];
+    }count;
+    count.word = 0;
+    if (wdtcon0)
+    {
+	guint32 delta = 0;
+	if (future_cycle)
+            delta = 0.5 + (get_cycles().get() - last) * get_cycles().seconds_per_cycle()/timeout;
+        guint32 scale = 1 << (wdtcon0->value.get() >> 1);
+        guint32 mask = ~(0xffff << (wdtcon0->value.get() >> 1));
+        count.word = delta & mask;
+        wdtpsl->value.put(count.byte[0]);
+        wdtpsh->value.put(count.byte[1]);
+	unsigned int val = (delta / scale ) << WDTTMR::WDTTMR_shift;
+        val |= wdttmr->value.get() & WDTTMR::STATE;
+	val |= count.byte[2] & 0x3;
+	wdttmr->value.put(val);
+
+    WINprintf(("precount=%d 5bit=0x%x now=%ld last=%ld delta=%d scale=%d mask=0x%x prescale=0x%x\n", count.word, delta/scale, get_cycles().get(), last, delta, scale, mask, delta & mask));
+
+    }
+}
 
 //--------------------------------------------------
 // WDT::put - shouldn't be called?
@@ -1721,12 +1841,78 @@ void WDT::set_timeout(double _timeout)
     update();
 }
 
+// Configure window version of WDT from config word
+//  wdte - wdt enable bits
+//  ccs - wdt configure clock
+//  cws - wdt configure window selection
+//  cps - wdt configure period selection 
+void WDT::config(unsigned int wdte, unsigned int ccs, unsigned int cws, unsigned int cps)
+{
+
+   WINprintf(("ccs=0x%x cws=0x%x wdte=%d cps=0x%x\n",  ccs, cws, wdte, cps));
+
+    // Create Window registers on first call of this function
+    if (!wdtcon0)
+    {
+	wdtcon0 = new WDTCON0(this, cpu, "wdtcon0", "Watchdog Timer Control Register 0", 0x3f);
+        wdtcon1 = new WDTCON1(this, cpu, "wdtcon1", "Watchdog Timer Control Register 1", 0x77);
+        wdtpsl = new WDTPSL(this, cpu, "wdtpsl", "WDT Prescale Select Low Byte Register (READ ONLY)");
+        wdtpsh = new WDTPSH(this, cpu, "wdtpsh", "WDT Prescale Select High Byte Register (READ ONLY)");
+        wdttmr = new WDTTMR(this, cpu, "wdttmr", "WDT Timer Register (READ ONLY)");
+	// keep registers up to date for GUI
+	if (!wdt_interface)
+        {
+	    wdt_interface = new WDT_Interface(this);
+	    get_interface().prepend_interface(wdt_interface);
+        }
+    }
+
+     wdtcon1->wdtcs_readonly = (ccs != 7)?true:false;
+     wdtcon1->window_readonly = (cws != 7)?true:false;
+
+     // WDT armed above this postcounter
+     // csw from config is 0
+     low_window = (cws == 6) ? 0:(7-cws); // WDT armed below this postcounter
+     // cws == 6 from config low_window == 32, set cws in wdtcon1 to 7
+     int wdtcon1_por = (cws == 6) ? 7 : cws;
+     if (ccs == 7) ccs= 0;
+     wdtcon1_por |= ccs<<4;
+     wdtcon1->por_value.put(wdtcon1_por);
+     has_window = true;
+     if (ccs > 1)
+	fprintf(stderr, "WDT::config ccs=%d which is a reserved value\n", ccs);
+
+     wdtcon0->wdps_readonly = true;
+    //preselect
+    if (cps <= 0x12)  // use value as is, no software  
+    {
+        wdtcon0->set_por(cps<<1);
+	prescale = 1 << cps;
+    }
+    else if (cps == 0x1f) // wdtwps software control
+    {
+	prescale = 1 << 0xb;
+        wdtcon0->set_por(0xb<<1);
+	wdtcon0->wdps_readonly = false;
+    }
+    else		   // fixed at 1:32 about 1ms
+    {
+	prescale = 1;
+        wdtcon0->set_por(0);
+    }
+
+    initialize((int)wdte);
+    use_t0_prescale = false;
+
+}
+
 
 //  TMR0 prescale is WDT postscale
 void WDT::set_postscale(unsigned int newPostscale)
 {
     unsigned int value = 1 << newPostscale;
 
+
     if (verbose)
     {
         std::cout << "WDT::set_postscale postscale = " << std::dec << value << '\n';
@@ -1742,7 +1928,8 @@ void WDT::set_postscale(unsigned int newPostscale)
 
 void WDT::swdten(bool enable)
 {
-    if (cfgw_enable)
+    WINprintf(("enable=%d cfgw_enable=%d wdte=%d\n", enable, cfgw_enable, wdte));
+    if (!cfgw_enable)
     {
         return;
     }
@@ -1754,7 +1941,7 @@ void WDT::swdten(bool enable)
 
         if (verbose)
             std::cout << " WDT swdten "
-                      << ((enable) ?  "enabling\n" : ", but disabling WDT\n");
+                      << ((wdte) ?  "enabling\n" : ", but disabling WDT\n");
 
         if (wdte)
         {
@@ -1778,10 +1965,14 @@ void WDT::swdten(bool enable)
 }
 
 
-// For WDT period select 0-11
+// For WDT period select, postscale counter should be 32
+// if !use_t0_prescale
 void WDT::set_prescale(unsigned int newPrescale)
 {
-    unsigned int value = 1 << (5 + newPrescale);
+    guint64 value = 1 << newPrescale;
+
+    if (use_t0_prescale)
+	value = value << 5;
 
     if (verbose)
     {
@@ -1790,12 +1981,55 @@ void WDT::set_prescale(unsigned int newPrescale)
 
     if (value != prescale)
     {
+	WINprintf(("newPrescale=%d value=%ld t0=%d\n", newPrescale, value, use_t0_prescale));
         prescale = value;
         update();
     }
 }
 
 
+void WDT::initialize(int enable)
+{
+    use_t0_prescale = true;
+    cpu->set_wdt_exit_sleep(false);
+    switch(enable)
+    {
+    case 0:	//disabled in hardware; SWDTEN bit disabled
+	wdte = false;
+	cfgw_enable = false;
+        if (future_cycle)
+        {
+            std::cout << "Disabling WDT\n";
+            get_cycles().clear_break(this);
+            future_cycle = 0;
+        }
+	break;
+    case 1:	//enabled when device is active, disabled when device is in Sleep; SWDTEN bit disabled
+	wdte = true;
+	cfgw_enable = false;
+	update();
+	break;
+    case 2:	//controlled by the SWDTEN bit
+        cpu->set_wdt_exit_sleep(true);
+	wdte = false;
+	cfgw_enable = true;
+        if (future_cycle)
+        {
+            std::cout << "Disabling WDT\n";
+            get_cycles().clear_break(this);
+            future_cycle = 0;
+        }
+	break;
+    case 3:	//enabled in hardware; SWDTEN bit disabled
+        cpu->set_wdt_exit_sleep(true);
+	wdte = true;
+	cfgw_enable = false;
+	update();
+	break;
+    }
+	
+	
+}
 void WDT::initialize(bool enable, bool _use_t0_prescale)
 {
     wdte = enable;
@@ -1810,11 +2044,13 @@ void WDT::initialize(bool enable, bool _use_t0_prescale)
 
     if (wdte)
     {
+	cfgw_enable = false;
         update();
 
     }
     else
     {
+	cfgw_enable = true;
         if (future_cycle)
         {
             std::cout << "Disabling WDT\n";
@@ -1844,6 +2080,7 @@ void WDT::reset(RESET_TYPE r)
         break;
 
     default:
+      WINprintf(("r=%d\n", r));
         ;
     }
 }
@@ -1857,6 +2094,28 @@ void WDT::set_breakpoint(unsigned int bpn)
 
 void WDT::callback()
 {
+    assert(wdte);
+    guint64 delta; 
+
+    delta = 0.5 + (get_cycles().get() - last) * get_cycles().seconds_per_cycle()/timeout;
+    WINprintf(("total=%ld prescale=%ld  postscale_cnt=%d, postscale=%d timeout=%f cps %.1f\n", delta, prescale, postscale_cnt+1, postscale, timeout, 1./get_cycles().seconds_per_cycle()));
+    if (++postscale_cnt < postscale)
+    {
+	if (wdttmr && (postscale_cnt == low_window))
+	{
+	    WINprintf(("now=%ld set state active postscale_cnt=%d low_window=%d\n", get_cycles().get(), postscale_cnt, low_window));
+		//set state active
+		wdttmr->value.put(wdttmr->value.get() | WDTTMR::STATE);
+        }
+
+	
+        delta = (guint64)(prescale * timeout / get_cycles().seconds_per_cycle());
+ 	future_cycle = get_cycles().get() + delta;
+        get_cycles().set_break(future_cycle, this);
+	return;
+    }
+	
+
     if (wdte)
     {
         if (verbose)
@@ -1893,6 +2152,20 @@ void WDT::clear()
 {
     if (wdte)
     {
+	if (wdttmr)
+	{
+    WINprintf(("wdte=%d wdttmr::state=%d\n", wdte, (bool)(wdttmr->value.get() & WDTTMR::STATE)));
+	    // if state not active, do WDT break
+	    if (!(wdttmr->value.get() & WDTTMR::STATE))
+	    {
+        	if (future_cycle)
+            	    get_cycles().clear_break(this);
+		future_cycle = 0;
+                cpu->status->put_TO(0);
+                cpu->reset(WDTWV_RESET);
+		return;
+	    }
+        }
         update();
 
     }
@@ -1901,6 +2174,7 @@ void WDT::clear()
         warned = 1;
         std::cout << "The WDT is not enabled - clrwdt has no effect!\n";
     }
+    cpu->status->put_TO(1);
 }
 
 
@@ -2004,11 +2278,11 @@ public:
     explicit MCLRPinMonitor(pic_processor *pCpu);
     ~MCLRPinMonitor() {}
 
-    virtual void setDrivenState(char);
-    virtual void setDrivingState(char) {}
-    virtual void set_nodeVoltage(double) {}
-    virtual void putState(char) {}
-    virtual void setDirection() {}
+    void setDrivenState(char) override;
+    void setDrivingState(char) override {}
+    void set_nodeVoltage(double) override {}
+    void putState(char) override {}
+    void setDirection() override {}
 
 private:
     pic_processor *m_pCpu;
@@ -2136,11 +2410,11 @@ public:
     {
     }
     ~IO_SignalControl() {}
-    virtual char getState()
+    char getState() override
     {
         return direction;
     }
-    virtual void release() {}
+    void release() override {}
     void setState(char _dir)
     {
         direction = _dir;
