@@ -6,7 +6,7 @@
 #include "processor.h"
 
 PIE::PIE(Processor *pCpu, const char *pName, const char *pDesc)
-  : sfr_register(pCpu, pName, pDesc), pir(0)
+  : sfr_register(pCpu, pName, pDesc), pir(nullptr)
 {
 }
 
