@@ -19,16 +19,17 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
-#include <glib.h>
+#include <assert.h>
 
-#include "trace.h"
 #include "pir.h"
 #include "intcon.h"
+#include "pie.h"
 #include "processor.h"
+#include "trace.h"
 
 PIR::PIR(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_intcon, PIE *_pie, int _valid_bits)
-  : sfr_register(pCpu,pName,pDesc),
-    intcon(_intcon),pie(_pie),ipr(0),valid_bits(_valid_bits),writable_bits(0)
+  : sfr_register(pCpu, pName, pDesc),
+    intcon(_intcon), pie(_pie), ipr(nullptr), valid_bits(_valid_bits), writable_bits(0)
 {
 }
 
@@ -43,9 +44,8 @@ void PIR::put(unsigned int new_value)
   //trace.register_write(address,value.get());
   value.put((new_value & writable_bits) | (value.get() & ~writable_bits));
 
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
-
 }
 
 void PIR::set_intcon(INTCON *_intcon)
@@ -67,7 +67,7 @@ void PIR::set_ipr(sfr_register *_ipr)
 void PIR::setInterrupt(unsigned int bitMask)
 {
   value.put(value.get() | bitMask);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
 
@@ -125,11 +125,10 @@ void InterruptSource::release()
 }
 
 
-
 //------------------------------------------------------------------------
 
 PIR1v1::PIR1v1(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_intcon, PIE *_pie)
-  : PIR(pCpu,pName,pDesc,_intcon, _pie,0)
+  : PIR(pCpu, pName, pDesc, _intcon, _pie, 0)
 {
   // Even though TXIF is a valid bit, it can't be written by the PIC
   // source code.  Its state reflects whether the usart txreg is full
@@ -139,59 +138,60 @@ PIR1v1::PIR1v1(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_in
 }
 
 
-void PIR1v1::clear_sspif(void)
+void PIR1v1::clear_sspif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() & ~SSPIF);
 }
 
-void PIR1v1::set_txif(void)
+void PIR1v1::set_txif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | TXIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
 
-void PIR1v1::clear_txif(void)
+void PIR1v1::clear_txif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() & ~TXIF);
 }
 
-void PIR1v1::set_rcif(void)
+void PIR1v1::set_rcif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | RCIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
 
-void PIR1v1::clear_rcif(void)
+void PIR1v1::clear_rcif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() & ~RCIF);
 }
 
-void PIR1v1::set_cmif(void)
+void PIR1v1::set_cmif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | CMIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
 
-void PIR1v1::set_eeif(void)
+void PIR1v1::set_eeif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | EEIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
+
 //------------------------------------------------------------------------
 //
-PIR1v2::PIR1v2(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_intcon, PIE *_pie)
-  : PIR(pCpu,pName,pDesc,_intcon, _pie,0)
+PIR1v2::PIR1v2(Processor *pCpu, const char *pName, const char *pDesc, INTCON *_intcon, PIE *_pie)
+  : PIR(pCpu, pName, pDesc, _intcon, _pie, 0)
 {
   // Even though TXIF is a valid bit, it can't be written by the PIC
   // source code.  Its state reflects whether the usart txreg is full
@@ -200,13 +200,13 @@ PIR1v2::PIR1v2(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_in
   writable_bits = TMR1IF | TMR2IF | CCP1IF | SSPIF |  ADIF | PSPIF;
 }
 
-void PIR1v2::clear_sspif(void)
+void PIR1v2::clear_sspif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() & ~SSPIF);
 }
 
-void PIR1v2::set_txif(void)
+void PIR1v2::set_txif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | TXIF);
@@ -214,35 +214,37 @@ void PIR1v2::set_txif(void)
     setPeripheralInterrupt();
 }
 
-void PIR1v2::set_pspif(void)
+void PIR1v2::set_pspif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | PSPIF);
-  if( value.get() & pie->value.get() )
-    setPeripheralInterrupt();
-}
-void PIR1v2::set_sppif(void)
-{
-  trace.raw(write_trace.get() | value.get());
-  value.put(value.get() | SPPIF);
-  if( value.get() & pie->value.get() )
-    setPeripheralInterrupt();
-}
-void PIR1v2::set_sspif(void)
-{
-  trace.raw(write_trace.get() | value.get());
-  value.put(value.get() | SSPIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
 
-void PIR1v2::clear_txif(void)
+void PIR1v2::set_sppif()
+{
+  trace.raw(write_trace.get() | value.get());
+  value.put(value.get() | SPPIF);
+  if ( value.get() & pie->value.get() )
+    setPeripheralInterrupt();
+}
+
+void PIR1v2::set_sspif()
+{
+  trace.raw(write_trace.get() | value.get());
+  value.put(value.get() | SSPIF);
+  if ( value.get() & pie->value.get() )
+    setPeripheralInterrupt();
+}
+
+void PIR1v2::clear_txif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() & ~TXIF);
 }
 
-void PIR1v2::set_rcif(void)
+void PIR1v2::set_rcif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | RCIF);
@@ -250,7 +252,7 @@ void PIR1v2::set_rcif(void)
     setPeripheralInterrupt();
 }
 
-void PIR1v2::clear_rcif(void)
+void PIR1v2::clear_rcif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() & ~RCIF);
@@ -258,216 +260,233 @@ void PIR1v2::clear_rcif(void)
 
 //------------------------------------------------------------------------
 
-PIR1v3::PIR1v3(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_intcon, PIE *_pie)
-  : PIR(pCpu,pName,pDesc,_intcon, _pie,0)
+PIR1v3::PIR1v3(Processor *pCpu, const char *pName, const char *pDesc, INTCON *_intcon, PIE *_pie)
+  : PIR(pCpu, pName, pDesc, _intcon, _pie, 0)
 {
   valid_bits = TMR1IF | ADIF | CMIF | EEIF;
   writable_bits = TMR1IF | ADIF | CMIF | EEIF;
 }
 
-void PIR1v3::set_tmr1if(void)
+void PIR1v3::set_tmr1if()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | TMR1IF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
 
-void PIR1v3::set_tmr2if(void)
+void PIR1v3::set_tmr2if()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | TMR2IF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
 
-void PIR1v3::set_cmif(void)
+void PIR1v3::set_cmif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | CMIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
 
-void PIR1v3::set_eeif(void)
+void PIR1v3::set_eeif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | EEIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
-void PIR1v3::set_adif(void)
+
+void PIR1v3::set_adif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | ADIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
-void PIR1v3::set_c1if(void)
+void PIR1v3::set_c1if()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | C1IF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
-void PIR1v3::set_c2if(void)
+void PIR1v3::set_c2if()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | C2IF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
 
 //------------------------------------------------------------------------
 
-PIR1v4::PIR1v4(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_intcon, PIE *_pie)
-  : PIR(pCpu,pName,pDesc,_intcon, _pie,0)
+PIR1v4::PIR1v4(Processor *pCpu, const char *pName, const char *pDesc, INTCON *_intcon, PIE *_pie)
+  : PIR(pCpu, pName, pDesc, _intcon, _pie, 0)
 {
   writable_bits = TMR1IF | TMR2IF | CCP1IF | SSPIF | ADIF | EEIF;
   valid_bits = 0xff;
 }
-void PIR1v4::set_txif(void)
+
+void PIR1v4::set_txif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | TXIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
-void PIR1v4::clear_txif(void)
+
+void PIR1v4::clear_txif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() & ~TXIF);
 }
 
-void PIR1v4::set_rcif(void)
+void PIR1v4::set_rcif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | RCIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
-void PIR1v4::clear_rcif(void)
+
+void PIR1v4::clear_rcif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() & ~RCIF);
 }
+
 //------------------------------------------------------------------------
-PIR2v1::PIR2v1(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_intcon, PIE *_pie)
-  : PIR(pCpu,pName,pDesc,_intcon, _pie,0)
+PIR2v1::PIR2v1(Processor *pCpu, const char *pName, const char *pDesc, INTCON *_intcon, PIE *_pie)
+  : PIR(pCpu, pName, pDesc, _intcon, _pie, 0)
 {
   valid_bits = CCP2IF;
   writable_bits = valid_bits;
 }
+
 //------------------------------------------------------------------------
-PIR2v2::PIR2v2(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_intcon, PIE *_pie)
-  : PIR(pCpu,pName,pDesc,_intcon, _pie,0)
+PIR2v2::PIR2v2(Processor *pCpu, const char *pName, const char *pDesc, INTCON *_intcon, PIE *_pie)
+  : PIR(pCpu, pName, pDesc, _intcon, _pie, 0)
 {
   valid_bits = ECCP1IF | TMR3IF | LVDIF | BCLIF | EEIF | CMIF;
   writable_bits = valid_bits;
 }
 
-void PIR2v2::set_cmif(void)
+void PIR2v2::set_cmif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | CMIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
-void PIR2v2::set_eeif(void)
+
+void PIR2v2::set_eeif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | EEIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
-void PIR2v2::set_bclif(void)
+
+void PIR2v2::set_bclif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | BCLIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
+
 //------------------------------------------------------------------------
-PIR2v3::PIR2v3(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_intcon, PIE *_pie)
-  : PIR(pCpu,pName,pDesc,_intcon, _pie,0)
+PIR2v3::PIR2v3(Processor *pCpu, const char *pName, const char *pDesc, INTCON *_intcon, PIE *_pie)
+  : PIR(pCpu, pName, pDesc, _intcon, _pie, 0)
 {
   valid_bits = CCP2IF | ULPWUIF | BCLIF | EEIF | C1IF | C2IF | OSFIF;
   writable_bits = valid_bits;
 }
 
-void PIR2v3::set_c1if(void)
+void PIR2v3::set_c1if()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | C1IF);
-  if( value.get() & pie->value.get() )
-    setPeripheralInterrupt();
-}
-void PIR2v3::set_c2if(void)
-{
-  trace.raw(write_trace.get() | value.get());
-  value.put(value.get() | C2IF);
-  if( value.get() & pie->value.get() )
-    setPeripheralInterrupt();
-}
-void PIR2v3::set_eeif(void)
-{
-  trace.raw(write_trace.get() | value.get());
-  value.put(value.get() | EEIF);
-  if( value.get() & pie->value.get() )
-    setPeripheralInterrupt();
-}
-void PIR2v3::set_bclif(void)
-{
-  trace.raw(write_trace.get() | value.get());
-  value.put(value.get() | BCLIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
 
-PIR2v4::PIR2v4(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_intcon, PIE *_pie)
-  : PIR(pCpu,pName,pDesc,_intcon, _pie,0)
+void PIR2v3::set_c2if()
+{
+  trace.raw(write_trace.get() | value.get());
+  value.put(value.get() | C2IF);
+  if ( value.get() & pie->value.get() )
+    setPeripheralInterrupt();
+}
+
+void PIR2v3::set_eeif()
+{
+  trace.raw(write_trace.get() | value.get());
+  value.put(value.get() | EEIF);
+  if ( value.get() & pie->value.get() )
+    setPeripheralInterrupt();
+}
+
+void PIR2v3::set_bclif()
+{
+  trace.raw(write_trace.get() | value.get());
+  value.put(value.get() | BCLIF);
+  if ( value.get() & pie->value.get() )
+    setPeripheralInterrupt();
+}
+
+PIR2v4::PIR2v4(Processor *pCpu, const char *pName, const char *pDesc, INTCON *_intcon, PIE *_pie)
+  : PIR(pCpu, pName, pDesc, _intcon, _pie, 0)
 {
   valid_bits = OSCFIF | CMIF | USBIF | EEIF | BCLIF | HLVDIF | TMR3IF | CCP2IF;
   writable_bits = valid_bits;
 }
-void PIR2v4::set_usbif(void)
+
+void PIR2v4::set_usbif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | USBIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
-void PIR2v4::set_cmif(void)
+
+void PIR2v4::set_cmif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | CMIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
-void PIR2v4::set_eeif(void)
+
+void PIR2v4::set_eeif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | EEIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
-void PIR2v4::set_bclif(void)
+
+void PIR2v4::set_bclif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | BCLIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
-PIR2v5::PIR2v5(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_intcon, PIE *_pie)
-  : PIR(pCpu,pName,pDesc,_intcon, _pie,0)
+
+PIR2v5::PIR2v5(Processor *pCpu, const char *pName, const char *pDesc, INTCON *_intcon, PIE *_pie)
+  : PIR(pCpu, pName, pDesc, _intcon, _pie, 0)
 {
   valid_bits = OSFIF | LVDIF | LCDIF | C1IF | C2IF |CCP2IF;
   writable_bits = valid_bits;
 }
 //------------------------------------------------------------------------
 
-PIR3v1::PIR3v1(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_intcon, PIE *_pie)
-  : PIR(pCpu,pName,pDesc,_intcon, _pie,0)
+PIR3v1::PIR3v1(Processor *pCpu, const char *pName, const char *pDesc, INTCON *_intcon, PIE *_pie)
+  : PIR(pCpu, pName, pDesc, _intcon, _pie, 0)
 {
   // Even though TXIF is a valid bit, it can't be written by the PIC
   // source code.  Its state reflects whether the usart txreg is full
@@ -477,59 +496,58 @@ PIR3v1::PIR3v1(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_in
 }
 
 
-void PIR3v1::set_txif(void)
+void PIR3v1::set_txif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | TXIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
 
-void PIR3v1::clear_txif(void)
+void PIR3v1::clear_txif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() & ~TXIF);
 }
 
-void PIR3v1::set_rcif(void)
+void PIR3v1::set_rcif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() | RCIF);
-  if( value.get() & pie->value.get() )
+  if ( value.get() & pie->value.get() )
     setPeripheralInterrupt();
 }
 
-void PIR3v1::clear_rcif(void)
+void PIR3v1::clear_rcif()
 {
   trace.raw(write_trace.get() | value.get());
   value.put(value.get() & ~RCIF);
 }
 
 //------------------------------------------------------------------------
-PIR3v2::PIR3v2(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_intcon, PIE *_pie)
-  : PIR(pCpu,pName,pDesc,_intcon, _pie,0)
+PIR3v2::PIR3v2(Processor *pCpu, const char *pName, const char *pDesc, INTCON *_intcon, PIE *_pie)
+  : PIR(pCpu, pName, pDesc, _intcon, _pie, 0)
 {
   valid_bits = RXB0IF | RXB1IF | TXB0IF | TXB1IF | TXB2IF | ERRIF |
     WAKIF | IRXIF;
   writable_bits = valid_bits;
 }
 
-PIR3v3::PIR3v3(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_intcon, PIE *_pie)
-  : PIR(pCpu,pName,pDesc,_intcon, _pie,0)
+PIR3v3::PIR3v3(Processor *pCpu, const char *pName, const char *pDesc, INTCON *_intcon, PIE *_pie)
+  : PIR(pCpu, pName, pDesc, _intcon, _pie, 0)
 {
-  valid_bits = TMR3GIF | TMR5GIF | TMR1GIF | CTMUIF | TX2IF | RC2IF 
-	| BCL2IF | SSP2IF;
+  valid_bits = TMR3GIF | TMR5GIF | TMR1GIF | CTMUIF | TX2IF | RC2IF | BCL2IF | SSP2IF;
   writable_bits = valid_bits;
 }
 
-PIR4v1::PIR4v1(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_intcon, PIE *_pie)
-  : PIR(pCpu,pName,pDesc,_intcon, _pie,0)
+PIR4v1::PIR4v1(Processor *pCpu, const char *pName, const char *pDesc, INTCON *_intcon, PIE *_pie)
+  : PIR(pCpu, pName, pDesc, _intcon, _pie, 0)
 {
   valid_bits = CCP3IF | CCP4IF | CCP5IF ;
   writable_bits = CCP3IF | CCP4IF | CCP5IF;
 }
-PIR5v1::PIR5v1(Processor *pCpu, const char *pName, const char *pDesc,INTCON *_intcon, PIE *_pie)
-  : PIR(pCpu,pName,pDesc,_intcon, _pie,0)
+PIR5v1::PIR5v1(Processor *pCpu, const char *pName, const char *pDesc, INTCON *_intcon, PIE *_pie)
+  : PIR(pCpu, pName, pDesc, _intcon, _pie, 0)
 {
   valid_bits = TMR4IF | TMR5IF | TMR6IF ;
   writable_bits = TMR4IF | TMR5IF | TMR6IF ;
