@@ -21,6 +21,7 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
+#include "gpsim_time.h"
 #include "trace.h"
 #include "pic-processor.h"
 #include "processor.h"
@@ -271,11 +272,10 @@ void PM_RW::erase_row()
     rd_adr |= 0x2000;
   }
 
-  int index = rd_adr & (num_latches - 1);
   get_cycles().set_break(get_cycles().get() + 2e-3 * get_cycles().instruction_cps(), this);
   rd_adr &= ~(num_latches - 1);
 
-  for (index = 0; index < num_latches; index++) {
+  for (int index = 0; index < num_latches; index++) {
     cpu->init_program_memory_at_index(rd_adr, LATCH_EMPTY);
     write_latches[index] = LATCH_EMPTY;
     rd_adr++;
