@@ -19,15 +19,10 @@ License along with this library; if not, see
 */
 
 #include <stdio.h>
-#ifdef _WIN32
-#include "uxtime.h"
-#endif
-#ifndef _MSC_VER
-#include <sys/time.h>
-#endif
-#include <time.h>
+
 #include <iostream>
 #include <string>
+#include <utility>
 
 #ifndef _WIN32
 #if !defined(_MAX_PATH)
@@ -38,9 +33,6 @@ License along with this library; if not, see
 #include <direct.h>
 #endif
 
-
-#include "../config.h"
-
 #include "fopen-path.h"
 #include "gpsim_interface.h"
 #include "gpsim_time.h"
@@ -111,7 +103,7 @@ bool CSimulationContext::SetDefaultProcessor(const char * processor_type,
     const char * processor_new_name)
 {
   if (processor_type) {
-    ProcessorConstructor *pc = ProcessorConstructorList::GetList()->findByType(processor_type);
+    ProcessorConstructor *pc = ProcessorConstructor::findByType(processor_type);
 
     if (pc) {
       m_DefProcessorName = processor_type;
@@ -139,17 +131,16 @@ Processor * CSimulationContext::SetProcessorByType(const char * processor_type,
     const char * processor_new_name)
 {
   Processor *p;
-  CProcessorList::iterator it = processor_list.findByType(std::string(processor_type));
+  CProcessorList::iterator it = find_by_type(processor_type);
   GetBreakpoints().clear_all(GetActiveCPU());
-  std::cout << __FUNCTION__ << " FIXME \n";
+  std::cout << __func__ << " FIXME \n";
   // GetSymbolTable().Reinitialize();
 
   if (processor_list.end() == it) {
     p = add_processor(processor_type, processor_new_name);
 
   } else {
-    p = it->second;
-    delete p;
+    delete it->second;
     p = add_processor(processor_type, processor_new_name);
     //    p->init
   }
@@ -162,18 +153,20 @@ Processor * CSimulationContext::SetProcessorByType(const char * processor_type,
 Processor * CSimulationContext::add_processor(const char * processor_type,
     const char * processor_new_name)
 {
-  if (verbose)
+  if (verbose && processor_new_name) {
     std::cout << "Trying to add new processor '" << processor_type << "' named '"
          << processor_new_name << "'\n";
+  }
 
-  ProcessorConstructor *pc = ProcessorConstructorList::GetList()->findByType(processor_type);
+  ProcessorConstructor *pc = ProcessorConstructor::findByType(processor_type);
 
   if (pc) {
     return add_processor(pc, processor_new_name ? processor_new_name : m_DefProcessorNameNew.c_str());
 
-  } else
+  } else {
     std::cout << processor_type << " is not a valid processor.\n"
          "(try 'processor list' to see a list of valid processors.\n";
+  }
 
   return nullptr;
 }
@@ -205,9 +198,9 @@ Processor * CSimulationContext::add_processor(Processor *p)
   active_cpu_id = ++cpu_ids;
 
   if (verbose) {
-    std::cout << p->name() << '\n';
-    std::cout << "Program Memory size " <<  p->program_memory_size() << " words\n";
-    std::cout << "Register Memory size " <<  p->register_memory_size() << '\n';
+    std::cout << p->name()
+      << "\nProgram Memory size " <<  p->program_memory_size()
+      << " words\nRegister Memory size " <<  p->register_memory_size() << '\n';
   }
 
   trace.switch_cpus(p);
@@ -289,17 +282,13 @@ int CSimulationContext::LoadProgram(const char *filename,
 void CSimulationContext::dump_processor_list()
 {
   std::cout << "Processor List\n";
-  bool have_processors = false;
-  CProcessorList::iterator processor_iterator = processor_list.begin();
 
-  for ( ; processor_iterator != processor_list.end(); ++processor_iterator) {
-    CProcessorList::value_type vt = *processor_iterator;
+  for (const auto &vt : processor_list) {
     Processor *p = vt.second;
     std::cout << p->name() << '\n';
-    have_processors = true;
   }
 
-  if (!have_processors) {
+  if (processor_list.empty()) {
     std::cout << "(empty)\n";
   }
 }
@@ -307,10 +296,7 @@ void CSimulationContext::dump_processor_list()
 
 void CSimulationContext::Clear()
 {
-  CProcessorList::iterator processor_iterator = processor_list.begin();
-
-  for ( ; processor_iterator != processor_list.end(); ++processor_iterator) {
-    CProcessorList::value_type vt = *processor_iterator;
+  for (auto &vt : processor_list) {
     Processor *p = vt.second;
     GetBreakpoints().clear_all(p);
     delete p;
@@ -333,7 +319,7 @@ void CSimulationContext::Reset(RESET_TYPE )
       }
   }
   */
-  std::cout << __FUNCTION__ << " FIXME \n";
+  std::cout << __func__ << " FIXME \n";
 }
 
 
@@ -380,25 +366,23 @@ Cycle_Counter * CSimulationContext::GetCycleCounter()
 
 
 CSimulationContext::CProcessorList::iterator
-CSimulationContext::CProcessorList::findByType(const key_type& _Keyval)
+CSimulationContext::find_by_type(const CProcessorList::key_type& Keyval)
 {
   // First find a ProcessorConstructor that matches the
   // processor type we are looking for. This should handle
   // naming variations.
-  ProcessorConstructorList * pcl = ProcessorConstructorList::GetList();
-  ProcessorConstructor * pc = pcl->findByType(_Keyval.c_str());
+  ProcessorConstructor * pc = ProcessorConstructor::findByType(Keyval.c_str());
+  auto itEnd = processor_list.end();
 
   if (pc == nullptr) {
-    return end();
+    return itEnd;
   }
 
   // Now find the specific allocated processor that
   // was created with the ProcessorConstructor object
   // we found above.
-  iterator it;
-  iterator itEnd = end();
 
-  for (it = begin(); it != itEnd; ++it) {
+  for (auto it = processor_list.begin(); it != itEnd; ++it) {
     if (it->second->m_pConstructorObject == pc) {
       return it;
     }
