@@ -20,11 +20,15 @@ License along with this library; if not, see
 
 #include <stdio.h>
 #include <iostream>
+#include <string>
 
-#include "../config.h"
+#include "gpsim_time.h"
+#include "ioports.h"
+#include "pic-ioports.h"
+#include "pir.h"
+#include "processor.h"
 #include "stimuli.h"
 #include "spp.h"
-#include "ioports.h"
 #include "trace.h"
 #include "ui.h"
 
@@ -48,7 +52,7 @@ public:
     state = '?';
   }
   ~SppSignalSource() {}
-  virtual char getState()
+  char getState() override
   {
     return state;
   }
@@ -56,7 +60,7 @@ public:
   {
     state = _state;
   }
-  virtual void release()
+  void release() override
   {
     delete this;
   }
