@@ -21,15 +21,14 @@ License along with this library; if not, see
 
 
 #include <stdio.h>
-#include <ctype.h>
 #include <iostream>
-#include <stdlib.h>
 #include <string>
 #include <list>
 #include <sstream>
 
 #include <math.h>
 #include <string.h>
+#include <cassert>
 
 #include "errors.h"
 #include "gpsim_interface.h"
@@ -37,6 +36,7 @@ License along with this library; if not, see
 #include "gpsim_time.h"
 #include "ioports.h"
 #include "stimuli.h"
+#include "symbol.h"
 #include "ui.h"
 #include "value.h"
 
@@ -128,7 +128,8 @@ std::string Stimulus_Node::toString()
 //========================================================================
 
 Stimulus_Node::Stimulus_Node(const char *n)
-    : TriggerObject(nullptr)
+    : TriggerObject(nullptr),
+      cap_start_cycle(0), future_cycle(0), settlingTimeStep(0)
 {
     warned  = 0;
     voltage = 0;
@@ -137,14 +138,11 @@ Stimulus_Node::Stimulus_Node(const char *n)
     current_time_constant = 0.0;
     delta_voltage = 0.0;
     minThreshold = 0.1; // volts
-    cap_start_cycle = 0;
-    future_cycle = 0;
     initial_voltage = 0.0;
     DCVoltage = 0.0;
     bSettling = false;
     stimuli = 0;
     nStimuli = 0;
-    settlingTimeStep = 0;
 
     if (n)
         gpsimObject::new_name(n);
@@ -312,7 +310,6 @@ void Stimulus_Node::refresh()
 {
     if (stimuli)
     {
-
         stimulus *sptr = stimuli;
 
         initial_voltage = get_nodeVoltage();
@@ -396,7 +393,7 @@ void Stimulus_Node::refresh()
 
         current_time_constant = Cth * Zth;
         Dprintf(("%s DCVoltage %.3f voltage %.3f Cth=%.2e Zth=%2e time_constant %fsec or %" PRINTF_GINT64_MODIFIER "d cycles now=%" PRINTF_GINT64_MODIFIER "d \n",name().c_str(), DCVoltage, voltage, Cth, Zth, current_time_constant, (guint64)(current_time_constant*get_cycles().instruction_cps()), get_cycles().get()));
-        if (((guint64)(current_time_constant*get_cycles().instruction_cps()) < 5) ||
+        if (((guint64)(current_time_constant * get_cycles().instruction_cps()) < 5) ||
                 (fabs(DCVoltage - voltage) < minThreshold))
         {
             if (verbose)
@@ -489,7 +486,6 @@ void Stimulus_Node::update()
 {
     if (stimuli)
     {
-
         refresh();
         updateStimuli();
     }
@@ -703,7 +699,7 @@ PinMonitor::~PinMonitor()
     // Release all of the sinks:
     for (SignalSink *ssi : sinks)
     {
-        Dprintf(("release sink %p\n", ssi));
+        //Dprintf(("release sink %p\n", ssi));
         fflush(stdout);
         (*ssi).release();
     }
@@ -774,7 +770,7 @@ double square_wave::get_Vth()
     if (verbose & 1)
         std::cout << "Getting new state of the square wave.\n";
 
-    if (((current_time+phase) % period) <= duty)
+    if (((current_time + phase) % period) <= duty)
         return Vth;
     else
         return 0.0;
@@ -796,7 +792,7 @@ triangle_wave::triangle_wave(unsigned int p, unsigned int dc, unsigned int ph, c
         char name_str[100];
         snprintf(name_str, sizeof(name_str), "s%d_triangle_wave", num_stimuli);
         num_stimuli++;
-        new_name(name_str,false);
+        new_name(name_str, false);
     }
 
     if (p == 0)  //error
@@ -807,8 +803,8 @@ triangle_wave::triangle_wave(unsigned int p, unsigned int dc, unsigned int ph, c
     duty   = dc;  // # of cycles over the period for which the sq wave is high
     phase  = ph;  // phase of the sq wave wrt the cycle counter
     time   = 0;   // simulation time
-    snode = 0;
-    next = 0;
+    snode  = 0;
+    next   = 0;
 
     //cout << "duty cycle " << dc << " period " << p << " drive " << drive << '\n';
 
@@ -857,8 +853,8 @@ double triangle_wave::get_Vth()
 // Event
 
 Event::Event()
+    : current_state(0)
 {
-    current_state = 0;
 }
 
 //========================================================================
@@ -958,8 +954,8 @@ void IOPIN::set_digital_threshold(double vdd)
 {
     if (schmitt_level)
     {
-        set_l2h_threshold(0.8*vdd);
-        set_h2l_threshold(0.2*vdd);
+        set_l2h_threshold(0.8 * vdd);
+        set_h2l_threshold(0.2 * vdd);
     }
     else
     {
@@ -977,10 +973,10 @@ void IOPIN::setMonitor(PinMonitor *new_pinMonitor)
     else
         m_monitor = new_pinMonitor;
 }
+
 // True = set schmitt trigger levels, False = set TTL levels
 void IOPIN::set_schmitt_level(bool _schmitt, double vdd)
 {
-
     if (_schmitt != schmitt_level)
     {
         schmitt_level = _schmitt;
@@ -1177,7 +1173,6 @@ void IOPIN::forceDrivenState(char newForcedState)
 {
     if (cForcedDrivenState != newForcedState)
     {
-
         cForcedDrivenState = newForcedState;
 
         bDrivenState = cForcedDrivenState == '1' || cForcedDrivenState == 'W';
@@ -1272,6 +1267,7 @@ void IO_bi_directional::getThevenin(double &v, double &z, double &c)
     z = get_Zth();
     c = get_Cth();
 }
+
 void IO_bi_directional::set_nodeVoltage(double new_nodeVoltage)
 {
     IOPIN::set_nodeVoltage(new_nodeVoltage);
@@ -1282,7 +1278,6 @@ double IO_bi_directional::get_Vth()
     if (getDriving())
         return getDrivingState() ? Vth : 0.0;
 
-
     //return getDrivingState() ? VthIn : 0;
     return VthIn;
 }
@@ -1389,6 +1384,7 @@ void IO_bi_directional_pu::getThevenin(double &v, double &z, double &c)
     z = get_Zth();
     c = get_Cth();
 }
+
 void IO_bi_directional_pu::set_is_analog(bool flag)
 {
     if (is_analog != flag)
@@ -1473,13 +1469,12 @@ char IO_bi_directional_pu::getBitChar()
 {
     if (!snode && !getDriving() )
     {
-        char cForced=getForcedDrivenState();
-        return (cForced=='Z' && bPullUp) ? 'W' : cForced;
+        char cForced = getForcedDrivenState();
+        return (cForced == 'Z' && bPullUp) ? 'W' : cForced;
     }
 
     if (snode)
     {
-
         if (!getDriving())		// input pin
         {
             if (snode->get_nodeZth() > ZthFloating)
@@ -1657,7 +1652,6 @@ ValueStimulus::~ValueStimulus()
             sample_iterator != samples.end();
             ++sample_iterator)
     {
-
         delete (*sample_iterator).v;
     }
 }
@@ -1671,17 +1665,13 @@ void ValueStimulus::show()
 
     std::list<ValueStimulusData>::iterator si;
 
-    for (si = samples.begin();
-            si != samples.end();
-            ++si)
+    for (si = samples.begin(); si != samples.end(); ++si)
     {
-
         //double d;
         //(*si).v->get(d);
         std::cout << "    t=" << std::dec << (*si).time
                   <<  ",v=" << (*si).v->toString()
                   << '\n';
-
     }
 
     if (initial.v)
@@ -1738,7 +1728,7 @@ void ValueStimulus::callback()
         future_cycle = 0;
 
     if (verbose & 1)
-        std::cout <<"  next transition = " << future_cycle << '\n';
+        std::cout << "  next transition = " << future_cycle << '\n';
 }
 
 void ValueStimulus::put_initial_state(Value *pValue)
@@ -1785,7 +1775,6 @@ void ValueStimulus::start()
 
     if (period)
     {
-
         // Create a data point for the rollover condition.
         // If an initial value was supplied when the stimulus was created, then
         // that's what we'll use for the rollover. Otherwise, we'll create
@@ -1822,7 +1811,6 @@ ValueStimulusData *ValueStimulus::getNextSample()
 
     if (sample_iterator == samples.end())
     {
-
         // We've gone through all of the data. Now let's try to start over
 
         sample_iterator = samples.begin();
@@ -1975,3 +1963,77 @@ void stimuli_attach(gpsimObject *pNode, gpsimObjectList_t *pPinList)
         }
     }
 }
+
+void DATA_SERVER::attach_data(DATA_RECEIVER *pt_rcv)
+{
+    DATA_RECEIVER *spt = data_rcv;
+    bool searching = true;
+    Dprintf(("DATA_SERVER 0x%x spt=%p this=%p\n", source_code, spt, this));
+    if (data_rcv)
+    {
+	while(searching)
+	{
+	    if (pt_rcv == spt)  // Receiver already attached
+	    {
+	        Dprintf(("DATA_SERVER dup %p %s\n", pt_rcv, pt_rcv->name().c_str()));
+		return;
+	    }
+
+	    if (spt->next == 0)
+            {
+	        Dprintf(("DATA_SERVER attach %p %s\n", pt_rcv, pt_rcv->name().c_str()));
+		spt->next = pt_rcv;
+		searching = false;
+	     }
+	     spt = spt->next;
+	}
+    }
+    else	// first entry to attach
+    {
+	data_rcv = pt_rcv;
+	return;
+    }
+    spt->next = nullptr;
+
+}
+void DATA_SERVER::detach_data(DATA_RECEIVER *pt_rcv)
+{
+    DATA_RECEIVER *spt = data_rcv;
+
+    if (!pt_rcv || !spt)	// Cannot remove null receiver or list empty
+	return;
+
+    Dprintf(("DATA_SERVER 0x%x spt=%p %s this=%p\n", source_code, spt, pt_rcv->name().c_str(), this));
+    if (pt_rcv == spt)
+    {
+	// This is the first entry in the list
+	//data_rcv = pt_rcv;
+	data_rcv = spt->next;
+	return;
+    }
+    else
+    {
+	do
+	{
+	    if (pt_rcv == spt->next) // got match
+	    {
+		spt->next = pt_rcv->next;
+		return;
+	    }
+	    spt = spt->next;
+	} while(spt);
+    }
+    
+}
+void DATA_SERVER::send_data(int v1, int v2)
+{
+    DATA_RECEIVER *spt = data_rcv;
+
+    v2 |= source_code;	// Tag server source
+    
+    while(spt)
+    {
+	spt->rcv_data(v1, v2);
+	spt = spt->next;
+    }
+}
