@@ -1,33 +1,34 @@
 /*
    Copyright (C) 1998 T. Scott Dattalo
 
-This file is part of gpsim.
+This file is part of the libgpsim library of gpsim
 
-gpsim is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
 
-gpsim is distributed in the hope that it will be useful,
+This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+Lesser General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with gpsim; see the file COPYING.  If not, write to
-the Free Software Foundation, 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA.  */
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, see
+<http://www.gnu.org/licenses/lgpl-2.1.html>.
+*/
 
 
-#if !defined(__TRIGGER_H__)
-#define __TRIGGER_H__
+#ifndef SRC_TRIGGER_H_
+#define SRC_TRIGGER_H_
+
 #include <string>
-using namespace std;
 
 class TriggerObject;
 class TraceType;
 class Expression;
 class Trace;
+
 //========================================================================
 //
 // Triggers
@@ -37,7 +38,7 @@ class Trace;
 // The TriggerObject is something that gets evaluated. If it evaluates
 // to true then a TriggerAction is invoked.
 // Most breakpoints are simple and don't need this complexity. For example,
-// an execution breakpoint only needs to halt simulation whenever it's 
+// an execution breakpoint only needs to halt simulation whenever it's
 // encountered. But gpsim defines the TriggerObject to be something like
 // 'if address is executed' and the TriggerAction to be 'halt simulation'.
 // However this design accomodates much more complicated situations. For
@@ -48,7 +49,7 @@ class Trace;
 // break w reg(42) (reg(42) == 0) && (STATUS & GIE == 0)
 //
 // In this case, the compound expression gets associated with write operations
-// to register 42. 
+// to register 42.
 
 class TriggerAction
 {
@@ -63,8 +64,8 @@ public:
 class SimpleTriggerAction : public TriggerAction
 {
 public:
-  SimpleTriggerAction(TriggerObject *_to);
-  virtual void action();
+  explicit SimpleTriggerAction(TriggerObject *_to);
+  void action() override;
 protected:
   TriggerObject *to;
 
@@ -73,10 +74,10 @@ protected:
 // TriggerObject - a base class for handling all of gpsim's breakpoints.
 //
 // The TriggerObject class is designed to be part of a multiple inheritance
-// class heirarchy. Its main function is to provide an interface to the 
+// class heirarchy. Its main function is to provide an interface to the
 // breakpoint functionality.
 //
-// 
+//
 
 class TriggerObject
 {
@@ -98,7 +99,7 @@ class TriggerObject
   virtual void callback_print();
 
   // clear_trigger is invoked when the breakpoint associated with
-  // this object is cleared. 
+  // this object is cleared.
   virtual void clear_trigger();
 
   // Will search for a place to store this break point.
@@ -133,12 +134,12 @@ class TriggerObject
   virtual void invokeAction();
 
   // Messages can be associatated with triggers
-  string &message() {return m_sMessage;}
+  std::string &message() {return m_sMessage;}
   virtual void new_message(const char *);
-  virtual void new_message(string &);
+  virtual void new_message(std::string &);
 
   TriggerObject();
-  TriggerObject(TriggerAction *);
+  explicit TriggerObject(TriggerAction *);
   // Virtual destructor place holder
   virtual ~TriggerObject();
 protected:
@@ -147,9 +148,9 @@ protected:
 
 private:
   Expression *m_PExpr;
-  string m_sMessage;
+  std::string m_sMessage;
 
-  // When the TriggerObject becomes true, then the TriggerAction is 
+  // When the TriggerObject becomes true, then the TriggerAction is
   // evaluated. E.g. If the trigger object is an execution breakpoint,
   // then whenever the PC == break address, the Breakpoint_Instruction
   // class (which is derived from this class) will invoke action->evaluate()
@@ -160,4 +161,4 @@ private:
 
 
 
-#endif // !defined(__TRIGGER_H__)
+#endif // SRC_TRIGGER_H_
