@@ -18,6 +18,8 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
+#include <pthread.h>
+
 #include "ttoken.h"
 #include "pthread-wrap.h"
 
@@ -28,12 +30,17 @@ namespace gpsim {
     thread = new ThreadWrapper();
   }
 
+  Token::~Token()
+  {
+    // TODO: should delete the thread.
+  }
+
   void Token::Initialize(void *(*child) (void *), void *data)
   {
 
-    pthread_mutex_init(&thread->mutex, NULL);
-    pthread_cond_init (&thread->cvWaitOnParent, NULL);
-    pthread_cond_init (&thread->cvWaitOnChild, NULL);
+    pthread_mutex_init(&thread->mutex, nullptr);
+    pthread_cond_init (&thread->cvWaitOnParent, nullptr);
+    pthread_cond_init (&thread->cvWaitOnChild, nullptr);
 
     grab();
 
