@@ -1,6 +1,6 @@
 /*
    Copyright (C) 1998,1999 Scott Dattalo
-   Copyright (C) 2014	Roy R. Rankin
+   Copyright (C) 2014,2022 Roy R. Rankin
 
 This file is part of the libgpsim library of gpsim
 
@@ -19,13 +19,12 @@ License along with this library; if not, see
 <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
 
-#include <stdio.h>
 #include <iostream>
-
-#include "../config.h"
+#include <string>
 
 #include "uart.h"
 #include <assert.h>     // for assert
+#include "gpsim_time.h"
 #include "pir.h"        // for PIR
 #include "processor.h"  // for Processor
 #include "stimuli.h"    // for IOPIN, SignalSink
@@ -34,8 +33,6 @@ License along with this library; if not, see
 #define p_cpu ((Processor *)cpu)
 
 
-// defining EUSART_PIN  causes TX pin direction to be set for EUSART devices
-#define EUSART_PIN
 //#define DEBUG
 #if defined(DEBUG)
 #define Dprintf(arg) {printf("%s:%d-%s() ",__FILE__,__LINE__,__FUNCTION__); printf arg; }
@@ -56,11 +53,11 @@ public:
         assert(m_txsta);
     }
     ~TXSignalSource() { }
-    virtual char getState()
+    char getState() override
     {
         return m_txsta->getState();
     }
-    virtual void release()
+    void release() override
     {
         m_txsta->releasePin();
     }
@@ -76,8 +73,8 @@ public:
         : m_txsta(_txsta)
     { }
     ~TXSignalControl() { }
-    virtual char getState() { return '0'; }
-    virtual void release()
+    char getState() override { return '0'; }
+    void release() override
     {
         m_txsta->releasePin();
     }
@@ -93,9 +90,9 @@ public:
         : m_rcsta(_rcsta)
     { }
     ~RCSignalControl() { }
-    virtual char getState() { return '0'; }
+    char getState() override { return '0'; }
     //virtual char getState() { return m_rcsta->getDir(); }
-    virtual void release()
+    void release() override
     {
         m_rcsta->releasePin();
     }
@@ -113,11 +110,11 @@ public:
         assert(m_rcsta);
     }
     ~RCSignalSource() { }
-    virtual char getState()
+    char getState() override
     {
         return m_rcsta->getState();
     }
-    virtual void release()
+    void release() override
     {
         m_rcsta->releasePin();
     }
@@ -139,8 +136,8 @@ public:
         assert(_rcsta);
     }
 
-    virtual void setSinkState(char new3State) { m_rcsta->setState(new3State); }
-    virtual void release() {delete this; }
+    void setSinkState(char new3State) override { m_rcsta->setState(new3State); }
+    void release() override { delete this; }
 private:
     _RCSTA *m_rcsta;
 };
@@ -159,9 +156,8 @@ public:
         assert(_rcsta);
     }
 
-    virtual void setSinkState(char new3State) { m_rcsta->clock_edge(new3State); }
-//  virtual void release() { delete this; }
-    virtual void release() {delete this; }
+    void setSinkState(char new3State) override { m_rcsta->clock_edge(new3State); }
+    void release() override { delete this; }
 private:
     _RCSTA *m_rcsta;
 };
@@ -169,14 +165,14 @@ private:
 //-----------------------------------------------------------
 _RCSTA::_RCSTA(Processor *pCpu, const char *pName, const char *pDesc, USART_MODULE *pUSART)
     : sfr_register(pCpu, pName, pDesc),
-      rcreg(0), spbrg(0),
-      txsta(0), txreg(nullptr), sync_next_clock_edge_high(false),
+      rcreg(nullptr), spbrg(nullptr),
+      txsta(nullptr), txreg(nullptr), sync_next_clock_edge_high(false),
       rsr(0), bit_count(0), rx_bit(0), sample(0),
       state(_RCSTA::RCSTA_DISABLED), sample_state(0),
       future_cycle(0), last_cycle(0),
       mUSART(pUSART),
-      m_PinModule(0), m_sink(0), m_cRxState('?'),
-      SourceActive(false), m_control(0), m_source(0), m_cTxState('\0'),
+      m_PinModule(nullptr), m_sink(nullptr), m_cRxState('?'),
+      SourceActive(false), m_control(nullptr), m_source(nullptr), m_cTxState('\0'),
       m_DTdirection('0'), bInvertPin(false),
       old_clock_state(true)
 {
@@ -187,8 +183,8 @@ _RCSTA::~_RCSTA()
 {
     if (SourceActive && m_PinModule)
     {
-        m_PinModule->setSource(0);
-        m_PinModule->setControl(0);
+        m_PinModule->setSource(nullptr);
+        m_PinModule->setControl(nullptr);
     }
 
     delete m_source;
@@ -197,13 +193,13 @@ _RCSTA::~_RCSTA()
 
 //-----------------------------------------------------------
 _TXSTA::_TXSTA(Processor *pCpu, const char *pName, const char *pDesc, USART_MODULE *pUSART)
-    : sfr_register(pCpu, pName, pDesc), txreg(0), spbrg(0),
+    : sfr_register(pCpu, pName, pDesc), txreg(nullptr), spbrg(nullptr),
       rcsta(nullptr), tsr(0), bit_count(0),
       mUSART(pUSART),
-      m_PinModule(0),
-      m_source(0),
-      m_control(0),
-      m_clkSink(0),
+      m_PinModule(nullptr),
+      m_source(nullptr),
+      m_control(nullptr),
+      m_clkSink(nullptr),
       SourceActive(false),
       m_cTxState('?'),
       bInvertPin(false)
@@ -215,24 +211,24 @@ _TXSTA::~_TXSTA()
 {
     if (SourceActive && m_PinModule)
     {
-        m_PinModule->setSource(0);
-        m_PinModule->setControl(0);
+        m_PinModule->setSource(nullptr);
+        m_PinModule->setControl(nullptr);
     }
 
-    delete m_source;
-    delete m_control;
+    if (m_source) delete m_source;
+    if (m_control) delete m_control;
 }
 
 //-----------------------------------------------------------
 _RCREG::_RCREG(Processor *pCpu, const char *pName, const char *pDesc, USART_MODULE *pUSART)
     : sfr_register(pCpu, pName, pDesc),
-      oldest_value(0), fifo_sp(0),  mUSART(pUSART), m_rcsta(0)
+      oldest_value(0), fifo_sp(0),  mUSART(pUSART), m_rcsta(nullptr)
 {
     assert(mUSART);
 }
 
 _TXREG::_TXREG(Processor *pCpu, const char *pName, const char *pDesc, USART_MODULE *pUSART)
-    : sfr_register(pCpu, pName, pDesc), m_txsta(0), m_rcsta(nullptr),
+    : sfr_register(pCpu, pName, pDesc), m_txsta(nullptr), m_rcsta(nullptr),
       mUSART(pUSART), full(false)
 {
     assert(mUSART);
@@ -247,14 +243,15 @@ _BAUDCON::_BAUDCON(Processor *pCpu, const char *pName, const char *pDesc)
 
 _SPBRG::_SPBRG(Processor *pCpu, const char *pName, const char *pDesc)
     : sfr_register(pCpu, pName, pDesc),
-      txsta(0), rcsta(0), brgh(0), baudcon(0), start_cycle(0), last_cycle(0),
+      txsta(nullptr), rcsta(nullptr), brgh(nullptr), baudcon(nullptr),
+      start_cycle(0), last_cycle(0),
       future_cycle(0), running(false), skip(0)
 {
 }
 
 
 _SPBRGH::_SPBRGH(Processor *pCpu, const char *pName, const char *pDesc)
-    : sfr_register(pCpu, pName, pDesc), m_spbrg(0)
+    : sfr_register(pCpu, pName, pDesc), m_spbrg(nullptr)
 {
 }
 
@@ -322,10 +319,12 @@ void _TXREG::callback()
         mUSART->emptyTX();
     }
 }
+
 void _TXREG::callback_print()
 {
     std::cout << "TXREG " << name() << " CallBack ID " << CallBackID << '\n';
 }
+
 //-----------------------------------------------------------
 // TXSTA - setIOpin - assign the I/O pin associated with the
 // the transmitter.
@@ -352,10 +351,28 @@ void _TXSTA::setIOpin(PinModule *newPinModule)
 
 void _TXSTA::disableTXPin()
 {
+
     if (m_PinModule)
     {
-        m_PinModule->setSource(0);
-        m_PinModule->setControl(0);
+
+        if (input_as_output)
+        {
+            IO_bi_directional * m_io = (IO_bi_directional *)&m_PinModule->getPin();
+
+            input_as_output = false;
+            m_io->set_VthIn(save_VthIn);
+            m_io->set_ZthIn(save_ZthIn);
+        }
+        if (pullup_input_as_output)
+        {
+            IO_bi_directional_pu * m_io = (IO_bi_directional_pu *)&m_PinModule->getPin();
+
+            pullup_input_as_output = false;
+            m_io->set_Vpullup(save_Vpullup);
+            m_io->set_Zpullup(save_Zpullup);
+        }
+        m_PinModule->setSource(nullptr);
+        m_PinModule->setControl(nullptr);
         SourceActive = false;
         m_PinModule->getPin().newGUIname(m_PinModule->getPin().name().c_str());
         if (m_clkSink)
@@ -370,10 +387,10 @@ void _TXSTA::disableTXPin()
 
 void _TXSTA::setCKpin(PinModule *ck_pin)
 {
-
     if (!SourceActive)
         m_PinModule = ck_pin;
 }
+
 void _TXSTA::enableTXPin()
 {
     assert(m_PinModule);
@@ -381,7 +398,9 @@ void _TXSTA::enableTXPin()
     if (m_PinModule && !SourceActive)
     {
         char out;
-        char reg_no = *(name().c_str() + 5);
+        char reg_no = *(name().c_str() + 2);    // Cope with 16f170x naming
+        if ( !isdigit(reg_no) )                 // or more common naming
+            reg_no = *(name().c_str() + 5);
         if (bSYNC())
         {
             char ck[4] = "CK";
@@ -415,15 +434,24 @@ void _TXSTA::enableTXPin()
             m_PinModule->getPin().newGUIname(tx);
             out = '1';
         }
-        m_PinModule->setSource(m_source);
-#ifdef EUSART_PIN
+
+        // For EUSART set TX as output
         if (mUSART->IsEUSART())
+        {
             m_PinModule->setControl(m_control);
-#else
-        m_PinModule->setControl(m_control);
-#endif
+            m_PinModule->setSource(m_source);
+            SourceActive = true;
+        }
+        else
+        {
+            m_PinModule->setSource(m_source);
+            SourceActive = true;
+            if (use_input_pin_only && (m_PinModule->getControlState() == '0'))  // pin is output
+            {
+                printf("*** FAIL USART TX pin not input\n");
+            }
+        }
         putTXState(out);
-        SourceActive = true;
     }
 
     mUSART->emptyTX();
@@ -447,6 +475,53 @@ void _TXSTA::putTXState(char newTXState)
 {
     m_cTxState = bInvertPin ? newTXState ^ 1 : newTXState;
 
+    // if not EUSART, TX pin is input, bit bang input
+    if (!mUSART->IsEUSART())
+    {
+        if (m_PinModule->getControlState() == '1')	// pin is input
+        {
+            IO_bi_directional_pu * m_io_pu = (IO_bi_directional_pu *)(&m_PinModule->getPin());
+            if (m_io_pu->getPullupStatus())
+            {
+                if (!pullup_input_as_output)
+                {
+                    pullup_input_as_output = true;
+                    save_Vpullup = m_io_pu->get_Vpullup();
+                    save_Zpullup = m_io_pu->get_Zpullup();
+                    m_io_pu->set_Zpullup(150.);
+                }
+                if (m_cTxState == '0')
+                    m_io_pu->set_Vpullup(0.5);
+                else
+                    m_io_pu->set_Vpullup(get_cpu()->get_Vdd());
+            }
+            else
+            {
+                IO_bi_directional * m_io = (IO_bi_directional *)&m_PinModule->getPin();
+
+                if (!input_as_output)
+                {
+                    input_as_output = true;
+                    save_VthIn = m_io->get_VthIn();
+                    save_ZthIn = m_io->get_ZthIn();
+                    m_io->set_ZthIn(150.);
+                }
+                if (m_cTxState == '0')
+                {
+                    m_io->set_VthIn(0.5);
+                }
+                else
+                {
+                    m_io->set_VthIn(get_cpu()->get_Vdd());
+                }
+
+            }
+        }
+        else    //Pin is output
+        {
+            if (use_input_pin_only) return;
+        }
+    }
     if (m_PinModule)
         m_PinModule->updatePinModule();
 }
@@ -510,10 +585,10 @@ void _TXSTA::put(unsigned int new_value)
             stop_transmitting();
             mUSART->full();         // Turn off TXIF
             disableTXPin();
-
         }
     }
 }
+
 //------------------------------------------------------------
 //
 char _TXSTA::getState()
@@ -549,7 +624,6 @@ void _TXSTA::stop_transmitting()
     // get set.
     //
     //  txreg->full();   // Clear TXIF
-
 }
 
 void _TXSTA::start_transmitting()
@@ -1640,6 +1714,11 @@ void _SPBRG::callback()
     }
 }
 
+void _SPBRG::callback_print()
+{
+    std::cout << "_SPBRG " << name() << " CallBack ID " << CallBackID << '\n';
+}
+
 //-----------------------------------------------------------
 // TXSTA - Transmit Register Status and Control
 
@@ -1711,7 +1790,6 @@ void USART_MODULE::initialize(PIR *_pir,
 
 void USART_MODULE::setIOpin(PinModule *pin, int data)
 {
-
     switch (data)
     {
     case TX_PIN:
@@ -1809,18 +1887,18 @@ void USART_MODULE::mk_txif_int(PIR *reg, unsigned int bit)
 }
 
 //--------------------------------------------------
-void USART_MODULE::set_eusart(bool is_it )
+void USART_MODULE::set_eusart(bool is_it)
 {
     if (is_it)
     {
-        spbrgh.assign_spbrg ( &spbrg );
+        spbrgh.assign_spbrg(&spbrg);
         spbrg.baudcon = &baudcon;
         spbrg.brgh = &spbrgh;
         is_eusart = true;
     }
     else
     {
-        spbrgh.assign_spbrg ( 0 );
+        spbrgh.assign_spbrg(0);
         spbrg.baudcon = 0;
         spbrg.brgh = 0;
         is_eusart = false;
