@@ -39,48 +39,48 @@ public:
   virtual ~CGpsimUserInterface() {}
 
   void         SetStreams(FILE *in, FILE *out);
-  virtual ISimConsole &GetConsole();
-  virtual void SetConsole(ISimConsole *pConsole);
-  virtual void DisplayMessage(unsigned int uStringID, ...);
-  virtual void DisplayMessage(FILE * pOut, unsigned int uStringID, ...);
-  virtual void DisplayMessage(const char *fmt, ...);
-  virtual void DisplayMessage(FILE * pOut, const char *fmt, ...);
+  ISimConsole &GetConsole() override;
+  void SetConsole(ISimConsole *pConsole) override;
+  void DisplayMessage(unsigned int uStringID, ...) override;
+  void DisplayMessage(FILE * pOut, unsigned int uStringID, ...) override;
+  void DisplayMessage(const char *fmt, ...) override;
+  void DisplayMessage(FILE * pOut, const char *fmt, ...) override;
 
-  virtual const char * FormatProgramAddress(unsigned int uAddress,
-    unsigned int uMask);
-  virtual const char * FormatProgramAddress(unsigned int uAddress,
-    unsigned int uMask, int iRadix);
-  virtual const char * FormatRegisterAddress(Register *);
-  virtual const char * FormatRegisterAddress(unsigned int uAddress,
-    unsigned int uMask);
-  virtual const char * FormatLabeledValue(const char * pLabel,
-    unsigned int uValue);
+  const char * FormatProgramAddress(unsigned int uAddress,
+    unsigned int uMask) override;
+  const char * FormatProgramAddress(unsigned int uAddress,
+    unsigned int uMask, int iRadix) override;
+  const char * FormatRegisterAddress(Register *) override;
+  const char * FormatRegisterAddress(unsigned int uAddress,
+    unsigned int uMask) override;
+  const char * FormatLabeledValue(const char * pLabel,
+    unsigned int uValue) override;
   virtual const char * FormatLabeledValue(const char * pLabel,
     unsigned int uValue, unsigned int uMask, int iRadix,
     const char *pHexPrefix);
-  virtual const char * FormatValue(unsigned int uValue);
-  virtual const char * FormatValue(gint64 uValue);
-  virtual const char * FormatValue(gint64 uValue, guint64 uMask);
-  virtual const char * FormatValue(gint64 uValue, guint64 uMask,
-    int iRadix);
+  const char * FormatValue(unsigned int uValue) override;
+  const char * FormatValue(gint64 uValue) override;
+  const char * FormatValue(gint64 uValue, guint64 uMask) override;
+  const char * FormatValue(gint64 uValue, guint64 uMask,
+    int iRadix) override;
   virtual const char * FormatValue(gint64 uValue,
     guint64 uMask, int iRadix, const char * pHexPrefix);
 
-  virtual const char * FormatValue(char *str, int len,
-    int iRegisterSize, RegisterValue value);
+  const char * FormatValue(char *str, int len,
+    int iRegisterSize, RegisterValue value) override;
 //  virtual char *       FormatValueAsBinary(char *str, int len,
 //    int iRegisterSize, RegisterValue value);
 
-  virtual void SetProgramAddressRadix(int iRadix);
-  virtual void SetRegisterAddressRadix(int iRadix);
-  virtual void SetValueRadix(int iRadix);
+  void SetProgramAddressRadix(int iRadix) override;
+  void SetRegisterAddressRadix(int iRadix) override;
+  void SetValueRadix(int iRadix) override;
 
-  virtual void SetProgramAddressMask(unsigned int uMask);
-  virtual void SetRegisterAddressMask(unsigned int uMask);
-  virtual void SetValueMask(unsigned int uMask);
+  void SetProgramAddressMask(unsigned int uMask) override;
+  void SetRegisterAddressMask(unsigned int uMask) override;
+  void SetValueMask(unsigned int uMask) override;
 
-  virtual void SetExitOnBreak(FNNOTIFYEXITONBREAK);
-  virtual void NotifyExitOnBreak(int iExitCode);
+  void SetExitOnBreak(FNNOTIFYEXITONBREAK) override;
+  void NotifyExitOnBreak(int iExitCode) override;
 
   static Integer  s_iValueRadix;
   static String   s_sValueHexPrefix;
@@ -116,11 +116,11 @@ Integer CGpsimUserInterface::s_iRAMAddrMask(      "UIRAMAddressMask",        0xf
 
 class NullConsole : public ISimConsole {
 public:
-  virtual void Printf(const char * /* fmt */, ...) {}
-  virtual void VPrintf(const char * /* fmt */, va_list /* argptr */) {}
-  virtual void Puts(const char*) {}
-  virtual void Putc(const char) {}
-  virtual const char * Gets(char *, int) { return "";}
+  void Printf(const char * /* fmt */, ...) override {}
+  void VPrintf(const char * /* fmt */, va_list /* argptr */) override {}
+  void Puts(const char*) override {}
+  void Putc(const char) override {}
+  const char * Gets(char *, int) override { return "";}
 };
 
 
@@ -130,42 +130,42 @@ static ISimConsole    *g_pConsole = &g_NullConsole;
 class NullUserInterface : public IUserInterface {
 //  NullConsole m_Console;
 public:
-  virtual ISimConsole &GetConsole() { return *g_pConsole; }
-  virtual void SetConsole(ISimConsole *pConsole) { g_pConsole = pConsole; }
-  virtual void DisplayMessage(unsigned int /* uStringID */, ...) {}
-  virtual void DisplayMessage(FILE * /* pOut */, unsigned int /* uStringID */, ...) {}
-  virtual void DisplayMessage(const char * /* fmt */, ...) {}
-  virtual void DisplayMessage(FILE * /* pOut */, const char * /* fmt */, ...) {}
+  ISimConsole &GetConsole() override { return *g_pConsole; }
+  void SetConsole(ISimConsole *pConsole) override { g_pConsole = pConsole; }
+  void DisplayMessage(unsigned int /* uStringID */, ...) override {}
+  void DisplayMessage(FILE * /* pOut */, unsigned int /* uStringID */, ...) override {}
+  void DisplayMessage(const char * /* fmt */, ...) override {}
+  void DisplayMessage(FILE * /* pOut */, const char * /* fmt */, ...) override {}
 
-  virtual const char * FormatProgramAddress(unsigned int /* uAddress */,
-    unsigned int /* uMask */) {return "";}
-  virtual const char * FormatProgramAddress(unsigned int /* uAddress */,
-    unsigned int /* uMask */, int /* iRadix */) {return "";}
-  virtual const char * FormatRegisterAddress(Register *)
+  const char * FormatProgramAddress(unsigned int /* uAddress */,
+    unsigned int /* uMask */) override {return "";}
+  const char * FormatProgramAddress(unsigned int /* uAddress */,
+    unsigned int /* uMask */, int /* iRadix */) override {return "";}
+  const char * FormatRegisterAddress(Register *) override
   { return ""; }
-  virtual const char * FormatRegisterAddress(unsigned int /* uAddress */,
-    unsigned int /* uMask */) {return "";}
-  virtual const char * FormatLabeledValue(const char * /* pLabel */,
-    unsigned int /* uValue */) {return "";}
-  virtual const char * FormatValue(unsigned int /* uValue */) {return "";}
-  virtual const char * FormatValue(gint64 /* uValue */) {return "";}
-  virtual const char * FormatValue(gint64 /* uValue */, guint64 /* uMask */) {return "";}
-  virtual const char * FormatValue(gint64 /* uValue */, guint64 /* uMask */,
-    int /* iRadix */) {return "";}
+  const char * FormatRegisterAddress(unsigned int /* uAddress */,
+    unsigned int /* uMask */) override {return "";}
+  const char * FormatLabeledValue(const char * /* pLabel */,
+    unsigned int /* uValue */) override {return "";}
+  const char * FormatValue(unsigned int /* uValue */) override {return "";}
+  const char * FormatValue(gint64 /* uValue */) override {return "";}
+  const char * FormatValue(gint64 /* uValue */, guint64 /* uMask */) override {return "";}
+  const char * FormatValue(gint64 /* uValue */, guint64 /* uMask */,
+    int /* iRadix */) override {return "";}
 
-  virtual const char * FormatValue(char * /* str */, int /* len */,
-    int /* iRegisterSize */, RegisterValue /* value */) {return "";}
+  const char * FormatValue(char * /* str */, int /* len */,
+    int /* iRegisterSize */, RegisterValue /* value */) override {return "";}
 
-  virtual void SetProgramAddressRadix(int /* iRadix */) {}
-  virtual void SetRegisterAddressRadix(int /* iRadix */) {}
-  virtual void SetValueRadix(int /* iRadix */) {}
+  void SetProgramAddressRadix(int /* iRadix */) override {}
+  void SetRegisterAddressRadix(int /* iRadix */) override {}
+  void SetValueRadix(int /* iRadix */) override {}
 
-  virtual void SetProgramAddressMask(unsigned int /* uMask */) {}
-  virtual void SetRegisterAddressMask(unsigned int /* uMask */) {}
-  virtual void SetValueMask(unsigned int /* uMask */) {}
+  void SetProgramAddressMask(unsigned int /* uMask */) override {}
+  void SetRegisterAddressMask(unsigned int /* uMask */) override {}
+  void SetValueMask(unsigned int /* uMask */) override {}
 
-  virtual void SetExitOnBreak(FNNOTIFYEXITONBREAK) {}
-  virtual void NotifyExitOnBreak(int /* iExitCode */) {}
+  void SetExitOnBreak(FNNOTIFYEXITONBREAK) override {}
+  void NotifyExitOnBreak(int /* iExitCode */) override {}
 };
 
 
@@ -235,7 +235,7 @@ void CGpsimUserInterface::SetConsole(ISimConsole *pConsole)
 void CGpsimUserInterface::DisplayMessage(unsigned int uStringID, ...)
 {
   va_list ap;
-  va_start(ap,uStringID);
+  va_start(ap, uStringID);
   g_pConsole->VPrintf(m_paStrings[uStringID], ap);
   va_end(ap);
 }
@@ -244,7 +244,7 @@ void CGpsimUserInterface::DisplayMessage(unsigned int uStringID, ...)
 void CGpsimUserInterface::DisplayMessage(FILE * pOut, unsigned int uStringID, ...)
 {
   va_list ap;
-  va_start(ap,uStringID);
+  va_start(ap, uStringID);
   if (!pOut || pOut == stdout) {
     g_pConsole->VPrintf(m_paStrings[uStringID], ap);
   }
@@ -258,7 +258,7 @@ void CGpsimUserInterface::DisplayMessage(FILE * pOut, unsigned int uStringID, ..
 void CGpsimUserInterface::DisplayMessage(const char *fmt, ...)
 {
   va_list ap;
-  va_start(ap,fmt);
+  va_start(ap, fmt);
   g_pConsole->VPrintf(fmt, ap);
   va_end(ap);
 }
@@ -267,7 +267,7 @@ void CGpsimUserInterface::DisplayMessage(const char *fmt, ...)
 void CGpsimUserInterface::DisplayMessage(FILE * pOut, const char *fmt, ...)
 {
   va_list ap;
-  va_start(ap,fmt);
+  va_start(ap, fmt);
   if (!pOut || pOut == stdout) {
     g_pConsole->VPrintf(fmt, ap);
   }
@@ -423,7 +423,6 @@ const char * CGpsimUserInterface::FormatValue(gint64 uValue,
     guint64 uMask, int iRadix, const char * pHexPrefix)
 {
   std::ostringstream osValue;
-  std::string sPrefix;
   int iBytes = 0;
   guint64 l_uMask = uMask;
   int iDigits;
@@ -431,18 +430,21 @@ const char * CGpsimUserInterface::FormatValue(gint64 uValue,
     iBytes++;
     l_uMask >>= 8;
   }
+
   switch (iRadix) {
   case eHex:
     iDigits = iBytes * 2;
     osValue << pHexPrefix;
     osValue << std::hex << std::setw(iDigits) << std::setfill('0');
     break;
+
   case eDec:
     osValue << std::dec;
     break;
+
   case eOct:
     iDigits = iBytes * 3;
-    osValue << "0";
+    osValue << '0';
     osValue << std::oct << std::setw(iDigits) << std::setfill('0');
     break;
   }
