@@ -186,7 +186,7 @@ void Value::set(Expression *expr)
     delete v;
   }
 
-  catch (Error &err) {
+  catch (const Error &err) {
     std::cout << "ERROR:" << err.what() << '\n';
   }
 }
@@ -285,7 +285,7 @@ Module *Value::get_module()
   return cpu;
 }
 
-void Value::addName(std::string &r_sAliasedName)
+void Value::addName(const std::string &r_sAliasedName)
 {
   m_aka.push_back(r_sAliasedName);
 }
@@ -898,7 +898,10 @@ std::string Integer::toString()
   gint64 i;
   get(i);
   IUserInterface & TheUI = GetUserInterface();
-  return std::string(TheUI.FormatValue(i, (unsigned int)bitmask));
+  if (bitmask == 0xff && i > 256)
+      return std::string(TheUI.FormatValue(i, 0xffff));
+  else
+      return std::string(TheUI.FormatValue(i, (unsigned int)bitmask));
 }
 
 std::string Integer::toString(const char* format)
@@ -947,7 +950,7 @@ char *Integer::toBitStr(char *return_str, int len)
     gint64 i;
     get(i);
     int j = 0;
-    int mask = 1 << 31;
+    gint64 mask = 1UL << 31;
     for ( ; mask ; mask >>= 1, j++)
       if (j < len)
         return_str[j] = ((i & mask) ? 1 : 0);
@@ -984,7 +987,7 @@ Integer* Integer::assertValid(Value* val, std::string valDesc, gint64 valMin)
                     );
   }
 
-  return(iVal);
+  return iVal;
 }
 
 Integer* Integer::assertValid(Value* val, std::string valDesc, gint64 valMin, gint64 valMax)
@@ -1015,6 +1018,7 @@ bool Integer::compare(ComparisonOperator *compOp, Value *rvalue)
   get(i);
   rv->get(r);
 
+
   if (i < r)
     return compOp->less();
 
@@ -1326,10 +1330,7 @@ namespace gpsim {
 
   std::string Function::description()
   {
-    if (cpDescription)
-      return cpDescription;
-    else
-      return "no description";
+    return cpDescription ? cpDescription : "no description";
   }
 
   std::string Function::toString()
