@@ -20,7 +20,7 @@ License along with this library; if not, see
 
 #include "xref.h"
 #include "gpsim_interface.h"
-
+#include "gpsim_object.h"
 
 XrefObject::XrefObject()
 {
@@ -35,12 +35,9 @@ XrefObject::XrefObject(gpsimObject *value)
 
 XrefObject::~XrefObject()
 {
-  std::list<void *>::iterator ioi = xrefs.begin();
-
-  while ((ioi = xrefs.begin()) != xrefs.end()) {
-    XrefObject *xref = (XrefObject *) *ioi;
-    clear(xref);
-    delete xref;
+  for (auto ioi = xrefs.begin(); ioi != xrefs.end(); ++ioi)
+  {
+    delete (XrefObject *) *ioi;
   }
 }
 
